@@ -50,32 +50,32 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "accelerator_2fallback_8hpp.html",
-"blas3__solve_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc",
-"classviennacl_1_1coordinate__matrix.html#ad5b57c8ab8bcc8d839aba53be7cb1463",
-"classviennacl_1_1hyb__matrix.html#a83cb07a6aa15fcf960b40b4a82fdc574",
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a6efe3ab857ef8a25a28990c3712a32c3",
-"classviennacl_1_1matrix__base.html#a33997bfe92e860894b22f5bb518a1290",
-"classviennacl_1_1ocl_1_1invalid__arg__value.html",
-"classviennacl_1_1sliced__ell__matrix.html#abbc671358c44037b7c2b22a01f17c3a7",
-"classviennacl_1_1vector__iterator.html#a3d6f0cdf4dc263a0158620734e1e5c0b",
-"cuda_2matrix__operations_8hpp.html#a70728abd4e950c940cb4ab08ea643347",
-"detail_2spai_2qr_8hpp.html#a34b989396d25d3ec653ea0aa1e620f55",
-"examples_2benchmarks_2sparse_8cpp.html",
-"functions_func_d.html",
-"globals_vars.html",
-"ilu0_8hpp_source.html",
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html",
-"matrix__col__float_8cpp_source.html",
-"matrix__proxy_8hpp.html#a638aa5c54fe703aac75a9613b6fa992a",
-"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html",
-"opencl_2sparse__matrix__operations_8hpp.html#a3a97d7d39ed0063efc0e2a7184c63711",
-"scheduler_2execute_8hpp.html#a7969d99d3180d9e8b3f250f8abe04242",
-"sparse__matrix__operations_8hpp.html#a2ee5dd77d41040e0a937a60346475b84",
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#ab9e9f54c99ee5c4fa7b03c86fb3c7bac",
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a004b1ebc6c30dd52c7864dac15ffdcf5",
-"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mult_01_4.html#a7136fe8c9cd3f0b530d2669c4f96362ea97a4114c2c8ca3d12d7c3a2d085f093a",
-"tql2_8cpp.html",
-"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015"
+"blas2__opencl_8cpp.html#ad5aba7b0e90e197d4732066e81fa81d1",
+"classviennacl_1_1const__entry__proxy.html#abc1b268a517bbb435434b9bf54f2313a",
+"classviennacl_1_1ell__matrix.html#a8575f900add9d7ff93f73063ac90b4b9",
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7dfd62f90e89c9c44817742853f9bfdb",
+"classviennacl_1_1linalg_1_1row__scaling.html#a772edd12410c3d582f4ad4f3d1bcd110",
+"classviennacl_1_1ocl_1_1device.html#a9efdfafd0819090844b28a123510283c",
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a670faef4da7eb44516eaf0502e0da52e",
+"classviennacl_1_1vector__base.html#aa2a13cb2712dc5dd36eea81c7549a278",
+"cuda_2iterative__operations_8hpp.html#a704ee2a70cf3563e3928fec38ac16bc0",
+"custom-kernels_8cpp_source.html",
+"direct__solve_8hpp.html#a87b19fc27005f6e13a9ee981965a5e97",
+"forwards_8h.html#ab3331c10c42bdec311e4c6b8665b01ac",
+"globals_func_s.html",
+"host__based_2vector__operations_8hpp.html#a2fff34b2cb787d5c2ae89f59a93cfde8",
+"linalg_2opencl_2common_8hpp.html#a3a8f0ed5e591a8db7b6f58d6dcb0d876",
+"matrix_8hpp.html#a97d5a2c7b8514856ee97a68dee279ac2",
+"matrix__operations__row_8hpp.html#af2b44cf9690bfb3f9e5dff5b26b607e9",
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html",
+"opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528",
+"row__scaling_8hpp.html",
+"small__matrix_8hpp_source.html",
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html",
+"structviennacl_1_1op__fmod.html",
+"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__fabs_01_4_01_4.html#a83900c06dec61651be8bb974185c1f13a71f4169164f5bd32365e1f9170ac279b",
+"tests_2src_2sparse_8cpp.html#a3d8742cd384cb6e7893805a6c54791b2",
+"vector__operations_8hpp.html#ad648cd691bb8fa8358f552d00bce2946"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
