@@ -1,5 +1,25 @@
 var NAVTREEINDEX1 =
 {
+"blas2__opencl_8cpp.html#ad5aba7b0e90e197d4732066e81fa81d1":[7,0,1,1,6,2],
+"blas2__opencl_8cpp_source.html":[7,0,1,1,6],
+"blas3_8cpp-example.html":[8,5],
+"blas3_8hpp.html":[7,0,1,1,8],
+"blas3_8hpp.html#a3ab3ec44d81f38ad6c838aaf1c827215":[7,0,1,1,8,0],
+"blas3_8hpp_source.html":[7,0,1,1,8],
+"blas3__host_8cpp.html":[7,0,1,1,9],
+"blas3__host_8cpp.html#a68b35db95872e6f1b217603f6977bb51":[7,0,1,1,9,2],
+"blas3__host_8cpp.html#a810d03745eaffd98e7bbd1edf7b6184f":[7,0,1,1,9,1],
+"blas3__host_8cpp.html#acc1214fc3867539788965c386a822ddd":[7,0,1,1,9,0],
+"blas3__host_8cpp_source.html":[7,0,1,1,9],
+"blas3__opencl_8cpp.html":[7,0,1,1,10],
+"blas3__opencl_8cpp_source.html":[7,0,1,1,10],
+"blas3__solve_8cpp.html":[7,0,2,0,1],
+"blas3__solve_8cpp.html#a23a3d893dfd2dd3b809ce30cee04069a":[7,0,2,0,1,3],
+"blas3__solve_8cpp.html#a5bb6753909d55e8254bdb5fabda1a6a6":[7,0,2,0,1,6],
+"blas3__solve_8cpp.html#a5e7ed643cc5a720945fb7ea661b4bbfc":[7,0,2,0,1,9],
+"blas3__solve_8cpp.html#a8cbd379f9259e534655784896a6eac6c":[7,0,2,0,1,4],
+"blas3__solve_8cpp.html#a9e9682ea50c4aca4b26062dbaba28340":[7,0,2,0,1,8],
+"blas3__solve_8cpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,1,0],
 "blas3__solve_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,1,7],
 "blas3__solve_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,1,5],
 "blas3__solve_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,1,1],
@@ -30,9 +50,29 @@ var NAVTREEINDEX1 =
 "cedar_8hpp.html#ae4ed13a8aedb8d5e9b7b82005804d3d1":[7,0,3,2,0,0,2,0,0,0,0],
 "cedar_8hpp_source.html":[7,0,3,2,0,0,2,0,0,0],
 "cg_8hpp.html":[7,0,3,4,8],
-"cg_8hpp.html#a0679942882efd21c540fac8e78a6d56a":[7,0,3,4,8,5],
-"cg_8hpp.html#a2fad8cb9d4b354019644518915c7f54f":[7,0,3,4,8,4],
-"cg_8hpp.html#a42030ae104a39e1b24288128b4664c7f":[7,0,3,4,8,3],
+"cg_8hpp.html#a019c6f56a56a6df23d20b6f4a5a01d96":[7,0,3,4,8,13],
+"cg_8hpp.html#a0679942882efd21c540fac8e78a6d56a":[7,0,3,4,8,25],
+"cg_8hpp.html#a09ea72ff5ae59d760a1a603553c8cde6":[7,0,3,4,8,7],
+"cg_8hpp.html#a2fad8cb9d4b354019644518915c7f54f":[7,0,3,4,8,24],
+"cg_8hpp.html#a35647c644ad47c5df6641a9b59e5cc70":[7,0,3,4,8,4],
+"cg_8hpp.html#a4279aed4311dfdb6c86c04bb272bedab":[7,0,3,4,8,12],
+"cg_8hpp.html#a4c0065e1a0718a5e81201ad17e9513cf":[7,0,3,4,8,10],
+"cg_8hpp.html#a56e7b4501a39e47cb86280dfc38d9345":[7,0,3,4,8,14],
+"cg_8hpp.html#a588bdb06ebab2632fd9e595e9da1670a":[7,0,3,4,8,17],
+"cg_8hpp.html#a5b4ec2f25666da4c2316adb5bb80e5a7":[7,0,3,4,8,18],
+"cg_8hpp.html#a624316de462e222f324473d308bfb807":[7,0,3,4,8,16],
+"cg_8hpp.html#a648e6f5c6adb0ae7e6821839f5311f2b":[7,0,3,4,8,20],
+"cg_8hpp.html#a7536ca1ef3a636eeef04d325ee1debb0":[7,0,3,4,8,15],
+"cg_8hpp.html#a79123e0b681bfc5f3ff48949de6abf29":[7,0,3,4,8,11],
+"cg_8hpp.html#a7afb51022c37f4351730888a06006072":[7,0,3,4,8,19],
+"cg_8hpp.html#a88ea7eede7c5ef487fc4d90027339f6f":[7,0,3,4,8,3],
+"cg_8hpp.html#aaa85748a980089c5c18b6b23a836a8b9":[7,0,3,4,8,23],
+"cg_8hpp.html#ab6a6ea2647fba0d63ec0384f784dc30f":[7,0,3,4,8,9],
+"cg_8hpp.html#ac4d87c51afc65d6e67a1420d9d0a1fe3":[7,0,3,4,8,8],
+"cg_8hpp.html#acf0d7aeeeb376dc3bf69b99c45f45f15":[7,0,3,4,8,22],
+"cg_8hpp.html#af4552898dc42c2b09c75adda8b4ee635":[7,0,3,4,8,21],
+"cg_8hpp.html#afc8b57752ccfed7c59a93af5e6c85cef":[7,0,3,4,8,6],
+"cg_8hpp.html#affab5dfeb8eec8a9f7cc5e5bf24a558d":[7,0,3,4,8,5],
 "cg_8hpp_source.html":[7,0,3,4,8],
 "changelog.html":[2,16],
 "circulant__matrix_8hpp.html":[7,0,3,11],
@@ -112,34 +152,34 @@ var NAVTREEINDEX1 =
 "classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html#aede2f174e7cde9c3a7e6ace5ff35e47e":[6,0,0,0,6,2],
 "classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html#af69b0bbba6bba94e1bad0b0059913e7f":[6,0,0,0,6,6],
 "classviennacl_1_1basic__range.html":[6,0,0,11],
-"classviennacl_1_1basic__range.html#a086579df41cd54835531c7baabf49c00":[6,0,0,11,10],
-"classviennacl_1_1basic__range.html#a0d5f11c0c300a33e8ae4181ebbabeb01":[6,0,0,11,6],
-"classviennacl_1_1basic__range.html#a666628fe9b604dc566fa7eb0123f8ddd":[6,0,0,11,7],
-"classviennacl_1_1basic__range.html#a8708b1743bca7c539a81be8099f49f90":[6,0,0,11,8],
-"classviennacl_1_1basic__range.html#a98fe8293684a30f75d6aacad7ec13bde":[6,0,0,11,2],
-"classviennacl_1_1basic__range.html#aa34b76f6efe362415edb407937e0cba4":[6,0,0,11,0],
-"classviennacl_1_1basic__range.html#abb9929b7929b0741e17b3cfe8b928079":[6,0,0,11,1],
-"classviennacl_1_1basic__range.html#abd197f659f5498ee5e3fb4977664f057":[6,0,0,11,12],
-"classviennacl_1_1basic__range.html#ac90a11d76a2b1e29da3cd0633d442324":[6,0,0,11,9],
-"classviennacl_1_1basic__range.html#ad012ab1496aae10765aa38a79b927d75":[6,0,0,11,3],
-"classviennacl_1_1basic__range.html#ae213fd034e4db9cd0ce570c1be075efc":[6,0,0,11,5],
-"classviennacl_1_1basic__range.html#aea4fe4dd7cdf834b8f40675c3ad7e0e6":[6,0,0,11,4],
-"classviennacl_1_1basic__range.html#af2ae0723d25249de4e6ac3398c532849":[6,0,0,11,11],
+"classviennacl_1_1basic__range.html#a19cc82c72c48f3a228040975e0277639":[6,0,0,11,7],
+"classviennacl_1_1basic__range.html#a23b0af93d74104dfbe4158b94ded751b":[6,0,0,11,6],
+"classviennacl_1_1basic__range.html#a2541840a74de59d8392c2ef2f5e14688":[6,0,0,11,8],
+"classviennacl_1_1basic__range.html#a4120d60389efc52cb5235dd796897aa3":[6,0,0,11,4],
+"classviennacl_1_1basic__range.html#a76e130f45289f502bb75637391b6ebaf":[6,0,0,11,11],
+"classviennacl_1_1basic__range.html#a7862bf679f6f3d74ac0449b4fcb81edd":[6,0,0,11,9],
+"classviennacl_1_1basic__range.html#a96bc2ca82dc308bfe484e5c93213f925":[6,0,0,11,0],
+"classviennacl_1_1basic__range.html#aa6e54d5a8c0d51d4310bb57f98bec3eb":[6,0,0,11,1],
+"classviennacl_1_1basic__range.html#ab5e949b2f3c1495eb423f568623ec862":[6,0,0,11,12],
+"classviennacl_1_1basic__range.html#abf9f70746fdf670cf1f134ae74db9c02":[6,0,0,11,10],
+"classviennacl_1_1basic__range.html#af055791c1672b45ca992d0fd6045d5d5":[6,0,0,11,3],
+"classviennacl_1_1basic__range.html#af96be8225f4918a7f2bd85ef9d739210":[6,0,0,11,5],
+"classviennacl_1_1basic__range.html#af98fd6cd691b6cdc6fe92b66e72ec581":[6,0,0,11,2],
 "classviennacl_1_1basic__slice.html":[6,0,0,12],
-"classviennacl_1_1basic__slice.html#a09d5a73b2d94035ac6171c85e76f9a2a":[6,0,0,12,5],
-"classviennacl_1_1basic__slice.html#a107d2a257efd86a3496a2095b14d390c":[6,0,0,12,6],
-"classviennacl_1_1basic__slice.html#a1f3bee006aa6206cd5c2d465bc1ec7b9":[6,0,0,12,0],
-"classviennacl_1_1basic__slice.html#a6c0632edd54727c588037d4f01d4a7f5":[6,0,0,12,3],
-"classviennacl_1_1basic__slice.html#a7eccf03bc2a7d3ecb61df27f4c1230a9":[6,0,0,12,13],
-"classviennacl_1_1basic__slice.html#a8a81ffae54298af31d0ee4524e96ce6c":[6,0,0,12,4],
-"classviennacl_1_1basic__slice.html#aa82399e34bba223d9873613e05e93e2d":[6,0,0,12,10],
-"classviennacl_1_1basic__slice.html#ab03350f92555c7d4278f039347f7c200":[6,0,0,12,1],
-"classviennacl_1_1basic__slice.html#ad0a964026f2456cba267c2e577f8f4b3":[6,0,0,12,12],
-"classviennacl_1_1basic__slice.html#ad68a4709ed2046d3c1fabb2a35a77c8e":[6,0,0,12,9],
-"classviennacl_1_1basic__slice.html#ade9eed27085e548ae36b0872cf7502bf":[6,0,0,12,2],
-"classviennacl_1_1basic__slice.html#ae4fe7a9208a59756c8214734835897f7":[6,0,0,12,11],
-"classviennacl_1_1basic__slice.html#aeb7a706834740984fa46aec18c0265c8":[6,0,0,12,8],
-"classviennacl_1_1basic__slice.html#afd7e1263cd81282515c203ae039adf6b":[6,0,0,12,7],
+"classviennacl_1_1basic__slice.html#a0b6d101bae091dba51d3345ecd860855":[6,0,0,12,0],
+"classviennacl_1_1basic__slice.html#a2a6813112d126c662827a988963f2078":[6,0,0,12,10],
+"classviennacl_1_1basic__slice.html#a38cc42b6a33d1d94257d6d2a14348412":[6,0,0,12,7],
+"classviennacl_1_1basic__slice.html#a3a7bac8d57ee54a8b6fe56ffcfaac638":[6,0,0,12,3],
+"classviennacl_1_1basic__slice.html#a58c9942b91aa224c0aa552be7f0a45b0":[6,0,0,12,11],
+"classviennacl_1_1basic__slice.html#a7b8cf1d3e5790b7263aa2147a4eecf74":[6,0,0,12,5],
+"classviennacl_1_1basic__slice.html#a8d251dc812858795ecd43307ad9697cc":[6,0,0,12,13],
+"classviennacl_1_1basic__slice.html#aa55fc37b7e4f63295e4f18bf467b3f22":[6,0,0,12,8],
+"classviennacl_1_1basic__slice.html#aa6d0070558344d0fc00f55385b45bd2e":[6,0,0,12,1],
+"classviennacl_1_1basic__slice.html#adfcc1b0f7e5c71e0a9c95da0051ca19e":[6,0,0,12,2],
+"classviennacl_1_1basic__slice.html#af141c5755a25cb69564d15b488dc2c7b":[6,0,0,12,6],
+"classviennacl_1_1basic__slice.html#af1caf81d3003290ca700e63133fa7479":[6,0,0,12,9],
+"classviennacl_1_1basic__slice.html#afc8c94993c7b04fe8b78dacb22d463f9":[6,0,0,12,12],
+"classviennacl_1_1basic__slice.html#afdd8df15a78772bab3804aa32bd3703b":[6,0,0,12,4],
 "classviennacl_1_1circulant__matrix.html":[6,0,0,13],
 "classviennacl_1_1circulant__matrix.html#a1117ac76564254e55a0aa840094c188f":[6,0,0,13,1],
 "classviennacl_1_1circulant__matrix.html#a20add1ca7973763648451656c1a691c2":[6,0,0,13,0],
@@ -208,46 +248,6 @@ var NAVTREEINDEX1 =
 "classviennacl_1_1compressed__matrix.html#af71dec61a70e8df4f78a527aa989a106":[6,0,0,18,11],
 "classviennacl_1_1compressed__matrix.html#afcf49945a63836e1edfca536fcd191fb":[6,0,0,18,22],
 "classviennacl_1_1const__entry__proxy.html":[6,0,0,19],
-"classviennacl_1_1const__entry__proxy.html#a7292550b61e1a625496dd362339c7187":[6,0,0,19,0],
-"classviennacl_1_1const__entry__proxy.html#abe9e28e8a14d528af431c4c946a46f80":[6,0,0,19,3],
-"classviennacl_1_1const__entry__proxy.html#adb02059e2c2baddfcc1fd7b97614213a":[6,0,0,19,4],
-"classviennacl_1_1const__entry__proxy.html#aed2935b8d5040b680419cde80828b5f2":[6,0,0,19,1],
-"classviennacl_1_1const__entry__proxy.html#af3cd5a538ac1202e0dac28bcf887077d":[6,0,0,19,2],
-"classviennacl_1_1const__vector__iterator.html":[6,0,0,20],
-"classviennacl_1_1const__vector__iterator.html#a0ce7b1d338d35efc3e378ec7af7e4b8c":[6,0,0,20,10],
-"classviennacl_1_1const__vector__iterator.html#a29aad8e236f2fe712ebdf98825f427ee":[6,0,0,20,2],
-"classviennacl_1_1const__vector__iterator.html#a40596679a283d524291a9a63af97e5f5":[6,0,0,20,17],
-"classviennacl_1_1const__vector__iterator.html#a63de71957553776e0178f1bb2a795ea6":[6,0,0,20,9],
-"classviennacl_1_1const__vector__iterator.html#a74689fc520d387564e70d5e73f527ddd":[6,0,0,20,4],
-"classviennacl_1_1const__vector__iterator.html#a7871517dbb0e61034ecc87dba13bd2cb":[6,0,0,20,7],
-"classviennacl_1_1const__vector__iterator.html#a866aa6ce744d8c59819cb4061a48166f":[6,0,0,20,14],
-"classviennacl_1_1const__vector__iterator.html#a96f34aa17ad546ea8d97e205d05b372b":[6,0,0,20,1],
-"classviennacl_1_1const__vector__iterator.html#a9f5686cab330f99c29ab57925f84b136":[6,0,0,20,15],
-"classviennacl_1_1const__vector__iterator.html#aac68e355edde844dec53cec7851de2af":[6,0,0,20,6],
-"classviennacl_1_1const__vector__iterator.html#aacc19519a7cd9a50a76197efd5202b27":[6,0,0,20,0],
-"classviennacl_1_1const__vector__iterator.html#aaff6b3b9edca90b6fac60fef55332b77":[6,0,0,20,18],
-"classviennacl_1_1const__vector__iterator.html#abda30c30684ac0ee23edebf6538a483f":[6,0,0,20,19],
-"classviennacl_1_1const__vector__iterator.html#ac0f2d487d81e6fcb9500d333f3dfe3b7":[6,0,0,20,8],
-"classviennacl_1_1const__vector__iterator.html#acf6f49633b55a04677eb0e05fd414d34":[6,0,0,20,5],
-"classviennacl_1_1const__vector__iterator.html#ad5b5840973672401934ddb081020691b":[6,0,0,20,13],
-"classviennacl_1_1const__vector__iterator.html#ad83ced390bbb5be3d10eeab4e250a640":[6,0,0,20,3],
-"classviennacl_1_1const__vector__iterator.html#ae34886f524c5a05bb2722adc87dddfa3":[6,0,0,20,11],
-"classviennacl_1_1const__vector__iterator.html#ae798738527a30c65c6ce3b3b3a019299":[6,0,0,20,16],
-"classviennacl_1_1const__vector__iterator.html#afaae3d7d629117d5fae91586c5aac66c":[6,0,0,20,12],
-"classviennacl_1_1context.html":[6,0,0,21],
-"classviennacl_1_1context.html#a88b51d155aee396ef6d8d8a96bd7e90a":[6,0,0,21,1],
-"classviennacl_1_1context.html#a8f95db066e453ccd52aa9305fbd71243":[6,0,0,21,0],
-"classviennacl_1_1context.html#aadf575d49ed144e8fa4707cdad69c349":[6,0,0,21,2],
-"classviennacl_1_1coordinate__matrix.html":[6,0,0,22],
-"classviennacl_1_1coordinate__matrix.html#a04c51b826e4bae9c97a3749ee2161b87":[6,0,0,22,13],
-"classviennacl_1_1coordinate__matrix.html#a2035ac2e7acc39c21cf13bb6f9c2dc08":[6,0,0,22,12],
-"classviennacl_1_1coordinate__matrix.html#a3cd8e9989ee1b547dbcba2fe87f7b29d":[6,0,0,22,18],
-"classviennacl_1_1coordinate__matrix.html#a472604b5e8e7a818fcee171898df1c92":[6,0,0,22,6],
-"classviennacl_1_1coordinate__matrix.html#a4a8183e8f8e3a91e379d12ada4943b99":[6,0,0,22,17],
-"classviennacl_1_1coordinate__matrix.html#a4fccbe4157aa8833d23b0541803e06af":[6,0,0,22,7],
-"classviennacl_1_1coordinate__matrix.html#a5363ed7b82aaad8549c85d880755f846":[6,0,0,22,15],
-"classviennacl_1_1coordinate__matrix.html#a5497d1e7fdce125b7a5bd12530002b4f":[6,0,0,22,0],
-"classviennacl_1_1coordinate__matrix.html#a626ac84303ae01ac4f7e964f2c2972b6":[6,0,0,22,3],
-"classviennacl_1_1coordinate__matrix.html#a66b7f5c5487b719c91bc76984f89f97f":[6,0,0,22,11],
-"classviennacl_1_1coordinate__matrix.html#a734ed32ff1858ef5453c170326fda377":[6,0,0,22,16]
+"classviennacl_1_1const__entry__proxy.html#a8f916f229ef166b16006b514b13d1318":[6,0,0,19,0],
+"classviennacl_1_1const__entry__proxy.html#a9906f1d945b78b11ab14feef6367d2c8":[6,0,0,19,1]
 };
