@@ -1,5 +1,43 @@
 var NAVTREEINDEX11 =
 {
+"direct__solve_8hpp.html#a87b19fc27005f6e13a9ee981965a5e97":[7,0,3,4,10,28],
+"direct__solve_8hpp.html#a8ff7d3cc1ecf2686dcb0795d188ecdf0":[7,0,3,4,10,24],
+"direct__solve_8hpp.html#aacfff27023e7934e8fc91add06a00015":[7,0,3,4,10,2],
+"direct__solve_8hpp.html#aaf694e493220c997a56117180898e34d":[7,0,3,4,10,3],
+"direct__solve_8hpp.html#ab46903287704fb77078a994bbe7450c3":[7,0,3,4,10,4],
+"direct__solve_8hpp.html#ab726081ab01b69a8292d3be04e5fc3e2":[7,0,3,4,10,16],
+"direct__solve_8hpp.html#ac0c2e482814cd46a9dc139af45d5977e":[7,0,3,4,10,29],
+"direct__solve_8hpp.html#ac5653f3afdba6531933d14ed561cece7":[7,0,3,4,10,12],
+"direct__solve_8hpp.html#ac76b5c350f25569a8c503ab102289dfa":[7,0,3,4,10,26],
+"direct__solve_8hpp.html#ac8e8ed654f145cb91cd73e759603683c":[7,0,3,4,10,22],
+"direct__solve_8hpp.html#adf06f61be9418e5817eed66004f9dd2b":[7,0,3,4,10,1],
+"direct__solve_8hpp.html#adf2d1656abbdd59e83cb335f22f94743":[7,0,3,4,10,6],
+"direct__solve_8hpp.html#ae6d7887a8badaa283e9522d63a611a56":[7,0,3,4,10,25],
+"direct__solve_8hpp.html#ae7017a135e4f7d4132fedeadbfc4fec5":[7,0,3,4,10,11],
+"direct__solve_8hpp.html#af31c775455862c55e51fd4119befb8f4":[7,0,3,4,10,10],
+"direct__solve_8hpp_source.html":[7,0,3,4,10],
+"eig_8hpp.html":[7,0,3,4,11],
+"eig_8hpp_source.html":[7,0,3,4,11],
+"eigen-with-viennacl_8cpp-example.html":[8,8],
+"eigen-with-viennacl_8cpp.html":[7,0,0,1,9],
+"eigen-with-viennacl_8cpp_source.html":[7,0,0,1,9],
+"ell__matrix_8hpp.html":[7,0,3,16],
+"ell__matrix_8hpp.html#a86076cab217f7a739775b848fbb2a58f":[7,0,3,16,1],
+"ell__matrix_8hpp.html#a94125a5d77782ecabf9896c4a7378ae6":[7,0,3,16,2],
+"ell__matrix_8hpp.html#adbe5d5ca06633e7eb223bc43df45351d":[7,0,3,16,4],
+"ell__matrix_8hpp.html#aeb9b4abab4a308f6850d8a379ce9d19c":[7,0,3,16,3],
+"ell__matrix_8hpp_source.html":[7,0,3,16],
+"enable__if_8hpp.html":[7,0,3,5,0],
+"enable__if_8hpp_source.html":[7,0,3,5,0],
+"enqueue_8hpp.html":[7,0,3,7,5],
+"enqueue_8hpp.html#a41b8d9b3d5b6fec7edc48484fb2ce3cb":[7,0,3,7,5,4],
+"enqueue_8hpp.html#a5f2022f653ea1cf364d20e3ff84dcada":[7,0,3,7,5,0],
+"enqueue_8hpp.html#a6791536cfb686087f8469152786d17ab":[7,0,3,7,5,2],
+"enqueue_8hpp.html#a7257cac9a7db083d6035053747481a64":[7,0,3,7,5,1],
+"enqueue_8hpp.html#a826887e3aa906648a31b1b41073cb01c":[7,0,3,7,5,3],
+"enqueue_8hpp_source.html":[7,0,3,7,5],
+"entry__proxy_8hpp.html":[7,0,3,9,1],
+"entry__proxy_8hpp_source.html":[7,0,3,9,1],
 "error_8hpp.html":[7,0,3,7,6],
 "error_8hpp.html#a44f070f54255e72eb40c75ebd72ea602":[7,0,3,7,6,51],
 "error_8hpp.html#a6d42757cdf0e944ebe5236aa4f96b6aa":[7,0,3,7,6,50],
@@ -32,21 +70,18 @@ var NAVTREEINDEX11 =
 "examples_2tutorial_2nmf_8cpp_source.html":[7,0,0,1,22],
 "examples_2tutorial_2qr__method_8cpp.html":[7,0,0,1,25],
 "examples_2tutorial_2qr__method_8cpp_source.html":[7,0,0,1,25],
-"examples_2tutorial_2scheduler__matrix_8cpp.html":[7,0,0,1,28],
-"examples_2tutorial_2scheduler__matrix_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,1,28,0],
-"examples_2tutorial_2scheduler__matrix_8cpp_source.html":[7,0,0,1,28],
-"examples_2tutorial_2sparse_8cpp.html":[7,0,0,1,30],
-"examples_2tutorial_2sparse_8cpp_source.html":[7,0,0,1,30],
-"examples_2tutorial_2structured-matrices_8cpp.html":[7,0,0,1,31],
-"examples_2tutorial_2structured-matrices_8cpp_source.html":[7,0,0,1,31],
+"examples_2tutorial_2sparse_8cpp.html":[7,0,0,1,29],
+"examples_2tutorial_2sparse_8cpp_source.html":[7,0,0,1,29],
+"examples_2tutorial_2structured-matrices_8cpp.html":[7,0,0,1,30],
+"examples_2tutorial_2structured-matrices_8cpp_source.html":[7,0,0,1,30],
 "execute__axbx_8hpp.html":[7,0,3,8,1],
 "execute__axbx_8hpp.html#a2f9d553c7deffb59338de92689a6bd21":[7,0,3,8,1,0],
 "execute__axbx_8hpp_source.html":[7,0,3,8,1],
 "execute__elementwise_8hpp.html":[7,0,3,8,2],
 "execute__elementwise_8hpp.html#a0637666aeba76d4f30d97a81d8b8eb36":[7,0,3,8,2,2],
 "execute__elementwise_8hpp.html#a4eba46ca2fed779c016547178786202d":[7,0,3,8,2,3],
-"execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,1],
 "execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,0],
+"execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,1],
 "execute__elementwise_8hpp.html#aaaa93acc7901ab5a44ff4b00b986362b":[7,0,3,8,2,4],
 "execute__elementwise_8hpp_source.html":[7,0,3,8,2],
 "execute__generic__dispatcher_8hpp.html":[7,0,3,8,3],
@@ -116,9 +151,9 @@ var NAVTREEINDEX11 =
 "fft__1d_8cpp.html#a10dea82a2fa07d8d38107391a60965cf":[7,0,2,0,4,13],
 "fft__1d_8cpp.html#a130b38a8dcc95afd21cc3937e996fd81":[7,0,2,0,4,20],
 "fft__1d_8cpp.html#a23a4f0ce6452f4e3e946dddf0ae77b7e":[7,0,2,0,4,17],
-"fft__1d_8cpp.html#a2a45245a8d0c1b133d9876722dfb2b7e":[7,0,2,0,4,3],
 "fft__1d_8cpp.html#a3042870eb8881681860b088156ccf079":[7,0,2,0,4,11],
 "fft__1d_8cpp.html#a43f5046b412bf346fe3821f020ce36b8":[7,0,2,0,4,19],
+"fft__1d_8cpp.html#a4b189d809e837b0a80d17a81f0649314":[7,0,2,0,4,1],
 "fft__1d_8cpp.html#a50090af3f56c8a964b17ccd9ea6ba500":[7,0,2,0,4,26],
 "fft__1d_8cpp.html#a56353420d188d1181ae49bf69283b497":[7,0,2,0,4,14],
 "fft__1d_8cpp.html#a6a4a1ee00ce74b6815ae3c9b8e00d10e":[7,0,2,0,4,23],
@@ -131,11 +166,11 @@ var NAVTREEINDEX11 =
 "fft__1d_8cpp.html#ac6e604e018809020ccd77546f3329e77":[7,0,2,0,4,10],
 "fft__1d_8cpp.html#acaa4a4c5600c798706da45006e3b7210":[7,0,2,0,4,4],
 "fft__1d_8cpp.html#ace9acba72e03f317c16a9d6b4d888f73":[7,0,2,0,4,5],
+"fft__1d_8cpp.html#ad431337acacff9e06c1286095e78f8ac":[7,0,2,0,4,3],
 "fft__1d_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,4,2],
 "fft__1d_8cpp.html#ada492f44f9e83b833972a277284864be":[7,0,2,0,4,7],
 "fft__1d_8cpp.html#ae0bafa0f4214db07d0fd1e5a486caba9":[7,0,2,0,4,21],
 "fft__1d_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,4,18],
-"fft__1d_8cpp.html#aeb9e349ae153e1baf7e55868792ee5af":[7,0,2,0,4,1],
 "fft__1d_8cpp.html#af439f7a9be2c4f5746d22bfecb527bdd":[7,0,2,0,4,24],
 "fft__1d_8cpp.html#af6f913fdc71ad35c8ec4d99fe8671987":[7,0,2,0,4,28],
 "fft__1d_8cpp.html#afc156a01486ed303c46673d3e0976e1f":[7,0,2,0,4,22],
@@ -143,17 +178,17 @@ var NAVTREEINDEX11 =
 "fft__2d_8cpp.html":[7,0,2,0,5],
 "fft__2d_8cpp.html#a05ddc634f34ae8fb86372ff8626a059f":[7,0,2,0,5,9],
 "fft__2d_8cpp.html#a0b36333131d10fd9a0abb3aa21b0b445":[7,0,2,0,5,14],
-"fft__2d_8cpp.html#a2a45245a8d0c1b133d9876722dfb2b7e":[7,0,2,0,5,3],
 "fft__2d_8cpp.html#a3042870eb8881681860b088156ccf079":[7,0,2,0,5,6],
 "fft__2d_8cpp.html#a40b89a65d3390cf44a03717ee53eedca":[7,0,2,0,5,5],
 "fft__2d_8cpp.html#a4461a05ba16b9052cf36f4752c63619e":[7,0,2,0,5,4],
+"fft__2d_8cpp.html#a4b189d809e837b0a80d17a81f0649314":[7,0,2,0,5,1],
 "fft__2d_8cpp.html#a4eb5cd8352d689f5495ec1ba1ea49f0a":[7,0,2,0,5,15],
 "fft__2d_8cpp.html#a50090af3f56c8a964b17ccd9ea6ba500":[7,0,2,0,5,13],
 "fft__2d_8cpp.html#a7cee249cffcd5d7be1c31ea17a284cd9":[7,0,2,0,5,11],
 "fft__2d_8cpp.html#aadad85fa5cbf31466487bb0585d1a769":[7,0,2,0,5,7],
+"fft__2d_8cpp.html#ad431337acacff9e06c1286095e78f8ac":[7,0,2,0,5,3],
 "fft__2d_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,5,2],
 "fft__2d_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,5,10],
-"fft__2d_8cpp.html#aeb9e349ae153e1baf7e55868792ee5af":[7,0,2,0,5,1],
 "fft__2d_8cpp.html#af439f7a9be2c4f5746d22bfecb527bdd":[7,0,2,0,5,12],
 "fft__2d_8cpp.html#af6f913fdc71ad35c8ec4d99fe8671987":[7,0,2,0,5,16],
 "fft__2d_8cpp.html#afc07a94f6f8fca89904a2b6a89bc4e14":[7,0,2,0,5,8],
@@ -214,40 +249,5 @@ var NAVTREEINDEX11 =
 "forwards_8h.html#aaa84915fbd15d5fb318c41f715c2b337":[7,0,3,18,129],
 "forwards_8h.html#aaac6b8ed7edad298388c5936e476f783":[7,0,3,18,136],
 "forwards_8h.html#aabf5182473bb609dedc9c85148553b55":[7,0,3,18,166],
-"forwards_8h.html#aafc6db8d806f67c24f93eaaded84b853":[7,0,3,18,174],
-"forwards_8h.html#ab3331c10c42bdec311e4c6b8665b01ac":[7,0,3,18,141],
-"forwards_8h.html#abcf0050426d4b7147d50588919f690da":[7,0,3,18,160],
-"forwards_8h.html#ac3e5d39428cebc0a54a6ba2c10a3f73c":[7,0,3,18,175],
-"forwards_8h.html#ac4ba2d9041f7c09bfb2f0ec65f8cf63c":[7,0,3,18,154],
-"forwards_8h.html#ac7a454946f278e2e94199871f55c081a":[7,0,3,18,155],
-"forwards_8h.html#ac9139574d3d99501f0ef6c3fc322e548":[7,0,3,18,137],
-"forwards_8h.html#ac9c1f7718f95bf4ed4cddc264b24c623":[7,0,3,18,135],
-"forwards_8h.html#acefc10657837355dd686f359e2f2bdd3":[7,0,3,18,168],
-"forwards_8h.html#ad6f228d570bffac37abb106970b08532":[7,0,3,18,157],
-"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722ac":[7,0,3,18,133],
-"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca0750e54730307e2c1d1b6bfaabc7a1dd":[7,0,3,18,133,3],
-"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca2546ac1effa27e3727e38c15fe13cc08":[7,0,3,18,133,0],
-"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca4229608063b20108bf18fbf2a166a642":[7,0,3,18,133,1],
-"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca61e9ff7ddcbf0446b560f94907c24e11":[7,0,3,18,133,2],
-"forwards_8h.html#add42dc3329c401285f39cb6d6e0000e2":[7,0,3,18,159],
-"forwards_8h.html#ae7a946e478e53f6464d1dedeb3a46c89":[7,0,3,18,176],
-"forwards_8h.html#ae92c62d9fd59870c1f6b881e391d32aa":[7,0,3,18,128],
-"forwards_8h.html#af754ca05f664675f759aca2de035bc7a":[7,0,3,18,153],
-"forwards_8h.html#af8d50400363dab7d4edef7d9f67954c9":[7,0,3,18,169],
-"forwards_8h.html#afad612e26a65487b7e747c18c678ffd9":[7,0,3,18,130],
-"forwards_8h_source.html":[7,0,3,18],
-"fspai_8hpp.html":[7,0,3,4,1,3,2],
-"fspai_8hpp.html#a097e316b51cf3854abec362e6a6d1d47":[7,0,3,4,1,3,2,2],
-"fspai_8hpp.html#a23b282bb53b72b43e7f76d9aeb3df64b":[7,0,3,4,1,3,2,3],
-"fspai_8hpp.html#ac3aaf276d63d5442f2f95d060912c4ab":[7,0,3,4,1,3,2,1],
-"fspai_8hpp.html#acd198c046af39cfe38f1aad62c0580ae":[7,0,3,4,1,3,2,5],
-"fspai_8hpp.html#ae5f2c2a17a35ffa9682589bc3bd692dc":[7,0,3,4,1,3,2,6],
-"fspai_8hpp.html#aeac5736cf32d6afbea570aa683dbe115":[7,0,3,4,1,3,2,4],
-"fspai_8hpp.html#af1ff03eb8bd6bd2f78f4738731394f7d":[7,0,3,4,1,3,2,7],
-"fspai_8hpp_source.html":[7,0,3,4,1,3,2],
-"functions.html":[6,3,0],
-"functions.html":[6,3,0,0],
-"functions_b.html":[6,3,0,1],
-"functions_c.html":[6,3,0,2],
-"functions_d.html":[6,3,0,3]
+"forwards_8h.html#aafc6db8d806f67c24f93eaaded84b853":[7,0,3,18,174]
 };
