@@ -1,5 +1,40 @@
 var NAVTREEINDEX12 =
 {
+"forwards_8h.html#ab3331c10c42bdec311e4c6b8665b01ac":[7,0,3,18,141],
+"forwards_8h.html#abcf0050426d4b7147d50588919f690da":[7,0,3,18,160],
+"forwards_8h.html#ac3e5d39428cebc0a54a6ba2c10a3f73c":[7,0,3,18,175],
+"forwards_8h.html#ac4ba2d9041f7c09bfb2f0ec65f8cf63c":[7,0,3,18,154],
+"forwards_8h.html#ac7a454946f278e2e94199871f55c081a":[7,0,3,18,155],
+"forwards_8h.html#ac9139574d3d99501f0ef6c3fc322e548":[7,0,3,18,137],
+"forwards_8h.html#ac9c1f7718f95bf4ed4cddc264b24c623":[7,0,3,18,135],
+"forwards_8h.html#acefc10657837355dd686f359e2f2bdd3":[7,0,3,18,168],
+"forwards_8h.html#ad6f228d570bffac37abb106970b08532":[7,0,3,18,157],
+"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722ac":[7,0,3,18,133],
+"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca0750e54730307e2c1d1b6bfaabc7a1dd":[7,0,3,18,133,3],
+"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca2546ac1effa27e3727e38c15fe13cc08":[7,0,3,18,133,0],
+"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca4229608063b20108bf18fbf2a166a642":[7,0,3,18,133,1],
+"forwards_8h.html#adc2e9ed3e4d9fb0258840837aaa722aca61e9ff7ddcbf0446b560f94907c24e11":[7,0,3,18,133,2],
+"forwards_8h.html#add42dc3329c401285f39cb6d6e0000e2":[7,0,3,18,159],
+"forwards_8h.html#ae7a946e478e53f6464d1dedeb3a46c89":[7,0,3,18,176],
+"forwards_8h.html#ae92c62d9fd59870c1f6b881e391d32aa":[7,0,3,18,128],
+"forwards_8h.html#af754ca05f664675f759aca2de035bc7a":[7,0,3,18,153],
+"forwards_8h.html#af8d50400363dab7d4edef7d9f67954c9":[7,0,3,18,169],
+"forwards_8h.html#afad612e26a65487b7e747c18c678ffd9":[7,0,3,18,130],
+"forwards_8h_source.html":[7,0,3,18],
+"fspai_8hpp.html":[7,0,3,4,1,3,2],
+"fspai_8hpp.html#a097e316b51cf3854abec362e6a6d1d47":[7,0,3,4,1,3,2,2],
+"fspai_8hpp.html#a23b282bb53b72b43e7f76d9aeb3df64b":[7,0,3,4,1,3,2,3],
+"fspai_8hpp.html#ac3aaf276d63d5442f2f95d060912c4ab":[7,0,3,4,1,3,2,1],
+"fspai_8hpp.html#acd198c046af39cfe38f1aad62c0580ae":[7,0,3,4,1,3,2,5],
+"fspai_8hpp.html#ae5f2c2a17a35ffa9682589bc3bd692dc":[7,0,3,4,1,3,2,6],
+"fspai_8hpp.html#aeac5736cf32d6afbea570aa683dbe115":[7,0,3,4,1,3,2,4],
+"fspai_8hpp.html#af1ff03eb8bd6bd2f78f4738731394f7d":[7,0,3,4,1,3,2,7],
+"fspai_8hpp_source.html":[7,0,3,4,1,3,2],
+"functions.html":[6,3,0],
+"functions.html":[6,3,0,0],
+"functions_b.html":[6,3,0,1],
+"functions_c.html":[6,3,0,2],
+"functions_d.html":[6,3,0,3],
 "functions_e.html":[6,3,0,4],
 "functions_enum.html":[6,3,4],
 "functions_eval.html":[6,3,5],
@@ -194,8 +229,8 @@ var NAVTREEINDEX12 =
 "global__variables_8cpp.html#a9b48d95dbfbe8e26ae8911c753406d37":[7,0,2,0,6,5],
 "global__variables_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,6,0],
 "global__variables_8cpp_source.html":[7,0,2,0,6],
-"globals.html":[7,1,0],
 "globals.html":[7,1,0,0],
+"globals.html":[7,1,0],
 "globals_c.html":[7,1,0,1],
 "globals_d.html":[7,1,0,2],
 "globals_defs.html":[7,1,6],
@@ -214,40 +249,5 @@ var NAVTREEINDEX12 =
 "globals_func_m.html":[7,1,1,7],
 "globals_func_o.html":[7,1,1,8],
 "globals_func_p.html":[7,1,1,9],
-"globals_func_r.html":[7,1,1,10],
-"globals_func_s.html":[7,1,1,11],
-"globals_func_t.html":[7,1,1,12],
-"globals_func_v.html":[7,1,1,13],
-"globals_g.html":[7,1,0,5],
-"globals_h.html":[7,1,0,6],
-"globals_i.html":[7,1,0,7],
-"globals_m.html":[7,1,0,8],
-"globals_n.html":[7,1,0,9],
-"globals_o.html":[7,1,0,10],
-"globals_p.html":[7,1,0,11],
-"globals_r.html":[7,1,0,12],
-"globals_s.html":[7,1,0,13],
-"globals_t.html":[7,1,0,14],
-"globals_type.html":[7,1,3],
-"globals_v.html":[7,1,0,15],
-"globals_vars.html":[7,1,2],
-"gmres_8hpp.html":[7,0,3,4,13],
-"gmres_8hpp.html#a29d6b53b3a99961196a859fa7ef46537":[7,0,3,4,13,4],
-"gmres_8hpp.html#a7714c5d2a59986f4c2cd9fdb47817ba0":[7,0,3,4,13,5],
-"gmres_8hpp.html#a9dace8e3f8cafdc7c5b56282860e5a97":[7,0,3,4,13,1],
-"gmres_8hpp.html#ac34f2a4be7c82ecf4fd10e05ecc24273":[7,0,3,4,13,7],
-"gmres_8hpp.html#ad2b2c8a343124143d1ddc2fee8b2ce73":[7,0,3,4,13,3],
-"gmres_8hpp.html#af6c0a087d090d74573763d9dd48c9074":[7,0,3,4,13,6],
-"gmres_8hpp.html#afb24b0bd7c338eff5ecf6b8b35f2757a":[7,0,3,4,13,2],
-"gmres_8hpp_source.html":[7,0,3,4,13],
-"gpu_2fallback_8hpp.html":[7,0,3,2,0,0,2,2],
-"gpu_2fallback_8hpp.html#a165e05191585908e619174cc89662cd1":[7,0,3,2,0,0,2,2,1],
-"gpu_2fallback_8hpp.html#a1c59b69f8e3bd9a3ac749254166e5631":[7,0,3,2,0,0,2,2,16],
-"gpu_2fallback_8hpp.html#a24f3d26d0f7d3f109909cc5c748e0a55":[7,0,3,2,0,0,2,2,9],
-"gpu_2fallback_8hpp.html#a33a37096f9f0ea65e8798e844f645f1b":[7,0,3,2,0,0,2,2,13],
-"gpu_2fallback_8hpp.html#a33b18acc254b1857b13e7e4889410e5d":[7,0,3,2,0,0,2,2,11],
-"gpu_2fallback_8hpp.html#a3476b3346a369ec706b48c711e184883":[7,0,3,2,0,0,2,2,12],
-"gpu_2fallback_8hpp.html#a4d19637e7dcb5012d9c60fffa561d959":[7,0,3,2,0,0,2,2,3],
-"gpu_2fallback_8hpp.html#a575cb62848f2516a12eb405d29a91d92":[7,0,3,2,0,0,2,2,2],
-"gpu_2fallback_8hpp.html#a5764b80284de678fd73c0675cd28e41a":[7,0,3,2,0,0,2,2,8]
+"globals_func_r.html":[7,1,1,10]
 };
