@@ -1,5 +1,60 @@
 var NAVTREEINDEX13 =
 {
+"globals_func_s.html":[7,1,1,11],
+"globals_func_t.html":[7,1,1,12],
+"globals_func_v.html":[7,1,1,13],
+"globals_g.html":[7,1,0,5],
+"globals_h.html":[7,1,0,6],
+"globals_i.html":[7,1,0,7],
+"globals_m.html":[7,1,0,8],
+"globals_n.html":[7,1,0,9],
+"globals_o.html":[7,1,0,10],
+"globals_p.html":[7,1,0,11],
+"globals_r.html":[7,1,0,12],
+"globals_s.html":[7,1,0,13],
+"globals_t.html":[7,1,0,14],
+"globals_type.html":[7,1,3],
+"globals_v.html":[7,1,0,15],
+"globals_vars.html":[7,1,2],
+"gmres_8hpp.html":[7,0,3,4,13],
+"gmres_8hpp.html#a05ffd9f9211b79d34c10b2c00a8802e3":[7,0,3,4,13,24],
+"gmres_8hpp.html#a10625517026527b8567929799f16aa07":[7,0,3,4,13,9],
+"gmres_8hpp.html#a1230427ed7fcb64c2211c5e320765408":[7,0,3,4,13,13],
+"gmres_8hpp.html#a284ac1d2d875ffb343e2febe0aa83c6b":[7,0,3,4,13,23],
+"gmres_8hpp.html#a29d6b53b3a99961196a859fa7ef46537":[7,0,3,4,13,4],
+"gmres_8hpp.html#a5fad5ebfd70cdaf09faee26860b7e55c":[7,0,3,4,13,15],
+"gmres_8hpp.html#a63cc3b92ba06f8f8a2582cf834ca46fd":[7,0,3,4,13,10],
+"gmres_8hpp.html#a6bfbfa17ee1712ca53346094f4052ea3":[7,0,3,4,13,18],
+"gmres_8hpp.html#a71c173a423b650b386df37ba6e1ff795":[7,0,3,4,13,5],
+"gmres_8hpp.html#a83ea2ac4c9adff23eae20f62bd18b4c1":[7,0,3,4,13,17],
+"gmres_8hpp.html#a87ed247748491c082b970b62eb786f12":[7,0,3,4,13,12],
+"gmres_8hpp.html#a8f13bed9d72a563b5349b91adb92cd43":[7,0,3,4,13,16],
+"gmres_8hpp.html#a912d28b88f04c3de5d8bc3d8d7bb09b0":[7,0,3,4,13,14],
+"gmres_8hpp.html#a91f7ed200fd17886a3ad993acdcc917a":[7,0,3,4,13,7],
+"gmres_8hpp.html#a959455c598b20baff5868cac41df50dc":[7,0,3,4,13,21],
+"gmres_8hpp.html#a96fc280f5a35d7ffd15404cbd6a19a52":[7,0,3,4,13,22],
+"gmres_8hpp.html#a97583e79ad1412001b227b2f6191b735":[7,0,3,4,13,25],
+"gmres_8hpp.html#a9dace8e3f8cafdc7c5b56282860e5a97":[7,0,3,4,13,1],
+"gmres_8hpp.html#abd55991455cb1970de542ba42618b2d4":[7,0,3,4,13,20],
+"gmres_8hpp.html#ac21d857bc4ab34b631500b014401ca45":[7,0,3,4,13,11],
+"gmres_8hpp.html#ac34f2a4be7c82ecf4fd10e05ecc24273":[7,0,3,4,13,27],
+"gmres_8hpp.html#ad2b2c8a343124143d1ddc2fee8b2ce73":[7,0,3,4,13,3],
+"gmres_8hpp.html#af6272023aa909b683a953c6b2d549da2":[7,0,3,4,13,19],
+"gmres_8hpp.html#af6c0a087d090d74573763d9dd48c9074":[7,0,3,4,13,26],
+"gmres_8hpp.html#af92fa2403e651c8dbe5bb521b4fb0c8d":[7,0,3,4,13,8],
+"gmres_8hpp.html#afb24b0bd7c338eff5ecf6b8b35f2757a":[7,0,3,4,13,2],
+"gmres_8hpp.html#afd3c79eb88333260f46f15df6525f2b0":[7,0,3,4,13,6],
+"gmres_8hpp_source.html":[7,0,3,4,13],
+"gpu_2fallback_8hpp.html":[7,0,3,2,0,0,2,2],
+"gpu_2fallback_8hpp.html#a165e05191585908e619174cc89662cd1":[7,0,3,2,0,0,2,2,1],
+"gpu_2fallback_8hpp.html#a1c59b69f8e3bd9a3ac749254166e5631":[7,0,3,2,0,0,2,2,16],
+"gpu_2fallback_8hpp.html#a24f3d26d0f7d3f109909cc5c748e0a55":[7,0,3,2,0,0,2,2,9],
+"gpu_2fallback_8hpp.html#a33a37096f9f0ea65e8798e844f645f1b":[7,0,3,2,0,0,2,2,13],
+"gpu_2fallback_8hpp.html#a33b18acc254b1857b13e7e4889410e5d":[7,0,3,2,0,0,2,2,11],
+"gpu_2fallback_8hpp.html#a3476b3346a369ec706b48c711e184883":[7,0,3,2,0,0,2,2,12],
+"gpu_2fallback_8hpp.html#a4d19637e7dcb5012d9c60fffa561d959":[7,0,3,2,0,0,2,2,3],
+"gpu_2fallback_8hpp.html#a575cb62848f2516a12eb405d29a91d92":[7,0,3,2,0,0,2,2,2],
+"gpu_2fallback_8hpp.html#a5764b80284de678fd73c0675cd28e41a":[7,0,3,2,0,0,2,2,8],
 "gpu_2fallback_8hpp.html#a5976cb702fa7ae70988337ea3f87d18a":[7,0,3,2,0,0,2,2,15],
 "gpu_2fallback_8hpp.html#a658d72b419715ea281694759c006f2ee":[7,0,3,2,0,0,2,2,17],
 "gpu_2fallback_8hpp.html#a6cde4bbd0b6de4556e43668c0451a65b":[7,0,3,2,0,0,2,2,10],
@@ -194,60 +249,5 @@ var NAVTREEINDEX13 =
 "host__based_2sparse__matrix__operations_8hpp.html#aeb8b53bd67e6c4c406a97cdd3b1951a6":[7,0,3,4,2,8,14],
 "host__based_2sparse__matrix__operations_8hpp.html#af4b7e22d1ff9f68847f98a0a9e788ce0":[7,0,3,4,2,8,2],
 "host__based_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,2,8],
-"host__based_2vector__operations_8hpp.html":[7,0,3,4,2,11],
-"host__based_2vector__operations_8hpp.html#a306a6b1400991db3671a1511fa8f6f40":[7,0,3,4,2,11,10],
-"host__based_2vector__operations_8hpp.html#a38954effaaf57109159e51a31293a6c1":[7,0,3,4,2,11,20],
-"host__based_2vector__operations_8hpp.html#a47e4fa3cd849b7beab25f195633a38ad":[7,0,3,4,2,11,1],
-"host__based_2vector__operations_8hpp.html#a64a65b7cd5c499e1a2e12ae921ec1ca2":[7,0,3,4,2,11,18],
-"host__based_2vector__operations_8hpp.html#a7038bea435ceada730575e20bbcd56a6":[7,0,3,4,2,11,19],
-"host__based_2vector__operations_8hpp.html#a7446f9329fa901df46a4f487a43601ca":[7,0,3,4,2,11,9],
-"host__based_2vector__operations_8hpp.html#a7634739b4c75267d38297dfcb19fad63":[7,0,3,4,2,11,2],
-"host__based_2vector__operations_8hpp.html#a84f017afe97029f92d48c968774f245b":[7,0,3,4,2,11,17],
-"host__based_2vector__operations_8hpp.html#a9d0a372a4ffd0c6347ecff6046ca4dec":[7,0,3,4,2,11,8],
-"host__based_2vector__operations_8hpp.html#a9e173eb4a7b8b63e7bddb53074d764ec":[7,0,3,4,2,11,3],
-"host__based_2vector__operations_8hpp.html#aa1b0719a06924fc82f8d8ed6c739a04d":[7,0,3,4,2,11,0],
-"host__based_2vector__operations_8hpp.html#aa9936ab7a49e99f2935f7dc33b95c976":[7,0,3,4,2,11,11],
-"host__based_2vector__operations_8hpp.html#abd382e4bde97fb842b7b52b2b4d36379":[7,0,3,4,2,11,6],
-"host__based_2vector__operations_8hpp.html#abd70c99f406759e0f1ae2ffc6c9e8fed":[7,0,3,4,2,11,13],
-"host__based_2vector__operations_8hpp.html#ac4670f3fd14af7a2caf44c4036536010":[7,0,3,4,2,11,15],
-"host__based_2vector__operations_8hpp.html#ac765726382000520401dc9d70483dabb":[7,0,3,4,2,11,21],
-"host__based_2vector__operations_8hpp.html#ad21ec9fa116f8f1bd34d426c058c504b":[7,0,3,4,2,11,16],
-"host__based_2vector__operations_8hpp.html#ad78c38a7e4a3ae75bc2e149b28854eaa":[7,0,3,4,2,11,12],
-"host__based_2vector__operations_8hpp.html#ade2c77ef8044d4664c6857e96398304b":[7,0,3,4,2,11,14],
-"host__based_2vector__operations_8hpp.html#ade366c76e4b0db7585c51d890c88051d":[7,0,3,4,2,11,5],
-"host__based_2vector__operations_8hpp.html#ae3225408ae3e81b004fab27aeb6a9482":[7,0,3,4,2,11,7],
-"host__based_2vector__operations_8hpp.html#affd4a240838f3d33cfd0f37c4085d558":[7,0,3,4,2,11,4],
-"host__based_2vector__operations_8hpp_source.html":[7,0,3,4,2,11],
-"hyb__matrix_8hpp.html":[7,0,3,20],
-"hyb__matrix_8hpp.html#a3eccd807b53d2713366addeaf1137bae":[7,0,3,20,1],
-"hyb__matrix_8hpp.html#ad947ef8abf3c3cd4f69649b01ffb6d7e":[7,0,3,20,4],
-"hyb__matrix_8hpp.html#aee077076d127c528b236cc78ff6b8bbe":[7,0,3,20,3],
-"hyb__matrix_8hpp.html#aef3fd50d62ce69e229ebdc92f9ddb6a6":[7,0,3,20,2],
-"hyb__matrix_8hpp_source.html":[7,0,3,20],
-"ichol_8hpp.html":[7,0,3,4,15],
-"ichol_8hpp.html#a674c204660f61ec3c8b881fe86ef1dfd":[7,0,3,4,15,3],
-"ichol_8hpp_source.html":[7,0,3,4,15],
-"ilu0_8hpp.html":[7,0,3,4,1,2,2],
-"ilu0_8hpp.html#ae92ae6061c4ac82fdea8230c9877badc":[7,0,3,4,1,2,2,3],
-"ilu0_8hpp_source.html":[7,0,3,4,1,2,2],
-"ilu_8hpp.html":[7,0,3,4,16],
-"ilu_8hpp_source.html":[7,0,3,4,16],
-"ilut_8hpp.html":[7,0,3,4,1,2,3],
-"ilut_8hpp.html#a18218af41096d0913c54322e022d780d":[7,0,3,4,1,2,3,5],
-"ilut_8hpp.html#a39ed99a266c4ca46f851316297ce9bf6":[7,0,3,4,1,2,3,3],
-"ilut_8hpp.html#a79537640cb9e9f4dd0be0024143860b1":[7,0,3,4,1,2,3,4],
-"ilut_8hpp_source.html":[7,0,3,4,1,2,3],
-"index.html":[],
-"index.html":[0],
-"init__matrix_8hpp.html":[7,0,1,1,11],
-"init__matrix_8hpp_source.html":[7,0,1,1,11],
-"init__vector_8hpp.html":[7,0,1,1,12],
-"init__vector_8hpp_source.html":[7,0,1,1,12],
-"inner__prod_8hpp.html":[7,0,3,4,17],
-"inner__prod_8hpp.html#a3d9ef35327424393d599467538882522":[7,0,3,4,17,5],
-"inner__prod_8hpp.html#aac998ca060d47ba7c4b8bc1a994060ac":[7,0,3,4,17,4],
-"inner__prod_8hpp.html#ab35950c4374eb3be08a03d852508c01a":[7,0,3,4,17,0],
-"inner__prod_8hpp.html#ac71bae6daf6dc8a5803071f79565582a":[7,0,3,4,17,3],
-"inner__prod_8hpp.html#ad273e72f4a44fcd9802e3609d06af5e6":[7,0,3,4,17,1],
-"inner__prod_8hpp.html#ae4c12bee75a1dff46f0bd4b48abca2a5":[7,0,3,4,17,2]
+"host__based_2vector__operations_8hpp.html":[7,0,3,4,2,11]
 };
