@@ -1,5 +1,66 @@
 var NAVTREEINDEX14 =
 {
+"host__based_2vector__operations_8hpp.html#a2fff34b2cb787d5c2ae89f59a93cfde8":[7,0,3,4,2,11,5],
+"host__based_2vector__operations_8hpp.html#a306a6b1400991db3671a1511fa8f6f40":[7,0,3,4,2,11,16],
+"host__based_2vector__operations_8hpp.html#a38954effaaf57109159e51a31293a6c1":[7,0,3,4,2,11,26],
+"host__based_2vector__operations_8hpp.html#a47e4fa3cd849b7beab25f195633a38ad":[7,0,3,4,2,11,7],
+"host__based_2vector__operations_8hpp.html#a5ac8ca975475c4350eba91cc3d97ae81":[7,0,3,4,2,11,2],
+"host__based_2vector__operations_8hpp.html#a64a65b7cd5c499e1a2e12ae921ec1ca2":[7,0,3,4,2,11,24],
+"host__based_2vector__operations_8hpp.html#a7038bea435ceada730575e20bbcd56a6":[7,0,3,4,2,11,25],
+"host__based_2vector__operations_8hpp.html#a71fb7fd5be61a0297a8d19220cff479b":[7,0,3,4,2,11,1],
+"host__based_2vector__operations_8hpp.html#a7446f9329fa901df46a4f487a43601ca":[7,0,3,4,2,11,15],
+"host__based_2vector__operations_8hpp.html#a7634739b4c75267d38297dfcb19fad63":[7,0,3,4,2,11,8],
+"host__based_2vector__operations_8hpp.html#a84f017afe97029f92d48c968774f245b":[7,0,3,4,2,11,23],
+"host__based_2vector__operations_8hpp.html#a9d0a372a4ffd0c6347ecff6046ca4dec":[7,0,3,4,2,11,14],
+"host__based_2vector__operations_8hpp.html#a9e173eb4a7b8b63e7bddb53074d764ec":[7,0,3,4,2,11,9],
+"host__based_2vector__operations_8hpp.html#aa1b0719a06924fc82f8d8ed6c739a04d":[7,0,3,4,2,11,6],
+"host__based_2vector__operations_8hpp.html#aa9936ab7a49e99f2935f7dc33b95c976":[7,0,3,4,2,11,17],
+"host__based_2vector__operations_8hpp.html#aaf35aadcae50e5e59946aa92b7f22aa2":[7,0,3,4,2,11,0],
+"host__based_2vector__operations_8hpp.html#abd382e4bde97fb842b7b52b2b4d36379":[7,0,3,4,2,11,12],
+"host__based_2vector__operations_8hpp.html#abd70c99f406759e0f1ae2ffc6c9e8fed":[7,0,3,4,2,11,19],
+"host__based_2vector__operations_8hpp.html#ac4670f3fd14af7a2caf44c4036536010":[7,0,3,4,2,11,21],
+"host__based_2vector__operations_8hpp.html#ac765726382000520401dc9d70483dabb":[7,0,3,4,2,11,27],
+"host__based_2vector__operations_8hpp.html#ad21ec9fa116f8f1bd34d426c058c504b":[7,0,3,4,2,11,22],
+"host__based_2vector__operations_8hpp.html#ad78c38a7e4a3ae75bc2e149b28854eaa":[7,0,3,4,2,11,18],
+"host__based_2vector__operations_8hpp.html#ade2c77ef8044d4664c6857e96398304b":[7,0,3,4,2,11,20],
+"host__based_2vector__operations_8hpp.html#ade366c76e4b0db7585c51d890c88051d":[7,0,3,4,2,11,11],
+"host__based_2vector__operations_8hpp.html#ae3225408ae3e81b004fab27aeb6a9482":[7,0,3,4,2,11,13],
+"host__based_2vector__operations_8hpp.html#af7aa8317885702b7e1295d9eb802fba5":[7,0,3,4,2,11,3],
+"host__based_2vector__operations_8hpp.html#af97743e472ad389e0ad82849002fd0af":[7,0,3,4,2,11,4],
+"host__based_2vector__operations_8hpp.html#affd4a240838f3d33cfd0f37c4085d558":[7,0,3,4,2,11,10],
+"host__based_2vector__operations_8hpp_source.html":[7,0,3,4,2,11],
+"hyb__matrix_8hpp.html":[7,0,3,20],
+"hyb__matrix_8hpp.html#a3eccd807b53d2713366addeaf1137bae":[7,0,3,20,1],
+"hyb__matrix_8hpp.html#ad947ef8abf3c3cd4f69649b01ffb6d7e":[7,0,3,20,4],
+"hyb__matrix_8hpp.html#aee077076d127c528b236cc78ff6b8bbe":[7,0,3,20,3],
+"hyb__matrix_8hpp.html#aef3fd50d62ce69e229ebdc92f9ddb6a6":[7,0,3,20,2],
+"hyb__matrix_8hpp_source.html":[7,0,3,20],
+"ichol_8hpp.html":[7,0,3,4,15],
+"ichol_8hpp.html#a674c204660f61ec3c8b881fe86ef1dfd":[7,0,3,4,15,3],
+"ichol_8hpp_source.html":[7,0,3,4,15],
+"ilu0_8hpp.html":[7,0,3,4,1,2,2],
+"ilu0_8hpp.html#ae92ae6061c4ac82fdea8230c9877badc":[7,0,3,4,1,2,2,3],
+"ilu0_8hpp_source.html":[7,0,3,4,1,2,2],
+"ilu_8hpp.html":[7,0,3,4,16],
+"ilu_8hpp_source.html":[7,0,3,4,16],
+"ilut_8hpp.html":[7,0,3,4,1,2,3],
+"ilut_8hpp.html#a18218af41096d0913c54322e022d780d":[7,0,3,4,1,2,3,5],
+"ilut_8hpp.html#a39ed99a266c4ca46f851316297ce9bf6":[7,0,3,4,1,2,3,3],
+"ilut_8hpp.html#a79537640cb9e9f4dd0be0024143860b1":[7,0,3,4,1,2,3,4],
+"ilut_8hpp_source.html":[7,0,3,4,1,2,3],
+"index.html":[],
+"index.html":[0],
+"init__matrix_8hpp.html":[7,0,1,1,11],
+"init__matrix_8hpp_source.html":[7,0,1,1,11],
+"init__vector_8hpp.html":[7,0,1,1,12],
+"init__vector_8hpp_source.html":[7,0,1,1,12],
+"inner__prod_8hpp.html":[7,0,3,4,17],
+"inner__prod_8hpp.html#a3d9ef35327424393d599467538882522":[7,0,3,4,17,5],
+"inner__prod_8hpp.html#aac998ca060d47ba7c4b8bc1a994060ac":[7,0,3,4,17,4],
+"inner__prod_8hpp.html#ab35950c4374eb3be08a03d852508c01a":[7,0,3,4,17,0],
+"inner__prod_8hpp.html#ac71bae6daf6dc8a5803071f79565582a":[7,0,3,4,17,3],
+"inner__prod_8hpp.html#ad273e72f4a44fcd9802e3609d06af5e6":[7,0,3,4,17,1],
+"inner__prod_8hpp.html#ae4c12bee75a1dff46f0bd4b48abca2a5":[7,0,3,4,17,2],
 "inner__prod_8hpp_source.html":[7,0,3,4,17],
 "io_8hpp.html":[7,0,3,8,11],
 "io_8hpp.html#a2642d47c8e7a49835d0512734863e664":[7,0,3,8,11,3],
@@ -31,7 +92,6 @@ var NAVTREEINDEX14 =
 "iterative_8hpp.html#a308bdd25097efe84bb3d5f185d6b5a00":[7,0,3,4,3,0,8,4],
 "iterative_8hpp.html#a37ac57cf20f3ad734be17004061c1d64":[7,0,3,4,3,0,8,6],
 "iterative_8hpp.html#a3b5087693478ac4973289739d6f73bca":[7,0,3,4,3,0,8,14],
-"iterative_8hpp.html#a56882e465f6a115cb97f0ef6f4a64e7e":[7,0,3,4,3,0,8,16],
 "iterative_8hpp.html#a5bb161ac1be172ac646e184400660688":[7,0,3,4,3,0,8,1],
 "iterative_8hpp.html#a656464442cd911a5f7ffc95ff1fdede6":[7,0,3,4,3,0,8,3],
 "iterative_8hpp.html#a6b13382369ce1d8e21c501626028b531":[7,0,3,4,3,0,8,5],
@@ -41,6 +101,7 @@ var NAVTREEINDEX14 =
 "iterative_8hpp.html#aabb1337d0c7c092e031671b3e87b33d1":[7,0,3,4,3,0,8,7],
 "iterative_8hpp.html#ab11934c9ed7c97d96cdf5562ab736cd0":[7,0,3,4,3,0,8,15],
 "iterative_8hpp.html#ab52f7da07997b68a6b6a3f72cde0ec6c":[7,0,3,4,3,0,8,8],
+"iterative_8hpp.html#ad21d2720f708d7bb2022cbd27fd043a1":[7,0,3,4,3,0,8,16],
 "iterative_8hpp.html#ad81c63b98b2bb8606fbfdef87f92485f":[7,0,3,4,3,0,8,17],
 "iterative_8hpp.html#af5824a63a5c1f5e928e0a6346d614c3b":[7,0,3,4,3,0,8,18],
 "iterative_8hpp.html#afca54a4582b99a74ede8298e3d8f52b7":[7,0,3,4,3,0,8,2],
@@ -188,66 +249,5 @@ var NAVTREEINDEX14 =
 "linalg_2opencl_2common_8hpp.html#a1ed4b5fefdb8188be7ba2909a66bc653":[7,0,3,4,3,2,0],
 "linalg_2opencl_2common_8hpp.html#a259dfb67a35ecf1c7309ed8d758fc1b2":[7,0,3,4,3,2,11],
 "linalg_2opencl_2common_8hpp.html#a2bd490c2d7b21ec32230923b7c81bd0d":[7,0,3,4,3,2,4],
-"linalg_2opencl_2common_8hpp.html#a3747235a0998169ffadee525577d930e":[7,0,3,4,3,2,9],
-"linalg_2opencl_2common_8hpp.html#a3a8f0ed5e591a8db7b6f58d6dcb0d876":[7,0,3,4,3,2,15],
-"linalg_2opencl_2common_8hpp.html#a3bbbf414930d196b64d32eed990ed41b":[7,0,3,4,3,2,12],
-"linalg_2opencl_2common_8hpp.html#a463f2f570185fea98e0a1182b81f3ed2":[7,0,3,4,3,2,10],
-"linalg_2opencl_2common_8hpp.html#a492429cdf1788cb5b2da254f8975e045":[7,0,3,4,3,2,19],
-"linalg_2opencl_2common_8hpp.html#a61fe01db8afecaaaff7925f5a3783bba":[7,0,3,4,3,2,1],
-"linalg_2opencl_2common_8hpp.html#a685282399bcfb05ee912c02fed7f922f":[7,0,3,4,3,2,2],
-"linalg_2opencl_2common_8hpp.html#a706ada240e749a7fce2b59d8b0c307bc":[7,0,3,4,3,2,8],
-"linalg_2opencl_2common_8hpp.html#a783260fb41b8a52a796fa781db119fb1":[7,0,3,4,3,2,13],
-"linalg_2opencl_2common_8hpp.html#a7acbdad2a5672bc7129b8a7662a282bb":[7,0,3,4,3,2,20],
-"linalg_2opencl_2common_8hpp.html#a886e3de6509c88a2afb0de8867eaf931":[7,0,3,4,3,2,16],
-"linalg_2opencl_2common_8hpp.html#a887095b7f33bd650dafbe5c3a439bbae":[7,0,3,4,3,2,18],
-"linalg_2opencl_2common_8hpp.html#aaeb876e922457f997cd0e7f2a51c4e1d":[7,0,3,4,3,2,3],
-"linalg_2opencl_2common_8hpp.html#ab631c1d3f69abf29c6fbdc692372d208":[7,0,3,4,3,2,14],
-"linalg_2opencl_2common_8hpp.html#ae201d64c8b784292b2d9ebce683c408f":[7,0,3,4,3,2,6],
-"linalg_2opencl_2common_8hpp.html#af5d430b3c73ae4f648448e70e407d805":[7,0,3,4,3,2,7],
-"linalg_2opencl_2common_8hpp_source.html":[7,0,3,4,3,2],
-"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html":[7,0,3,4,3,0,1],
-"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html#ab57b99365ec8570f2d637fc09b54a69b":[7,0,3,4,3,0,1,1],
-"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp_source.html":[7,0,3,4,3,0,1],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html":[7,0,3,4,3,0,2],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a225e1900a97e29f2cd2decd0f61ca64c":[7,0,3,4,3,0,2,18],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a44ec7e25b4ae88ce6ccd05d539fefc7a":[7,0,3,4,3,0,2,15],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a519ceb09f2716dbcd853996506ef0a33":[7,0,3,4,3,0,2,17],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a599e788cba3fe48ef4a3213479a3edc7":[7,0,3,4,3,0,2,12],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a5bcbd44df6949ddf0013e193c3e72d26":[7,0,3,4,3,0,2,10],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a5eaf4660ccb083b812ee69644e8b5645":[7,0,3,4,3,0,2,3],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a62917553c4b0e142cac810166dd99592":[7,0,3,4,3,0,2,8],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a672e2a29693434c7b00fa3b3eb866372":[7,0,3,4,3,0,2,14],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a7aedb5b15922b66a8461607fdac5ddc4":[7,0,3,4,3,0,2,16],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a8bc1a2e018b5fa310935bb77e2f0d2e7":[7,0,3,4,3,0,2,7],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a96b8ee12b10b3496bf6de09b4ecdccfa":[7,0,3,4,3,0,2,19],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a9849f99f4cdc7bb9bf26a81316aea6a7":[7,0,3,4,3,0,2,9],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#aa0e15853bf8ce1c8e9d378a6165e894d":[7,0,3,4,3,0,2,2],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#aa2c92426757453bfde0039006139c4b1":[7,0,3,4,3,0,2,6],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#abf5f8755c942bfe3b362792a99733e61":[7,0,3,4,3,0,2,13],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#ad76920526ec2bb8354840b0c814b3794":[7,0,3,4,3,0,2,11],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#adae8b4e52dfd836b1ca21ec19f9514a7":[7,0,3,4,3,0,2,5],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#ae2bf04c2598b9482f3b9bd5f3e2865fb":[7,0,3,4,3,0,2,4],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#af37f85ae0d4cee5a2ab550de681da27b":[7,0,3,4,3,0,2,1],
-"linalg_2opencl_2kernels_2compressed__matrix_8hpp_source.html":[7,0,3,4,3,0,2],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[7,0,3,4,3,0,3],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a23ff7b816118c0d1bef3965ae3ef941b":[7,0,3,4,3,0,3,1],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a4a3dd26085bc1f2f42717d6cd25371b0":[7,0,3,4,3,0,3,3],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a64f3806d00d953c07d3c31e4514b17eb":[7,0,3,4,3,0,3,2],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#afd2bb5a0a4802b32b6ffe26036395755":[7,0,3,4,3,0,3,4],
-"linalg_2opencl_2kernels_2coordinate__matrix_8hpp_source.html":[7,0,3,4,3,0,3],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[7,0,3,4,3,0,4],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#a7868cd7436d34ded05a200226df77b75":[7,0,3,4,3,0,4,3],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aaab30445458756f2a6b9e4afd54feafc":[7,0,3,4,3,0,4,1],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aff4ab5e5474e310e09eb03a10aaa6844":[7,0,3,4,3,0,4,2],
-"linalg_2opencl_2kernels_2ell__matrix_8hpp_source.html":[7,0,3,4,3,0,4],
-"linalg_2opencl_2kernels_2fft_8hpp.html":[7,0,3,4,3,0,5],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a03d946ea93037f1a394325d1c524383b":[7,0,3,4,3,0,5,8],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a056ee100af7f100796c7e6893617c1cb":[7,0,3,4,3,0,5,5],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a08dcb168fcfe7292634e1d15e0ecb577":[7,0,3,4,3,0,5,2],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a1953cd9bfa9ae539106f7d5364488f20":[7,0,3,4,3,0,5,3],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a5bc438da1adb4fe04d869bbe9318d2db":[7,0,3,4,3,0,5,9],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a72c23e31b4c043ac2a373988576f7aa8":[7,0,3,4,3,0,5,7],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a829073b7bfc3c121a1baba87a595462a":[7,0,3,4,3,0,5,4],
-"linalg_2opencl_2kernels_2fft_8hpp.html#a909a503c6a235fdff7b7d95900513dc3":[7,0,3,4,3,0,5,6],
-"linalg_2opencl_2kernels_2fft_8hpp.html#acbcd37b7373b647d9eb2d93e77902ba2":[7,0,3,4,3,0,5,10]
+"linalg_2opencl_2common_8hpp.html#a3747235a0998169ffadee525577d930e":[7,0,3,4,3,2,9]
 };
