@@ -1,5 +1,66 @@
 var NAVTREEINDEX15 =
 {
+"linalg_2opencl_2common_8hpp.html#a3a8f0ed5e591a8db7b6f58d6dcb0d876":[7,0,3,4,3,2,15],
+"linalg_2opencl_2common_8hpp.html#a3bbbf414930d196b64d32eed990ed41b":[7,0,3,4,3,2,12],
+"linalg_2opencl_2common_8hpp.html#a463f2f570185fea98e0a1182b81f3ed2":[7,0,3,4,3,2,10],
+"linalg_2opencl_2common_8hpp.html#a492429cdf1788cb5b2da254f8975e045":[7,0,3,4,3,2,19],
+"linalg_2opencl_2common_8hpp.html#a61fe01db8afecaaaff7925f5a3783bba":[7,0,3,4,3,2,1],
+"linalg_2opencl_2common_8hpp.html#a685282399bcfb05ee912c02fed7f922f":[7,0,3,4,3,2,2],
+"linalg_2opencl_2common_8hpp.html#a706ada240e749a7fce2b59d8b0c307bc":[7,0,3,4,3,2,8],
+"linalg_2opencl_2common_8hpp.html#a783260fb41b8a52a796fa781db119fb1":[7,0,3,4,3,2,13],
+"linalg_2opencl_2common_8hpp.html#a7acbdad2a5672bc7129b8a7662a282bb":[7,0,3,4,3,2,20],
+"linalg_2opencl_2common_8hpp.html#a886e3de6509c88a2afb0de8867eaf931":[7,0,3,4,3,2,16],
+"linalg_2opencl_2common_8hpp.html#a887095b7f33bd650dafbe5c3a439bbae":[7,0,3,4,3,2,18],
+"linalg_2opencl_2common_8hpp.html#aaeb876e922457f997cd0e7f2a51c4e1d":[7,0,3,4,3,2,3],
+"linalg_2opencl_2common_8hpp.html#ab631c1d3f69abf29c6fbdc692372d208":[7,0,3,4,3,2,14],
+"linalg_2opencl_2common_8hpp.html#ae201d64c8b784292b2d9ebce683c408f":[7,0,3,4,3,2,6],
+"linalg_2opencl_2common_8hpp.html#af5d430b3c73ae4f648448e70e407d805":[7,0,3,4,3,2,7],
+"linalg_2opencl_2common_8hpp_source.html":[7,0,3,4,3,2],
+"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html":[7,0,3,4,3,0,1],
+"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html#ab57b99365ec8570f2d637fc09b54a69b":[7,0,3,4,3,0,1,1],
+"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp_source.html":[7,0,3,4,3,0,1],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html":[7,0,3,4,3,0,2],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a225e1900a97e29f2cd2decd0f61ca64c":[7,0,3,4,3,0,2,18],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a44ec7e25b4ae88ce6ccd05d539fefc7a":[7,0,3,4,3,0,2,15],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a519ceb09f2716dbcd853996506ef0a33":[7,0,3,4,3,0,2,17],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a599e788cba3fe48ef4a3213479a3edc7":[7,0,3,4,3,0,2,12],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a5bcbd44df6949ddf0013e193c3e72d26":[7,0,3,4,3,0,2,10],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a5eaf4660ccb083b812ee69644e8b5645":[7,0,3,4,3,0,2,3],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a62917553c4b0e142cac810166dd99592":[7,0,3,4,3,0,2,8],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a672e2a29693434c7b00fa3b3eb866372":[7,0,3,4,3,0,2,14],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a7aedb5b15922b66a8461607fdac5ddc4":[7,0,3,4,3,0,2,16],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a8bc1a2e018b5fa310935bb77e2f0d2e7":[7,0,3,4,3,0,2,7],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a96b8ee12b10b3496bf6de09b4ecdccfa":[7,0,3,4,3,0,2,19],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#a9849f99f4cdc7bb9bf26a81316aea6a7":[7,0,3,4,3,0,2,9],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#aa0e15853bf8ce1c8e9d378a6165e894d":[7,0,3,4,3,0,2,2],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#aa2c92426757453bfde0039006139c4b1":[7,0,3,4,3,0,2,6],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#abf5f8755c942bfe3b362792a99733e61":[7,0,3,4,3,0,2,13],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#ad76920526ec2bb8354840b0c814b3794":[7,0,3,4,3,0,2,11],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#adae8b4e52dfd836b1ca21ec19f9514a7":[7,0,3,4,3,0,2,5],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#ae2bf04c2598b9482f3b9bd5f3e2865fb":[7,0,3,4,3,0,2,4],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html#af37f85ae0d4cee5a2ab550de681da27b":[7,0,3,4,3,0,2,1],
+"linalg_2opencl_2kernels_2compressed__matrix_8hpp_source.html":[7,0,3,4,3,0,2],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[7,0,3,4,3,0,3],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a23ff7b816118c0d1bef3965ae3ef941b":[7,0,3,4,3,0,3,1],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a4a3dd26085bc1f2f42717d6cd25371b0":[7,0,3,4,3,0,3,3],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#a64f3806d00d953c07d3c31e4514b17eb":[7,0,3,4,3,0,3,2],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html#afd2bb5a0a4802b32b6ffe26036395755":[7,0,3,4,3,0,3,4],
+"linalg_2opencl_2kernels_2coordinate__matrix_8hpp_source.html":[7,0,3,4,3,0,3],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[7,0,3,4,3,0,4],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#a7868cd7436d34ded05a200226df77b75":[7,0,3,4,3,0,4,3],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aaab30445458756f2a6b9e4afd54feafc":[7,0,3,4,3,0,4,1],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp.html#aff4ab5e5474e310e09eb03a10aaa6844":[7,0,3,4,3,0,4,2],
+"linalg_2opencl_2kernels_2ell__matrix_8hpp_source.html":[7,0,3,4,3,0,4],
+"linalg_2opencl_2kernels_2fft_8hpp.html":[7,0,3,4,3,0,5],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a03d946ea93037f1a394325d1c524383b":[7,0,3,4,3,0,5,8],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a056ee100af7f100796c7e6893617c1cb":[7,0,3,4,3,0,5,5],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a08dcb168fcfe7292634e1d15e0ecb577":[7,0,3,4,3,0,5,2],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a1953cd9bfa9ae539106f7d5364488f20":[7,0,3,4,3,0,5,3],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a5bc438da1adb4fe04d869bbe9318d2db":[7,0,3,4,3,0,5,9],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a72c23e31b4c043ac2a373988576f7aa8":[7,0,3,4,3,0,5,7],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a829073b7bfc3c121a1baba87a595462a":[7,0,3,4,3,0,5,4],
+"linalg_2opencl_2kernels_2fft_8hpp.html#a909a503c6a235fdff7b7d95900513dc3":[7,0,3,4,3,0,5,6],
+"linalg_2opencl_2kernels_2fft_8hpp.html#acbcd37b7373b647d9eb2d93e77902ba2":[7,0,3,4,3,0,5,10],
 "linalg_2opencl_2kernels_2fft_8hpp.html#ae143c2d7887d9060ef8d1319a1022769":[7,0,3,4,3,0,5,1],
 "linalg_2opencl_2kernels_2fft_8hpp.html#ae93743370d109b9e5e468651c8ccec49":[7,0,3,4,3,0,5,11],
 "linalg_2opencl_2kernels_2fft_8hpp_source.html":[7,0,3,4,3,0,5],
@@ -188,66 +249,5 @@ var NAVTREEINDEX15 =
 "matrix_8hpp.html#a7fca08f4a83edffe7f47666d298ca87d":[7,0,3,21,5],
 "matrix_8hpp.html#a8707f526944ee24f12c399234fed56da":[7,0,3,21,64],
 "matrix_8hpp.html#a886d3a303d99d70d54820473e1349757":[7,0,3,21,32],
-"matrix_8hpp.html#a92695ea6fa06cb0b9d940bb14080b62a":[7,0,3,21,13],
-"matrix_8hpp.html#a97d5a2c7b8514856ee97a68dee279ac2":[7,0,3,21,38],
-"matrix_8hpp.html#a99433d936260c16ae92dad64d2af42d4":[7,0,3,21,42],
-"matrix_8hpp.html#a9b5f1f57f46bcf1c5949022b1600a229":[7,0,3,21,34],
-"matrix_8hpp.html#a9dc06bea5c7f930db9ff33f0f06b37ec":[7,0,3,21,44],
-"matrix_8hpp.html#aa04b51b11118a495d5202f50fadd1576":[7,0,3,21,6],
-"matrix_8hpp.html#aa0da914c1ab007cc95f3dceed9eedab7":[7,0,3,21,33],
-"matrix_8hpp.html#aa1be36347ee913ccefc9d42c9dbdd361":[7,0,3,21,58],
-"matrix_8hpp.html#aa29579b205318b44886a3cc868feb064":[7,0,3,21,60],
-"matrix_8hpp.html#aa60bf08e0585fc5feea364450e696558":[7,0,3,21,50],
-"matrix_8hpp.html#aa850e0b2b3ff9bb2647cb536b4fffb90":[7,0,3,21,15],
-"matrix_8hpp.html#abbd254c13a3a3dc4d50df850726bd13d":[7,0,3,21,29],
-"matrix_8hpp.html#ac3e47d6dce13c75a6b32d792cd854ffa":[7,0,3,21,30],
-"matrix_8hpp.html#ac58516a40d21e78d01366ebf3f9b5782":[7,0,3,21,21],
-"matrix_8hpp.html#acc1015874fe77649ea83df1ae264f623":[7,0,3,21,18],
-"matrix_8hpp.html#acc887938113f86149365f506e29ba938":[7,0,3,21,37],
-"matrix_8hpp.html#ad0e1cf3b5bddbb11b2500599ac6343b7":[7,0,3,21,31],
-"matrix_8hpp.html#ad1bb4021955c62357d76faf3a02e8fae":[7,0,3,21,52],
-"matrix_8hpp.html#adff5bcd6a96666051b8e45e9d0cf36a4":[7,0,3,21,35],
-"matrix_8hpp.html#ae14d7130f2bf7648805ed09381263928":[7,0,3,21,55],
-"matrix_8hpp.html#ae5bfb1e933c577c593814b926ae405e8":[7,0,3,21,48],
-"matrix_8hpp.html#aeaca8fd86909b87757f7c1f2ff837092":[7,0,3,21,51],
-"matrix_8hpp.html#aedf958f77e4e8b2f4235675131e391ea":[7,0,3,21,67],
-"matrix_8hpp.html#aefaf3038b632cba603d17de16b2a6b95":[7,0,3,21,46],
-"matrix_8hpp.html#af1057a25ff074250d9dc656ebed4c606":[7,0,3,21,12],
-"matrix_8hpp.html#af4dffb3b912475aa7e25494c8f75e294":[7,0,3,21,39],
-"matrix_8hpp.html#af61f6e7bfb0b18b8f824d12e7cb36930":[7,0,3,21,14],
-"matrix_8hpp.html#af6b752094b8c244a080136cdd5e2f271":[7,0,3,21,63],
-"matrix_8hpp.html#af7f75fa1ed33f5ed4728e49528720999":[7,0,3,21,7],
-"matrix_8hpp_source.html":[7,0,3,21],
-"matrix__axpy_8hpp.html":[7,0,3,2,0,2],
-"matrix__axpy_8hpp.html#a12cc0a5309100d6c569e9e9790e9a095":[7,0,3,2,0,2,0],
-"matrix__axpy_8hpp.html#aada33a8c81e3eb69b66e16d452ce4c86":[7,0,3,2,0,2,1],
-"matrix__axpy_8hpp_source.html":[7,0,3,2,0,2],
-"matrix__axpy__template_8hpp.html":[7,0,3,2,1,0],
-"matrix__axpy__template_8hpp_source.html":[7,0,3,2,1,0],
-"matrix__col__double_8cpp.html":[7,0,2,0,11],
-"matrix__col__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,11,0],
-"matrix__col__double_8cpp_source.html":[7,0,2,0,11],
-"matrix__col__float_8cpp.html":[7,0,2,0,12],
-"matrix__col__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,12,0],
-"matrix__col__float_8cpp_source.html":[7,0,2,0,12],
-"matrix__col__int_8cpp.html":[7,0,2,0,13],
-"matrix__col__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,13,0],
-"matrix__col__int_8cpp_source.html":[7,0,2,0,13],
-"matrix__def_8hpp.html":[7,0,3,1,0],
-"matrix__def_8hpp_source.html":[7,0,3,1,0],
-"matrix__float__double_8hpp.html":[7,0,2,0,14],
-"matrix__float__double_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,14,1],
-"matrix__float__double_8hpp.html#a3eeb8dff5404f0ba9ff74f4ee5b9095d":[7,0,2,0,14,5],
-"matrix__float__double_8hpp.html#a931ce6a0abe4400075e9db9f45456a6d":[7,0,2,0,14,3],
-"matrix__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,14,0],
-"matrix__float__double_8hpp.html#ab3fef5684e0d6531328592e7028143d9":[7,0,2,0,14,4],
-"matrix__float__double_8hpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,14,2],
-"matrix__float__double_8hpp_source.html":[7,0,2,0,14],
-"matrix__generation_8hpp.html":[7,0,3,9,2],
-"matrix__generation_8hpp.html#a2702f36c2589c4c7149933392df2d2c5":[7,0,3,9,2,1],
-"matrix__generation_8hpp.html#a2f78fcdf605a26a07bc8a74abf43cebd":[7,0,3,9,2,2],
-"matrix__generation_8hpp.html#ad234a38b10b156c750260065c3d3883c":[7,0,3,9,2,0],
-"matrix__generation_8hpp.html#ad8bbea154a3967f21dd72eb90c32e8b6":[7,0,3,9,2,5],
-"matrix__generation_8hpp.html#add4bc9eb3478008256fb745ea682cf0e":[7,0,3,9,2,4],
-"matrix__generation_8hpp.html#af9cd8936be17b4cf089bf18fec7861fb":[7,0,3,9,2,3]
+"matrix_8hpp.html#a92695ea6fa06cb0b9d940bb14080b62a":[7,0,3,21,13]
 };
