@@ -1,5 +1,66 @@
 var NAVTREEINDEX16 =
 {
+"matrix_8hpp.html#a97d5a2c7b8514856ee97a68dee279ac2":[7,0,3,21,38],
+"matrix_8hpp.html#a99433d936260c16ae92dad64d2af42d4":[7,0,3,21,42],
+"matrix_8hpp.html#a9b5f1f57f46bcf1c5949022b1600a229":[7,0,3,21,34],
+"matrix_8hpp.html#a9dc06bea5c7f930db9ff33f0f06b37ec":[7,0,3,21,44],
+"matrix_8hpp.html#aa04b51b11118a495d5202f50fadd1576":[7,0,3,21,6],
+"matrix_8hpp.html#aa0da914c1ab007cc95f3dceed9eedab7":[7,0,3,21,33],
+"matrix_8hpp.html#aa1be36347ee913ccefc9d42c9dbdd361":[7,0,3,21,58],
+"matrix_8hpp.html#aa29579b205318b44886a3cc868feb064":[7,0,3,21,60],
+"matrix_8hpp.html#aa60bf08e0585fc5feea364450e696558":[7,0,3,21,50],
+"matrix_8hpp.html#aa850e0b2b3ff9bb2647cb536b4fffb90":[7,0,3,21,15],
+"matrix_8hpp.html#abbd254c13a3a3dc4d50df850726bd13d":[7,0,3,21,29],
+"matrix_8hpp.html#ac3e47d6dce13c75a6b32d792cd854ffa":[7,0,3,21,30],
+"matrix_8hpp.html#ac58516a40d21e78d01366ebf3f9b5782":[7,0,3,21,21],
+"matrix_8hpp.html#acc1015874fe77649ea83df1ae264f623":[7,0,3,21,18],
+"matrix_8hpp.html#acc887938113f86149365f506e29ba938":[7,0,3,21,37],
+"matrix_8hpp.html#ad0e1cf3b5bddbb11b2500599ac6343b7":[7,0,3,21,31],
+"matrix_8hpp.html#ad1bb4021955c62357d76faf3a02e8fae":[7,0,3,21,52],
+"matrix_8hpp.html#adff5bcd6a96666051b8e45e9d0cf36a4":[7,0,3,21,35],
+"matrix_8hpp.html#ae14d7130f2bf7648805ed09381263928":[7,0,3,21,55],
+"matrix_8hpp.html#ae5bfb1e933c577c593814b926ae405e8":[7,0,3,21,48],
+"matrix_8hpp.html#aeaca8fd86909b87757f7c1f2ff837092":[7,0,3,21,51],
+"matrix_8hpp.html#aedf958f77e4e8b2f4235675131e391ea":[7,0,3,21,67],
+"matrix_8hpp.html#aefaf3038b632cba603d17de16b2a6b95":[7,0,3,21,46],
+"matrix_8hpp.html#af1057a25ff074250d9dc656ebed4c606":[7,0,3,21,12],
+"matrix_8hpp.html#af4dffb3b912475aa7e25494c8f75e294":[7,0,3,21,39],
+"matrix_8hpp.html#af61f6e7bfb0b18b8f824d12e7cb36930":[7,0,3,21,14],
+"matrix_8hpp.html#af6b752094b8c244a080136cdd5e2f271":[7,0,3,21,63],
+"matrix_8hpp.html#af7f75fa1ed33f5ed4728e49528720999":[7,0,3,21,7],
+"matrix_8hpp_source.html":[7,0,3,21],
+"matrix__axpy_8hpp.html":[7,0,3,2,0,2],
+"matrix__axpy_8hpp.html#a12cc0a5309100d6c569e9e9790e9a095":[7,0,3,2,0,2,0],
+"matrix__axpy_8hpp.html#aada33a8c81e3eb69b66e16d452ce4c86":[7,0,3,2,0,2,1],
+"matrix__axpy_8hpp_source.html":[7,0,3,2,0,2],
+"matrix__axpy__template_8hpp.html":[7,0,3,2,1,0],
+"matrix__axpy__template_8hpp_source.html":[7,0,3,2,1,0],
+"matrix__col__double_8cpp.html":[7,0,2,0,11],
+"matrix__col__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,11,0],
+"matrix__col__double_8cpp_source.html":[7,0,2,0,11],
+"matrix__col__float_8cpp.html":[7,0,2,0,12],
+"matrix__col__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,12,0],
+"matrix__col__float_8cpp_source.html":[7,0,2,0,12],
+"matrix__col__int_8cpp.html":[7,0,2,0,13],
+"matrix__col__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,13,0],
+"matrix__col__int_8cpp_source.html":[7,0,2,0,13],
+"matrix__def_8hpp.html":[7,0,3,1,0],
+"matrix__def_8hpp_source.html":[7,0,3,1,0],
+"matrix__float__double_8hpp.html":[7,0,2,0,14],
+"matrix__float__double_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,14,1],
+"matrix__float__double_8hpp.html#a3eeb8dff5404f0ba9ff74f4ee5b9095d":[7,0,2,0,14,5],
+"matrix__float__double_8hpp.html#a931ce6a0abe4400075e9db9f45456a6d":[7,0,2,0,14,3],
+"matrix__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,14,0],
+"matrix__float__double_8hpp.html#ab3fef5684e0d6531328592e7028143d9":[7,0,2,0,14,4],
+"matrix__float__double_8hpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,14,2],
+"matrix__float__double_8hpp_source.html":[7,0,2,0,14],
+"matrix__generation_8hpp.html":[7,0,3,9,2],
+"matrix__generation_8hpp.html#a2702f36c2589c4c7149933392df2d2c5":[7,0,3,9,2,1],
+"matrix__generation_8hpp.html#a2f78fcdf605a26a07bc8a74abf43cebd":[7,0,3,9,2,2],
+"matrix__generation_8hpp.html#ad234a38b10b156c750260065c3d3883c":[7,0,3,9,2,0],
+"matrix__generation_8hpp.html#ad8bbea154a3967f21dd72eb90c32e8b6":[7,0,3,9,2,5],
+"matrix__generation_8hpp.html#add4bc9eb3478008256fb745ea682cf0e":[7,0,3,9,2,4],
+"matrix__generation_8hpp.html#af9cd8936be17b4cf089bf18fec7861fb":[7,0,3,9,2,3],
 "matrix__generation_8hpp_source.html":[7,0,3,9,2],
 "matrix__int_8hpp.html":[7,0,2,0,15],
 "matrix__int_8hpp.html#a1a31691278c2c097329150c6fd1a04f2":[7,0,2,0,15,0],
@@ -63,59 +124,59 @@ var NAVTREEINDEX16 =
 "matrix__operations_8hpp.html#af8d50400363dab7d4edef7d9f67954c9":[7,0,3,4,22,21],
 "matrix__operations_8hpp_source.html":[7,0,3,4,22],
 "matrix__operations__col_8hpp.html":[7,0,3,4,0,11],
-"matrix__operations__col_8hpp.html#a0c2c3094bd2311dfa7d556488631c96d":[7,0,3,4,0,11,27],
+"matrix__operations__col_8hpp.html#a0549ca86fcc12b0ade31a71884c15a5b":[7,0,3,4,0,11,26],
 "matrix__operations__col_8hpp.html#a13b2a55ca7df73985ab6ab1d7cf4976e":[7,0,3,4,0,11,20],
+"matrix__operations__col_8hpp.html#a1d46df86192612762697a3d54d4edc6b":[7,0,3,4,0,11,21],
 "matrix__operations__col_8hpp.html#a1eda64ee9b4614785aaea3b6ea4783cb":[7,0,3,4,0,11,50],
 "matrix__operations__col_8hpp.html#a24d7b938c62c7683a4350287216010bd":[7,0,3,4,0,11,31],
 "matrix__operations__col_8hpp.html#a2668643387244a92f994813d8058c127":[7,0,3,4,0,11,34],
 "matrix__operations__col_8hpp.html#a27ba381af6485a1f6a44d381194a4de6":[7,0,3,4,0,11,4],
-"matrix__operations__col_8hpp.html#a29e99b39e451f1fd0c50bbffdb3d75e8":[7,0,3,4,0,11,13],
 "matrix__operations__col_8hpp.html#a2b4fe87147319813dbdf36df2de91444":[7,0,3,4,0,11,8],
+"matrix__operations__col_8hpp.html#a2d3b259a431af96de478a49789c31016":[7,0,3,4,0,11,25],
 "matrix__operations__col_8hpp.html#a3988d6581519c75da05cbb56f6d90bc3":[7,0,3,4,0,11,48],
-"matrix__operations__col_8hpp.html#a41e44fbce666dfee6672d4b62e24a979":[7,0,3,4,0,11,28],
-"matrix__operations__col_8hpp.html#a433d265c74f62110fc10789d5e77ad8f":[7,0,3,4,0,11,12],
-"matrix__operations__col_8hpp.html#a47ffbf3e786be82559654f94d019b198":[7,0,3,4,0,11,22],
-"matrix__operations__col_8hpp.html#a52fdf7db3c278991cd09dcba09bacb0e":[7,0,3,4,0,11,17],
+"matrix__operations__col_8hpp.html#a39ebb0f5f28d79b723dbaac8a64273a9":[7,0,3,4,0,11,12],
 "matrix__operations__col_8hpp.html#a58b2c423ab9e3d062e5ac177b38ee37e":[7,0,3,4,0,11,49],
+"matrix__operations__col_8hpp.html#a5a5428207a302cf214abff0bb33b516b":[7,0,3,4,0,11,11],
 "matrix__operations__col_8hpp.html#a654f609cd7848b45b38939e003fbf5af":[7,0,3,4,0,11,55],
-"matrix__operations__col_8hpp.html#a66360684148dbd142e49fbd71e751783":[7,0,3,4,0,11,24],
 "matrix__operations__col_8hpp.html#a67e2b1c13c39fc67a993a2a596346f60":[7,0,3,4,0,11,39],
+"matrix__operations__col_8hpp.html#a6c57d2fd37a41d5b2984076b949ba2ea":[7,0,3,4,0,11,16],
 "matrix__operations__col_8hpp.html#a6ccccd2be71ff145d29fd0dfa8545e18":[7,0,3,4,0,11,46],
 "matrix__operations__col_8hpp.html#a6e0a14ead7f5dda49ed8ab603dd73b4f":[7,0,3,4,0,11,33],
+"matrix__operations__col_8hpp.html#a71f2ca5126aa0a9c745cb5575fdef3f6":[7,0,3,4,0,11,28],
 "matrix__operations__col_8hpp.html#a73702d7116c0b7bbfa9553052719f928":[7,0,3,4,0,11,30],
-"matrix__operations__col_8hpp.html#a7579789fa8118e805d676bed5dce8b81":[7,0,3,4,0,11,14],
+"matrix__operations__col_8hpp.html#a78741b4ca602471b1009ad8919ebb379":[7,0,3,4,0,11,15],
 "matrix__operations__col_8hpp.html#a788c0ada220dd8062a391525eb37851d":[7,0,3,4,0,11,5],
+"matrix__operations__col_8hpp.html#a7e4d5ed0c0b4e2e2511c11c8e71cf794":[7,0,3,4,0,11,17],
 "matrix__operations__col_8hpp.html#a8106216445b4a1da22a5e00b82c821d4":[7,0,3,4,0,11,37],
 "matrix__operations__col_8hpp.html#a87a97b430df75bec5177d7e73e8af682":[7,0,3,4,0,11,19],
 "matrix__operations__col_8hpp.html#a896e84eed510eabefb25c2dc08bffef4":[7,0,3,4,0,11,0],
 "matrix__operations__col_8hpp.html#a8ac375a8ba317dacc0070d3a57a2ed40":[7,0,3,4,0,11,47],
 "matrix__operations__col_8hpp.html#a8b9865449bd2d824e280400cd13f3802":[7,0,3,4,0,11,32],
 "matrix__operations__col_8hpp.html#a8cbb34fbe2eb691e0837a5c36757ba9b":[7,0,3,4,0,11,7],
+"matrix__operations__col_8hpp.html#a8cdfd433b14d36f5b2ba2467e3770e9c":[7,0,3,4,0,11,13],
 "matrix__operations__col_8hpp.html#a8f4e7ebf412327b90fdfe1cccea00535":[7,0,3,4,0,11,3],
+"matrix__operations__col_8hpp.html#a915463c1be02a593266096a6ea6f18d1":[7,0,3,4,0,11,14],
 "matrix__operations__col_8hpp.html#a91b71139db24f7f9ba9c5b71d52074f2":[7,0,3,4,0,11,1],
 "matrix__operations__col_8hpp.html#a92c425e21d85ab908add7be2d622a9f2":[7,0,3,4,0,11,9],
-"matrix__operations__col_8hpp.html#a937d0197c9336ad73a3391cd45adbb32":[7,0,3,4,0,11,26],
 "matrix__operations__col_8hpp.html#a9703dbb75f6c498ba004687ae8c5b107":[7,0,3,4,0,11,6],
+"matrix__operations__col_8hpp.html#a9a148ebc1c5e9509474e08692c67bec1":[7,0,3,4,0,11,22],
 "matrix__operations__col_8hpp.html#a9e360496b7b0878be62a1c156c689a4a":[7,0,3,4,0,11,35],
 "matrix__operations__col_8hpp.html#aa33c1216c92d0d31410113e5cb50fa58":[7,0,3,4,0,11,36],
-"matrix__operations__col_8hpp.html#aa4bad2723cb62eb4e5be202e0733feb7":[7,0,3,4,0,11,21],
 "matrix__operations__col_8hpp.html#aa73250643a44654944ed433511e7a780":[7,0,3,4,0,11,51],
+"matrix__operations__col_8hpp.html#aa7ed32e33a8c13b9a4e434e9dd01d68d":[7,0,3,4,0,11,24],
 "matrix__operations__col_8hpp.html#aaf4d4d703f35bf88fd4aa7fb195a7ed7":[7,0,3,4,0,11,40],
 "matrix__operations__col_8hpp.html#ab26871a2c3d398727fd025c5c97c40a9":[7,0,3,4,0,11,43],
 "matrix__operations__col_8hpp.html#ab9ebd33c063c26f9ed13af8158cec4e8":[7,0,3,4,0,11,41],
-"matrix__operations__col_8hpp.html#ac539ec8efe3001c1ed5c3f86f856d7e2":[7,0,3,4,0,11,11],
-"matrix__operations__col_8hpp.html#ac69de11245870aef4142aa0813c35870":[7,0,3,4,0,11,23],
 "matrix__operations__col_8hpp.html#acb867a2ff386478be186cfe56d9db7c5":[7,0,3,4,0,11,45],
-"matrix__operations__col_8hpp.html#ad17661c01875051780d1b85a7c5d52f7":[7,0,3,4,0,11,25],
 "matrix__operations__col_8hpp.html#ad186550fd426ada7b82e6b7e6e6d0592":[7,0,3,4,0,11,18],
-"matrix__operations__col_8hpp.html#ad1b934070e72c040d29c6ca65f523e6b":[7,0,3,4,0,11,15],
 "matrix__operations__col_8hpp.html#ad3013060178ead4df58b45267f40d4c0":[7,0,3,4,0,11,2],
 "matrix__operations__col_8hpp.html#ad4a98a06b04ed2cfeab79551ec045e9e":[7,0,3,4,0,11,52],
-"matrix__operations__col_8hpp.html#ad4e4fe89b36cca3e5761c99b9631001e":[7,0,3,4,0,11,16],
 "matrix__operations__col_8hpp.html#ad6cd8f178b41df4c7cd3e6e89d27782b":[7,0,3,4,0,11,10],
 "matrix__operations__col_8hpp.html#ada17736bf8769a2151354ce39ef64936":[7,0,3,4,0,11,54],
+"matrix__operations__col_8hpp.html#adbb7c5e437951f0b9062811120ad4339":[7,0,3,4,0,11,23],
 "matrix__operations__col_8hpp.html#ae44c6f379268a44bd60b4a8943b1cb3f":[7,0,3,4,0,11,38],
 "matrix__operations__col_8hpp.html#ae5ee136bf581cc57aba1e01e989378fb":[7,0,3,4,0,11,29],
+"matrix__operations__col_8hpp.html#ae6c6dd3942c0d897ff5df75cdbc5bfb6":[7,0,3,4,0,11,27],
 "matrix__operations__col_8hpp.html#aeb7831fd06322b2df2ccd37f9cd359d2":[7,0,3,4,0,11,42],
 "matrix__operations__col_8hpp.html#aec60885b11f195e5bb71fbb926c71dc4":[7,0,3,4,0,11,53],
 "matrix__operations__col_8hpp.html#af5634b169dad1d4c9616b3b251f29f19":[7,0,3,4,0,11,44],
@@ -188,66 +249,5 @@ var NAVTREEINDEX16 =
 "matrix__operations__row_8hpp.html#ad73ed63f68b5922248a9cc51ae878e60":[7,0,3,4,0,13,24],
 "matrix__operations__row_8hpp.html#adac9b13a79cd0c009dff3f6c41f2b570":[7,0,3,4,0,13,17],
 "matrix__operations__row_8hpp.html#ae0c1ab49bf9e4cd4cf694e3639d442dc":[7,0,3,4,0,13,4],
-"matrix__operations__row_8hpp.html#aef28890380b6a246d556390c13e26a61":[7,0,3,4,0,13,22],
-"matrix__operations__row_8hpp.html#af2b44cf9690bfb3f9e5dff5b26b607e9":[7,0,3,4,0,13,35],
-"matrix__operations__row_8hpp.html#af7f5b871860c650a17d06404fe61f9ac":[7,0,3,4,0,13,27],
-"matrix__operations__row_8hpp_source.html":[7,0,3,4,0,13],
-"matrix__product_8hpp.html":[7,0,3,2,0,3],
-"matrix__product_8hpp.html#a07786a0a76651ba3c30d60b7ae5ad6d0":[7,0,3,2,0,3,3],
-"matrix__product_8hpp.html#a0eef9981c2c419b5b0b6fb4f96dff088":[7,0,3,2,0,3,2],
-"matrix__product_8hpp.html#a6f63b3563756b4961647fe3ada8790d5":[7,0,3,2,0,3,1],
-"matrix__product_8hpp.html#a92cf5f3655b5e3bcb1ddcb9b31123067":[7,0,3,2,0,3,4],
-"matrix__product_8hpp.html#ad45fa18ffaecd758a25649b327a1895b":[7,0,3,2,0,3,0],
-"matrix__product_8hpp_source.html":[7,0,3,2,0,3],
-"matrix__product__double_8cpp.html":[7,0,2,0,16],
-"matrix__product__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,16,0],
-"matrix__product__double_8cpp_source.html":[7,0,2,0,16],
-"matrix__product__float_8cpp.html":[7,0,2,0,17],
-"matrix__product__float_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,17,0],
-"matrix__product__float_8cpp_source.html":[7,0,2,0,17],
-"matrix__product__float__double_8hpp.html":[7,0,2,0,18],
-"matrix__product__float__double_8hpp.html#a0168edce7007501cb7b66ea44ae6647b":[7,0,2,0,18,6],
-"matrix__product__float__double_8hpp.html#a0aece9314ad7b81303e5b15af37b6171":[7,0,2,0,18,12],
-"matrix__product__float__double_8hpp.html#a0d2a70fee25ea6dacda8b68b9385da3e":[7,0,2,0,18,10],
-"matrix__product__float__double_8hpp.html#a2d34222888cada9267456dd2c202a36b":[7,0,2,0,18,5],
-"matrix__product__float__double_8hpp.html#a40c835130ac9aa8aa9e48d9459b316ea":[7,0,2,0,18,7],
-"matrix__product__float__double_8hpp.html#a55e79356a78c9ef935cc4d11077b905d":[7,0,2,0,18,9],
-"matrix__product__float__double_8hpp.html#a9c961c45d9f8c1be8dce9678f9a6a128":[7,0,2,0,18,11],
-"matrix__product__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,18,4],
-"matrix__product__float__double_8hpp.html#af855327279fd1faab2e6126cbe3d9497":[7,0,2,0,18,8],
-"matrix__product__float__double_8hpp_source.html":[7,0,2,0,18],
-"matrix__product__template_8hpp.html":[7,0,3,2,1,1],
-"matrix__product__template_8hpp.html#a2cc2037be613c430d8976673945a2200":[7,0,3,2,1,1,3],
-"matrix__product__template_8hpp.html#a3eee04070ac5528e391f0f7ed0c423c2":[7,0,3,2,1,1,4],
-"matrix__product__template_8hpp.html#a68a8691a0e3237e2a504e4f016bc29a8":[7,0,3,2,1,1,2],
-"matrix__product__template_8hpp_source.html":[7,0,3,2,1,1],
-"matrix__proxy_8hpp.html":[7,0,3,22],
-"matrix__proxy_8hpp.html#a32c2dc32899cf921fc088bb5dd591e3f":[7,0,3,22,8],
-"matrix__proxy_8hpp.html#a3d33198f0cc7b3e811381c65dc497632":[7,0,3,22,13],
-"matrix__proxy_8hpp.html#a591856f7f277d0cfe1d88f8157b74b7e":[7,0,3,22,4],
-"matrix__proxy_8hpp.html#a5a8af211ade14d32939de1ab88fbfce3":[7,0,3,22,5],
-"matrix__proxy_8hpp.html#a5d0d5a12b085b5909596f1d754f0c9e3":[7,0,3,22,16],
-"matrix__proxy_8hpp.html#a638aa5c54fe703aac75a9613b6fa992a":[7,0,3,22,6],
-"matrix__proxy_8hpp.html#a784184338e26686e21bdf43d66c875ac":[7,0,3,22,11],
-"matrix__proxy_8hpp.html#a8943b9e05480eb6b7bcd11a0061912e3":[7,0,3,22,9],
-"matrix__proxy_8hpp.html#a99b5ce1b764503f97c07405b6a937fc7":[7,0,3,22,7],
-"matrix__proxy_8hpp.html#adc45a895937fe299100e2b235a442748":[7,0,3,22,12],
-"matrix__proxy_8hpp.html#ae9c089715c733e9e42ac80ee5fc99e29":[7,0,3,22,14],
-"matrix__proxy_8hpp.html#af2902ac57885aecf018516bc72fbab09":[7,0,3,22,10],
-"matrix__proxy_8hpp.html#afa9683f0ed709a227c267e33b3195ec2":[7,0,3,22,15],
-"matrix__proxy_8hpp_source.html":[7,0,3,22],
-"matrix__row__double_8cpp.html":[7,0,2,0,19],
-"matrix__row__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,19,0],
-"matrix__row__double_8cpp_source.html":[7,0,2,0,19],
-"matrix__row__float_8cpp.html":[7,0,2,0,20],
-"matrix__row__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,20,0],
-"matrix__row__float_8cpp_source.html":[7,0,2,0,20],
-"matrix__row__int_8cpp.html":[7,0,2,0,21],
-"matrix__row__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,21,0],
-"matrix__row__int_8cpp_source.html":[7,0,2,0,21],
-"matrix__size__deducer_8hpp.html":[7,0,3,9,3],
-"matrix__size__deducer_8hpp_source.html":[7,0,3,9,3],
-"matrix__solve_8hpp.html":[7,0,3,4,3,0,10],
-"matrix__solve_8hpp.html#a5db626a3b32b204504f4737f96982427":[7,0,3,4,3,0,10,1],
-"matrix__solve_8hpp_source.html":[7,0,3,4,3,0,10]
+"matrix__operations__row_8hpp.html#aef28890380b6a246d556390c13e26a61":[7,0,3,4,0,13,22]
 };
