@@ -1,5 +1,66 @@
 var NAVTREEINDEX17 =
 {
+"matrix__operations__row_8hpp.html#af2b44cf9690bfb3f9e5dff5b26b607e9":[7,0,3,4,0,13,35],
+"matrix__operations__row_8hpp.html#af7f5b871860c650a17d06404fe61f9ac":[7,0,3,4,0,13,27],
+"matrix__operations__row_8hpp_source.html":[7,0,3,4,0,13],
+"matrix__product_8hpp.html":[7,0,3,2,0,3],
+"matrix__product_8hpp.html#a07786a0a76651ba3c30d60b7ae5ad6d0":[7,0,3,2,0,3,3],
+"matrix__product_8hpp.html#a0eef9981c2c419b5b0b6fb4f96dff088":[7,0,3,2,0,3,2],
+"matrix__product_8hpp.html#a6f63b3563756b4961647fe3ada8790d5":[7,0,3,2,0,3,1],
+"matrix__product_8hpp.html#a92cf5f3655b5e3bcb1ddcb9b31123067":[7,0,3,2,0,3,4],
+"matrix__product_8hpp.html#ad45fa18ffaecd758a25649b327a1895b":[7,0,3,2,0,3,0],
+"matrix__product_8hpp_source.html":[7,0,3,2,0,3],
+"matrix__product__double_8cpp.html":[7,0,2,0,16],
+"matrix__product__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,16,0],
+"matrix__product__double_8cpp_source.html":[7,0,2,0,16],
+"matrix__product__float_8cpp.html":[7,0,2,0,17],
+"matrix__product__float_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,17,0],
+"matrix__product__float_8cpp_source.html":[7,0,2,0,17],
+"matrix__product__float__double_8hpp.html":[7,0,2,0,18],
+"matrix__product__float__double_8hpp.html#a0168edce7007501cb7b66ea44ae6647b":[7,0,2,0,18,6],
+"matrix__product__float__double_8hpp.html#a0aece9314ad7b81303e5b15af37b6171":[7,0,2,0,18,12],
+"matrix__product__float__double_8hpp.html#a0d2a70fee25ea6dacda8b68b9385da3e":[7,0,2,0,18,10],
+"matrix__product__float__double_8hpp.html#a2d34222888cada9267456dd2c202a36b":[7,0,2,0,18,5],
+"matrix__product__float__double_8hpp.html#a40c835130ac9aa8aa9e48d9459b316ea":[7,0,2,0,18,7],
+"matrix__product__float__double_8hpp.html#a55e79356a78c9ef935cc4d11077b905d":[7,0,2,0,18,9],
+"matrix__product__float__double_8hpp.html#a9c961c45d9f8c1be8dce9678f9a6a128":[7,0,2,0,18,11],
+"matrix__product__float__double_8hpp.html#aa2c0476a142c9e172a2c18d054b6c210":[7,0,2,0,18,4],
+"matrix__product__float__double_8hpp.html#af855327279fd1faab2e6126cbe3d9497":[7,0,2,0,18,8],
+"matrix__product__float__double_8hpp_source.html":[7,0,2,0,18],
+"matrix__product__template_8hpp.html":[7,0,3,2,1,1],
+"matrix__product__template_8hpp.html#a2cc2037be613c430d8976673945a2200":[7,0,3,2,1,1,3],
+"matrix__product__template_8hpp.html#a3eee04070ac5528e391f0f7ed0c423c2":[7,0,3,2,1,1,4],
+"matrix__product__template_8hpp.html#a68a8691a0e3237e2a504e4f016bc29a8":[7,0,3,2,1,1,2],
+"matrix__product__template_8hpp_source.html":[7,0,3,2,1,1],
+"matrix__proxy_8hpp.html":[7,0,3,22],
+"matrix__proxy_8hpp.html#a32c2dc32899cf921fc088bb5dd591e3f":[7,0,3,22,8],
+"matrix__proxy_8hpp.html#a3d33198f0cc7b3e811381c65dc497632":[7,0,3,22,13],
+"matrix__proxy_8hpp.html#a591856f7f277d0cfe1d88f8157b74b7e":[7,0,3,22,4],
+"matrix__proxy_8hpp.html#a5a8af211ade14d32939de1ab88fbfce3":[7,0,3,22,5],
+"matrix__proxy_8hpp.html#a5d0d5a12b085b5909596f1d754f0c9e3":[7,0,3,22,16],
+"matrix__proxy_8hpp.html#a638aa5c54fe703aac75a9613b6fa992a":[7,0,3,22,6],
+"matrix__proxy_8hpp.html#a784184338e26686e21bdf43d66c875ac":[7,0,3,22,11],
+"matrix__proxy_8hpp.html#a8943b9e05480eb6b7bcd11a0061912e3":[7,0,3,22,9],
+"matrix__proxy_8hpp.html#a99b5ce1b764503f97c07405b6a937fc7":[7,0,3,22,7],
+"matrix__proxy_8hpp.html#adc45a895937fe299100e2b235a442748":[7,0,3,22,12],
+"matrix__proxy_8hpp.html#ae9c089715c733e9e42ac80ee5fc99e29":[7,0,3,22,14],
+"matrix__proxy_8hpp.html#af2902ac57885aecf018516bc72fbab09":[7,0,3,22,10],
+"matrix__proxy_8hpp.html#afa9683f0ed709a227c267e33b3195ec2":[7,0,3,22,15],
+"matrix__proxy_8hpp_source.html":[7,0,3,22],
+"matrix__row__double_8cpp.html":[7,0,2,0,19],
+"matrix__row__double_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,19,0],
+"matrix__row__double_8cpp_source.html":[7,0,2,0,19],
+"matrix__row__float_8cpp.html":[7,0,2,0,20],
+"matrix__row__float_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,20,0],
+"matrix__row__float_8cpp_source.html":[7,0,2,0,20],
+"matrix__row__int_8cpp.html":[7,0,2,0,21],
+"matrix__row__int_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,21,0],
+"matrix__row__int_8cpp_source.html":[7,0,2,0,21],
+"matrix__size__deducer_8hpp.html":[7,0,3,9,3],
+"matrix__size__deducer_8hpp_source.html":[7,0,3,9,3],
+"matrix__solve_8hpp.html":[7,0,3,4,3,0,10],
+"matrix__solve_8hpp.html#a5db626a3b32b204504f4737f96982427":[7,0,3,4,3,0,10,1],
+"matrix__solve_8hpp_source.html":[7,0,3,4,3,0,10],
 "matrix__vector_8cpp.html":[7,0,2,0,22],
 "matrix__vector_8cpp.html#a00412d857cf1280ac59bac80061ccf0a":[7,0,2,0,22,7],
 "matrix__vector_8cpp.html#a0fa2d0d0ec97d6cd1192a960d64d92ec":[7,0,2,0,22,6],
@@ -66,34 +127,34 @@ var NAVTREEINDEX17 =
 "multithreaded__cg_8cpp_source.html":[7,0,0,1,21],
 "multithreaded_cg_8cpp-example.html":[8,20],
 "namespacedetail.html":[5,0,0],
-"namespacemembers.html":[5,1,0,9],
-"namespacemembers.html":[5,1,0,20],
-"namespacemembers.html":[5,1,0,13],
+"namespacemembers.html":[5,1,0,10],
 "namespacemembers.html":[5,1,0,11],
+"namespacemembers.html":[5,1,0,22],
 "namespacemembers.html":[5,1,0,8],
+"namespacemembers.html":[5,1,0,9],
+"namespacemembers.html":[5,1,0,19],
+"namespacemembers.html":[5,1,0,15],
+"namespacemembers.html":[5,1,0,7],
 "namespacemembers.html":[5,1,0],
 "namespacemembers.html":[5,1,0,0],
-"namespacemembers.html":[5,1,0,14],
 "namespacemembers.html":[5,1,0,1],
 "namespacemembers.html":[5,1,0,2],
 "namespacemembers.html":[5,1,0,3],
-"namespacemembers.html":[5,1,0,7],
 "namespacemembers.html":[5,1,0,4],
 "namespacemembers.html":[5,1,0,5],
 "namespacemembers.html":[5,1,0,6],
-"namespacemembers.html":[5,1,0,10],
 "namespacemembers.html":[5,1,0,12],
-"namespacemembers.html":[5,1,0,15],
+"namespacemembers.html":[5,1,0,13],
+"namespacemembers.html":[5,1,0,14],
 "namespacemembers.html":[5,1,0,16],
 "namespacemembers.html":[5,1,0,17],
+"namespacemembers.html":[5,1,0,20],
 "namespacemembers.html":[5,1,0,21],
-"namespacemembers.html":[5,1,0,19],
 "namespacemembers.html":[5,1,0,23],
 "namespacemembers.html":[5,1,0,18],
-"namespacemembers.html":[5,1,0,22],
 "namespacemembers_enum.html":[5,1,4],
 "namespacemembers_eval.html":[5,1,5],
-"namespacemembers_func.html":[5,1,1,14],
+"namespacemembers_func.html":[5,1,1,13],
 "namespacemembers_func.html":[5,1,1],
 "namespacemembers_func.html":[5,1,1,0],
 "namespacemembers_func.html":[5,1,1,1],
@@ -108,7 +169,7 @@ var NAVTREEINDEX17 =
 "namespacemembers_func.html":[5,1,1,10],
 "namespacemembers_func.html":[5,1,1,11],
 "namespacemembers_func.html":[5,1,1,12],
-"namespacemembers_func.html":[5,1,1,13],
+"namespacemembers_func.html":[5,1,1,14],
 "namespacemembers_func.html":[5,1,1,15],
 "namespacemembers_func.html":[5,1,1,16],
 "namespacemembers_func.html":[5,1,1,17],
@@ -128,14 +189,14 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1backend_1_1cpu__ram.html":[6,0,0,0,0],
 "namespaceviennacl_1_1backend_1_1cpu__ram_1_1detail.html":[5,0,1,0,0,0],
 "namespaceviennacl_1_1backend_1_1cpu__ram_1_1detail.html":[6,0,0,0,0,0],
-"namespaceviennacl_1_1backend_1_1cuda.html":[6,0,0,0,1],
 "namespaceviennacl_1_1backend_1_1cuda.html":[5,0,1,0,1],
+"namespaceviennacl_1_1backend_1_1cuda.html":[6,0,0,0,1],
 "namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[5,0,1,0,1,0],
 "namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[6,0,0,0,1,0],
 "namespaceviennacl_1_1backend_1_1detail.html":[6,0,0,0,2],
 "namespaceviennacl_1_1backend_1_1detail.html":[5,0,1,0,2],
-"namespaceviennacl_1_1backend_1_1opencl.html":[6,0,0,0,3],
 "namespaceviennacl_1_1backend_1_1opencl.html":[5,0,1,0,3],
+"namespaceviennacl_1_1backend_1_1opencl.html":[6,0,0,0,3],
 "namespaceviennacl_1_1backend_1_1opencl_1_1detail.html":[5,0,1,0,3,0],
 "namespaceviennacl_1_1detail.html":[6,0,0,1],
 "namespaceviennacl_1_1detail.html":[5,0,1,1],
@@ -145,18 +206,18 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1device__specific.html":[6,0,0,2],
 "namespaceviennacl_1_1device__specific.html":[5,0,1,2],
 "namespaceviennacl_1_1device__specific_1_1autotune.html":[5,0,1,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database.html":[5,0,1,2,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database.html":[6,0,0,2,0],
+"namespaceviennacl_1_1device__specific_1_1builtin__database.html":[5,0,1,2,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[5,0,1,2,1,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[6,0,0,2,0,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[6,0,0,2,0,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[5,0,1,2,1,0,0],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[6,0,0,2,0,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator_1_1fallback.html":[5,0,1,2,1,0,0,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[5,0,1,2,1,0,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[6,0,0,2,0,0,1],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[5,0,1,2,1,0,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu_1_1fallback.html":[5,0,1,2,1,0,1,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[5,0,1,2,1,0,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[6,0,0,2,0,0,2],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[5,0,1,2,1,0,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[5,0,1,2,1,0,2,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[6,0,0,2,0,0,2,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[5,0,1,2,1,0,2,0,0],
@@ -171,83 +232,22 @@ var NAVTREEINDEX17 =
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[5,0,1,2,1,0,2,0,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[6,0,0,2,0,0,2,0,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands_1_1tahiti.html":[5,0,1,2,1,0,2,0,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[5,0,1,2,1,0,2,0,3],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[6,0,0,2,0,0,2,0,3],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[5,0,1,2,1,0,2,0,3],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands_1_1hawaii.html":[5,0,1,2,1,0,2,0,3,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1fallback.html":[5,0,1,2,1,0,2,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[5,0,1,2,1,0,2,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[6,0,0,2,0,0,2,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[5,0,1,2,1,0,2,2,0],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[5,0,1,2,1,0,2,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[6,0,0,2,0,0,2,1,0],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[5,0,1,2,1,0,2,2,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gt__540m.html":[5,0,1,2,1,0,2,2,0,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__470.html":[5,0,1,2,1,0,2,2,0,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__580.html":[5,0,1,2,1,0,2,2,0,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1tesla__c2050.html":[5,0,1,2,1,0,2,2,0,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[6,0,0,2,0,0,2,1,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[5,0,1,2,1,0,2,2,1],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[6,0,0,2,0,0,2,1,1],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler_1_1tesla__k20m.html":[5,0,1,2,1,0,2,2,1,0],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell.html":[5,0,1,2,1,0,2,2,2],
 "namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell.html":[6,0,0,2,0,0,2,1,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell_1_1geforce__gtx__750__ti.html":[5,0,1,2,1,0,2,2,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[5,0,1,2,1,0,2,2,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[6,0,0,2,0,0,2,1,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla_1_1geforce__gtx__260.html":[5,0,1,2,1,0,2,2,3,0],
-"namespaceviennacl_1_1device__specific_1_1detail.html":[5,0,1,2,2],
-"namespaceviennacl_1_1device__specific_1_1profiles.html":[5,0,1,2,3],
-"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[5,0,1,2,4],
-"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
-"namespaceviennacl_1_1device__specific_1_1utils.html":[5,0,1,2,5],
-"namespaceviennacl_1_1device__specific_1_1utils.html":[6,0,0,2,2],
-"namespaceviennacl_1_1io.html":[5,0,1,3],
-"namespaceviennacl_1_1io.html":[6,0,0,3],
-"namespaceviennacl_1_1io_1_1detail.html":[5,0,1,3,0],
-"namespaceviennacl_1_1io_1_1tag.html":[5,0,1,3,1],
-"namespaceviennacl_1_1io_1_1val.html":[5,0,1,3,2],
-"namespaceviennacl_1_1linalg.html":[5,0,1,4],
-"namespaceviennacl_1_1linalg.html":[6,0,0,4],
-"namespaceviennacl_1_1linalg_1_1cuda.html":[5,0,1,4,0],
-"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[5,0,1,4,0,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[5,0,1,4,0,0,0],
-"namespaceviennacl_1_1linalg_1_1detail.html":[6,0,0,4,1],
-"namespaceviennacl_1_1linalg_1_1detail.html":[5,0,1,4,1],
-"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[6,0,0,4,1,0],
-"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[5,0,1,4,1,0],
-"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[5,0,1,4,1,1],
-"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[5,0,1,4,1,2],
-"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[6,0,0,4,1,1],
-"namespaceviennacl_1_1linalg_1_1host__based.html":[5,0,1,4,2],
-"namespaceviennacl_1_1linalg_1_1host__based.html":[6,0,0,4,2],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[5,0,1,4,2,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[5,0,1,4,2,0,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[6,0,0,4,2,0,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,4,2,0,0,0],
-"namespaceviennacl_1_1linalg_1_1kernels.html":[5,0,1,4,3],
-"namespaceviennacl_1_1linalg_1_1opencl.html":[5,0,1,4,4],
-"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,0],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,1],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,1,0],
-"namespaceviennacl_1_1ocl.html":[6,0,0,5],
-"namespaceviennacl_1_1ocl.html":[5,0,1,5],
-"namespaceviennacl_1_1result__of.html":[5,0,1,6],
-"namespaceviennacl_1_1result__of.html":[6,0,0,6],
-"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
-"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
-"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
-"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
-"namespaceviennacl_1_1tools.html":[5,0,1,8],
-"namespaceviennacl_1_1tools.html":[6,0,0,8],
-"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
-"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
-"namespaceviennacl_1_1traits.html":[5,0,1,9],
-"namespaceviennacl_1_1traits.html":[6,0,0,9],
-"nmf_8cpp-example.html":[8,21],
-"nmf_8hpp.html":[7,0,3,4,26],
-"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,26,0]
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell_1_1geforce__gtx__750__ti.html":[5,0,1,2,1,0,2,2,2,0]
 };
