@@ -1,5 +1,66 @@
 var NAVTREEINDEX18 =
 {
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[5,0,1,2,1,0,2,2,3],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[6,0,0,2,0,0,2,1,3],
+"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla_1_1geforce__gtx__260.html":[5,0,1,2,1,0,2,2,3,0],
+"namespaceviennacl_1_1device__specific_1_1detail.html":[5,0,1,2,2],
+"namespaceviennacl_1_1device__specific_1_1profiles.html":[5,0,1,2,3],
+"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
+"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[5,0,1,2,4],
+"namespaceviennacl_1_1device__specific_1_1utils.html":[5,0,1,2,5],
+"namespaceviennacl_1_1device__specific_1_1utils.html":[6,0,0,2,2],
+"namespaceviennacl_1_1io.html":[6,0,0,3],
+"namespaceviennacl_1_1io.html":[5,0,1,3],
+"namespaceviennacl_1_1io_1_1detail.html":[5,0,1,3,0],
+"namespaceviennacl_1_1io_1_1tag.html":[5,0,1,3,1],
+"namespaceviennacl_1_1io_1_1val.html":[5,0,1,3,2],
+"namespaceviennacl_1_1linalg.html":[5,0,1,4],
+"namespaceviennacl_1_1linalg.html":[6,0,0,4],
+"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
+"namespaceviennacl_1_1linalg_1_1cuda.html":[5,0,1,4,0],
+"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
+"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[5,0,1,4,0,0],
+"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[5,0,1,4,0,0,0],
+"namespaceviennacl_1_1linalg_1_1detail.html":[6,0,0,4,1],
+"namespaceviennacl_1_1linalg_1_1detail.html":[5,0,1,4,1],
+"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[6,0,0,4,1,0],
+"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[5,0,1,4,1,0],
+"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[5,0,1,4,1,1],
+"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[5,0,1,4,1,2],
+"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[6,0,0,4,1,1],
+"namespaceviennacl_1_1linalg_1_1host__based.html":[5,0,1,4,2],
+"namespaceviennacl_1_1linalg_1_1host__based.html":[6,0,0,4,2],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[5,0,1,4,2,0],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,0],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[5,0,1,4,2,0,0],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[6,0,0,4,2,0,0],
+"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,4,2,0,0,0],
+"namespaceviennacl_1_1linalg_1_1kernels.html":[5,0,1,4,3],
+"namespaceviennacl_1_1linalg_1_1opencl.html":[5,0,1,4,4],
+"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,0],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,1],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
+"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,1,0],
+"namespaceviennacl_1_1ocl.html":[6,0,0,5],
+"namespaceviennacl_1_1ocl.html":[5,0,1,5],
+"namespaceviennacl_1_1result__of.html":[6,0,0,6],
+"namespaceviennacl_1_1result__of.html":[5,0,1,6],
+"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
+"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
+"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
+"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
+"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
+"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
+"namespaceviennacl_1_1tools.html":[5,0,1,8],
+"namespaceviennacl_1_1tools.html":[6,0,0,8],
+"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
+"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
+"namespaceviennacl_1_1traits.html":[5,0,1,9],
+"namespaceviennacl_1_1traits.html":[6,0,0,9],
+"nmf_8cpp-example.html":[8,21],
+"nmf_8hpp.html":[7,0,3,4,26],
+"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,26,0],
 "nmf_8hpp_source.html":[7,0,3,4,26],
 "norm__1_8hpp.html":[7,0,3,4,27],
 "norm__1_8hpp.html#a18799037aaa2e6b5e1778cdf203a0274":[7,0,3,4,27,1],
@@ -188,66 +249,5 @@ var NAVTREEINDEX18 =
 "opencl_2matrix__operations_8hpp.html#a7e146ec12db4a4ec440d6ca9b8e46b79":[7,0,3,4,3,6,2],
 "opencl_2matrix__operations_8hpp.html#a83f95bb0dba31593bfdea7d48825ef45":[7,0,3,4,3,6,26],
 "opencl_2matrix__operations_8hpp.html#a86b4bd11f0b1f0b701afa9448cbb865f":[7,0,3,4,3,6,30],
-"opencl_2matrix__operations_8hpp.html#a896e84eed510eabefb25c2dc08bffef4":[7,0,3,4,3,6,0],
-"opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528":[7,0,3,4,3,6,3],
-"opencl_2matrix__operations_8hpp.html#a9b46aa01fc67f7d7fbc95056a1f050c6":[7,0,3,4,3,6,1],
-"opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565":[7,0,3,4,3,6,23],
-"opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95":[7,0,3,4,3,6,12],
-"opencl_2matrix__operations_8hpp.html#ab334de39e0a14eec29eef532cf625be9":[7,0,3,4,3,6,19],
-"opencl_2matrix__operations_8hpp.html#ab4be1fe81c4ca79108c4db2d7b23ec2c":[7,0,3,4,3,6,7],
-"opencl_2matrix__operations_8hpp.html#ac04e7aa6506170485722039430d329ab":[7,0,3,4,3,6,14],
-"opencl_2matrix__operations_8hpp.html#ac35599cd7a904c6187e3d1e4c5b2d38b":[7,0,3,4,3,6,35],
-"opencl_2matrix__operations_8hpp.html#ac368f3b6c47973062b06a7b765ca4521":[7,0,3,4,3,6,21],
-"opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170":[7,0,3,4,3,6,10],
-"opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c":[7,0,3,4,3,6,27],
-"opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646":[7,0,3,4,3,6,29],
-"opencl_2matrix__operations_8hpp.html#ae3f1e3bfcb56428f4e73e030ebae7066":[7,0,3,4,3,6,20],
-"opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379":[7,0,3,4,3,6,5],
-"opencl_2matrix__operations_8hpp.html#af22fcf715396698796b26f45bece179e":[7,0,3,4,3,6,17],
-"opencl_2matrix__operations_8hpp.html#af9c69aabdf179456bdf212e4b34e8b9a":[7,0,3,4,3,6,8],
-"opencl_2matrix__operations_8hpp.html#affe958b9b7dc9ad1986e2b2b2cdb757a":[7,0,3,4,3,6,18],
-"opencl_2matrix__operations_8hpp_source.html":[7,0,3,4,3,6],
-"opencl_2misc__operations_8hpp.html":[7,0,3,4,3,7],
-"opencl_2misc__operations_8hpp.html#ad939e77692cf9b3c5746b11ba9ff024c":[7,0,3,4,3,7,0],
-"opencl_2misc__operations_8hpp_source.html":[7,0,3,4,3,7],
-"opencl_2nmf__operations_8hpp.html":[7,0,3,4,3,8],
-"opencl_2nmf__operations_8hpp.html#a9f0c073c618b76460027457d7331ba33":[7,0,3,4,3,8,0],
-"opencl_2nmf__operations_8hpp_source.html":[7,0,3,4,3,8],
-"opencl_2scalar__operations_8hpp.html":[7,0,3,4,3,9],
-"opencl_2scalar__operations_8hpp.html#a11ed680640c9598490f6a98c16828d77":[7,0,3,4,3,9,0],
-"opencl_2scalar__operations_8hpp.html#a54a07e7d66ac02c7879af93ce5eb2336":[7,0,3,4,3,9,2],
-"opencl_2scalar__operations_8hpp.html#ac02d4b9c2ac529bcd8a76c081c9702eb":[7,0,3,4,3,9,1],
-"opencl_2scalar__operations_8hpp.html#af17184fcbab9dbaa872694436946a174":[7,0,3,4,3,9,3],
-"opencl_2scalar__operations_8hpp_source.html":[7,0,3,4,3,9],
-"opencl_2sparse__matrix__operations_8hpp.html":[7,0,3,4,3,10],
-"opencl_2sparse__matrix__operations_8hpp.html#a0a16aa6006192d8f3f127b48bfcf9ca5":[7,0,3,4,3,10,18],
-"opencl_2sparse__matrix__operations_8hpp.html#a144fd7dc25be2029356c24f07f281edc":[7,0,3,4,3,10,0],
-"opencl_2sparse__matrix__operations_8hpp.html#a1b40072f44f7e9bd156d9560ca7ee30e":[7,0,3,4,3,10,11],
-"opencl_2sparse__matrix__operations_8hpp.html#a1fcccd84db8c1659e268e6d7719df94e":[7,0,3,4,3,10,25],
-"opencl_2sparse__matrix__operations_8hpp.html#a20c8cd535c54bba79b1912abce227d04":[7,0,3,4,3,10,22],
-"opencl_2sparse__matrix__operations_8hpp.html#a246453c807f9114ad40e6ae5c22dabc2":[7,0,3,4,3,10,10],
-"opencl_2sparse__matrix__operations_8hpp.html#a256a599dedd093618c9936e85a75b3d4":[7,0,3,4,3,10,24],
-"opencl_2sparse__matrix__operations_8hpp.html#a3a97d7d39ed0063efc0e2a7184c63711":[7,0,3,4,3,10,5],
-"opencl_2sparse__matrix__operations_8hpp.html#a435057e12f3596a3bf78e4267b7f7c00":[7,0,3,4,3,10,21],
-"opencl_2sparse__matrix__operations_8hpp.html#a58540b3dfdf2451f59a8d69b0d503977":[7,0,3,4,3,10,8],
-"opencl_2sparse__matrix__operations_8hpp.html#a66050024d4fd7fe421fdec79b082268e":[7,0,3,4,3,10,3],
-"opencl_2sparse__matrix__operations_8hpp.html#a720d4cb00c0c08602f62608ecaa9a835":[7,0,3,4,3,10,1],
-"opencl_2sparse__matrix__operations_8hpp.html#a72fb925402b34c304e02fb4feafb8bc9":[7,0,3,4,3,10,16],
-"opencl_2sparse__matrix__operations_8hpp.html#a7ecec23db21c19f887742bdecb69b2d3":[7,0,3,4,3,10,13],
-"opencl_2sparse__matrix__operations_8hpp.html#a7f4c33a310f17f3379aac2f88348f85b":[7,0,3,4,3,10,7],
-"opencl_2sparse__matrix__operations_8hpp.html#a82d0e161d210b339dbda37d6ebc6318f":[7,0,3,4,3,10,2],
-"opencl_2sparse__matrix__operations_8hpp.html#a83199d78f9adbf3b16034fc8a093ed38":[7,0,3,4,3,10,15],
-"opencl_2sparse__matrix__operations_8hpp.html#ab533b18fa44834dcb24da21403e151a9":[7,0,3,4,3,10,17],
-"opencl_2sparse__matrix__operations_8hpp.html#ac0ec44510ac05abee01a6b869be68d0c":[7,0,3,4,3,10,20],
-"opencl_2sparse__matrix__operations_8hpp.html#adc9e31f7f23c948acc29e15970acd07f":[7,0,3,4,3,10,9],
-"opencl_2sparse__matrix__operations_8hpp.html#adda9f05f3e9ac885e8603f5eed57db1b":[7,0,3,4,3,10,23],
-"opencl_2sparse__matrix__operations_8hpp.html#ae0b9b74ba21c79a3d9421bc68c74712b":[7,0,3,4,3,10,6],
-"opencl_2sparse__matrix__operations_8hpp.html#ae166d736e11c7a6d102115fcb0dddf03":[7,0,3,4,3,10,19],
-"opencl_2sparse__matrix__operations_8hpp.html#ae83a113e8217c08655530df7d0b846b1":[7,0,3,4,3,10,4],
-"opencl_2sparse__matrix__operations_8hpp.html#af50b89f6d9d21d281be8613a54f7d96e":[7,0,3,4,3,10,12],
-"opencl_2sparse__matrix__operations_8hpp.html#af7d2c1881e671ae1dd573bb49b900c5b":[7,0,3,4,3,10,14],
-"opencl_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,3,10],
-"opencl_2vandermonde__matrix__operations_8hpp.html":[7,0,3,4,3,11],
-"opencl_2vandermonde__matrix__operations_8hpp.html#a4fcce6e27674c9c10dc323440cfbfbb6":[7,0,3,4,3,11,0],
-"opencl_2vandermonde__matrix__operations_8hpp_source.html":[7,0,3,4,3,11]
+"opencl_2matrix__operations_8hpp.html#a896e84eed510eabefb25c2dc08bffef4":[7,0,3,4,3,6,0]
 };
