@@ -1,5 +1,66 @@
 var NAVTREEINDEX19 =
 {
+"opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528":[7,0,3,4,3,6,3],
+"opencl_2matrix__operations_8hpp.html#a9b46aa01fc67f7d7fbc95056a1f050c6":[7,0,3,4,3,6,1],
+"opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565":[7,0,3,4,3,6,23],
+"opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95":[7,0,3,4,3,6,12],
+"opencl_2matrix__operations_8hpp.html#ab334de39e0a14eec29eef532cf625be9":[7,0,3,4,3,6,19],
+"opencl_2matrix__operations_8hpp.html#ab4be1fe81c4ca79108c4db2d7b23ec2c":[7,0,3,4,3,6,7],
+"opencl_2matrix__operations_8hpp.html#ac04e7aa6506170485722039430d329ab":[7,0,3,4,3,6,14],
+"opencl_2matrix__operations_8hpp.html#ac35599cd7a904c6187e3d1e4c5b2d38b":[7,0,3,4,3,6,35],
+"opencl_2matrix__operations_8hpp.html#ac368f3b6c47973062b06a7b765ca4521":[7,0,3,4,3,6,21],
+"opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170":[7,0,3,4,3,6,10],
+"opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c":[7,0,3,4,3,6,27],
+"opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646":[7,0,3,4,3,6,29],
+"opencl_2matrix__operations_8hpp.html#ae3f1e3bfcb56428f4e73e030ebae7066":[7,0,3,4,3,6,20],
+"opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379":[7,0,3,4,3,6,5],
+"opencl_2matrix__operations_8hpp.html#af22fcf715396698796b26f45bece179e":[7,0,3,4,3,6,17],
+"opencl_2matrix__operations_8hpp.html#af9c69aabdf179456bdf212e4b34e8b9a":[7,0,3,4,3,6,8],
+"opencl_2matrix__operations_8hpp.html#affe958b9b7dc9ad1986e2b2b2cdb757a":[7,0,3,4,3,6,18],
+"opencl_2matrix__operations_8hpp_source.html":[7,0,3,4,3,6],
+"opencl_2misc__operations_8hpp.html":[7,0,3,4,3,7],
+"opencl_2misc__operations_8hpp.html#ad939e77692cf9b3c5746b11ba9ff024c":[7,0,3,4,3,7,0],
+"opencl_2misc__operations_8hpp_source.html":[7,0,3,4,3,7],
+"opencl_2nmf__operations_8hpp.html":[7,0,3,4,3,8],
+"opencl_2nmf__operations_8hpp.html#a9f0c073c618b76460027457d7331ba33":[7,0,3,4,3,8,0],
+"opencl_2nmf__operations_8hpp_source.html":[7,0,3,4,3,8],
+"opencl_2scalar__operations_8hpp.html":[7,0,3,4,3,9],
+"opencl_2scalar__operations_8hpp.html#a11ed680640c9598490f6a98c16828d77":[7,0,3,4,3,9,0],
+"opencl_2scalar__operations_8hpp.html#a54a07e7d66ac02c7879af93ce5eb2336":[7,0,3,4,3,9,2],
+"opencl_2scalar__operations_8hpp.html#ac02d4b9c2ac529bcd8a76c081c9702eb":[7,0,3,4,3,9,1],
+"opencl_2scalar__operations_8hpp.html#af17184fcbab9dbaa872694436946a174":[7,0,3,4,3,9,3],
+"opencl_2scalar__operations_8hpp_source.html":[7,0,3,4,3,9],
+"opencl_2sparse__matrix__operations_8hpp.html":[7,0,3,4,3,10],
+"opencl_2sparse__matrix__operations_8hpp.html#a0a16aa6006192d8f3f127b48bfcf9ca5":[7,0,3,4,3,10,18],
+"opencl_2sparse__matrix__operations_8hpp.html#a144fd7dc25be2029356c24f07f281edc":[7,0,3,4,3,10,0],
+"opencl_2sparse__matrix__operations_8hpp.html#a1b40072f44f7e9bd156d9560ca7ee30e":[7,0,3,4,3,10,11],
+"opencl_2sparse__matrix__operations_8hpp.html#a1fcccd84db8c1659e268e6d7719df94e":[7,0,3,4,3,10,25],
+"opencl_2sparse__matrix__operations_8hpp.html#a20c8cd535c54bba79b1912abce227d04":[7,0,3,4,3,10,22],
+"opencl_2sparse__matrix__operations_8hpp.html#a246453c807f9114ad40e6ae5c22dabc2":[7,0,3,4,3,10,10],
+"opencl_2sparse__matrix__operations_8hpp.html#a256a599dedd093618c9936e85a75b3d4":[7,0,3,4,3,10,24],
+"opencl_2sparse__matrix__operations_8hpp.html#a3a97d7d39ed0063efc0e2a7184c63711":[7,0,3,4,3,10,5],
+"opencl_2sparse__matrix__operations_8hpp.html#a435057e12f3596a3bf78e4267b7f7c00":[7,0,3,4,3,10,21],
+"opencl_2sparse__matrix__operations_8hpp.html#a58540b3dfdf2451f59a8d69b0d503977":[7,0,3,4,3,10,8],
+"opencl_2sparse__matrix__operations_8hpp.html#a66050024d4fd7fe421fdec79b082268e":[7,0,3,4,3,10,3],
+"opencl_2sparse__matrix__operations_8hpp.html#a720d4cb00c0c08602f62608ecaa9a835":[7,0,3,4,3,10,1],
+"opencl_2sparse__matrix__operations_8hpp.html#a72fb925402b34c304e02fb4feafb8bc9":[7,0,3,4,3,10,16],
+"opencl_2sparse__matrix__operations_8hpp.html#a7ecec23db21c19f887742bdecb69b2d3":[7,0,3,4,3,10,13],
+"opencl_2sparse__matrix__operations_8hpp.html#a7f4c33a310f17f3379aac2f88348f85b":[7,0,3,4,3,10,7],
+"opencl_2sparse__matrix__operations_8hpp.html#a82d0e161d210b339dbda37d6ebc6318f":[7,0,3,4,3,10,2],
+"opencl_2sparse__matrix__operations_8hpp.html#a83199d78f9adbf3b16034fc8a093ed38":[7,0,3,4,3,10,15],
+"opencl_2sparse__matrix__operations_8hpp.html#ab533b18fa44834dcb24da21403e151a9":[7,0,3,4,3,10,17],
+"opencl_2sparse__matrix__operations_8hpp.html#ac0ec44510ac05abee01a6b869be68d0c":[7,0,3,4,3,10,20],
+"opencl_2sparse__matrix__operations_8hpp.html#adc9e31f7f23c948acc29e15970acd07f":[7,0,3,4,3,10,9],
+"opencl_2sparse__matrix__operations_8hpp.html#adda9f05f3e9ac885e8603f5eed57db1b":[7,0,3,4,3,10,23],
+"opencl_2sparse__matrix__operations_8hpp.html#ae0b9b74ba21c79a3d9421bc68c74712b":[7,0,3,4,3,10,6],
+"opencl_2sparse__matrix__operations_8hpp.html#ae166d736e11c7a6d102115fcb0dddf03":[7,0,3,4,3,10,19],
+"opencl_2sparse__matrix__operations_8hpp.html#ae83a113e8217c08655530df7d0b846b1":[7,0,3,4,3,10,4],
+"opencl_2sparse__matrix__operations_8hpp.html#af50b89f6d9d21d281be8613a54f7d96e":[7,0,3,4,3,10,12],
+"opencl_2sparse__matrix__operations_8hpp.html#af7d2c1881e671ae1dd573bb49b900c5b":[7,0,3,4,3,10,14],
+"opencl_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,3,10],
+"opencl_2vandermonde__matrix__operations_8hpp.html":[7,0,3,4,3,11],
+"opencl_2vandermonde__matrix__operations_8hpp.html#a4fcce6e27674c9c10dc323440cfbfbb6":[7,0,3,4,3,11,0],
+"opencl_2vandermonde__matrix__operations_8hpp_source.html":[7,0,3,4,3,11],
 "opencl_2vector__operations_8hpp.html":[7,0,3,4,3,12],
 "opencl_2vector__operations_8hpp.html#a03243122a1a2c45b41fb02d04ce2f21b":[7,0,3,4,3,12,0],
 "opencl_2vector__operations_8hpp.html#a23aad63531d04768c6d28c3f25ce64f4":[7,0,3,4,3,12,4],
@@ -188,66 +249,5 @@ var NAVTREEINDEX19 =
 "row__major_8hpp.html#a168a8edd0b615b77f2f1da2da28f8ffb":[7,0,3,10,4,0],
 "row__major_8hpp.html#a2453eef1148e0ebf3c049dd8060c71d6":[7,0,3,10,4,2],
 "row__major_8hpp.html#ac61b7efb6bd14f87ad19a7b7a9f824ad":[7,0,3,10,4,1],
-"row__major_8hpp_source.html":[7,0,3,10,4],
-"row__scaling_8hpp.html":[7,0,3,4,37],
-"row__scaling_8hpp_source.html":[7,0,3,4,37],
-"row__wise__reduction_8hpp.html":[7,0,3,2,0,5],
-"row__wise__reduction_8hpp.html#acc860d5de6af4b72c61b60bdc7a9a174":[7,0,3,2,0,5,2],
-"row__wise__reduction_8hpp.html#ada1a0edeebe3cf05071c547d32b522b6":[7,0,3,2,0,5,1],
-"row__wise__reduction_8hpp.html#add2b8c1f8c4530be6ea83ea0e81fb44d":[7,0,3,2,0,5,0],
-"row__wise__reduction_8hpp_source.html":[7,0,3,2,0,5],
-"row__wise__reduction__template_8hpp.html":[7,0,3,2,1,3],
-"row__wise__reduction__template_8hpp_source.html":[7,0,3,2,1,3],
-"scalar_8cpp.html":[7,0,2,0,28],
-"scalar_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,28,2],
-"scalar_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,28,1],
-"scalar_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,28,0],
-"scalar_8cpp_source.html":[7,0,2,0,28],
-"scalar_8hpp.html":[7,0,3,24],
-"scalar_8hpp.html#a60033f942852a5e462d920c62eeaced9":[7,0,3,24,10],
-"scalar_8hpp.html#acd36bb3a442eb6ef1ade2aad14be5ff9":[7,0,3,24,9],
-"scalar_8hpp_source.html":[7,0,3,24],
-"scalar__operations_8hpp.html":[7,0,3,4,38],
-"scalar__operations_8hpp.html#a02e0b6945112135e1e023cd9da9c8805":[7,0,3,4,38,2],
-"scalar__operations_8hpp.html#a04dc6e11ec77f197ac82ec2b2580b672":[7,0,3,4,38,1],
-"scalar__operations_8hpp.html#a376a98ceee0ab85880a4b5a9c343d802":[7,0,3,4,38,3],
-"scalar__operations_8hpp.html#ab2573d0a189f441a1ee62209ef7c1cfa":[7,0,3,4,38,0],
-"scalar__operations_8hpp_source.html":[7,0,3,4,38],
-"scan_8cpp.html":[7,0,2,0,29],
-"scan_8cpp.html#a323f3ef0f263f9f6315bfec0ec307af9":[7,0,2,0,29,6],
-"scan_8cpp.html#a580b3d505aa6fd5df6e51a0ff64aca48":[7,0,2,0,29,7],
-"scan_8cpp.html#a6ebf6899d6c1c8b7b9d09be872c05aae":[7,0,2,0,29,0],
-"scan_8cpp.html#a87483649bc87ee73edfc9c5f37db9128":[7,0,2,0,29,5],
-"scan_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,29,1],
-"scan_8cpp.html#a9941a4630f455cbe6a6a252d2421f77a":[7,0,2,0,29,3],
-"scan_8cpp.html#ab54e2986a8338188b22ee39797298ed2":[7,0,2,0,29,8],
-"scan_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,29,2],
-"scan_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,29,4],
-"scan_8cpp_source.html":[7,0,2,0,29],
-"scheduler_2execute_8hpp.html":[7,0,3,8,0],
-"scheduler_2execute_8hpp.html#a29f7fd027b643066b775562af636e8d3":[7,0,3,8,0,1],
-"scheduler_2execute_8hpp.html#a73d449eded09d4481110844e6c8b471d":[7,0,3,8,0,3],
-"scheduler_2execute_8hpp.html#a7969d99d3180d9e8b3f250f8abe04242":[7,0,3,8,0,2],
-"scheduler_2execute_8hpp.html#a7c54b25dd9b7af74a98800e92035d398":[7,0,3,8,0,0],
-"scheduler_2execute_8hpp_source.html":[7,0,3,8,0],
-"scheduler_2forwards_8h.html":[7,0,3,8,10],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914":[7,0,3,8,10,82],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a0eb2fa398999ffdb62792cc553a25f23":[7,0,3,8,10,82,0],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a45aad1cb2159d71779449d7152217727":[7,0,3,8,10,82,2],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a7353714a084a9f822edc26fe2bca4f8a":[7,0,3,8,10,82,4],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a894ffb1bc4900d3f06ec728e04de4e01":[7,0,3,8,10,82,3],
-"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a8dacc89f3e43c4ca287b23d5d89b75c5":[7,0,3,8,10,82,1],
-"scheduler_2forwards_8h.html#a29f7fd027b643066b775562af636e8d3":[7,0,3,8,10,83],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35":[7,0,3,8,10,78],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a075c87768842f364303bb64127453b2d":[7,0,3,8,10,78,42],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a0c239b137d9dd360a6aedfe5f88dca70":[7,0,3,8,10,78,33],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a0cb4cc0174769a4d12a11a040dba7215":[7,0,3,8,10,78,58],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a136719a66d82a037a875a4b1f8411cf0":[7,0,3,8,10,78,18],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1b7ffa7de0c66231664936fc14b3c4f8":[7,0,3,8,10,78,36],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1f934789dd600ee73f7c22bcd8273d61":[7,0,3,8,10,78,13],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1fa11cb4db8cb099a55fafbe7931a5d4":[7,0,3,8,10,78,45],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a23a42cb76dedaa2d0adf725408da2abd":[7,0,3,8,10,78,51],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a23a62bf8d1c42288dfc0e7a8470c1402":[7,0,3,8,10,78,34],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a247f91a6bec2085f3b31f9ec32b76f1b":[7,0,3,8,10,78,46],
-"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a29c513ff24ce91bb30234dc7f23d151a":[7,0,3,8,10,78,55]
+"row__major_8hpp_source.html":[7,0,3,10,4]
 };
