@@ -1,5 +1,66 @@
 var NAVTREEINDEX20 =
 {
+"row__scaling_8hpp.html":[7,0,3,4,37],
+"row__scaling_8hpp_source.html":[7,0,3,4,37],
+"row__wise__reduction_8hpp.html":[7,0,3,2,0,5],
+"row__wise__reduction_8hpp.html#acc860d5de6af4b72c61b60bdc7a9a174":[7,0,3,2,0,5,2],
+"row__wise__reduction_8hpp.html#ada1a0edeebe3cf05071c547d32b522b6":[7,0,3,2,0,5,1],
+"row__wise__reduction_8hpp.html#add2b8c1f8c4530be6ea83ea0e81fb44d":[7,0,3,2,0,5,0],
+"row__wise__reduction_8hpp_source.html":[7,0,3,2,0,5],
+"row__wise__reduction__template_8hpp.html":[7,0,3,2,1,3],
+"row__wise__reduction__template_8hpp_source.html":[7,0,3,2,1,3],
+"scalar_8cpp.html":[7,0,2,0,28],
+"scalar_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,28,2],
+"scalar_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,28,1],
+"scalar_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,28,0],
+"scalar_8cpp_source.html":[7,0,2,0,28],
+"scalar_8hpp.html":[7,0,3,24],
+"scalar_8hpp.html#a60033f942852a5e462d920c62eeaced9":[7,0,3,24,10],
+"scalar_8hpp.html#acd36bb3a442eb6ef1ade2aad14be5ff9":[7,0,3,24,9],
+"scalar_8hpp_source.html":[7,0,3,24],
+"scalar__operations_8hpp.html":[7,0,3,4,38],
+"scalar__operations_8hpp.html#a02e0b6945112135e1e023cd9da9c8805":[7,0,3,4,38,2],
+"scalar__operations_8hpp.html#a04dc6e11ec77f197ac82ec2b2580b672":[7,0,3,4,38,1],
+"scalar__operations_8hpp.html#a376a98ceee0ab85880a4b5a9c343d802":[7,0,3,4,38,3],
+"scalar__operations_8hpp.html#ab2573d0a189f441a1ee62209ef7c1cfa":[7,0,3,4,38,0],
+"scalar__operations_8hpp_source.html":[7,0,3,4,38],
+"scan_8cpp.html":[7,0,2,0,29],
+"scan_8cpp.html#a323f3ef0f263f9f6315bfec0ec307af9":[7,0,2,0,29,6],
+"scan_8cpp.html#a580b3d505aa6fd5df6e51a0ff64aca48":[7,0,2,0,29,7],
+"scan_8cpp.html#a6ebf6899d6c1c8b7b9d09be872c05aae":[7,0,2,0,29,0],
+"scan_8cpp.html#a87483649bc87ee73edfc9c5f37db9128":[7,0,2,0,29,5],
+"scan_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,29,1],
+"scan_8cpp.html#a9941a4630f455cbe6a6a252d2421f77a":[7,0,2,0,29,3],
+"scan_8cpp.html#ab54e2986a8338188b22ee39797298ed2":[7,0,2,0,29,8],
+"scan_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,29,2],
+"scan_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,29,4],
+"scan_8cpp_source.html":[7,0,2,0,29],
+"scheduler_2execute_8hpp.html":[7,0,3,8,0],
+"scheduler_2execute_8hpp.html#a29f7fd027b643066b775562af636e8d3":[7,0,3,8,0,1],
+"scheduler_2execute_8hpp.html#a73d449eded09d4481110844e6c8b471d":[7,0,3,8,0,3],
+"scheduler_2execute_8hpp.html#a7969d99d3180d9e8b3f250f8abe04242":[7,0,3,8,0,2],
+"scheduler_2execute_8hpp.html#a7c54b25dd9b7af74a98800e92035d398":[7,0,3,8,0,0],
+"scheduler_2execute_8hpp_source.html":[7,0,3,8,0],
+"scheduler_2forwards_8h.html":[7,0,3,8,10],
+"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914":[7,0,3,8,10,82],
+"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a0eb2fa398999ffdb62792cc553a25f23":[7,0,3,8,10,82,0],
+"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a45aad1cb2159d71779449d7152217727":[7,0,3,8,10,82,2],
+"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a7353714a084a9f822edc26fe2bca4f8a":[7,0,3,8,10,82,4],
+"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a894ffb1bc4900d3f06ec728e04de4e01":[7,0,3,8,10,82,3],
+"scheduler_2forwards_8h.html#a02ec095c8e7689f4fa0a0937f8f10914a8dacc89f3e43c4ca287b23d5d89b75c5":[7,0,3,8,10,82,1],
+"scheduler_2forwards_8h.html#a29f7fd027b643066b775562af636e8d3":[7,0,3,8,10,83],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35":[7,0,3,8,10,78],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a075c87768842f364303bb64127453b2d":[7,0,3,8,10,78,42],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a0c239b137d9dd360a6aedfe5f88dca70":[7,0,3,8,10,78,33],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a0cb4cc0174769a4d12a11a040dba7215":[7,0,3,8,10,78,58],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a136719a66d82a037a875a4b1f8411cf0":[7,0,3,8,10,78,18],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1b7ffa7de0c66231664936fc14b3c4f8":[7,0,3,8,10,78,36],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1f934789dd600ee73f7c22bcd8273d61":[7,0,3,8,10,78,13],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a1fa11cb4db8cb099a55fafbe7931a5d4":[7,0,3,8,10,78,45],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a23a42cb76dedaa2d0adf725408da2abd":[7,0,3,8,10,78,51],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a23a62bf8d1c42288dfc0e7a8470c1402":[7,0,3,8,10,78,34],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a247f91a6bec2085f3b31f9ec32b76f1b":[7,0,3,8,10,78,46],
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a29c513ff24ce91bb30234dc7f23d151a":[7,0,3,8,10,78,55],
 "scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a2ab4584ae045d23d13a57e2ce3b505bd":[7,0,3,8,10,78,19],
 "scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a2bfc469fbd12756a21b5d8d66578ae2c":[7,0,3,8,10,78,11],
 "scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a398108639e7d778512959c8d0cc7f112":[7,0,3,8,10,78,9],
@@ -91,6 +152,14 @@ var NAVTREEINDEX20 =
 "scheduler_2forwards_8h.html#ae691d1992521cd384c3dad19ac46a6c4acc68622943068fc12d1d3d2d76dcc731":[7,0,3,8,10,81,0],
 "scheduler_2forwards_8h_source.html":[7,0,3,8,10],
 "scheduler_8cpp-example.html":[8,25],
+"scheduler__matrix_8cpp.html":[7,0,2,0,30],
+"scheduler__matrix_8cpp.html#a0fc34f49b0e6eaed5e5c3accb409b1d1":[7,0,2,0,30,3],
+"scheduler__matrix_8cpp.html#a3eeb8dff5404f0ba9ff74f4ee5b9095d":[7,0,2,0,30,5],
+"scheduler__matrix_8cpp.html#a931ce6a0abe4400075e9db9f45456a6d":[7,0,2,0,30,2],
+"scheduler__matrix_8cpp.html#ab3fef5684e0d6531328592e7028143d9":[7,0,2,0,30,4],
+"scheduler__matrix_8cpp.html#adb1975f54982e94e2bcd2db1577c1e67":[7,0,2,0,30,0],
+"scheduler__matrix_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,30,1],
+"scheduler__matrix_8cpp_source.html":[7,0,2,0,30],
 "scheduler__matrix__matrix_8cpp.html":[7,0,2,0,31],
 "scheduler__matrix__matrix_8cpp.html#a23a3d893dfd2dd3b809ce30cee04069a":[7,0,2,0,31,2],
 "scheduler__matrix__matrix_8cpp.html#a2a0fa312c59f09be09409aa4ae5ba438":[7,0,2,0,31,7],
@@ -180,74 +249,5 @@ var NAVTREEINDEX20 =
 "sliced__ell__matrix_8hpp_source.html":[7,0,3,26],
 "small__matrix_8hpp.html":[7,0,3,4,1,3,4],
 "small__matrix_8hpp.html#a75d03e25caf5c1957fab6334c0d91c31":[7,0,3,4,1,3,4,1],
-"small__matrix_8hpp.html#ad6543d2795df36b19080b431aca258b1":[7,0,3,4,1,3,4,0],
-"small__matrix_8hpp_source.html":[7,0,3,4,1,3,4],
-"solver_8cpp.html":[7,0,0,0,6],
-"solver_8cpp.html#a1f843c90fc96fbef2ece33a7a818fcfd":[7,0,0,0,6,3],
-"solver_8cpp.html#a6779b1f6aa4bd394fd8a8dff6ba18476":[7,0,0,0,6,6],
-"solver_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,0,0,6,1],
-"solver_8cpp.html#a9b90f6647b9bb73122488fbba0c0f4b3":[7,0,0,0,6,4],
-"solver_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18":[7,0,0,0,6,0],
-"solver_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,6,5],
-"solver_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,0,0,6,2],
-"solver_8cpp.html#afadbea4317c8f42f54d4622cf0a1829f":[7,0,0,0,6,7],
-"solver_8cpp_source.html":[7,0,0,0,6],
-"spai-dynamic_8hpp.html":[7,0,3,4,1,3,5],
-"spai-dynamic_8hpp.html#a030bd1b3e7fb96ca912e86e190e7cb9a":[7,0,3,4,1,3,5,4],
-"spai-dynamic_8hpp.html#a04f2cf7cafff244de64e0f5e54507963":[7,0,3,4,1,3,5,10],
-"spai-dynamic_8hpp.html#a2a6a2326a67eed3c453880e1a9887b55":[7,0,3,4,1,3,5,1],
-"spai-dynamic_8hpp.html#a453c8768ecde4b09adaff9e130d8f3ed":[7,0,3,4,1,3,5,11],
-"spai-dynamic_8hpp.html#a4ed76d80fb1f213aa6ac3df4756a173a":[7,0,3,4,1,3,5,9],
-"spai-dynamic_8hpp.html#a76346f2d37c99cdda3737ad76942bdb2":[7,0,3,4,1,3,5,13],
-"spai-dynamic_8hpp.html#a8a63d610aebbcd68a76468e22e33ac83":[7,0,3,4,1,3,5,5],
-"spai-dynamic_8hpp.html#a8ec10e331a15985f8d5fd3891332d60d":[7,0,3,4,1,3,5,8],
-"spai-dynamic_8hpp.html#aa76c2d795781c203de394c73c62b0420":[7,0,3,4,1,3,5,12],
-"spai-dynamic_8hpp.html#aac7edbe83326cd05affc0ac8e68c6a2d":[7,0,3,4,1,3,5,6],
-"spai-dynamic_8hpp.html#ab97e4f8849c15f3dea55584f4a1fcc85":[7,0,3,4,1,3,5,2],
-"spai-dynamic_8hpp.html#ada295fb9ae10dcc0bc6728be3c006cd4":[7,0,3,4,1,3,5,3],
-"spai-dynamic_8hpp.html#ae53274082aa46458002bff392267fbaa":[7,0,3,4,1,3,5,7],
-"spai-dynamic_8hpp_source.html":[7,0,3,4,1,3,5],
-"spai-static_8hpp.html":[7,0,3,4,1,3,6],
-"spai-static_8hpp.html#a04773e48e2b2afdbeee55fdda179ff5c":[7,0,3,4,1,3,6,4],
-"spai-static_8hpp.html#a6ae3f653e6eacca58ccf36e972017d36":[7,0,3,4,1,3,6,1],
-"spai-static_8hpp.html#a6b348879ddf3c802a8fe03cc2539b43c":[7,0,3,4,1,3,6,0],
-"spai-static_8hpp.html#aa448e23270c2fd92b9f6c9c4df359a6a":[7,0,3,4,1,3,6,5],
-"spai-static_8hpp.html#ab19057ee4834fe816e96f0d52863cc45":[7,0,3,4,1,3,6,2],
-"spai-static_8hpp.html#ab8477f662432b03c92b4287e3a4db3d6":[7,0,3,4,1,3,6,3],
-"spai-static_8hpp.html#ae548ee7e9301caf3cc50ada65389bce0":[7,0,3,4,1,3,6,6],
-"spai-static_8hpp_source.html":[7,0,3,4,1,3,6],
-"spai_8cpp-example.html":[8,26],
-"spai_8cpp.html":[7,0,0,1,29],
-"spai_8cpp_source.html":[7,0,0,1,29],
-"spai_8hpp.html":[7,0,3,4,39],
-"spai_8hpp.html#a1938ef67659d8ba96e9b9517e680cccf":[7,0,3,4,39,5],
-"spai_8hpp.html#ab87a5b5e7c60eee5c2e45f9ab21c935c":[7,0,3,4,39,4],
-"spai_8hpp_source.html":[7,0,3,4,39],
-"spai__tag_8hpp.html":[7,0,3,4,1,3,8],
-"spai__tag_8hpp_source.html":[7,0,3,4,1,3,8],
-"sparse_8cpp-example.html":[8,27],
-"sparse__matrix__operations_8hpp.html":[7,0,3,4,40],
-"sparse__matrix__operations_8hpp.html#a02babae1af157516bd1e92d28c711957":[7,0,3,4,40,2],
-"sparse__matrix__operations_8hpp.html#a07ddf85f2f61d198160ffd13bf7aebac":[7,0,3,4,40,7],
-"sparse__matrix__operations_8hpp.html#a2cd904fcd01a99005ca9f83f3c696b41":[7,0,3,4,40,1],
-"sparse__matrix__operations_8hpp.html#a2ee5dd77d41040e0a937a60346475b84":[7,0,3,4,40,9],
-"sparse__matrix__operations_8hpp.html#a5309df539f189a889f45f5e25098930f":[7,0,3,4,40,4],
-"sparse__matrix__operations_8hpp.html#a5ef8943054b39077573f94234980bd0f":[7,0,3,4,40,8],
-"sparse__matrix__operations_8hpp.html#a926494a1bd9b3c66def0c860bf564b42":[7,0,3,4,40,0],
-"sparse__matrix__operations_8hpp.html#ab85e3912a40d5d479835e7608808f07e":[7,0,3,4,40,3],
-"sparse__matrix__operations_8hpp.html#ac6448c1d1c0cdb1010a146c0238c8d20":[7,0,3,4,40,6],
-"sparse__matrix__operations_8hpp.html#af0e2c481d5920946ce6fce0874cd8138":[7,0,3,4,40,5],
-"sparse__matrix__operations_8hpp_source.html":[7,0,3,4,40],
-"sparse__matrix__operations__solve_8hpp.html":[7,0,3,4,0,18],
-"sparse__matrix__operations__solve_8hpp.html#a0fdaf16a87e07c124373a52254c173ad":[7,0,3,4,0,18,4],
-"sparse__matrix__operations__solve_8hpp.html#a1c1b2731df8afb9c3f915b9d0d639753":[7,0,3,4,0,18,2],
-"sparse__matrix__operations__solve_8hpp.html#a233ac7fb62f71e33255e7c9cba345ed7":[7,0,3,4,0,18,9],
-"sparse__matrix__operations__solve_8hpp.html#a8000df1bca574a42318a5b7edbe6b97f":[7,0,3,4,0,18,0],
-"sparse__matrix__operations__solve_8hpp.html#a9abc8d66c512f9124bbb993eee4b5586":[7,0,3,4,0,18,1],
-"sparse__matrix__operations__solve_8hpp.html#aa12dd112fa13a12a456cf19945adc9c0":[7,0,3,4,0,18,5],
-"sparse__matrix__operations__solve_8hpp.html#aa52e774f145abd8da05d99dc722acc28":[7,0,3,4,0,18,3],
-"sparse__matrix__operations__solve_8hpp.html#acddaf2035898ce13496e3494dd22cd69":[7,0,3,4,0,18,6],
-"sparse__matrix__operations__solve_8hpp.html#adcf87e5dfd0c05d2d88c7be8bf81395a":[7,0,3,4,0,18,11],
-"sparse__matrix__operations__solve_8hpp.html#ae4caa7ec537c21ce87da42e70289633c":[7,0,3,4,0,18,8],
-"sparse__matrix__operations__solve_8hpp.html#af45d44700626214f9474848e09fb9126":[7,0,3,4,0,18,7]
+"small__matrix_8hpp.html#ad6543d2795df36b19080b431aca258b1":[7,0,3,4,1,3,4,0]
 };
