@@ -1,5 +1,74 @@
 var NAVTREEINDEX21 =
 {
+"small__matrix_8hpp_source.html":[7,0,3,4,1,3,4],
+"solver_8cpp.html":[7,0,0,0,6],
+"solver_8cpp.html#a1f843c90fc96fbef2ece33a7a818fcfd":[7,0,0,0,6,3],
+"solver_8cpp.html#a6779b1f6aa4bd394fd8a8dff6ba18476":[7,0,0,0,6,6],
+"solver_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,0,0,6,1],
+"solver_8cpp.html#a9b90f6647b9bb73122488fbba0c0f4b3":[7,0,0,0,6,4],
+"solver_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18":[7,0,0,0,6,0],
+"solver_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,6,5],
+"solver_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,0,0,6,2],
+"solver_8cpp.html#afadbea4317c8f42f54d4622cf0a1829f":[7,0,0,0,6,7],
+"solver_8cpp_source.html":[7,0,0,0,6],
+"spai-dynamic_8hpp.html":[7,0,3,4,1,3,5],
+"spai-dynamic_8hpp.html#a030bd1b3e7fb96ca912e86e190e7cb9a":[7,0,3,4,1,3,5,4],
+"spai-dynamic_8hpp.html#a04f2cf7cafff244de64e0f5e54507963":[7,0,3,4,1,3,5,10],
+"spai-dynamic_8hpp.html#a2a6a2326a67eed3c453880e1a9887b55":[7,0,3,4,1,3,5,1],
+"spai-dynamic_8hpp.html#a453c8768ecde4b09adaff9e130d8f3ed":[7,0,3,4,1,3,5,11],
+"spai-dynamic_8hpp.html#a4ed76d80fb1f213aa6ac3df4756a173a":[7,0,3,4,1,3,5,9],
+"spai-dynamic_8hpp.html#a76346f2d37c99cdda3737ad76942bdb2":[7,0,3,4,1,3,5,13],
+"spai-dynamic_8hpp.html#a8a63d610aebbcd68a76468e22e33ac83":[7,0,3,4,1,3,5,5],
+"spai-dynamic_8hpp.html#a8ec10e331a15985f8d5fd3891332d60d":[7,0,3,4,1,3,5,8],
+"spai-dynamic_8hpp.html#aa76c2d795781c203de394c73c62b0420":[7,0,3,4,1,3,5,12],
+"spai-dynamic_8hpp.html#aac7edbe83326cd05affc0ac8e68c6a2d":[7,0,3,4,1,3,5,6],
+"spai-dynamic_8hpp.html#ab97e4f8849c15f3dea55584f4a1fcc85":[7,0,3,4,1,3,5,2],
+"spai-dynamic_8hpp.html#ada295fb9ae10dcc0bc6728be3c006cd4":[7,0,3,4,1,3,5,3],
+"spai-dynamic_8hpp.html#ae53274082aa46458002bff392267fbaa":[7,0,3,4,1,3,5,7],
+"spai-dynamic_8hpp_source.html":[7,0,3,4,1,3,5],
+"spai-static_8hpp.html":[7,0,3,4,1,3,6],
+"spai-static_8hpp.html#a04773e48e2b2afdbeee55fdda179ff5c":[7,0,3,4,1,3,6,4],
+"spai-static_8hpp.html#a6ae3f653e6eacca58ccf36e972017d36":[7,0,3,4,1,3,6,1],
+"spai-static_8hpp.html#a6b348879ddf3c802a8fe03cc2539b43c":[7,0,3,4,1,3,6,0],
+"spai-static_8hpp.html#aa448e23270c2fd92b9f6c9c4df359a6a":[7,0,3,4,1,3,6,5],
+"spai-static_8hpp.html#ab19057ee4834fe816e96f0d52863cc45":[7,0,3,4,1,3,6,2],
+"spai-static_8hpp.html#ab8477f662432b03c92b4287e3a4db3d6":[7,0,3,4,1,3,6,3],
+"spai-static_8hpp.html#ae548ee7e9301caf3cc50ada65389bce0":[7,0,3,4,1,3,6,6],
+"spai-static_8hpp_source.html":[7,0,3,4,1,3,6],
+"spai_8cpp-example.html":[8,26],
+"spai_8cpp.html":[7,0,0,1,28],
+"spai_8cpp_source.html":[7,0,0,1,28],
+"spai_8hpp.html":[7,0,3,4,39],
+"spai_8hpp.html#a1938ef67659d8ba96e9b9517e680cccf":[7,0,3,4,39,5],
+"spai_8hpp.html#ab87a5b5e7c60eee5c2e45f9ab21c935c":[7,0,3,4,39,4],
+"spai_8hpp_source.html":[7,0,3,4,39],
+"spai__tag_8hpp.html":[7,0,3,4,1,3,8],
+"spai__tag_8hpp_source.html":[7,0,3,4,1,3,8],
+"sparse_8cpp-example.html":[8,27],
+"sparse__matrix__operations_8hpp.html":[7,0,3,4,40],
+"sparse__matrix__operations_8hpp.html#a02babae1af157516bd1e92d28c711957":[7,0,3,4,40,2],
+"sparse__matrix__operations_8hpp.html#a07ddf85f2f61d198160ffd13bf7aebac":[7,0,3,4,40,7],
+"sparse__matrix__operations_8hpp.html#a2cd904fcd01a99005ca9f83f3c696b41":[7,0,3,4,40,1],
+"sparse__matrix__operations_8hpp.html#a2ee5dd77d41040e0a937a60346475b84":[7,0,3,4,40,9],
+"sparse__matrix__operations_8hpp.html#a5309df539f189a889f45f5e25098930f":[7,0,3,4,40,4],
+"sparse__matrix__operations_8hpp.html#a5ef8943054b39077573f94234980bd0f":[7,0,3,4,40,8],
+"sparse__matrix__operations_8hpp.html#a926494a1bd9b3c66def0c860bf564b42":[7,0,3,4,40,0],
+"sparse__matrix__operations_8hpp.html#ab85e3912a40d5d479835e7608808f07e":[7,0,3,4,40,3],
+"sparse__matrix__operations_8hpp.html#ac6448c1d1c0cdb1010a146c0238c8d20":[7,0,3,4,40,6],
+"sparse__matrix__operations_8hpp.html#af0e2c481d5920946ce6fce0874cd8138":[7,0,3,4,40,5],
+"sparse__matrix__operations_8hpp_source.html":[7,0,3,4,40],
+"sparse__matrix__operations__solve_8hpp.html":[7,0,3,4,0,18],
+"sparse__matrix__operations__solve_8hpp.html#a0fdaf16a87e07c124373a52254c173ad":[7,0,3,4,0,18,4],
+"sparse__matrix__operations__solve_8hpp.html#a1c1b2731df8afb9c3f915b9d0d639753":[7,0,3,4,0,18,2],
+"sparse__matrix__operations__solve_8hpp.html#a233ac7fb62f71e33255e7c9cba345ed7":[7,0,3,4,0,18,9],
+"sparse__matrix__operations__solve_8hpp.html#a8000df1bca574a42318a5b7edbe6b97f":[7,0,3,4,0,18,0],
+"sparse__matrix__operations__solve_8hpp.html#a9abc8d66c512f9124bbb993eee4b5586":[7,0,3,4,0,18,1],
+"sparse__matrix__operations__solve_8hpp.html#aa12dd112fa13a12a456cf19945adc9c0":[7,0,3,4,0,18,5],
+"sparse__matrix__operations__solve_8hpp.html#aa52e774f145abd8da05d99dc722acc28":[7,0,3,4,0,18,3],
+"sparse__matrix__operations__solve_8hpp.html#acddaf2035898ce13496e3494dd22cd69":[7,0,3,4,0,18,6],
+"sparse__matrix__operations__solve_8hpp.html#adcf87e5dfd0c05d2d88c7be8bf81395a":[7,0,3,4,0,18,11],
+"sparse__matrix__operations__solve_8hpp.html#ae4caa7ec537c21ce87da42e70289633c":[7,0,3,4,0,18,8],
+"sparse__matrix__operations__solve_8hpp.html#af45d44700626214f9474848e09fb9126":[7,0,3,4,0,18,7],
 "sparse__matrix__operations__solve_8hpp.html#afd116a080fa6ff167e6845f62c7d5229":[7,0,3,4,0,18,10],
 "sparse__matrix__operations__solve_8hpp_source.html":[7,0,3,4,0,18],
 "sparse__vector_8hpp.html":[7,0,3,4,1,3,9],
@@ -180,74 +249,5 @@ var NAVTREEINDEX21 =
 "structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#ae4f54038c3465b5fcd440c68bd1d0701":[6,0,0,2,39,2,0],
 "structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#af859aa51f8a2c20e654f63fdb34bb5b6":[6,0,0,2,39,2,4],
 "structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type.html":[6,0,0,2,2,0],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01char_01_4.html":[6,0,0,2,2,1],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html":[6,0,0,2,2,2],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01float_01_4.html":[6,0,0,2,2,3],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01int_01_4.html":[6,0,0,2,2,4],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01long_01_4.html":[6,0,0,2,2,5],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01short_01_4.html":[6,0,0,2,2,6],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01char_01_4.html":[6,0,0,2,2,7],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01int_01_4.html":[6,0,0,2,2,8],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01long_01_4.html":[6,0,0,2,2,9],
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01short_01_4.html":[6,0,0,2,2,10],
-"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html":[6,0,0,2,2,11],
-"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html#a2eeea82437fdfca56530a290b4fd3237":[6,0,0,2,2,11,1],
-"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html#a51aba73af223f30ff44068b7cf58a062":[6,0,0,2,2,11,0],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html":[6,0,0,2,2,12],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html#a49dda80f9c881ef0044168c7391680a9":[6,0,0,2,2,12,1],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html#a94637ceae517b8f5ed07c3859a19a1cb":[6,0,0,2,2,12,0],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html":[6,0,0,2,2,13],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html#a32ec16c83f6accf8a4a3b4c3fa687ad3":[6,0,0,2,2,13,0],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html#af6a1615f03eb4e06f24a42cfb39d119d":[6,0,0,2,2,13,1],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html":[6,0,0,2,2,14],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html#a04b314dab25469a07e2c1815b2278ba7":[6,0,0,2,2,14,0],
-"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html#a591aa73f27eef9ce3e0353213d81939e":[6,0,0,2,2,14,1],
-"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html":[6,0,0,2,2,15],
-"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html#a5ca56050bcedeca039469d522da71bbda0de8ea24b6c4b31cf8e314f4870c363f":[6,0,0,2,2,15,0],
-"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html":[6,0,0,2,2,16],
-"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html#a0947d587134892dc795ad41f21c7cfe4a11fbe8b012f0400b71192e0961470798":[6,0,0,2,2,16,0],
-"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html":[6,0,0,2,2,18],
-"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html#a326c5de9c7d5e5956df21d9c51fae443":[6,0,0,2,2,18,1],
-"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html#a3ae543b5c47f099a79a66f7ccb0cc251":[6,0,0,2,2,18,0],
-"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html":[6,0,0,2,2,19],
-"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html#a4e33ade1964ba6d5240e3e83221677a8":[6,0,0,2,2,19,0],
-"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html#a7258a1cdc617a7cf3264f27650a324cc":[6,0,0,2,2,19,1],
-"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html":[6,0,0,2,2,20],
-"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html#a13c76e80d8d2476f7296d3a5eb9964a7":[6,0,0,2,2,20,0],
-"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html#afcf06528f70ce5af6cb12a735926c3e3":[6,0,0,2,2,20,1],
-"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html":[6,0,0,2,2,21],
-"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#aa25e886c6f7ea396dd3661ba22848d6c":[6,0,0,2,2,21,0],
-"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#ab8aaa1aa22a53ac8a37b7bd39f6b9ed0":[6,0,0,2,2,21,1],
-"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#ac12e6bc19b07d4e29130b1b631ae18e0":[6,0,0,2,2,21,2],
-"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#af6d99b4ee32ae88155cd1bf449a2989b":[6,0,0,2,2,21,3],
-"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html":[6,0,0,2,2,22],
-"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html#a6f788402ff5b7c320d4925a099dc0d68":[6,0,0,2,2,22,0],
-"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html#ae2f3250fd7f8dc1a52cdb5a0ee85080b":[6,0,0,2,2,22,1],
-"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html":[6,0,0,2,2,23],
-"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html#a042219c4692be2d1e62c31c6bf9ef43a":[6,0,0,2,2,23,0],
-"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html#abc0b675a97030f92bf8ef3aed0274c56":[6,0,0,2,2,23,1],
-"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html":[6,0,0,2,2,24],
-"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html#a3f999e9195f1917902bfcabca58aa401":[6,0,0,2,2,24,1],
-"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html#ac1c23304658b2f8be17c0f706817a592":[6,0,0,2,2,24,0],
-"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html":[6,0,0,2,2,25],
-"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#a8859a3effbc408c887156a3270377362":[6,0,0,2,2,25,1],
-"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#afa684b874dcbd93cecc20beaf5d5300b":[6,0,0,2,2,25,0],
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html":[6,0,0,2,2,26],
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#ab9e9f54c99ee5c4fa7b03c86fb3c7bac":[6,0,0,2,2,26,0],
-"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#acd76d9e773edd4ce64ab535898b7ee2e":[6,0,0,2,2,26,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html":[6,0,0,2,2,27],
-"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a0be523ad58edf147b3cd3adfdd58f621":[6,0,0,2,2,27,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a7bf16956f06a6bbf04e1ed2f86e42f3f":[6,0,0,2,2,27,0],
-"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html":[6,0,0,2,2,28],
-"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#a19297e53a833c520335ecc5320807d2c":[6,0,0,2,2,28,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#ad81e702da882bd123ace4a495da13df5":[6,0,0,2,2,28,0],
-"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html":[6,0,0,2,2,29],
-"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30737a886c21ee6e8b31b47f812e2312":[6,0,0,2,2,29,1],
-"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30b3642c00ccbf41e80ddbe1c8857112":[6,0,0,2,2,29,0],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html":[6,0,0,2,2,30],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html":[6,0,0,2,2,31],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html":[6,0,0,2,2,32],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html":[6,0,0,2,2,33],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html":[6,0,0,2,2,34],
-"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html":[6,0,0,2,2,35]
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01char_01_4.html":[6,0,0,2,2,1]
 };
