@@ -1,5 +1,74 @@
 var NAVTREEINDEX22 =
 {
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html":[6,0,0,2,2,2],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01float_01_4.html":[6,0,0,2,2,3],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01int_01_4.html":[6,0,0,2,2,4],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01long_01_4.html":[6,0,0,2,2,5],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01short_01_4.html":[6,0,0,2,2,6],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01char_01_4.html":[6,0,0,2,2,7],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01int_01_4.html":[6,0,0,2,2,8],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01long_01_4.html":[6,0,0,2,2,9],
+"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01short_01_4.html":[6,0,0,2,2,10],
+"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html":[6,0,0,2,2,11],
+"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html#a2eeea82437fdfca56530a290b4fd3237":[6,0,0,2,2,11,1],
+"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html#a51aba73af223f30ff44068b7cf58a062":[6,0,0,2,2,11,0],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html":[6,0,0,2,2,12],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html#a49dda80f9c881ef0044168c7391680a9":[6,0,0,2,2,12,1],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html#a94637ceae517b8f5ed07c3859a19a1cb":[6,0,0,2,2,12,0],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html":[6,0,0,2,2,13],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html#a32ec16c83f6accf8a4a3b4c3fa687ad3":[6,0,0,2,2,13,0],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html#af6a1615f03eb4e06f24a42cfb39d119d":[6,0,0,2,2,13,1],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html":[6,0,0,2,2,14],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html#a04b314dab25469a07e2c1815b2278ba7":[6,0,0,2,2,14,0],
+"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html#a591aa73f27eef9ce3e0353213d81939e":[6,0,0,2,2,14,1],
+"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html":[6,0,0,2,2,15],
+"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html#a5ca56050bcedeca039469d522da71bbda0de8ea24b6c4b31cf8e314f4870c363f":[6,0,0,2,2,15,0],
+"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html":[6,0,0,2,2,16],
+"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html#a0947d587134892dc795ad41f21c7cfe4a11fbe8b012f0400b71192e0961470798":[6,0,0,2,2,16,0],
+"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html":[6,0,0,2,2,18],
+"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html#a326c5de9c7d5e5956df21d9c51fae443":[6,0,0,2,2,18,1],
+"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html#a3ae543b5c47f099a79a66f7ccb0cc251":[6,0,0,2,2,18,0],
+"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html":[6,0,0,2,2,19],
+"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html#a4e33ade1964ba6d5240e3e83221677a8":[6,0,0,2,2,19,0],
+"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html#a7258a1cdc617a7cf3264f27650a324cc":[6,0,0,2,2,19,1],
+"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html":[6,0,0,2,2,20],
+"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html#a13c76e80d8d2476f7296d3a5eb9964a7":[6,0,0,2,2,20,0],
+"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html#afcf06528f70ce5af6cb12a735926c3e3":[6,0,0,2,2,20,1],
+"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html":[6,0,0,2,2,21],
+"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#aa25e886c6f7ea396dd3661ba22848d6c":[6,0,0,2,2,21,0],
+"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#ab8aaa1aa22a53ac8a37b7bd39f6b9ed0":[6,0,0,2,2,21,1],
+"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#ac12e6bc19b07d4e29130b1b631ae18e0":[6,0,0,2,2,21,2],
+"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html#af6d99b4ee32ae88155cd1bf449a2989b":[6,0,0,2,2,21,3],
+"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html":[6,0,0,2,2,22],
+"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html#a6f788402ff5b7c320d4925a099dc0d68":[6,0,0,2,2,22,0],
+"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html#ae2f3250fd7f8dc1a52cdb5a0ee85080b":[6,0,0,2,2,22,1],
+"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html":[6,0,0,2,2,23],
+"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html#a042219c4692be2d1e62c31c6bf9ef43a":[6,0,0,2,2,23,0],
+"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html#abc0b675a97030f92bf8ef3aed0274c56":[6,0,0,2,2,23,1],
+"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html":[6,0,0,2,2,24],
+"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html#a3f999e9195f1917902bfcabca58aa401":[6,0,0,2,2,24,1],
+"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html#ac1c23304658b2f8be17c0f706817a592":[6,0,0,2,2,24,0],
+"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html":[6,0,0,2,2,25],
+"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#a8859a3effbc408c887156a3270377362":[6,0,0,2,2,25,1],
+"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html#afa684b874dcbd93cecc20beaf5d5300b":[6,0,0,2,2,25,0],
+"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html":[6,0,0,2,2,26],
+"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#ab9e9f54c99ee5c4fa7b03c86fb3c7bac":[6,0,0,2,2,26,0],
+"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html#acd76d9e773edd4ce64ab535898b7ee2e":[6,0,0,2,2,26,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html":[6,0,0,2,2,27],
+"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a0be523ad58edf147b3cd3adfdd58f621":[6,0,0,2,2,27,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html#a7bf16956f06a6bbf04e1ed2f86e42f3f":[6,0,0,2,2,27,0],
+"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html":[6,0,0,2,2,28],
+"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#a19297e53a833c520335ecc5320807d2c":[6,0,0,2,2,28,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html#ad81e702da882bd123ace4a495da13df5":[6,0,0,2,2,28,0],
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html":[6,0,0,2,2,29],
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30737a886c21ee6e8b31b47f812e2312":[6,0,0,2,2,29,1],
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30b3642c00ccbf41e80ddbe1c8857112":[6,0,0,2,2,29,0],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string.html":[6,0,0,2,2,30],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html":[6,0,0,2,2,31],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html":[6,0,0,2,2,32],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html":[6,0,0,2,2,33],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html":[6,0,0,2,2,34],
+"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html":[6,0,0,2,2,35],
 "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html":[6,0,0,2,2,36],
 "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html":[6,0,0,2,2,37],
 "structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html":[6,0,0,2,2,38],
@@ -180,74 +249,5 @@ var NAVTREEINDEX22 =
 "structviennacl_1_1op__flip__sign.html":[6,0,0,93],
 "structviennacl_1_1op__floor.html":[6,0,0,94],
 "structviennacl_1_1op__fmax.html":[6,0,0,95],
-"structviennacl_1_1op__fmin.html":[6,0,0,96],
-"structviennacl_1_1op__fmod.html":[6,0,0,97],
-"structviennacl_1_1op__geq.html":[6,0,0,98],
-"structviennacl_1_1op__greater.html":[6,0,0,99],
-"structviennacl_1_1op__inner__prod.html":[6,0,0,100],
-"structviennacl_1_1op__inplace__add.html":[6,0,0,101],
-"structviennacl_1_1op__inplace__sub.html":[6,0,0,102],
-"structviennacl_1_1op__leq.html":[6,0,0,103],
-"structviennacl_1_1op__less.html":[6,0,0,104],
-"structviennacl_1_1op__log.html":[6,0,0,105],
-"structviennacl_1_1op__log10.html":[6,0,0,106],
-"structviennacl_1_1op__mat__mat__prod.html":[6,0,0,107],
-"structviennacl_1_1op__matrix__diag.html":[6,0,0,108],
-"structviennacl_1_1op__max.html":[6,0,0,109],
-"structviennacl_1_1op__min.html":[6,0,0,110],
-"structviennacl_1_1op__mult.html":[6,0,0,111],
-"structviennacl_1_1op__neq.html":[6,0,0,112],
-"structviennacl_1_1op__norm__1.html":[6,0,0,113],
-"structviennacl_1_1op__norm__2.html":[6,0,0,114],
-"structviennacl_1_1op__norm__frobenius.html":[6,0,0,115],
-"structviennacl_1_1op__norm__inf.html":[6,0,0,116],
-"structviennacl_1_1op__pow.html":[6,0,0,117],
-"structviennacl_1_1op__prod.html":[6,0,0,118],
-"structviennacl_1_1op__reduce__columns.html":[6,0,0,119],
-"structviennacl_1_1op__reduce__rows.html":[6,0,0,120],
-"structviennacl_1_1op__reduce__vector.html":[6,0,0,121],
-"structviennacl_1_1op__row.html":[6,0,0,122],
-"structviennacl_1_1op__sin.html":[6,0,0,123],
-"structviennacl_1_1op__sinh.html":[6,0,0,124],
-"structviennacl_1_1op__sqrt.html":[6,0,0,125],
-"structviennacl_1_1op__sub.html":[6,0,0,126],
-"structviennacl_1_1op__tan.html":[6,0,0,127],
-"structviennacl_1_1op__tanh.html":[6,0,0,128],
-"structviennacl_1_1op__trans.html":[6,0,0,129],
-"structviennacl_1_1op__vector__diag.html":[6,0,0,130],
-"structviennacl_1_1result__of_1_1alignment.html":[6,0,0,6,0],
-"structviennacl_1_1result__of_1_1alignment.html#a8568f5b82e9b4cd293e144d3d17b0d5ca9f8524cac5b3e3d4ece1d1975bef5404":[6,0,0,6,0,1],
-"structviennacl_1_1result__of_1_1alignment.html#aec42d09c43a5a60b5f651f283ac358f3":[6,0,0,6,0,0],
-"structviennacl_1_1result__of_1_1cl__type.html":[6,0,0,6,1],
-"structviennacl_1_1result__of_1_1cl__type.html#a340db346857782e06f4eefb3934f28c9":[6,0,0,6,1,0],
-"structviennacl_1_1result__of_1_1cpu__value__type.html":[6,0,0,6,2],
-"structviennacl_1_1result__of_1_1cpu__value__type.html#aa015d93f419985879a7c13b09633c5c6":[6,0,0,6,2,0],
-"structviennacl_1_1result__of_1_1size__type.html":[6,0,0,6,3],
-"structviennacl_1_1result__of_1_1size__type.html#a35e1136e9b35cce5f26f0eaf4427dcc3":[6,0,0,6,3,0],
-"structviennacl_1_1result__of_1_1value__type.html":[6,0,0,6,4],
-"structviennacl_1_1result__of_1_1value__type.html#a1fccdddb6d57eaba8f19506cea2051a3":[6,0,0,6,4,0],
-"structviennacl_1_1row__iteration.html":[6,0,0,131],
-"structviennacl_1_1row__major.html":[6,0,0,132],
-"structviennacl_1_1row__major.html#a16e67b00a2f71de63e15bb05c8ef0856":[6,0,0,132,0],
-"structviennacl_1_1row__major__tag.html":[6,0,0,133],
-"structviennacl_1_1scalar__vector.html":[6,0,0,144],
-"structviennacl_1_1scalar__vector.html#ab1110376608b81d0b1aa4c76a0a2ef46":[6,0,0,144,0],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html":[6,0,0,7,1],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a004b1ebc6c30dd52c7864dac15ffdcf5":[6,0,0,7,1,5],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0137a9fb11a97dc62832a72edfc2a293":[6,0,0,7,1,67],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0a66d1b72140af28cf0ea82d506bcde5":[6,0,0,7,1,20],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a0aa9cfe0e6438394453e18cb4b2d5f88":[6,0,0,7,1,31],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a141b47baf5ef9c2fc1e8e1775914911b":[6,0,0,7,1,13],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1518bbf03064436bbd8ebaeb27d02231":[6,0,0,7,1,37],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1714016d2100f1e6c1eb08112c5548de":[6,0,0,7,1,16],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1d729198a4b9c4ea8cf639984d332c68":[6,0,0,7,1,43],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a1f921a78e2e942208e8bc1c7ecc52401":[6,0,0,7,1,6],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a23d2b2c40c404c9005452d9810967293":[6,0,0,7,1,40],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2634adf095e95920e6c8fa5b484cb833":[6,0,0,7,1,33],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2a0432d9e22968d482b8b66058a3fbe5":[6,0,0,7,1,70],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a2fb5c22bfceabb819702ff1ea87f2eb0":[6,0,0,7,1,18],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a35fe2d6c0ef69f04ad2c94d7b10c7cdd":[6,0,0,7,1,52],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a3f7a03c29c0d4d79d20ef759f4fe88e2":[6,0,0,7,1,32],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a403714231bcd54f45438a296bfe7a631":[6,0,0,7,1,64],
-"structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a44882e8993eb5d47c40152868cdf5556":[6,0,0,7,1,46]
+"structviennacl_1_1op__fmin.html":[6,0,0,96]
 };
