@@ -1,5 +1,66 @@
 var NAVTREEINDEX25 =
 {
+"tests_2src_2sparse_8cpp.html#a3d8742cd384cb6e7893805a6c54791b2":[7,0,2,0,36,6],
+"tests_2src_2sparse_8cpp.html#a634d16026401b8fbaab23d72d4485b90":[7,0,2,0,36,7],
+"tests_2src_2sparse_8cpp.html#a8b9a4f6704d0fa5a6499ca7af211c5cf":[7,0,2,0,36,4],
+"tests_2src_2sparse_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,36,0],
+"tests_2src_2sparse_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc":[7,0,2,0,36,8],
+"tests_2src_2sparse_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,36,5],
+"tests_2src_2sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,36,1],
+"tests_2src_2sparse_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,36,2],
+"tests_2src_2sparse_8cpp_source.html":[7,0,2,0,36],
+"tests_2src_2structured-matrices_8cpp.html":[7,0,2,0,38],
+"tests_2src_2structured-matrices_8cpp.html#a0e28bd6526e1b7c613a4404844843da8":[7,0,2,0,38,1],
+"tests_2src_2structured-matrices_8cpp.html#a1c636bc9529b33fa277877d0ebe9a2b2":[7,0,2,0,38,5],
+"tests_2src_2structured-matrices_8cpp.html#a3042870eb8881681860b088156ccf079":[7,0,2,0,38,3],
+"tests_2src_2structured-matrices_8cpp.html#a9da71d9f01f41f9a08954fc15b2a655c":[7,0,2,0,38,9],
+"tests_2src_2structured-matrices_8cpp.html#aadad85fa5cbf31466487bb0585d1a769":[7,0,2,0,38,4],
+"tests_2src_2structured-matrices_8cpp.html#ab92d3f00b304a761998eb499f5f7bb46":[7,0,2,0,38,7],
+"tests_2src_2structured-matrices_8cpp.html#ac0e8e0cdd79549fd363949f10e66a1b4":[7,0,2,0,38,8],
+"tests_2src_2structured-matrices_8cpp.html#ad1c912fb25a41391411c00de85a1ebeb":[7,0,2,0,38,10],
+"tests_2src_2structured-matrices_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,38,6],
+"tests_2src_2structured-matrices_8cpp.html#af649847e70b328d7638362c2e9691ea1":[7,0,2,0,38,2],
+"tests_2src_2structured-matrices_8cpp_source.html":[7,0,2,0,38],
+"timer_8hpp.html":[7,0,3,9,6],
+"timer_8hpp_source.html":[7,0,3,9,6],
+"toeplitz__matrix_8hpp.html":[7,0,3,27],
+"toeplitz__matrix_8hpp.html#aa608856aa45efa0252105174c1e0a63d":[7,0,3,27,1],
+"toeplitz__matrix_8hpp.html#aac7e1dff63f0868e785113fb6553addd":[7,0,3,27,2],
+"toeplitz__matrix_8hpp.html#aacbbb1aee9a7a2b8a0cd85c049cad89a":[7,0,3,27,4],
+"toeplitz__matrix_8hpp.html#aece37a39663683a2bf4fe18d6f372e86":[7,0,3,27,5],
+"toeplitz__matrix_8hpp.html#affa275ef815673673afe615439a6e7dd":[7,0,3,27,3],
+"toeplitz__matrix_8hpp_source.html":[7,0,3,27],
+"toeplitz__matrix__operations_8hpp.html":[7,0,3,4,42],
+"toeplitz__matrix__operations_8hpp.html#ae45beece755553455daea6973a60043d":[7,0,3,4,42,0],
+"toeplitz__matrix__operations_8hpp_source.html":[7,0,3,4,42],
+"tools_8hpp.html":[7,0,3,9,7],
+"tools_8hpp.html#a04fa422bdea25fad60bdcc038499568b":[7,0,3,9,7,17],
+"tools_8hpp.html#a0b65446282c16f99368f247374f60e6b":[7,0,3,9,7,9],
+"tools_8hpp.html#a128f9b9d9dd98c5879fcfb19ab92613e":[7,0,3,9,7,11],
+"tools_8hpp.html#a2306cd11dc95d0957f7ed8662c028487":[7,0,3,9,7,15],
+"tools_8hpp.html#a26fc67a02d7e6d56f37fbcdbe6ea522e":[7,0,3,9,7,16],
+"tools_8hpp.html#a39d48e0f967fa4ed92ab6dc80a1dca0d":[7,0,3,9,7,7],
+"tools_8hpp.html#a534ecc78073a72515aff64c39d27b3a6":[7,0,3,9,7,18],
+"tools_8hpp.html#a5990ca1974b1d7643c9a940728a9225c":[7,0,3,9,7,3],
+"tools_8hpp.html#a5de8d3d77a5d52110c4315400229fc1e":[7,0,3,9,7,4],
+"tools_8hpp.html#a82bd65c2e387b888d311c70a913306b2":[7,0,3,9,7,10],
+"tools_8hpp.html#a869690c822da6cc54f686dca4aed87f5":[7,0,3,9,7,8],
+"tools_8hpp.html#aa590a4812efea2fafaaa2d1ab97629a8":[7,0,3,9,7,13],
+"tools_8hpp.html#aabb4df3a7c7f0f2e2d7baf1def5d053f":[7,0,3,9,7,14],
+"tools_8hpp.html#abbf7abeae5d6de9edeb5d8460d4fe831":[7,0,3,9,7,5],
+"tools_8hpp.html#ae999cf2ddbfc316b9bf2a3ba57dbe738":[7,0,3,9,7,6],
+"tools_8hpp.html#af89474b254231f5e81d311808eebcaef":[7,0,3,9,7,12],
+"tools_8hpp_source.html":[7,0,3,9,7],
+"tql2_8cpp-example.html":[8,29],
+"tql2_8cpp.html":[7,0,0,1,31],
+"tql2_8cpp_source.html":[7,0,0,1,31],
+"tql2_8hpp.html":[7,0,3,4,43],
+"tql2_8hpp.html#a3fe3eb20d4dcda794259fd6a6d30afb6":[7,0,3,4,43,0],
+"tql2_8hpp_source.html":[7,0,3,4,43],
+"tql_8cpp.html":[7,0,2,0,40],
+"tql_8cpp.html#a6ebf6899d6c1c8b7b9d09be872c05aae":[7,0,2,0,40,0],
+"tql_8cpp.html#a8204a5a8d4b9cbed559875cb65848656":[7,0,2,0,40,6],
+"tql_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e":[7,0,2,0,40,1],
 "tql_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,40,3],
 "tql_8cpp.html#addc3b5bf488c68ee7b156e7554638126":[7,0,2,0,40,5],
 "tql_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,40,4],
@@ -44,15 +105,15 @@ var NAVTREEINDEX25 =
 "vandermonde__matrix__operations_8hpp.html":[7,0,3,4,45],
 "vandermonde__matrix__operations_8hpp.html#a64b4f1d927a4df6416192cc8e69ed8aa":[7,0,3,4,45,0],
 "vandermonde__matrix__operations_8hpp_source.html":[7,0,3,4,45],
-"vector-io_8hpp.html":[7,0,0,1,33],
-"vector-io_8hpp.html#a2153ea85c265deda214decb215af6553":[7,0,0,1,33,2],
-"vector-io_8hpp.html#a303954a45833b84192a6dcf3065f85e3":[7,0,0,1,33,3],
-"vector-io_8hpp.html#a55017a0da63da825e2f206bac4607a7a":[7,0,0,1,33,1],
-"vector-io_8hpp.html#aeb6c51d29fa8bd684fa1e649415ad9c3":[7,0,0,1,33,4],
-"vector-io_8hpp_source.html":[7,0,0,1,33],
+"vector-io_8hpp.html":[7,0,0,1,32],
+"vector-io_8hpp.html#a2153ea85c265deda214decb215af6553":[7,0,0,1,32,2],
+"vector-io_8hpp.html#a303954a45833b84192a6dcf3065f85e3":[7,0,0,1,32,3],
+"vector-io_8hpp.html#a55017a0da63da825e2f206bac4607a7a":[7,0,0,1,32,1],
+"vector-io_8hpp.html#aeb6c51d29fa8bd684fa1e649415ad9c3":[7,0,0,1,32,4],
+"vector-io_8hpp_source.html":[7,0,0,1,32],
 "vector-range_8cpp-example.html":[8,30],
-"vector-range_8cpp.html":[7,0,0,1,34],
-"vector-range_8cpp_source.html":[7,0,0,1,34],
+"vector-range_8cpp.html":[7,0,0,1,33],
+"vector-range_8cpp_source.html":[7,0,0,1,33],
 "vector_8hpp.html":[7,0,3,29],
 "vector_8hpp.html#a0250b6a52a40df48e3ee18f1db6e4747":[7,0,3,29,55],
 "vector_8hpp.html#a0a9b799cd9d2b4ae4376c5216d5ac93f":[7,0,3,29,40],
@@ -188,66 +249,5 @@ var NAVTREEINDEX25 =
 "vector__operations_8hpp.html#abcf0050426d4b7147d50588919f690da":[7,0,3,4,46,23],
 "vector__operations_8hpp.html#acbacf04789215a3a748eca63743d50af":[7,0,3,4,46,37],
 "vector__operations_8hpp.html#ad345204a9420f9dd57bbad0b16fc40d9":[7,0,3,4,46,39],
-"vector__operations_8hpp.html#ad39b63615f03a2d316593075f9060b2d":[7,0,3,4,46,22],
-"vector__operations_8hpp.html#ad648cd691bb8fa8358f552d00bce2946":[7,0,3,4,46,35],
-"vector__operations_8hpp.html#ad6f228d570bffac37abb106970b08532":[7,0,3,4,46,20],
-"vector__operations_8hpp.html#ae13999d03d7afcfb56ffb08dc87c03d4":[7,0,3,4,46,1],
-"vector__operations_8hpp.html#af170246b8ee051270ea2c9fbd141d832":[7,0,3,4,46,10],
-"vector__operations_8hpp.html#af754ca05f664675f759aca2de035bc7a":[7,0,3,4,46,16],
-"vector__operations_8hpp_source.html":[7,0,3,4,46],
-"vector__proxy_8hpp.html":[7,0,3,30],
-"vector__proxy_8hpp.html#a212372cdbfca6aa45055ca3249d63649":[7,0,3,30,11],
-"vector__proxy_8hpp.html#a6c9ebd03331219bc6a77724dab6c2c16":[7,0,3,30,15],
-"vector__proxy_8hpp.html#a7f9afcfdb40091e366e2160d1e47bd2b":[7,0,3,30,9],
-"vector__proxy_8hpp.html#a86fe3d7623af671fc541309f49011a18":[7,0,3,30,4],
-"vector__proxy_8hpp.html#a89ee402303952a729fdd80e43ba7a069":[7,0,3,30,10],
-"vector__proxy_8hpp.html#a973a57be69fbaeecbf8ea71c749e1a48":[7,0,3,30,5],
-"vector__proxy_8hpp.html#aa48aab4f03a1cc65d7601f1db982e87f":[7,0,3,30,6],
-"vector__proxy_8hpp.html#ab4a676db96fd05c12757bde89bec72f5":[7,0,3,30,12],
-"vector__proxy_8hpp.html#abecb157ae33461b467d43a6b6eb3edd1":[7,0,3,30,14],
-"vector__proxy_8hpp.html#adc4171b2d0fb71c42ecdd32c9ed34451":[7,0,3,30,7],
-"vector__proxy_8hpp.html#ae54949548426c32cb2b7f651e41497ef":[7,0,3,30,13],
-"vector__proxy_8hpp.html#aff87e6c12c0c4774fb92fa88e0c44806":[7,0,3,30,8],
-"vector__proxy_8hpp_source.html":[7,0,3,30],
-"vector__uint_8cpp.html":[7,0,2,0,44],
-"vector__uint_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,44,2],
-"vector__uint_8cpp.html#a3886c6e131e2471b850fd7a4c85b4441":[7,0,2,0,44,7],
-"vector__uint_8cpp.html#a804cb698245c0bd3e4d40119b9f1dcde":[7,0,2,0,44,1],
-"vector__uint_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,44,8],
-"vector__uint_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,44,3],
-"vector__uint_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,44,5],
-"vector__uint_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,44,4],
-"vector__uint_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,44,6],
-"vector__uint_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,44,0],
-"vector__uint_8cpp_source.html":[7,0,2,0,44],
-"version_8hpp.html":[7,0,3,31],
-"version_8hpp.html#a3d45b5315400d02d83c3c11f0ee6b494":[7,0,3,31,1],
-"version_8hpp.html#ac4f352886df7f3da2e958797a8629b87":[7,0,3,31,2],
-"version_8hpp.html#acd20c0ad13043a1bda59bd2332c6fb3e":[7,0,3,31,0],
-"version_8hpp_source.html":[7,0,3,31],
-"viennacl-info_8cpp-example.html":[8,31],
-"viennacl-info_8cpp.html":[7,0,0,1,35],
-"viennacl-info_8cpp_source.html":[7,0,0,1,35],
-"viennacl_8hpp.html":[7,0,1,0,0],
-"viennacl_8hpp.html#a0274c655632f37c36f006b68540abcea":[7,0,1,0,0,38],
-"viennacl_8hpp.html#a061757a06f70dc035a9aca46d2ccc66b":[7,0,1,0,0,29],
-"viennacl_8hpp.html#a07e9a48d5b151e514f3352e6a9aa9db3":[7,0,1,0,0,23],
-"viennacl_8hpp.html#a0be49040fea447b67f2cbec40af9685b":[7,0,1,0,0,36],
-"viennacl_8hpp.html#a0c91c0efd72de04e1eb5826354af16a4":[7,0,1,0,0,82],
-"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519":[7,0,1,0,0,12],
-"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519a3b42685124166d6b933a4db104b8096a":[7,0,1,0,0,12,0],
-"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519a7fac0c3c6a5af870895446d06f7c13fc":[7,0,1,0,0,12,1],
-"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519ab858179ff3fab038dbb2e5e5c460084d":[7,0,1,0,0,12,2],
-"viennacl_8hpp.html#a11d74dcf290a16551b33c97ef3838d99":[7,0,1,0,0,51],
-"viennacl_8hpp.html#a13a355b36c39dd0cb150164a92f46f0a":[7,0,1,0,0,19],
-"viennacl_8hpp.html#a174b55e484de020634bb234f383f6078":[7,0,1,0,0,27],
-"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015":[7,0,1,0,0,11],
-"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015a29e68210bd47ec635255b78ebd6ace0f":[7,0,1,0,0,11,1],
-"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015ad8df17d6ac56ff06dab0547d9af8fc30":[7,0,1,0,0,11,0],
-"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87b":[7,0,1,0,0,10],
-"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87ba9914ab727e34dc6fe58e77516df3713c":[7,0,1,0,0,10,2],
-"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87bab82a7582744552581791992e118399f1":[7,0,1,0,0,10,0],
-"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87bac579d3deafe1fce44c8ae9319ea3e13b":[7,0,1,0,0,10,1],
-"viennacl_8hpp.html#a23c8eb8eab78d14cc4ba56e14e1441cd":[7,0,1,0,0,66],
-"viennacl_8hpp.html#a24361d25205ad5256ee2c130712299a9":[7,0,1,0,0,67]
+"vector__operations_8hpp.html#ad39b63615f03a2d316593075f9060b2d":[7,0,3,4,46,22]
 };
