@@ -1,5 +1,66 @@
 var NAVTREEINDEX26 =
 {
+"vector__operations_8hpp.html#ad648cd691bb8fa8358f552d00bce2946":[7,0,3,4,46,35],
+"vector__operations_8hpp.html#ad6f228d570bffac37abb106970b08532":[7,0,3,4,46,20],
+"vector__operations_8hpp.html#ae13999d03d7afcfb56ffb08dc87c03d4":[7,0,3,4,46,1],
+"vector__operations_8hpp.html#af170246b8ee051270ea2c9fbd141d832":[7,0,3,4,46,10],
+"vector__operations_8hpp.html#af754ca05f664675f759aca2de035bc7a":[7,0,3,4,46,16],
+"vector__operations_8hpp_source.html":[7,0,3,4,46],
+"vector__proxy_8hpp.html":[7,0,3,30],
+"vector__proxy_8hpp.html#a212372cdbfca6aa45055ca3249d63649":[7,0,3,30,11],
+"vector__proxy_8hpp.html#a6c9ebd03331219bc6a77724dab6c2c16":[7,0,3,30,15],
+"vector__proxy_8hpp.html#a7f9afcfdb40091e366e2160d1e47bd2b":[7,0,3,30,9],
+"vector__proxy_8hpp.html#a86fe3d7623af671fc541309f49011a18":[7,0,3,30,4],
+"vector__proxy_8hpp.html#a89ee402303952a729fdd80e43ba7a069":[7,0,3,30,10],
+"vector__proxy_8hpp.html#a973a57be69fbaeecbf8ea71c749e1a48":[7,0,3,30,5],
+"vector__proxy_8hpp.html#aa48aab4f03a1cc65d7601f1db982e87f":[7,0,3,30,6],
+"vector__proxy_8hpp.html#ab4a676db96fd05c12757bde89bec72f5":[7,0,3,30,12],
+"vector__proxy_8hpp.html#abecb157ae33461b467d43a6b6eb3edd1":[7,0,3,30,14],
+"vector__proxy_8hpp.html#adc4171b2d0fb71c42ecdd32c9ed34451":[7,0,3,30,7],
+"vector__proxy_8hpp.html#ae54949548426c32cb2b7f651e41497ef":[7,0,3,30,13],
+"vector__proxy_8hpp.html#aff87e6c12c0c4774fb92fa88e0c44806":[7,0,3,30,8],
+"vector__proxy_8hpp_source.html":[7,0,3,30],
+"vector__uint_8cpp.html":[7,0,2,0,44],
+"vector__uint_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503":[7,0,2,0,44,2],
+"vector__uint_8cpp.html#a3886c6e131e2471b850fd7a4c85b4441":[7,0,2,0,44,7],
+"vector__uint_8cpp.html#a804cb698245c0bd3e4d40119b9f1dcde":[7,0,2,0,44,1],
+"vector__uint_8cpp.html#a92820a2416aaddb1700fc935e63f6cdd":[7,0,2,0,44,8],
+"vector__uint_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb":[7,0,2,0,44,3],
+"vector__uint_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,44,5],
+"vector__uint_8cpp.html#ac9cdd803369376cdf31cba3dedafa739":[7,0,2,0,44,4],
+"vector__uint_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,44,6],
+"vector__uint_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,44,0],
+"vector__uint_8cpp_source.html":[7,0,2,0,44],
+"version_8hpp.html":[7,0,3,31],
+"version_8hpp.html#a3d45b5315400d02d83c3c11f0ee6b494":[7,0,3,31,1],
+"version_8hpp.html#ac4f352886df7f3da2e958797a8629b87":[7,0,3,31,2],
+"version_8hpp.html#acd20c0ad13043a1bda59bd2332c6fb3e":[7,0,3,31,0],
+"version_8hpp_source.html":[7,0,3,31],
+"viennacl-info_8cpp-example.html":[8,31],
+"viennacl-info_8cpp.html":[7,0,0,1,34],
+"viennacl-info_8cpp_source.html":[7,0,0,1,34],
+"viennacl_8hpp.html":[7,0,1,0,0],
+"viennacl_8hpp.html#a0274c655632f37c36f006b68540abcea":[7,0,1,0,0,38],
+"viennacl_8hpp.html#a061757a06f70dc035a9aca46d2ccc66b":[7,0,1,0,0,29],
+"viennacl_8hpp.html#a07e9a48d5b151e514f3352e6a9aa9db3":[7,0,1,0,0,23],
+"viennacl_8hpp.html#a0be49040fea447b67f2cbec40af9685b":[7,0,1,0,0,36],
+"viennacl_8hpp.html#a0c91c0efd72de04e1eb5826354af16a4":[7,0,1,0,0,82],
+"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519":[7,0,1,0,0,12],
+"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519a3b42685124166d6b933a4db104b8096a":[7,0,1,0,0,12,0],
+"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519a7fac0c3c6a5af870895446d06f7c13fc":[7,0,1,0,0,12,1],
+"viennacl_8hpp.html#a0f5320939ecbf84bb8d0f29646c5a519ab858179ff3fab038dbb2e5e5c460084d":[7,0,1,0,0,12,2],
+"viennacl_8hpp.html#a11d74dcf290a16551b33c97ef3838d99":[7,0,1,0,0,51],
+"viennacl_8hpp.html#a13a355b36c39dd0cb150164a92f46f0a":[7,0,1,0,0,19],
+"viennacl_8hpp.html#a174b55e484de020634bb234f383f6078":[7,0,1,0,0,27],
+"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015":[7,0,1,0,0,11],
+"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015a29e68210bd47ec635255b78ebd6ace0f":[7,0,1,0,0,11,1],
+"viennacl_8hpp.html#a1eafb7b56abfb102716cbb7378847015ad8df17d6ac56ff06dab0547d9af8fc30":[7,0,1,0,0,11,0],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87b":[7,0,1,0,0,10],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87ba9914ab727e34dc6fe58e77516df3713c":[7,0,1,0,0,10,2],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87bab82a7582744552581791992e118399f1":[7,0,1,0,0,10,0],
+"viennacl_8hpp.html#a21e9b133d8c582ad1e0457434362e87bac579d3deafe1fce44c8ae9319ea3e13b":[7,0,1,0,0,10,1],
+"viennacl_8hpp.html#a23c8eb8eab78d14cc4ba56e14e1441cd":[7,0,1,0,0,66],
+"viennacl_8hpp.html#a24361d25205ad5256ee2c130712299a9":[7,0,1,0,0,67],
 "viennacl_8hpp.html#a30218b4e517d3f1143078b92c74e64e1":[7,0,1,0,0,73],
 "viennacl_8hpp.html#a30910a6a7db0c0859ee10cdf7004a694":[7,0,1,0,0,20],
 "viennacl_8hpp.html#a346e1ada9aa0ed99ad69b2b3705d5e68":[7,0,1,0,0,28],
@@ -87,6 +148,6 @@ var NAVTREEINDEX26 =
 "viennacl__private_8hpp.html":[7,0,1,1,13],
 "viennacl__private_8hpp_source.html":[7,0,1,1,13],
 "wrap-host-buffer_8cpp-example.html":[8,32],
-"wrap-host-buffer_8cpp.html":[7,0,0,1,36],
-"wrap-host-buffer_8cpp_source.html":[7,0,0,1,36]
+"wrap-host-buffer_8cpp.html":[7,0,0,1,35],
+"wrap-host-buffer_8cpp_source.html":[7,0,0,1,35]
 };
