@@ -1,25 +1,64 @@
 var NAVTREEINDEX3 =
 {
-"classviennacl_1_1hyb__matrix.html#a2b1b27a7e14035e94742129e5b6c00b5":[6,0,0,30,12],
-"classviennacl_1_1hyb__matrix.html#a2f620a72f3f44c563dd9fdcd9c788324":[6,0,0,30,15],
-"classviennacl_1_1hyb__matrix.html#a3863e14e65c82bffbd5ac3f42ae72ffc":[6,0,0,30,7],
-"classviennacl_1_1hyb__matrix.html#a4a711db273189338d5c47793777f7a98":[6,0,0,30,18],
-"classviennacl_1_1hyb__matrix.html#a69cbf2163826b43e4cb6717199fd0474":[6,0,0,30,16],
-"classviennacl_1_1hyb__matrix.html#a6bb63193628710851ff6da33f70a1ce9":[6,0,0,30,6],
-"classviennacl_1_1hyb__matrix.html#a7ae9a356c47a3298619625df2392eb4e":[6,0,0,30,17],
-"classviennacl_1_1hyb__matrix.html#a829531b89c462d336136881073bb5fc4":[6,0,0,30,1],
-"classviennacl_1_1hyb__matrix.html#a933565e3dda939889ac55a64decbc96f":[6,0,0,30,13],
-"classviennacl_1_1hyb__matrix.html#a94d49d42b85e5424296c47823d036dfc":[6,0,0,30,9],
-"classviennacl_1_1hyb__matrix.html#a99f19b7f1f18c18ec9f86920548f72bb":[6,0,0,30,11],
-"classviennacl_1_1hyb__matrix.html#ab5017072236a32e18afbca82b02dec86":[6,0,0,30,0],
-"classviennacl_1_1hyb__matrix.html#ac062f8671868c51dd2b4eeab4cdb9168":[6,0,0,30,14],
-"classviennacl_1_1hyb__matrix.html#ac6d3dd46446e7aecfad31403e5a6857d":[6,0,0,30,8],
-"classviennacl_1_1hyb__matrix.html#ace03d552e9b1e5ae6de9484a8a1218ae":[6,0,0,30,5],
-"classviennacl_1_1hyb__matrix.html#ad6a8c43b8c110e6dc7377eecaf4fce7c":[6,0,0,30,2],
-"classviennacl_1_1hyb__matrix.html#ad937b9563e4c764fd4bd7858b3d95803":[6,0,0,30,3],
-"classviennacl_1_1hyb__matrix.html#adc4674678fa747c72ef2937fb7cef141":[6,0,0,30,4],
-"classviennacl_1_1hyb__matrix.html#ae35b2e77d7d4ecb2ea13770a5c3f4670":[6,0,0,30,10],
+"classviennacl_1_1ell__matrix.html#a8575f900add9d7ff93f73063ac90b4b9":[6,0,0,25,2],
+"classviennacl_1_1ell__matrix.html#a906c21cc40724b86f7f0cf636dc91f60":[6,0,0,25,0],
+"classviennacl_1_1ell__matrix.html#ac9fdc9e7cf3e57e1a9589c52b583a6d7":[6,0,0,25,1],
+"classviennacl_1_1ell__matrix.html#ae29cafe3078a0f6cc9f5a525a1f74f8f":[6,0,0,25,3],
+"classviennacl_1_1ell__matrix.html#ae3280590756e720a8d8dacdeed4b702a":[6,0,0,25,10],
+"classviennacl_1_1ell__matrix.html#aebd34a16c075d010736102865b0c9e29":[6,0,0,25,17],
+"classviennacl_1_1ell__matrix.html#aefdee554c0ef34d0f69e69f788030864":[6,0,0,25,15],
+"classviennacl_1_1ell__matrix.html#af2e571bfc69f9f0acf3e9b19ce2b9b9f":[6,0,0,25,12],
+"classviennacl_1_1ell__matrix.html#af52325d0e501652d68ca5be85d3ea98c":[6,0,0,25,14],
+"classviennacl_1_1ell__matrix.html#afeb18c524920cfa52a7d56cd0b31b3c1":[6,0,0,25,18],
+"classviennacl_1_1ell__matrix.html#aff440baf9a08f63a1aa886990aaf406b":[6,0,0,25,5],
+"classviennacl_1_1entry__proxy.html":[6,0,0,27],
+"classviennacl_1_1entry__proxy.html#a20d1e6598ba396eca5441e81866692bb":[6,0,0,27,6],
+"classviennacl_1_1entry__proxy.html#a42a889aa89772a30c2d58d5588a3ac04":[6,0,0,27,1],
+"classviennacl_1_1entry__proxy.html#a4433439fd4233b8bc585d8d8f2cc7619":[6,0,0,27,3],
+"classviennacl_1_1entry__proxy.html#a5aab26f84f0a0f33a16c801826e8b5aa":[6,0,0,27,0],
+"classviennacl_1_1entry__proxy.html#a719287b50d86b5c8a047af7dbe4a5b3a":[6,0,0,27,4],
+"classviennacl_1_1entry__proxy.html#a7219f5d36ca71d3bab8987747cb77d1c":[6,0,0,27,10],
+"classviennacl_1_1entry__proxy.html#a9e5cbe868cfad0720aba407d149c75e1":[6,0,0,27,7],
+"classviennacl_1_1entry__proxy.html#ab12fabdb323eefb4892edde6f7b3bf16":[6,0,0,27,8],
+"classviennacl_1_1entry__proxy.html#acf681a2389ab0b31b5f660205f39ab77":[6,0,0,27,2],
+"classviennacl_1_1entry__proxy.html#adc3fc7c7cb5e7602eedd2d3b4ce35e1c":[6,0,0,27,5],
+"classviennacl_1_1entry__proxy.html#ae0c4cf27e795235d75556894e677e0af":[6,0,0,27,11],
+"classviennacl_1_1entry__proxy.html#aeb73ef2abb2e995991e5ee4d10dfb099":[6,0,0,27,9],
+"classviennacl_1_1hankel__matrix.html":[6,0,0,29],
+"classviennacl_1_1hankel__matrix.html#a20b24d60a29462b8e683e471a1b9dbbc":[6,0,0,29,4],
+"classviennacl_1_1hankel__matrix.html#a2965b9cc1428525b503791ff404ac2f1":[6,0,0,29,12],
+"classviennacl_1_1hankel__matrix.html#a39d10d5bab1e2564a7d34864a5ea38bf":[6,0,0,29,10],
+"classviennacl_1_1hankel__matrix.html#a44bd0dc3e75be825b2383665d1473dbe":[6,0,0,29,8],
+"classviennacl_1_1hankel__matrix.html#a5f49dd26c680c8c03f576cc02f2724f0":[6,0,0,29,3],
+"classviennacl_1_1hankel__matrix.html#a6b584238a8f38c32facfe9dbf3e2792b":[6,0,0,29,0],
+"classviennacl_1_1hankel__matrix.html#a70394fe33c8d39dc5cf0d892cbc4d33d":[6,0,0,29,7],
+"classviennacl_1_1hankel__matrix.html#a724654e6113cca8296d33d3f080c0481":[6,0,0,29,6],
+"classviennacl_1_1hankel__matrix.html#a9336c061fc3ba521106feabe826ae359":[6,0,0,29,9],
+"classviennacl_1_1hankel__matrix.html#abc7d6eeffe38e08ed8374d351b2fc858":[6,0,0,29,2],
+"classviennacl_1_1hankel__matrix.html#abd607e8fd04765fc5693feee660e268c":[6,0,0,29,1],
+"classviennacl_1_1hankel__matrix.html#ad2f2c36d273f68fabc8f0648eb005916":[6,0,0,29,5],
+"classviennacl_1_1hankel__matrix.html#ae1fe055fd4987e7ccc9585eaa169ebb6":[6,0,0,29,11],
+"classviennacl_1_1hyb__matrix.html":[6,0,0,30],
+"classviennacl_1_1hyb__matrix.html#a0394426fd3b91afe253b64fbbfee97b1":[6,0,0,30,2],
+"classviennacl_1_1hyb__matrix.html#a24b112fc2e22907c32646227831d443a":[6,0,0,30,3],
+"classviennacl_1_1hyb__matrix.html#a321b40813370fc067e3b49afed3da469":[6,0,0,30,18],
+"classviennacl_1_1hyb__matrix.html#a4b3f5963def504d05e7ab97b972067f0":[6,0,0,30,9],
+"classviennacl_1_1hyb__matrix.html#a71a65b6963fe30384f160f4cf6c189c8":[6,0,0,30,15],
+"classviennacl_1_1hyb__matrix.html#a78944df9433891f6654713dbbf34ed93":[6,0,0,30,4],
+"classviennacl_1_1hyb__matrix.html#a83cb07a6aa15fcf960b40b4a82fdc574":[6,0,0,30,10],
+"classviennacl_1_1hyb__matrix.html#a85c8cfa2f303c11c2e8ebea46e4ea400":[6,0,0,30,11],
+"classviennacl_1_1hyb__matrix.html#a8e95fcc738d25bcbf274dbfd538f000f":[6,0,0,30,16],
+"classviennacl_1_1hyb__matrix.html#a98dfc47bcf5178ccd6c888f39b2ec0e4":[6,0,0,30,5],
+"classviennacl_1_1hyb__matrix.html#a9a02c98d000f3d316c297300a8117246":[6,0,0,30,0],
+"classviennacl_1_1hyb__matrix.html#ab5f077832dd0efade9f5037327a1786d":[6,0,0,30,17],
+"classviennacl_1_1hyb__matrix.html#ac80cf4d3ab3ab38f398405ecf88419cd":[6,0,0,30,14],
+"classviennacl_1_1hyb__matrix.html#ac93fc5b3db82256f22d780618ad362db":[6,0,0,30,7],
+"classviennacl_1_1hyb__matrix.html#acd8b0197ad9c5a92ed26cf6ec3ce6137":[6,0,0,30,12],
+"classviennacl_1_1hyb__matrix.html#ad283de5ab491d075b34788c3293890ce":[6,0,0,30,8],
 "classviennacl_1_1hyb__matrix.html#aea26738cc380b7355a9ca42d0c47497d":[6,0,0,30,19],
+"classviennacl_1_1hyb__matrix.html#aed5ff60ddfef1cd59108064a5d4cdd7f":[6,0,0,30,13],
+"classviennacl_1_1hyb__matrix.html#af433c1695c1607b3b4f81a464bda22b6":[6,0,0,30,1],
+"classviennacl_1_1hyb__matrix.html#af90d7f7564c2e70301ea71f7a994f245":[6,0,0,30,6],
 "classviennacl_1_1identity__matrix.html":[6,0,0,31],
 "classviennacl_1_1identity__matrix.html#a08fccf1a11df6b16574d06c518748525":[6,0,0,31,0],
 "classviennacl_1_1identity__matrix.html#ae2a1c61b696a5f38b99d7acdc05068e7":[6,0,0,31,1],
@@ -210,44 +249,5 @@ var NAVTREEINDEX3 =
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a3eb5e91735ea5cbe820c9e46341a1412":[6,0,0,4,1,0,4,0],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a57bac405b68fb39194b0388d0777ec88":[6,0,0,4,1,0,4,30],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a5ff5045f45aafcd1811e0a2daa6682c6":[6,0,0,4,1,0,4,3],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a71f9ee39eb6d7f1c3e883aeb1cebb7ab":[6,0,0,4,1,0,4,26],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7dfd62f90e89c9c44817742853f9bfdb":[6,0,0,4,1,0,4,15],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7f17948d8d6bd916938bc8364f0f57bd":[6,0,0,4,1,0,4,34],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7fb70ced112d7fe8d100094ac01e0218":[6,0,0,4,1,0,4,20],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a83b5b8ed76481c00f3f9ab9f4f2d092b":[6,0,0,4,1,0,4,19],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a8d2b0e5d736bd6b2474cb63527795ab2":[6,0,0,4,1,0,4,25],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a94c5381db26ca84a8ff9d8040b8f8ab0":[6,0,0,4,1,0,4,27],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#aa52af92edbc05b62831999a62fed7265":[6,0,0,4,1,0,4,28],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#aae9de5af9b08a709a75de22169c5e800":[6,0,0,4,1,0,4,16],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ac3652232477faa776f9bab8668633928":[6,0,0,4,1,0,4,31],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ac41f1d4f71f4c11bfb4b3337a01b463a":[6,0,0,4,1,0,4,7],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#acd3bceba64dfca6280497b62335b9d03":[6,0,0,4,1,0,4,9],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#acffae976dde8cb07cc7b41c3c7f176fa":[6,0,0,4,1,0,4,29],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#adee5390a50dca13658d46d78c9d1f1b9":[6,0,0,4,1,0,4,24],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ae314c34008bc24f937c1d114509c8167":[6,0,0,4,1,0,4,13],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ae966c6a4b16c0faddb6582cf61c51c59":[6,0,0,4,1,0,4,18],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ae9717cc8d50a83c61e2b4107f4b646db":[6,0,0,4,1,0,4,22],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#aef80d850cc6157e03ea57a4bef728e40":[6,0,0,4,1,0,4,17],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#af1c7ba228cd839e73ff91668057e59fd":[6,0,0,4,1,0,4,10],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#af6e8cc37a96ed35b417303aa5d32171a":[6,0,0,4,1,0,4,4],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html":[6,0,0,4,1,0,5],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a0dafe3192d929985fbab7daa315e645d":[6,0,0,4,1,0,5,5],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a24c00d676b7ac96eeca5dd154d021b39":[6,0,0,4,1,0,5,13],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a2ebf1e3a3bf1714fac773224c7f91a8f":[6,0,0,4,1,0,5,18],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a45231fe374f209e4501ccc2ac639f460":[6,0,0,4,1,0,5,12],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a4d61e57595de462201671112e1b15e09":[6,0,0,4,1,0,5,14],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a5747df01b74ee54ea08fbb787602eec6":[6,0,0,4,1,0,5,6],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a7216464cc41eb1a944166d0d7ebee336":[6,0,0,4,1,0,5,0],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a7de72e1bf4e5ecfee1fe6e23cf5ea438":[6,0,0,4,1,0,5,1],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a7f68808644315c6e89c4f77def6fdea0":[6,0,0,4,1,0,5,9],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a8dedbf19532e087e1a8c84993f46b137":[6,0,0,4,1,0,5,8],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9a44b13ff6e8b428ded24d0aaed3b2df":[6,0,0,4,1,0,5,7],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9a4b3fc36666f560070cfa77a8f0f944":[6,0,0,4,1,0,5,15],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9dfc69a1e8dc73a04472337364e18653":[6,0,0,4,1,0,5,3],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9e02a74648ac5c875ac5496201440544":[6,0,0,4,1,0,5,2],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ab698bc4bd994487388a2ba87f41a8c17":[6,0,0,4,1,0,5,17],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ac2cabe20900909465d4f78368611e251":[6,0,0,4,1,0,5,4],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ac488087c92d47d8f400f524ba5857071":[6,0,0,4,1,0,5,11],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#adab776ab70ecca767a16044f462f35c5":[6,0,0,4,1,0,5,10],
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ae1c58ea9ff93afc2992e3c24ba0a5a13":[6,0,0,4,1,0,5,19]
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a71f9ee39eb6d7f1c3e883aeb1cebb7ab":[6,0,0,4,1,0,4,26]
 };
