@@ -1,5 +1,44 @@
 var NAVTREEINDEX4 =
 {
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7dfd62f90e89c9c44817742853f9bfdb":[6,0,0,4,1,0,4,15],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7f17948d8d6bd916938bc8364f0f57bd":[6,0,0,4,1,0,4,34],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7fb70ced112d7fe8d100094ac01e0218":[6,0,0,4,1,0,4,20],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a83b5b8ed76481c00f3f9ab9f4f2d092b":[6,0,0,4,1,0,4,19],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a8d2b0e5d736bd6b2474cb63527795ab2":[6,0,0,4,1,0,4,25],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a94c5381db26ca84a8ff9d8040b8f8ab0":[6,0,0,4,1,0,4,27],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#aa52af92edbc05b62831999a62fed7265":[6,0,0,4,1,0,4,28],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#aae9de5af9b08a709a75de22169c5e800":[6,0,0,4,1,0,4,16],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ac3652232477faa776f9bab8668633928":[6,0,0,4,1,0,4,31],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ac41f1d4f71f4c11bfb4b3337a01b463a":[6,0,0,4,1,0,4,7],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#acd3bceba64dfca6280497b62335b9d03":[6,0,0,4,1,0,4,9],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#acffae976dde8cb07cc7b41c3c7f176fa":[6,0,0,4,1,0,4,29],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#adee5390a50dca13658d46d78c9d1f1b9":[6,0,0,4,1,0,4,24],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ae314c34008bc24f937c1d114509c8167":[6,0,0,4,1,0,4,13],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ae966c6a4b16c0faddb6582cf61c51c59":[6,0,0,4,1,0,4,18],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#ae9717cc8d50a83c61e2b4107f4b646db":[6,0,0,4,1,0,4,22],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#aef80d850cc6157e03ea57a4bef728e40":[6,0,0,4,1,0,4,17],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#af1c7ba228cd839e73ff91668057e59fd":[6,0,0,4,1,0,4,10],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#af6e8cc37a96ed35b417303aa5d32171a":[6,0,0,4,1,0,4,4],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html":[6,0,0,4,1,0,5],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a0dafe3192d929985fbab7daa315e645d":[6,0,0,4,1,0,5,5],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a24c00d676b7ac96eeca5dd154d021b39":[6,0,0,4,1,0,5,13],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a2ebf1e3a3bf1714fac773224c7f91a8f":[6,0,0,4,1,0,5,18],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a45231fe374f209e4501ccc2ac639f460":[6,0,0,4,1,0,5,12],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a4d61e57595de462201671112e1b15e09":[6,0,0,4,1,0,5,14],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a5747df01b74ee54ea08fbb787602eec6":[6,0,0,4,1,0,5,6],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a7216464cc41eb1a944166d0d7ebee336":[6,0,0,4,1,0,5,0],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a7de72e1bf4e5ecfee1fe6e23cf5ea438":[6,0,0,4,1,0,5,1],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a7f68808644315c6e89c4f77def6fdea0":[6,0,0,4,1,0,5,9],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a8dedbf19532e087e1a8c84993f46b137":[6,0,0,4,1,0,5,8],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9a44b13ff6e8b428ded24d0aaed3b2df":[6,0,0,4,1,0,5,7],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9a4b3fc36666f560070cfa77a8f0f944":[6,0,0,4,1,0,5,15],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9dfc69a1e8dc73a04472337364e18653":[6,0,0,4,1,0,5,3],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#a9e02a74648ac5c875ac5496201440544":[6,0,0,4,1,0,5,2],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ab698bc4bd994487388a2ba87f41a8c17":[6,0,0,4,1,0,5,17],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ac2cabe20900909465d4f78368611e251":[6,0,0,4,1,0,5,4],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ac488087c92d47d8f400f524ba5857071":[6,0,0,4,1,0,5,11],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#adab776ab70ecca767a16044f462f35c5":[6,0,0,4,1,0,5,10],
+"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#ae1c58ea9ff93afc2992e3c24ba0a5a13":[6,0,0,4,1,0,5,19],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html#aefe2e025be1e1caeea7ae2f238b8e492":[6,0,0,4,1,0,5,16],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html":[6,0,0,4,1,0,6],
 "classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html#a00756e2673490d7ff66157f81e934824":[6,0,0,4,1,0,6,0],
@@ -210,44 +249,5 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1linalg_1_1power__iter__tag.html#a829b376442fbba41a3a7398a32f69b67":[6,0,0,4,30,2],
 "classviennacl_1_1linalg_1_1power__iter__tag.html#ade62a68b85d3187a7470345f46a710ab":[6,0,0,4,30,4],
 "classviennacl_1_1linalg_1_1power__iter__tag.html#af75af4cbe75d54d797ce1cc3907d7741":[6,0,0,4,30,0],
-"classviennacl_1_1linalg_1_1row__scaling.html":[6,0,0,4,31],
-"classviennacl_1_1linalg_1_1row__scaling.html#a772edd12410c3d582f4ad4f3d1bcd110":[6,0,0,4,31,1],
-"classviennacl_1_1linalg_1_1row__scaling.html#aa72db3a13d55bccc107e4c83e6663aee":[6,0,0,4,31,0],
-"classviennacl_1_1linalg_1_1row__scaling.html#af749c6f614c4ca03919098f29486da37":[6,0,0,4,31,2],
-"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html":[6,0,0,4,32],
-"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#a1bd03c552dcc799006641e233da7c301":[6,0,0,4,32,0],
-"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#a23fc95af614b76b6c6a152a44dfa5f7c":[6,0,0,4,32,1],
-"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#ad808b8c0aa51c598225e6d1807df2ab1":[6,0,0,4,32,2],
-"classviennacl_1_1linalg_1_1row__scaling__tag.html":[6,0,0,4,33],
-"classviennacl_1_1linalg_1_1row__scaling__tag.html#a3c3bfb1f173289eb5e5e8e91c59d4e7d":[6,0,0,4,33,0],
-"classviennacl_1_1linalg_1_1row__scaling__tag.html#aa53822390da5f7d7d497c71d706446d7":[6,0,0,4,33,1],
-"classviennacl_1_1linalg_1_1spai__precond.html":[6,0,0,4,34],
-"classviennacl_1_1linalg_1_1spai__precond.html#a3d149f1afa7719c358c7415f2f306e14":[6,0,0,4,34,3],
-"classviennacl_1_1linalg_1_1spai__precond.html#a4a39605607ecf9095fad66426b11580e":[6,0,0,4,34,2],
-"classviennacl_1_1linalg_1_1spai__precond.html#a6f10195cff888f10be69814616c6c4a0":[6,0,0,4,34,1],
-"classviennacl_1_1linalg_1_1spai__precond.html#aa7f452bb409abe29b7d0835fc69728b3":[6,0,0,4,34,0],
-"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html":[6,0,0,4,35],
-"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#a964acb6fb9cda96c9ff15ad9e60dadb4":[6,0,0,4,35,0],
-"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#aabfc6ef7298c66e9189107614fe1a297":[6,0,0,4,35,1],
-"classviennacl_1_1matrix.html":[6,0,0,62],
-"classviennacl_1_1matrix.html#a4ee409dd9bb90fb9324758e786a9220c":[6,0,0,62,7],
-"classviennacl_1_1matrix.html#a4f2838c746c5a8db1377898ee44489e0":[6,0,0,62,1],
-"classviennacl_1_1matrix.html#a52fe7272d3d01be023e7e80d2e31085c":[6,0,0,62,9],
-"classviennacl_1_1matrix.html#a677954883f3e9baac8fabfc61879a045":[6,0,0,62,4],
-"classviennacl_1_1matrix.html#a743efa0137f5f82478a8a1b615a738a4":[6,0,0,62,3],
-"classviennacl_1_1matrix.html#a79ae164ce8f984f303304d90f042bdcf":[6,0,0,62,8],
-"classviennacl_1_1matrix.html#a8467bf0d29df43906d388c961ad6a573":[6,0,0,62,0],
-"classviennacl_1_1matrix.html#a85f7c011fe21676c6a790d770e817787":[6,0,0,62,6],
-"classviennacl_1_1matrix.html#a9004170f7d1aca2ef3379927170f4564":[6,0,0,62,2],
-"classviennacl_1_1matrix.html#a912547a8b6b58c92375f84e27bb6d054":[6,0,0,62,11],
-"classviennacl_1_1matrix.html#aaaf86c2934b1e93a48c616d0c915f76c":[6,0,0,62,5],
-"classviennacl_1_1matrix.html#adf2592ae9254d226e24a26389a04721c":[6,0,0,62,10],
-"classviennacl_1_1matrix__base.html":[6,0,0,63],
-"classviennacl_1_1matrix__base.html#a00e30fdc61081a73995b54175a91d220":[6,0,0,63,19],
-"classviennacl_1_1matrix__base.html#a050371bcbfcc677b0514f1a00c9bdf67":[6,0,0,63,4],
-"classviennacl_1_1matrix__base.html#a0871683c6bdf478a8875a9680c125729":[6,0,0,63,57],
-"classviennacl_1_1matrix__base.html#a0a523347f5392d5afd43c6b41cbbc6ce":[6,0,0,63,54],
-"classviennacl_1_1matrix__base.html#a15ec879f9e85a6fc209454b0bf137084":[6,0,0,63,50],
-"classviennacl_1_1matrix__base.html#a21c79063d8aa5108bdec78b7ee720da8":[6,0,0,63,24],
-"classviennacl_1_1matrix__base.html#a24e4f5fa27a1af5ad47e52a97c065d68":[6,0,0,63,52]
+"classviennacl_1_1linalg_1_1row__scaling.html":[6,0,0,4,31]
 };
