@@ -1,5 +1,44 @@
 var NAVTREEINDEX5 =
 {
+"classviennacl_1_1linalg_1_1row__scaling.html#a772edd12410c3d582f4ad4f3d1bcd110":[6,0,0,4,31,1],
+"classviennacl_1_1linalg_1_1row__scaling.html#aa72db3a13d55bccc107e4c83e6663aee":[6,0,0,4,31,0],
+"classviennacl_1_1linalg_1_1row__scaling.html#af749c6f614c4ca03919098f29486da37":[6,0,0,4,31,2],
+"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html":[6,0,0,4,32],
+"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#a1bd03c552dcc799006641e233da7c301":[6,0,0,4,32,0],
+"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#a23fc95af614b76b6c6a152a44dfa5f7c":[6,0,0,4,32,1],
+"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#ad808b8c0aa51c598225e6d1807df2ab1":[6,0,0,4,32,2],
+"classviennacl_1_1linalg_1_1row__scaling__tag.html":[6,0,0,4,33],
+"classviennacl_1_1linalg_1_1row__scaling__tag.html#a3c3bfb1f173289eb5e5e8e91c59d4e7d":[6,0,0,4,33,0],
+"classviennacl_1_1linalg_1_1row__scaling__tag.html#aa53822390da5f7d7d497c71d706446d7":[6,0,0,4,33,1],
+"classviennacl_1_1linalg_1_1spai__precond.html":[6,0,0,4,34],
+"classviennacl_1_1linalg_1_1spai__precond.html#a3d149f1afa7719c358c7415f2f306e14":[6,0,0,4,34,3],
+"classviennacl_1_1linalg_1_1spai__precond.html#a4a39605607ecf9095fad66426b11580e":[6,0,0,4,34,2],
+"classviennacl_1_1linalg_1_1spai__precond.html#a6f10195cff888f10be69814616c6c4a0":[6,0,0,4,34,1],
+"classviennacl_1_1linalg_1_1spai__precond.html#aa7f452bb409abe29b7d0835fc69728b3":[6,0,0,4,34,0],
+"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html":[6,0,0,4,35],
+"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#a964acb6fb9cda96c9ff15ad9e60dadb4":[6,0,0,4,35,0],
+"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#aabfc6ef7298c66e9189107614fe1a297":[6,0,0,4,35,1],
+"classviennacl_1_1matrix.html":[6,0,0,62],
+"classviennacl_1_1matrix.html#a1de4d71a10ba9b60a01005bae51027b5":[6,0,0,62,0],
+"classviennacl_1_1matrix.html#a69431725e09b2b73606dee084c962d7f":[6,0,0,62,11],
+"classviennacl_1_1matrix.html#a8a5ce7e676c57d1f0acd746951d32fec":[6,0,0,62,9],
+"classviennacl_1_1matrix.html#aa1d160f8ee553be461e27550d33a774e":[6,0,0,62,1],
+"classviennacl_1_1matrix.html#ab3ef00115276f179a8cd2172f9738e33":[6,0,0,62,3],
+"classviennacl_1_1matrix.html#ab8eb950050017f961faf5ac0184e934c":[6,0,0,62,8],
+"classviennacl_1_1matrix.html#ac3cd72a83b58d55a61357669bee23b38":[6,0,0,62,2],
+"classviennacl_1_1matrix.html#ac8dad9e664244e4a6dd9f45e061a4adc":[6,0,0,62,7],
+"classviennacl_1_1matrix.html#ad5fde9fad4e61456dfd9a4818bf210d0":[6,0,0,62,10],
+"classviennacl_1_1matrix.html#adae9b1fad83885bd3162031e012ed3ea":[6,0,0,62,4],
+"classviennacl_1_1matrix.html#adde2f19fc84b9d96db059b9bb9af448d":[6,0,0,62,5],
+"classviennacl_1_1matrix.html#aedafac235f345bca2e555930a748415d":[6,0,0,62,6],
+"classviennacl_1_1matrix__base.html":[6,0,0,63],
+"classviennacl_1_1matrix__base.html#a00e30fdc61081a73995b54175a91d220":[6,0,0,63,19],
+"classviennacl_1_1matrix__base.html#a050371bcbfcc677b0514f1a00c9bdf67":[6,0,0,63,4],
+"classviennacl_1_1matrix__base.html#a0871683c6bdf478a8875a9680c125729":[6,0,0,63,57],
+"classviennacl_1_1matrix__base.html#a0a523347f5392d5afd43c6b41cbbc6ce":[6,0,0,63,54],
+"classviennacl_1_1matrix__base.html#a15ec879f9e85a6fc209454b0bf137084":[6,0,0,63,50],
+"classviennacl_1_1matrix__base.html#a21c79063d8aa5108bdec78b7ee720da8":[6,0,0,63,24],
+"classviennacl_1_1matrix__base.html#a24e4f5fa27a1af5ad47e52a97c065d68":[6,0,0,63,52],
 "classviennacl_1_1matrix__base.html#a25b797fdf4d3c841cae4d047f9cfbaee":[6,0,0,63,36],
 "classviennacl_1_1matrix__base.html#a28087e6cd79a3eb13df18b40092966d3":[6,0,0,63,56],
 "classviennacl_1_1matrix__base.html#a2896fa7b137959c57bcb5966a2a37870":[6,0,0,63,25],
@@ -60,16 +99,16 @@ var NAVTREEINDEX5 =
 "classviennacl_1_1matrix__expression.html#aa2c582e8d2c1cafbf2ffdf05c9fdfaca":[6,0,0,64,2],
 "classviennacl_1_1matrix__expression.html#ad8516f3a2ef4db4d5379fb64832fd39f":[6,0,0,64,5],
 "classviennacl_1_1matrix__iterator.html":[6,0,0,65],
-"classviennacl_1_1matrix__iterator.html#a15bda6557c012f86dc73d712bc71d7f3":[6,0,0,65,7],
-"classviennacl_1_1matrix__iterator.html#a1837364083cd08f862d3ea5608af5f82":[6,0,0,65,2],
-"classviennacl_1_1matrix__iterator.html#a3ff1ff49f79aea6ba824ecdb460ecc14":[6,0,0,65,1],
-"classviennacl_1_1matrix__iterator.html#a839f7b14cdb91361b88dd6b230d6b505":[6,0,0,65,8],
-"classviennacl_1_1matrix__iterator.html#a9b8eeaefaa8bf5276b8d63cf3a471ade":[6,0,0,65,4],
-"classviennacl_1_1matrix__iterator.html#ab0dc7706eacde70d1857372b602b6bad":[6,0,0,65,3],
-"classviennacl_1_1matrix__iterator.html#ab5b8c98222880e6ae5f92d54c7d06e14":[6,0,0,65,6],
-"classviennacl_1_1matrix__iterator.html#ae11cd06a58c70e8a4f90fd5e1946a9ee":[6,0,0,65,0],
-"classviennacl_1_1matrix__iterator.html#ae473cc7d80378c7384b365d4959457df":[6,0,0,65,5],
-"classviennacl_1_1matrix__iterator.html#af1aee4972f71999a4f46dac773543530":[6,0,0,65,9],
+"classviennacl_1_1matrix__iterator.html#a121be30f9b9c7585e30d14dd0cdcc6a3":[6,0,0,65,0],
+"classviennacl_1_1matrix__iterator.html#a1d773c1b5ee19bc68b400442a9550e2e":[6,0,0,65,4],
+"classviennacl_1_1matrix__iterator.html#a2cab0902708eef3409d060525e7b1bd3":[6,0,0,65,7],
+"classviennacl_1_1matrix__iterator.html#a4801a7780c28b98488cfb2bf75c668c3":[6,0,0,65,6],
+"classviennacl_1_1matrix__iterator.html#a4ef6bffdf5f728b0bbba6ba175a0a4d9":[6,0,0,65,8],
+"classviennacl_1_1matrix__iterator.html#a6831a7e228fd80e84711d82e2362c6db":[6,0,0,65,5],
+"classviennacl_1_1matrix__iterator.html#a70cfd358baf22f4ee9570f1a6b7c1701":[6,0,0,65,2],
+"classviennacl_1_1matrix__iterator.html#a817d81d889d73ac2dc6e6177e062bd7a":[6,0,0,65,1],
+"classviennacl_1_1matrix__iterator.html#a895218ddd37e5f964c30bc89d0cd1781":[6,0,0,65,9],
+"classviennacl_1_1matrix__iterator.html#ac35c319df57718089c7f39d97733e1ba":[6,0,0,65,3],
 "classviennacl_1_1matrix__range.html":[6,0,0,66],
 "classviennacl_1_1matrix__range.html#a100b1ddda26bfd792b34b666c0dc23e2":[6,0,0,66,8],
 "classviennacl_1_1matrix__range.html#a294649e885898124628094aa3acd5fa5":[6,0,0,66,4],
@@ -210,44 +249,5 @@ var NAVTREEINDEX5 =
 "classviennacl_1_1ocl_1_1device.html#a9942f500eae3abcc9d4ed04571da7aec":[6,0,0,5,8,43],
 "classviennacl_1_1ocl_1_1device.html#a9ad000d1e977e3fe36d7d0df7d11c94a":[6,0,0,5,8,19],
 "classviennacl_1_1ocl_1_1device.html#a9cde93282f4e1fe0e5d29b2b47663ccd":[6,0,0,5,8,67],
-"classviennacl_1_1ocl_1_1device.html#a9d70b7e5140a2276f041eb2f0da5e713":[6,0,0,5,8,12],
-"classviennacl_1_1ocl_1_1device.html#a9efdfafd0819090844b28a123510283c":[6,0,0,5,8,20],
-"classviennacl_1_1ocl_1_1device.html#a9fae6852832319bb6b63e536ed745302":[6,0,0,5,8,17],
-"classviennacl_1_1ocl_1_1device.html#aa265513f3cd441860240d9d0a4da58c8":[6,0,0,5,8,32],
-"classviennacl_1_1ocl_1_1device.html#aa9701e2af3c67fb0b9682be23d1e4549":[6,0,0,5,8,35],
-"classviennacl_1_1ocl_1_1device.html#aacc7d3e11a3aaec763cd7d398e9b6638":[6,0,0,5,8,26],
-"classviennacl_1_1ocl_1_1device.html#ab1542d4241b875ef9c073ceca3ac73a6":[6,0,0,5,8,4],
-"classviennacl_1_1ocl_1_1device.html#ab2af60036bc98136d07090b9498e2b26":[6,0,0,5,8,42],
-"classviennacl_1_1ocl_1_1device.html#ab911d6e8731391fb4d7b793445f95144":[6,0,0,5,8,47],
-"classviennacl_1_1ocl_1_1device.html#abdd6815035bf4dfe6ff9b4bc1034f083":[6,0,0,5,8,8],
-"classviennacl_1_1ocl_1_1device.html#ac21b85d536377b4823d57e247babc8ce":[6,0,0,5,8,54],
-"classviennacl_1_1ocl_1_1device.html#ac512504fdb63e042e6034c145016d745":[6,0,0,5,8,33],
-"classviennacl_1_1ocl_1_1device.html#acdd69338283c7a1ca06b11b0759c8843":[6,0,0,5,8,7],
-"classviennacl_1_1ocl_1_1device.html#ad26c171dde7a764fa4f95c328b01bbab":[6,0,0,5,8,15],
-"classviennacl_1_1ocl_1_1device.html#ad378cbbb6b0db7d460216537832f1ce5":[6,0,0,5,8,36],
-"classviennacl_1_1ocl_1_1device.html#ad82b4da356f1f306b34eb87a53b8b7ec":[6,0,0,5,8,28],
-"classviennacl_1_1ocl_1_1device.html#adc951e818db7dab22ebbf4c65e4cbe42":[6,0,0,5,8,24],
-"classviennacl_1_1ocl_1_1device.html#add9bf288639d88f5188e09f71f7dd29c":[6,0,0,5,8,3],
-"classviennacl_1_1ocl_1_1device.html#af7cd6b2e1cb1d9d8ce4b03593767508c":[6,0,0,5,8,38],
-"classviennacl_1_1ocl_1_1device.html#af7dc4811d67aac349f79ed7fcbd4ecb1":[6,0,0,5,8,13],
-"classviennacl_1_1ocl_1_1device.html#afd017572cf46fa80de40baf9eef1cb25":[6,0,0,5,8,10],
-"classviennacl_1_1ocl_1_1device.html#afef78e460b0577fe72b8ad61a5aef8c5":[6,0,0,5,8,27],
-"classviennacl_1_1ocl_1_1device.html#aff7d09f8a5665b125bf4b7c749c9c144":[6,0,0,5,8,16],
-"classviennacl_1_1ocl_1_1device__not__available.html":[6,0,0,5,9],
-"classviennacl_1_1ocl_1_1device__not__found.html":[6,0,0,5,10],
-"classviennacl_1_1ocl_1_1double__precision__not__provided__error.html":[6,0,0,5,12],
-"classviennacl_1_1ocl_1_1handle.html":[6,0,0,5,15],
-"classviennacl_1_1ocl_1_1handle.html#a31e278200ed22f38e619ae63592c0e20":[6,0,0,5,15,1],
-"classviennacl_1_1ocl_1_1handle.html#a3d32cab83155c46b4c944aec28431ec9":[6,0,0,5,15,11],
-"classviennacl_1_1ocl_1_1handle.html#a5074caaee700015fc2d3b03540b01673":[6,0,0,5,15,7],
-"classviennacl_1_1ocl_1_1handle.html#a5198f1189817af5da775a9a497c82959":[6,0,0,5,15,5],
-"classviennacl_1_1ocl_1_1handle.html#a6c1f7f4d3445e6d6ef0e7106fa631417":[6,0,0,5,15,9],
-"classviennacl_1_1ocl_1_1handle.html#a92f8d895f659fc44cbd6a594c88f2c3b":[6,0,0,5,15,12],
-"classviennacl_1_1ocl_1_1handle.html#aabb9d0a4beed00a52500de6047651135":[6,0,0,5,15,4],
-"classviennacl_1_1ocl_1_1handle.html#ab7d6c40f287c57376928b4114e8176ed":[6,0,0,5,15,13],
-"classviennacl_1_1ocl_1_1handle.html#ab99e3ba37442fb195c1da4e022b6ff23":[6,0,0,5,15,10],
-"classviennacl_1_1ocl_1_1handle.html#abd32b02babef2794751f39eb749a556a":[6,0,0,5,15,6],
-"classviennacl_1_1ocl_1_1handle.html#ae3177c23936042f8984cc6f09f9e83d6":[6,0,0,5,15,3],
-"classviennacl_1_1ocl_1_1handle.html#ae422ce46a3a48223c08b87cead97bf7e":[6,0,0,5,15,0],
-"classviennacl_1_1ocl_1_1handle.html#ae9699f5b1f8d8df4eba7bacf0a563f32":[6,0,0,5,15,8]
+"classviennacl_1_1ocl_1_1device.html#a9d70b7e5140a2276f041eb2f0da5e713":[6,0,0,5,8,12]
 };
