@@ -1,5 +1,44 @@
 var NAVTREEINDEX6 =
 {
+"classviennacl_1_1ocl_1_1device.html#a9efdfafd0819090844b28a123510283c":[6,0,0,5,8,20],
+"classviennacl_1_1ocl_1_1device.html#a9fae6852832319bb6b63e536ed745302":[6,0,0,5,8,17],
+"classviennacl_1_1ocl_1_1device.html#aa265513f3cd441860240d9d0a4da58c8":[6,0,0,5,8,32],
+"classviennacl_1_1ocl_1_1device.html#aa9701e2af3c67fb0b9682be23d1e4549":[6,0,0,5,8,35],
+"classviennacl_1_1ocl_1_1device.html#aacc7d3e11a3aaec763cd7d398e9b6638":[6,0,0,5,8,26],
+"classviennacl_1_1ocl_1_1device.html#ab1542d4241b875ef9c073ceca3ac73a6":[6,0,0,5,8,4],
+"classviennacl_1_1ocl_1_1device.html#ab2af60036bc98136d07090b9498e2b26":[6,0,0,5,8,42],
+"classviennacl_1_1ocl_1_1device.html#ab911d6e8731391fb4d7b793445f95144":[6,0,0,5,8,47],
+"classviennacl_1_1ocl_1_1device.html#abdd6815035bf4dfe6ff9b4bc1034f083":[6,0,0,5,8,8],
+"classviennacl_1_1ocl_1_1device.html#ac21b85d536377b4823d57e247babc8ce":[6,0,0,5,8,54],
+"classviennacl_1_1ocl_1_1device.html#ac512504fdb63e042e6034c145016d745":[6,0,0,5,8,33],
+"classviennacl_1_1ocl_1_1device.html#acdd69338283c7a1ca06b11b0759c8843":[6,0,0,5,8,7],
+"classviennacl_1_1ocl_1_1device.html#ad26c171dde7a764fa4f95c328b01bbab":[6,0,0,5,8,15],
+"classviennacl_1_1ocl_1_1device.html#ad378cbbb6b0db7d460216537832f1ce5":[6,0,0,5,8,36],
+"classviennacl_1_1ocl_1_1device.html#ad82b4da356f1f306b34eb87a53b8b7ec":[6,0,0,5,8,28],
+"classviennacl_1_1ocl_1_1device.html#adc951e818db7dab22ebbf4c65e4cbe42":[6,0,0,5,8,24],
+"classviennacl_1_1ocl_1_1device.html#add9bf288639d88f5188e09f71f7dd29c":[6,0,0,5,8,3],
+"classviennacl_1_1ocl_1_1device.html#af7cd6b2e1cb1d9d8ce4b03593767508c":[6,0,0,5,8,38],
+"classviennacl_1_1ocl_1_1device.html#af7dc4811d67aac349f79ed7fcbd4ecb1":[6,0,0,5,8,13],
+"classviennacl_1_1ocl_1_1device.html#afd017572cf46fa80de40baf9eef1cb25":[6,0,0,5,8,10],
+"classviennacl_1_1ocl_1_1device.html#afef78e460b0577fe72b8ad61a5aef8c5":[6,0,0,5,8,27],
+"classviennacl_1_1ocl_1_1device.html#aff7d09f8a5665b125bf4b7c749c9c144":[6,0,0,5,8,16],
+"classviennacl_1_1ocl_1_1device__not__available.html":[6,0,0,5,9],
+"classviennacl_1_1ocl_1_1device__not__found.html":[6,0,0,5,10],
+"classviennacl_1_1ocl_1_1double__precision__not__provided__error.html":[6,0,0,5,12],
+"classviennacl_1_1ocl_1_1handle.html":[6,0,0,5,15],
+"classviennacl_1_1ocl_1_1handle.html#a31e278200ed22f38e619ae63592c0e20":[6,0,0,5,15,1],
+"classviennacl_1_1ocl_1_1handle.html#a3d32cab83155c46b4c944aec28431ec9":[6,0,0,5,15,11],
+"classviennacl_1_1ocl_1_1handle.html#a5074caaee700015fc2d3b03540b01673":[6,0,0,5,15,7],
+"classviennacl_1_1ocl_1_1handle.html#a5198f1189817af5da775a9a497c82959":[6,0,0,5,15,5],
+"classviennacl_1_1ocl_1_1handle.html#a6c1f7f4d3445e6d6ef0e7106fa631417":[6,0,0,5,15,9],
+"classviennacl_1_1ocl_1_1handle.html#a92f8d895f659fc44cbd6a594c88f2c3b":[6,0,0,5,15,12],
+"classviennacl_1_1ocl_1_1handle.html#aabb9d0a4beed00a52500de6047651135":[6,0,0,5,15,4],
+"classviennacl_1_1ocl_1_1handle.html#ab7d6c40f287c57376928b4114e8176ed":[6,0,0,5,15,13],
+"classviennacl_1_1ocl_1_1handle.html#ab99e3ba37442fb195c1da4e022b6ff23":[6,0,0,5,15,10],
+"classviennacl_1_1ocl_1_1handle.html#abd32b02babef2794751f39eb749a556a":[6,0,0,5,15,6],
+"classviennacl_1_1ocl_1_1handle.html#ae3177c23936042f8984cc6f09f9e83d6":[6,0,0,5,15,3],
+"classviennacl_1_1ocl_1_1handle.html#ae422ce46a3a48223c08b87cead97bf7e":[6,0,0,5,15,0],
+"classviennacl_1_1ocl_1_1handle.html#ae9699f5b1f8d8df4eba7bacf0a563f32":[6,0,0,5,15,8],
 "classviennacl_1_1ocl_1_1handle.html#aedfb2501c3d363bf46127d03cab9ad2f":[6,0,0,5,15,2],
 "classviennacl_1_1ocl_1_1handle__inc__dec__helper.html":[6,0,0,5,16],
 "classviennacl_1_1ocl_1_1image__format__mismatch.html":[6,0,0,5,17],
@@ -129,53 +168,53 @@ var NAVTREEINDEX6 =
 "classviennacl_1_1ocl_1_1program.html#acd547941bc65e0a26eb2d6a9c3e4c29f":[6,0,0,5,64,8],
 "classviennacl_1_1ocl_1_1unknown__error.html":[6,0,0,5,66],
 "classviennacl_1_1scalar.html":[6,0,0,134],
-"classviennacl_1_1scalar.html#a08c2d9ff4896a158886dcd25e5adb8d3":[6,0,0,134,38],
-"classviennacl_1_1scalar.html#a0d3e0ad91f3fcd6b01421a8736a09f56":[6,0,0,134,2],
-"classviennacl_1_1scalar.html#a1158f00ae60e1814779bc280019b77fb":[6,0,0,134,13],
-"classviennacl_1_1scalar.html#a1edb6d67dceb3c1e0a35b296a25ff247":[6,0,0,134,17],
-"classviennacl_1_1scalar.html#a2402edbb5081a3129c3ed51cae1c821a":[6,0,0,134,18],
-"classviennacl_1_1scalar.html#a247ef5ba45ecfa89cf77f88f1ea944c0":[6,0,0,134,21],
-"classviennacl_1_1scalar.html#a2550463c69ac48380b81784c2d033835":[6,0,0,134,5],
-"classviennacl_1_1scalar.html#a29593690a9b384bbfd5f6ec8b83420e8":[6,0,0,134,15],
-"classviennacl_1_1scalar.html#a2baf935224e17d6ff9d3dbd9a9e200ea":[6,0,0,134,33],
-"classviennacl_1_1scalar.html#a336274152948771e58a151ced13ab590":[6,0,0,134,36],
-"classviennacl_1_1scalar.html#a397022764ab50cb43eb26323d6289649":[6,0,0,134,14],
-"classviennacl_1_1scalar.html#a59a856b45ab90c25c50a28a87a5e96a6":[6,0,0,134,45],
-"classviennacl_1_1scalar.html#a633f9442401801c504485d3bf40137ae":[6,0,0,134,25],
-"classviennacl_1_1scalar.html#a64235c3e5db6f4ae8481f73262158da9":[6,0,0,134,16],
-"classviennacl_1_1scalar.html#a6706e7de76559bbf0c59b080d8c23af8":[6,0,0,134,44],
-"classviennacl_1_1scalar.html#a677d9162e070ba140d32200dc8286d1c":[6,0,0,134,0],
-"classviennacl_1_1scalar.html#a67c0b9d5ee5e1525b17d51daa939ace2":[6,0,0,134,12],
-"classviennacl_1_1scalar.html#a6e015ff1e1e91d34b62cf84324aafed7":[6,0,0,134,27],
-"classviennacl_1_1scalar.html#a6f9bee9cfee9774b8152064f91db74a3":[6,0,0,134,22],
-"classviennacl_1_1scalar.html#a74523d98c54af86ddbfbd105b81b4cb4":[6,0,0,134,35],
-"classviennacl_1_1scalar.html#a74a7c48ebab16d449260ee545e8d4a16":[6,0,0,134,8],
-"classviennacl_1_1scalar.html#a77ed90aa6e021bb56a16036dff9bf840":[6,0,0,134,24],
-"classviennacl_1_1scalar.html#a7ce155edb3984c0d4ac55f176b2b98a8":[6,0,0,134,42],
-"classviennacl_1_1scalar.html#a8454ca86b8e813bbcc9dd8d2848ae661":[6,0,0,134,41],
-"classviennacl_1_1scalar.html#a86fc93687caec15554bf9899b8b4b5fe":[6,0,0,134,37],
-"classviennacl_1_1scalar.html#a886772924333d38c331ff6075f52aaee":[6,0,0,134,6],
-"classviennacl_1_1scalar.html#a8b1050438e0ac684bc427c28ca518c72":[6,0,0,134,43],
-"classviennacl_1_1scalar.html#a8b356ca09132e5f02b1ed3d98c3d56a6":[6,0,0,134,20],
-"classviennacl_1_1scalar.html#a8f1444dd3d6625ad55c9ee448a89bffc":[6,0,0,134,26],
-"classviennacl_1_1scalar.html#a8fdf64948b6d57df95d2eb948ec0d309":[6,0,0,134,19],
-"classviennacl_1_1scalar.html#a93ddffb91eb58839512f20e1f31e3eee":[6,0,0,134,3],
-"classviennacl_1_1scalar.html#a984dbf64266ea3c69a3881c3adc047c4":[6,0,0,134,11],
-"classviennacl_1_1scalar.html#a9e3fc554897e2d89583e44b23c5dbacb":[6,0,0,134,31],
-"classviennacl_1_1scalar.html#a9ed196c307e0d8651db96554f601ea0b":[6,0,0,134,28],
-"classviennacl_1_1scalar.html#aa21ce8cf63c4eb0ba5dc73cce6887edd":[6,0,0,134,34],
-"classviennacl_1_1scalar.html#aa7833efb94a6e4bef447de465ce792a3":[6,0,0,134,40],
-"classviennacl_1_1scalar.html#ab2648786b83a24feaeb3acee44d9d1f3":[6,0,0,134,29],
-"classviennacl_1_1scalar.html#abc196fa7a5c88c211509bc08b6b3cffb":[6,0,0,134,23],
-"classviennacl_1_1scalar.html#abe064f0f208940ca6cf641e9f6c10d2e":[6,0,0,134,9],
-"classviennacl_1_1scalar.html#ace0a5bc265d1adb46887d9357d1a9a48":[6,0,0,134,39],
-"classviennacl_1_1scalar.html#ad055379bae77025ac33511134cd4d235":[6,0,0,134,32],
-"classviennacl_1_1scalar.html#adc0be626c3180f31f27a17ccb1e6826d":[6,0,0,134,1],
-"classviennacl_1_1scalar.html#ae23752527f0a3839de0ad8f4e58086e8":[6,0,0,134,4],
-"classviennacl_1_1scalar.html#ae5e3379620c912103a6ebf441f62ff74":[6,0,0,134,10],
-"classviennacl_1_1scalar.html#ae879be2125165b53e30fdf6a614d9ed2":[6,0,0,134,7],
-"classviennacl_1_1scalar.html#ae91913100fba02dc781872c78afc2eb1":[6,0,0,134,30],
-"classviennacl_1_1scalar.html#afa2d31bbedb21aeefd47b305e4638866":[6,0,0,134,46],
+"classviennacl_1_1scalar.html#a039864953bf3d52090a2745d2fe6fd7d":[6,0,0,134,36],
+"classviennacl_1_1scalar.html#a08003a51f240beb986e87e89c3e5aadb":[6,0,0,134,26],
+"classviennacl_1_1scalar.html#a0c8acf00720f9f1e6905afa49f161195":[6,0,0,134,42],
+"classviennacl_1_1scalar.html#a0e537abe4622c337c128fdeb69fa7bc3":[6,0,0,134,13],
+"classviennacl_1_1scalar.html#a0fb54e68e728d5498beccd8f576f2824":[6,0,0,134,4],
+"classviennacl_1_1scalar.html#a1348460f9568c82b03e702f0f462b103":[6,0,0,134,31],
+"classviennacl_1_1scalar.html#a13841f655ad0db828a051dc5c493f62e":[6,0,0,134,11],
+"classviennacl_1_1scalar.html#a20696140c3c8be4a8e57eac4c981e901":[6,0,0,134,16],
+"classviennacl_1_1scalar.html#a2848490d989bc3bbc43bce9c9e2e7e47":[6,0,0,134,46],
+"classviennacl_1_1scalar.html#a300abf63fd0a8c7d16a86b5c38fcba85":[6,0,0,134,19],
+"classviennacl_1_1scalar.html#a3a1c64828845f9cb3ff95c9b74d7d91e":[6,0,0,134,15],
+"classviennacl_1_1scalar.html#a40e8ee6244282b6fbf78721ad882d7f3":[6,0,0,134,43],
+"classviennacl_1_1scalar.html#a4796cc006370a23ad39c219345b8f9d1":[6,0,0,134,28],
+"classviennacl_1_1scalar.html#a4d3f381ef0e11f0982008478d6880260":[6,0,0,134,23],
+"classviennacl_1_1scalar.html#a4dd25a5b21b73666beb53be74c6600c0":[6,0,0,134,34],
+"classviennacl_1_1scalar.html#a5084e4fb32433ce7f89db0b360d02d6e":[6,0,0,134,12],
+"classviennacl_1_1scalar.html#a61edbb3444dc11d3f9a486471bb7c73f":[6,0,0,134,22],
+"classviennacl_1_1scalar.html#a61f087873af5cf044919a9d8cc65148b":[6,0,0,134,44],
+"classviennacl_1_1scalar.html#a62e91650a0e4c8bfea7295ec2ec135ae":[6,0,0,134,9],
+"classviennacl_1_1scalar.html#a69ce10d4e191713197693808422b44fa":[6,0,0,134,14],
+"classviennacl_1_1scalar.html#a6ade6278192bdccdea73d652572d0eff":[6,0,0,134,10],
+"classviennacl_1_1scalar.html#a6ae18afad2a90e658dad9f13590d6233":[6,0,0,134,24],
+"classviennacl_1_1scalar.html#a809eec0b71ad355e477d4373b752cdbc":[6,0,0,134,27],
+"classviennacl_1_1scalar.html#a86b08f019e042e64980409be388f964d":[6,0,0,134,17],
+"classviennacl_1_1scalar.html#a875ae8b5e6e94c647d7e936ceefcb6af":[6,0,0,134,1],
+"classviennacl_1_1scalar.html#a9a62e56c8941de87f86b6b7ccd4987e3":[6,0,0,134,7],
+"classviennacl_1_1scalar.html#a9aac3b41ba11b615ac4b7386760d8817":[6,0,0,134,37],
+"classviennacl_1_1scalar.html#aa6cfc729c8415bd77ead0279029ff10a":[6,0,0,134,0],
+"classviennacl_1_1scalar.html#aa99c65862c6bfdf615b500343a499a53":[6,0,0,134,45],
+"classviennacl_1_1scalar.html#aae8ff8c9d2f2c6a4f5dd949f357351fb":[6,0,0,134,38],
+"classviennacl_1_1scalar.html#ab3423f018ea6f514563afe6c9aa22b90":[6,0,0,134,5],
+"classviennacl_1_1scalar.html#ab66c8839c17398e14b580ce106a5065a":[6,0,0,134,18],
+"classviennacl_1_1scalar.html#abba3283c5cbc4b256b93d98cbeb7c547":[6,0,0,134,20],
+"classviennacl_1_1scalar.html#abca016cd21e4ad7b64613ce01f4b5d1b":[6,0,0,134,35],
+"classviennacl_1_1scalar.html#abe434dd18296ba57abd06953e18ff54d":[6,0,0,134,21],
+"classviennacl_1_1scalar.html#abf40c59a34e3ef69f94a6dce2864579a":[6,0,0,134,32],
+"classviennacl_1_1scalar.html#ac4a8f1294091d07ce08a843143447916":[6,0,0,134,39],
+"classviennacl_1_1scalar.html#ac9ae9cb3d8a2a4ac9b9f351b9c6728f0":[6,0,0,134,2],
+"classviennacl_1_1scalar.html#ad5a9f875223d34af2cf32c31fe38c7df":[6,0,0,134,29],
+"classviennacl_1_1scalar.html#ae52bd107e3502d5a3a617b5a2f5c2553":[6,0,0,134,8],
+"classviennacl_1_1scalar.html#ae930cde127fae5e9121b7fe1a70279d5":[6,0,0,134,41],
+"classviennacl_1_1scalar.html#af05f82cd1a2e83039743260ac20510d1":[6,0,0,134,25],
+"classviennacl_1_1scalar.html#af1efa3d0a079e942373354692ecd2645":[6,0,0,134,3],
+"classviennacl_1_1scalar.html#af534e2813fd3c2e452713b2744de19c8":[6,0,0,134,30],
+"classviennacl_1_1scalar.html#af82f32946ff33d23156c922a2be7c5c6":[6,0,0,134,40],
+"classviennacl_1_1scalar.html#afa017f43747cb3373bb3c7ef7b980c19":[6,0,0,134,33],
+"classviennacl_1_1scalar.html#afc9662763b781600f5daa2ae22961a29":[6,0,0,134,6],
 "classviennacl_1_1scalar__expression.html":[6,0,0,135],
 "classviennacl_1_1scalar__expression.html#a0193d061e7248e70783129db29a557d5":[6,0,0,135,3],
 "classviennacl_1_1scalar__expression.html#a53b924f0f346fb455ae3dc8a06f53c27":[6,0,0,135,1],
@@ -210,44 +249,5 @@ var NAVTREEINDEX6 =
 "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a10d33c07e2bb1d90fceb5fd2a9f61491":[6,0,0,140,1],
 "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a18353ae42ce4917bfc94880597d59887":[6,0,0,140,0],
 "classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a44c730ad1b5b07bd775c219880b85196":[6,0,0,140,2],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a5c396160db0ffed8c540e6d3c12af0ee":[6,0,0,140,4],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a670faef4da7eb44516eaf0502e0da52e":[6,0,0,140,3],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html":[6,0,0,141],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#a86f83b73234e0edf79091da73ce14c29":[6,0,0,141,0],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#ab15d868e688c03c848c1bc3eb3519108":[6,0,0,141,4],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#acf599122110d3d7332d874b943fd49be":[6,0,0,141,2],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#ad4a3e5a53aeebca6c63a2426c9b5e31d":[6,0,0,141,3],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#ad801407959eec646c0782a20e221392e":[6,0,0,141,1],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html":[6,0,0,142],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a0a3d8a45ae5f29887aa1eceb03abdbec":[6,0,0,142,1],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a0ac29370b6cf978a29691334da813d74":[6,0,0,142,2],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a23831b3a67caf34ee518be31d452838c":[6,0,0,142,4],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a85fbaae7c048f7a2dd05b3b1a9a20551":[6,0,0,142,0],
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#ad3bc2b4105e9c4f8aec25139299e8ada":[6,0,0,142,3],
-"classviennacl_1_1scalar__matrix.html":[6,0,0,143],
-"classviennacl_1_1scalar__matrix.html#a2d23a253337da08602d2b43e93defb08":[6,0,0,143,0],
-"classviennacl_1_1scalar__matrix.html#af8753d9f6650174415ed9284e9ceee52":[6,0,0,143,2],
-"classviennacl_1_1scalar__matrix.html#affdde5f291bb17e3b7934f8155fc5725":[6,0,0,143,1],
-"classviennacl_1_1scheduler_1_1statement.html":[6,0,0,7,3],
-"classviennacl_1_1scheduler_1_1statement.html#a0bf20346036ee130e78351991543cf09":[6,0,0,7,3,6],
-"classviennacl_1_1scheduler_1_1statement.html#a26f2ddb87584c4ae968edf599463424e":[6,0,0,7,3,4],
-"classviennacl_1_1scheduler_1_1statement.html#a3123bd3e34694366fd45a64929aa8b24":[6,0,0,7,3,1],
-"classviennacl_1_1scheduler_1_1statement.html#a600279969b8e7e2e88cf1be2c5bb0513":[6,0,0,7,3,0],
-"classviennacl_1_1scheduler_1_1statement.html#a917cc2d5770a7353cadd5f25c313046f":[6,0,0,7,3,3],
-"classviennacl_1_1scheduler_1_1statement.html#ad6ef5721eb619c3cbceec962fb327af4":[6,0,0,7,3,2],
-"classviennacl_1_1scheduler_1_1statement.html#afb794865f5960e34f91032674ea87cf2":[6,0,0,7,3,5],
-"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html":[6,0,0,7,5],
-"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a4148b7d0bbead5dcf8f46894750b0383":[6,0,0,7,5,0],
-"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a85575ff7bc146480f3a38d6f3fe8d96e":[6,0,0,7,5,1],
-"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a878174e36fef97bbdc14689561f540e2":[6,0,0,7,5,3],
-"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#afe2ee7ae206bc31dff70731bc3a6de51":[6,0,0,7,5,2],
-"classviennacl_1_1sliced__ell__matrix.html":[6,0,0,145],
-"classviennacl_1_1sliced__ell__matrix.html#a06b5f062eb56b5ca07d71f68956ae95c":[6,0,0,145,4],
-"classviennacl_1_1sliced__ell__matrix.html#a16cd8194ca5b263de32f131362498d77":[6,0,0,145,18],
-"classviennacl_1_1sliced__ell__matrix.html#a1b9a6e9229a8694123562166eb2d4e32":[6,0,0,145,8],
-"classviennacl_1_1sliced__ell__matrix.html#a2cdf3aeccfe9a10b89c48b3430cb4c93":[6,0,0,145,0],
-"classviennacl_1_1sliced__ell__matrix.html#a31d5fa9ec25dcfeb260f7e11c4db6571":[6,0,0,145,11],
-"classviennacl_1_1sliced__ell__matrix.html#a362dc0c5f0d644cbcf6514f3b3ee6529":[6,0,0,145,3],
-"classviennacl_1_1sliced__ell__matrix.html#a40c479e880ef7e7f50ed67cda91bb8e7":[6,0,0,145,20],
-"classviennacl_1_1sliced__ell__matrix.html#a45249ad5b44d0f506adc27e1e18aecdf":[6,0,0,145,12]
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a5c396160db0ffed8c540e6d3c12af0ee":[6,0,0,140,4]
 };
