@@ -1,7 +1,46 @@
 var NAVTREEINDEX7 =
 {
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a670faef4da7eb44516eaf0502e0da52e":[6,0,0,140,3],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html":[6,0,0,141],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#a86f83b73234e0edf79091da73ce14c29":[6,0,0,141,0],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#ab15d868e688c03c848c1bc3eb3519108":[6,0,0,141,4],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#acf599122110d3d7332d874b943fd49be":[6,0,0,141,2],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#ad4a3e5a53aeebca6c63a2426c9b5e31d":[6,0,0,141,3],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html#ad801407959eec646c0782a20e221392e":[6,0,0,141,1],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html":[6,0,0,142],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a0a3d8a45ae5f29887aa1eceb03abdbec":[6,0,0,142,1],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a0ac29370b6cf978a29691334da813d74":[6,0,0,142,2],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a23831b3a67caf34ee518be31d452838c":[6,0,0,142,4],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#a85fbaae7c048f7a2dd05b3b1a9a20551":[6,0,0,142,0],
+"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html#ad3bc2b4105e9c4f8aec25139299e8ada":[6,0,0,142,3],
+"classviennacl_1_1scalar__matrix.html":[6,0,0,143],
+"classviennacl_1_1scalar__matrix.html#a2d23a253337da08602d2b43e93defb08":[6,0,0,143,0],
+"classviennacl_1_1scalar__matrix.html#af8753d9f6650174415ed9284e9ceee52":[6,0,0,143,2],
+"classviennacl_1_1scalar__matrix.html#affdde5f291bb17e3b7934f8155fc5725":[6,0,0,143,1],
+"classviennacl_1_1scheduler_1_1statement.html":[6,0,0,7,3],
+"classviennacl_1_1scheduler_1_1statement.html#a0bf20346036ee130e78351991543cf09":[6,0,0,7,3,6],
+"classviennacl_1_1scheduler_1_1statement.html#a26f2ddb87584c4ae968edf599463424e":[6,0,0,7,3,4],
+"classviennacl_1_1scheduler_1_1statement.html#a3123bd3e34694366fd45a64929aa8b24":[6,0,0,7,3,1],
+"classviennacl_1_1scheduler_1_1statement.html#a600279969b8e7e2e88cf1be2c5bb0513":[6,0,0,7,3,0],
+"classviennacl_1_1scheduler_1_1statement.html#a917cc2d5770a7353cadd5f25c313046f":[6,0,0,7,3,3],
+"classviennacl_1_1scheduler_1_1statement.html#ad6ef5721eb619c3cbceec962fb327af4":[6,0,0,7,3,2],
+"classviennacl_1_1scheduler_1_1statement.html#afb794865f5960e34f91032674ea87cf2":[6,0,0,7,3,5],
+"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html":[6,0,0,7,5],
+"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a4148b7d0bbead5dcf8f46894750b0383":[6,0,0,7,5,0],
+"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a85575ff7bc146480f3a38d6f3fe8d96e":[6,0,0,7,5,1],
+"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a878174e36fef97bbdc14689561f540e2":[6,0,0,7,5,3],
+"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#afe2ee7ae206bc31dff70731bc3a6de51":[6,0,0,7,5,2],
+"classviennacl_1_1sliced__ell__matrix.html":[6,0,0,145],
+"classviennacl_1_1sliced__ell__matrix.html#a16cd8194ca5b263de32f131362498d77":[6,0,0,145,18],
+"classviennacl_1_1sliced__ell__matrix.html#a1b9a6e9229a8694123562166eb2d4e32":[6,0,0,145,8],
+"classviennacl_1_1sliced__ell__matrix.html#a2cdf3aeccfe9a10b89c48b3430cb4c93":[6,0,0,145,0],
+"classviennacl_1_1sliced__ell__matrix.html#a31d5fa9ec25dcfeb260f7e11c4db6571":[6,0,0,145,11],
+"classviennacl_1_1sliced__ell__matrix.html#a362dc0c5f0d644cbcf6514f3b3ee6529":[6,0,0,145,3],
+"classviennacl_1_1sliced__ell__matrix.html#a40c479e880ef7e7f50ed67cda91bb8e7":[6,0,0,145,20],
+"classviennacl_1_1sliced__ell__matrix.html#a45249ad5b44d0f506adc27e1e18aecdf":[6,0,0,145,12],
 "classviennacl_1_1sliced__ell__matrix.html#a727fd3a25232545c59204885ff3e32d4":[6,0,0,145,10],
 "classviennacl_1_1sliced__ell__matrix.html#a94043424c01974b2db8062f74f625825":[6,0,0,145,9],
+"classviennacl_1_1sliced__ell__matrix.html#a9f244082eff24e93495d3b4abec735b0":[6,0,0,145,4],
 "classviennacl_1_1sliced__ell__matrix.html#aa59ae796d592a679a4c6036ba84f61b0":[6,0,0,145,13],
 "classviennacl_1_1sliced__ell__matrix.html#aa725bf2d5b213f119bd4b9fe9258c201":[6,0,0,145,5],
 "classviennacl_1_1sliced__ell__matrix.html#aa9a7f4003687cae9a2af97f9fa328db5":[6,0,0,145,17],
@@ -14,19 +53,19 @@ var NAVTREEINDEX7 =
 "classviennacl_1_1sliced__ell__matrix.html#aec497ed037ef674d36729bda4db7e93f":[6,0,0,145,14],
 "classviennacl_1_1sliced__ell__matrix.html#af0672b686ad27ddcf948116bae059329":[6,0,0,145,2],
 "classviennacl_1_1toeplitz__matrix.html":[6,0,0,152],
-"classviennacl_1_1toeplitz__matrix.html#a0af2555299f10f2f56e2c58649463508":[6,0,0,152,4],
-"classviennacl_1_1toeplitz__matrix.html#a1522cb57680cd99ec5d1740ee99d2d60":[6,0,0,152,9],
-"classviennacl_1_1toeplitz__matrix.html#a1dd4cdc1c7548bba50af610bf44905f5":[6,0,0,152,11],
-"classviennacl_1_1toeplitz__matrix.html#a768848d0ac0636962b922470ce96b0b1":[6,0,0,152,2],
-"classviennacl_1_1toeplitz__matrix.html#a7d49889e7b1f9227660ed75eb769e736":[6,0,0,152,12],
-"classviennacl_1_1toeplitz__matrix.html#a84d02ddf2195dd6d5b5fd6498f200501":[6,0,0,152,10],
-"classviennacl_1_1toeplitz__matrix.html#a87aaa754492d520f8d5f376506d016d6":[6,0,0,152,3],
-"classviennacl_1_1toeplitz__matrix.html#a8827feaf51a55db8cb863590c9b6f555":[6,0,0,152,1],
-"classviennacl_1_1toeplitz__matrix.html#a9ebb8a923d7c1dfa27d6bef22c6e226e":[6,0,0,152,8],
-"classviennacl_1_1toeplitz__matrix.html#ab31a02a138d595d581541e67e9aa212e":[6,0,0,152,5],
-"classviennacl_1_1toeplitz__matrix.html#ab6d881291cd8d7711b49c1498e1cd3c2":[6,0,0,152,7],
-"classviennacl_1_1toeplitz__matrix.html#ace60368462f994e285c27150daa3eeab":[6,0,0,152,6],
-"classviennacl_1_1toeplitz__matrix.html#af5e843d27418c26c94680f70bf32b4d8":[6,0,0,152,0],
+"classviennacl_1_1toeplitz__matrix.html#a02da032567325736d8e42a0f1afc1434":[6,0,0,152,11],
+"classviennacl_1_1toeplitz__matrix.html#a177a397c0fec9467d3e85adac8b8472e":[6,0,0,152,9],
+"classviennacl_1_1toeplitz__matrix.html#a246b15c08c8f7c6bcd0d90c3ef62d230":[6,0,0,152,4],
+"classviennacl_1_1toeplitz__matrix.html#a27e7ab687472d5590f0b758ac7bf721a":[6,0,0,152,12],
+"classviennacl_1_1toeplitz__matrix.html#a40569bb6948d0eae678244eb5cac57a5":[6,0,0,152,1],
+"classviennacl_1_1toeplitz__matrix.html#a4270f98e47acf227d2ea894868213a4a":[6,0,0,152,8],
+"classviennacl_1_1toeplitz__matrix.html#a6ad1789b88235bdeddba34dcd139a142":[6,0,0,152,10],
+"classviennacl_1_1toeplitz__matrix.html#a81886bbfd3fab4c1051d1b284f2901c8":[6,0,0,152,7],
+"classviennacl_1_1toeplitz__matrix.html#abc3be2037d7dd180dcc096b14a49d7a1":[6,0,0,152,6],
+"classviennacl_1_1toeplitz__matrix.html#ac208edf451afb23b6b517887424399ce":[6,0,0,152,5],
+"classviennacl_1_1toeplitz__matrix.html#ac437a1cb3b3798fa0147b92bd8a3d79b":[6,0,0,152,0],
+"classviennacl_1_1toeplitz__matrix.html#ac56cd20ec4b03a4af7ed5498f48d4646":[6,0,0,152,2],
+"classviennacl_1_1toeplitz__matrix.html#aded8b43e7bda1df95bc777cfb718c67b":[6,0,0,152,3],
 "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html":[6,0,0,8,3],
 "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html#a0fc914cdbf7ee1a1a274795b0dd3d686":[6,0,0,8,3,8],
 "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html#a2fd2bdc3fa5a1982d54db6e4c4146a04":[6,0,0,8,3,9],
@@ -139,37 +178,37 @@ var NAVTREEINDEX7 =
 "classviennacl_1_1tools_1_1timer.html#ac3e360cdcecfb05861baa2800e4f2888":[6,0,0,8,11,2],
 "classviennacl_1_1tools_1_1timer.html#af44313f16c89e97704c90b1ebcc17bca":[6,0,0,8,11,1],
 "classviennacl_1_1vandermonde__matrix.html":[6,0,0,154],
-"classviennacl_1_1vandermonde__matrix.html#a106c7f6cd734a9036a421fcea3f21bb1":[6,0,0,154,12],
-"classviennacl_1_1vandermonde__matrix.html#a1bf2f35203ef6179dfdd5382e07b0d9b":[6,0,0,154,2],
-"classviennacl_1_1vandermonde__matrix.html#a2b9f5ed543e7e148569821ce115438f8":[6,0,0,154,6],
-"classviennacl_1_1vandermonde__matrix.html#a5418d4fd332df9df76d94c3d19a0425d":[6,0,0,154,3],
-"classviennacl_1_1vandermonde__matrix.html#a6e286a8425d504264b8b5910c6d0b531":[6,0,0,154,5],
-"classviennacl_1_1vandermonde__matrix.html#a78e04f188b375ea59ce39e9fb6ee5c18":[6,0,0,154,9],
-"classviennacl_1_1vandermonde__matrix.html#a92d6be5a35f867bdac45cd32ac7ebed2":[6,0,0,154,10],
-"classviennacl_1_1vandermonde__matrix.html#a9ada537246eda3970241e1d499d5ec28":[6,0,0,154,0],
-"classviennacl_1_1vandermonde__matrix.html#ab12e0f085c99524703bfdd67a58d0edc":[6,0,0,154,4],
-"classviennacl_1_1vandermonde__matrix.html#ab899a13f35a951e1fd94767dbf83e311":[6,0,0,154,8],
-"classviennacl_1_1vandermonde__matrix.html#ae021cff8cdbc8d3a9943c171385191dd":[6,0,0,154,11],
-"classviennacl_1_1vandermonde__matrix.html#afd9a029d3f4bcbadd2fa2b6022af2703":[6,0,0,154,1],
-"classviennacl_1_1vandermonde__matrix.html#afed38343a2f69b5248c58a3cfd03d04b":[6,0,0,154,7],
+"classviennacl_1_1vandermonde__matrix.html#a12be83df9631afeca56eb63096a312f0":[6,0,0,154,0],
+"classviennacl_1_1vandermonde__matrix.html#a2599d32b10b1051cec65cf6b9458f195":[6,0,0,154,9],
+"classviennacl_1_1vandermonde__matrix.html#a3fdab282172b78263faa3e782adb5ed0":[6,0,0,154,2],
+"classviennacl_1_1vandermonde__matrix.html#a5ea4016ca29b5a9c65ce34192c574bd3":[6,0,0,154,1],
+"classviennacl_1_1vandermonde__matrix.html#a63629c958e216bc68d67e2d3fbe75577":[6,0,0,154,4],
+"classviennacl_1_1vandermonde__matrix.html#a6b3eadef03c3a238fd1ec8e62b176926":[6,0,0,154,12],
+"classviennacl_1_1vandermonde__matrix.html#a8f6d67f35d5ab894c818252f393ba4b9":[6,0,0,154,7],
+"classviennacl_1_1vandermonde__matrix.html#a94af00b5b37b587aa54eb7dfa69ed3d0":[6,0,0,154,8],
+"classviennacl_1_1vandermonde__matrix.html#aa2454bc5dc95863e93f70bb11c67aadf":[6,0,0,154,5],
+"classviennacl_1_1vandermonde__matrix.html#aa2731747886c5d9bb625c996baa369cf":[6,0,0,154,10],
+"classviennacl_1_1vandermonde__matrix.html#ab478479b8cd5e48262adc6549ad0e2be":[6,0,0,154,3],
+"classviennacl_1_1vandermonde__matrix.html#acc23bc5cfe84e53e8eb8293b964683a8":[6,0,0,154,11],
+"classviennacl_1_1vandermonde__matrix.html#ae0a32feff8be75c7a4e12adcab31b7c5":[6,0,0,154,6],
 "classviennacl_1_1vector.html":[6,0,0,155],
-"classviennacl_1_1vector.html#a0265a7e75988e868bfbdfe2aaeb19487":[6,0,0,155,13],
-"classviennacl_1_1vector.html#a02c6926515cfe978cc4e11094f2d1f0f":[6,0,0,155,9],
-"classviennacl_1_1vector.html#a1c172d55c8c96822e661cd7311ce73ae":[6,0,0,155,1],
-"classviennacl_1_1vector.html#a3384c255d4757a235afbebacbbe82495":[6,0,0,155,4],
-"classviennacl_1_1vector.html#a3848da3369c5385bacb00cdce9acd3a4":[6,0,0,155,10],
-"classviennacl_1_1vector.html#a3ec15c5a5edb007132ff0949664cfdcb":[6,0,0,155,12],
-"classviennacl_1_1vector.html#a48bc22bb43ec5dff676b1b428c81f331":[6,0,0,155,5],
-"classviennacl_1_1vector.html#a51317190789589583d9e47808ae77fb5":[6,0,0,155,6],
-"classviennacl_1_1vector.html#a5155eca00e71a4e9fd89772d918783b3":[6,0,0,155,16],
-"classviennacl_1_1vector.html#a8551e636fb29c501be9abf165f22e147":[6,0,0,155,7],
-"classviennacl_1_1vector.html#a9df34196fc05e9c83c83f9d5eb7c1c97":[6,0,0,155,14],
-"classviennacl_1_1vector.html#a9f8cd5baea4bf57639586d38f5ca20e1":[6,0,0,155,0],
-"classviennacl_1_1vector.html#acdc1544d571d7ac5b03c22219cab6c33":[6,0,0,155,11],
-"classviennacl_1_1vector.html#ae07f0ce8823a6d07d096f443bf8b27d3":[6,0,0,155,15],
-"classviennacl_1_1vector.html#ae3f078bdf622bbbb9425f0eda22e14f4":[6,0,0,155,2],
-"classviennacl_1_1vector.html#aea709d4c3037f3da9492c569612835be":[6,0,0,155,8],
-"classviennacl_1_1vector.html#afaa66212b8e58889fb76782f269a4e65":[6,0,0,155,3],
+"classviennacl_1_1vector.html#a021fdd9e74d47f1bbbebe3141e3804ea":[6,0,0,155,1],
+"classviennacl_1_1vector.html#a07bb8d387673358d18fbe939b9f118fc":[6,0,0,155,7],
+"classviennacl_1_1vector.html#a1b73aadf0c7b6c0028fd237ebb30c767":[6,0,0,155,14],
+"classviennacl_1_1vector.html#a3c2a39b9ea60d9086bcd77b5043a21dc":[6,0,0,155,6],
+"classviennacl_1_1vector.html#a3fbd82bb7795e827693eaedf0d7e67eb":[6,0,0,155,11],
+"classviennacl_1_1vector.html#a45b1a9e18907072bace972c9acae6c8a":[6,0,0,155,5],
+"classviennacl_1_1vector.html#a4bd109b6136687f5aefcf7e3595f348a":[6,0,0,155,10],
+"classviennacl_1_1vector.html#a59f2ec43f298cc04d2f2bbbeee239bfe":[6,0,0,155,16],
+"classviennacl_1_1vector.html#a64491dd219701749e8afb18b148be471":[6,0,0,155,2],
+"classviennacl_1_1vector.html#a6bcfb05948eaf1d9b26e5e73e28dc94f":[6,0,0,155,8],
+"classviennacl_1_1vector.html#a7e683e134c8aad7b3cd057776a58c4c4":[6,0,0,155,0],
+"classviennacl_1_1vector.html#a805300e6add819e9fe6a5e3f27f42275":[6,0,0,155,3],
+"classviennacl_1_1vector.html#a8cbd168a74c13a026466575b88c4e126":[6,0,0,155,12],
+"classviennacl_1_1vector.html#ab45bacf9fd09acba5ca324b6a8834d72":[6,0,0,155,4],
+"classviennacl_1_1vector.html#ab8d0867a867e4aae13450a222c7a5f4c":[6,0,0,155,13],
+"classviennacl_1_1vector.html#aba321298847ca424e2656292138265d5":[6,0,0,155,9],
+"classviennacl_1_1vector.html#addd07176a7a8612888ce2386b57bc5cb":[6,0,0,155,15],
 "classviennacl_1_1vector__base.html":[6,0,0,156],
 "classviennacl_1_1vector__base.html#a0064de5b081cae912adc624860d66847":[6,0,0,156,4],
 "classviennacl_1_1vector__base.html#a00ce836edfc2e9022f289faf9cd1d2f8":[6,0,0,156,61],
@@ -210,44 +249,5 @@ var NAVTREEINDEX7 =
 "classviennacl_1_1vector__base.html#a991c29216e6f2502eac33d679ab229cd":[6,0,0,156,16],
 "classviennacl_1_1vector__base.html#a9fb21c7f26cce34077cdf06acd141ce1":[6,0,0,156,67],
 "classviennacl_1_1vector__base.html#a9fcc4eef8d6e43f5404a192533af299c":[6,0,0,156,72],
-"classviennacl_1_1vector__base.html#aa278b3b7a245d0dd35b5802ddf34a2bc":[6,0,0,156,44],
-"classviennacl_1_1vector__base.html#aa2a13cb2712dc5dd36eea81c7549a278":[6,0,0,156,58],
-"classviennacl_1_1vector__base.html#aa5cf7f89db0679d8bee9d776c22c94c5":[6,0,0,156,52],
-"classviennacl_1_1vector__base.html#aa9fd55dbcc3f1f71b1fedd18d20906ca":[6,0,0,156,2],
-"classviennacl_1_1vector__base.html#aaabd2cd126b77ee09b80b4c447bcbd3e":[6,0,0,156,70],
-"classviennacl_1_1vector__base.html#aaddeab99670f0bfa1cf15358432b0045":[6,0,0,156,3],
-"classviennacl_1_1vector__base.html#ab4f2c9bcce9e3b0815dc30b13ad6184d":[6,0,0,156,48],
-"classviennacl_1_1vector__base.html#ab877f5e3472212aecc8039f189cbd7d8":[6,0,0,156,26],
-"classviennacl_1_1vector__base.html#ab93411bae9553e9426e75b6cfae613e2":[6,0,0,156,11],
-"classviennacl_1_1vector__base.html#aba8a76bd4c96435ba68cf96b9e5132a6":[6,0,0,156,17],
-"classviennacl_1_1vector__base.html#abdb97f15a43a41cdc7131e49a21a34f8":[6,0,0,156,7],
-"classviennacl_1_1vector__base.html#abe42f2f709124d7d5bcf571fb6a170a1":[6,0,0,156,63],
-"classviennacl_1_1vector__base.html#abf09889e4e930f71e4d8868ac94f1f01":[6,0,0,156,10],
-"classviennacl_1_1vector__base.html#abf5acd243b2b1571cc7a486e89485ca0":[6,0,0,156,15],
-"classviennacl_1_1vector__base.html#abfbc4e1042163d3335e32ff8e0295c7a":[6,0,0,156,38],
-"classviennacl_1_1vector__base.html#ac0be05c73aee5ab3317efb6f8cd50409":[6,0,0,156,21],
-"classviennacl_1_1vector__base.html#ac4e8c37c470b13f20e5c32036aab303c":[6,0,0,156,27],
-"classviennacl_1_1vector__base.html#ac538c910d1a0bc1ee22eca7a5c9155d4":[6,0,0,156,12],
-"classviennacl_1_1vector__base.html#ad0fb77bdade129bb34da0812390646ee":[6,0,0,156,9],
-"classviennacl_1_1vector__base.html#ad3d4d1dca62d7fd08efd1e74880fcbe8":[6,0,0,156,40],
-"classviennacl_1_1vector__base.html#ad7d76cdc495086784c20eac98c0cdca4":[6,0,0,156,5],
-"classviennacl_1_1vector__base.html#adb464357b37310aab053591ead1bcb75":[6,0,0,156,73],
-"classviennacl_1_1vector__base.html#adc2bfeb8899289b4d7c529d6481c5941":[6,0,0,156,39],
-"classviennacl_1_1vector__base.html#addec9f37d536e930e7cd3b5e48fbfb39":[6,0,0,156,57],
-"classviennacl_1_1vector__base.html#adf638d9658bc0fc57e7b60f8fca1b724":[6,0,0,156,46],
-"classviennacl_1_1vector__base.html#ae62f560e1e3e1f84ff65dc5bbf697698":[6,0,0,156,45],
-"classviennacl_1_1vector__base.html#ae6d53b1851088253313be6b252fb9aa6":[6,0,0,156,6],
-"classviennacl_1_1vector__base.html#ae87145f9be1d6baa4e921f9ef5a24c88":[6,0,0,156,56],
-"classviennacl_1_1vector__base.html#aeb3a14cbd9e42a46c2890f3c555cea19":[6,0,0,156,30],
-"classviennacl_1_1vector__base.html#af1e0bd20ec7254908f6d49df07785cf4":[6,0,0,156,71],
-"classviennacl_1_1vector__base.html#af2be7f81292a4267e6302a268f47e79f":[6,0,0,156,62],
-"classviennacl_1_1vector__base.html#af4053980be9ce843baaecfd8c7458b52":[6,0,0,156,42],
-"classviennacl_1_1vector__base.html#af850336405004f44e2c1fd9c32d95e22":[6,0,0,156,53],
-"classviennacl_1_1vector__base.html#afa4c58f00531faf176ddb4ee94ce4fd8":[6,0,0,156,36],
-"classviennacl_1_1vector__base.html#afe3ba1767e02f37ef966fb6e9269548f":[6,0,0,156,64],
-"classviennacl_1_1vector__expression.html":[6,0,0,157],
-"classviennacl_1_1vector__expression.html#a2c4138095317b0d974978f88b9954a8a":[6,0,0,157,4],
-"classviennacl_1_1vector__expression.html#a500264730b5fd91d1a92907485a10055":[6,0,0,157,0],
-"classviennacl_1_1vector__expression.html#ad09c76581b59ec0e84c86168c5c959bdaf07e953529536df49f8da9a7a7285530":[6,0,0,157,1],
-"classviennacl_1_1vector__expression.html#aeb11d9ce8661771fa9750dd9d096c07f":[6,0,0,157,3]
+"classviennacl_1_1vector__base.html#aa278b3b7a245d0dd35b5802ddf34a2bc":[6,0,0,156,44]
 };
