@@ -1,19 +1,58 @@
 var NAVTREEINDEX8 =
 {
+"classviennacl_1_1vector__base.html#aa2a13cb2712dc5dd36eea81c7549a278":[6,0,0,156,58],
+"classviennacl_1_1vector__base.html#aa5cf7f89db0679d8bee9d776c22c94c5":[6,0,0,156,52],
+"classviennacl_1_1vector__base.html#aa9fd55dbcc3f1f71b1fedd18d20906ca":[6,0,0,156,2],
+"classviennacl_1_1vector__base.html#aaabd2cd126b77ee09b80b4c447bcbd3e":[6,0,0,156,70],
+"classviennacl_1_1vector__base.html#aaddeab99670f0bfa1cf15358432b0045":[6,0,0,156,3],
+"classviennacl_1_1vector__base.html#ab4f2c9bcce9e3b0815dc30b13ad6184d":[6,0,0,156,48],
+"classviennacl_1_1vector__base.html#ab877f5e3472212aecc8039f189cbd7d8":[6,0,0,156,26],
+"classviennacl_1_1vector__base.html#ab93411bae9553e9426e75b6cfae613e2":[6,0,0,156,11],
+"classviennacl_1_1vector__base.html#aba8a76bd4c96435ba68cf96b9e5132a6":[6,0,0,156,17],
+"classviennacl_1_1vector__base.html#abdb97f15a43a41cdc7131e49a21a34f8":[6,0,0,156,7],
+"classviennacl_1_1vector__base.html#abe42f2f709124d7d5bcf571fb6a170a1":[6,0,0,156,63],
+"classviennacl_1_1vector__base.html#abf09889e4e930f71e4d8868ac94f1f01":[6,0,0,156,10],
+"classviennacl_1_1vector__base.html#abf5acd243b2b1571cc7a486e89485ca0":[6,0,0,156,15],
+"classviennacl_1_1vector__base.html#abfbc4e1042163d3335e32ff8e0295c7a":[6,0,0,156,38],
+"classviennacl_1_1vector__base.html#ac0be05c73aee5ab3317efb6f8cd50409":[6,0,0,156,21],
+"classviennacl_1_1vector__base.html#ac4e8c37c470b13f20e5c32036aab303c":[6,0,0,156,27],
+"classviennacl_1_1vector__base.html#ac538c910d1a0bc1ee22eca7a5c9155d4":[6,0,0,156,12],
+"classviennacl_1_1vector__base.html#ad0fb77bdade129bb34da0812390646ee":[6,0,0,156,9],
+"classviennacl_1_1vector__base.html#ad3d4d1dca62d7fd08efd1e74880fcbe8":[6,0,0,156,40],
+"classviennacl_1_1vector__base.html#ad7d76cdc495086784c20eac98c0cdca4":[6,0,0,156,5],
+"classviennacl_1_1vector__base.html#adb464357b37310aab053591ead1bcb75":[6,0,0,156,73],
+"classviennacl_1_1vector__base.html#adc2bfeb8899289b4d7c529d6481c5941":[6,0,0,156,39],
+"classviennacl_1_1vector__base.html#addec9f37d536e930e7cd3b5e48fbfb39":[6,0,0,156,57],
+"classviennacl_1_1vector__base.html#adf638d9658bc0fc57e7b60f8fca1b724":[6,0,0,156,46],
+"classviennacl_1_1vector__base.html#ae62f560e1e3e1f84ff65dc5bbf697698":[6,0,0,156,45],
+"classviennacl_1_1vector__base.html#ae6d53b1851088253313be6b252fb9aa6":[6,0,0,156,6],
+"classviennacl_1_1vector__base.html#ae87145f9be1d6baa4e921f9ef5a24c88":[6,0,0,156,56],
+"classviennacl_1_1vector__base.html#aeb3a14cbd9e42a46c2890f3c555cea19":[6,0,0,156,30],
+"classviennacl_1_1vector__base.html#af1e0bd20ec7254908f6d49df07785cf4":[6,0,0,156,71],
+"classviennacl_1_1vector__base.html#af2be7f81292a4267e6302a268f47e79f":[6,0,0,156,62],
+"classviennacl_1_1vector__base.html#af4053980be9ce843baaecfd8c7458b52":[6,0,0,156,42],
+"classviennacl_1_1vector__base.html#af850336405004f44e2c1fd9c32d95e22":[6,0,0,156,53],
+"classviennacl_1_1vector__base.html#afa4c58f00531faf176ddb4ee94ce4fd8":[6,0,0,156,36],
+"classviennacl_1_1vector__base.html#afe3ba1767e02f37ef966fb6e9269548f":[6,0,0,156,64],
+"classviennacl_1_1vector__expression.html":[6,0,0,157],
+"classviennacl_1_1vector__expression.html#a2c4138095317b0d974978f88b9954a8a":[6,0,0,157,4],
+"classviennacl_1_1vector__expression.html#a500264730b5fd91d1a92907485a10055":[6,0,0,157,0],
+"classviennacl_1_1vector__expression.html#ad09c76581b59ec0e84c86168c5c959bdaf07e953529536df49f8da9a7a7285530":[6,0,0,157,1],
+"classviennacl_1_1vector__expression.html#aeb11d9ce8661771fa9750dd9d096c07f":[6,0,0,157,3],
 "classviennacl_1_1vector__expression.html#af32367d489747d02c0e48e5fcca12469":[6,0,0,157,5],
 "classviennacl_1_1vector__expression.html#aff94c356857f48e8d676ec82c6f98c03":[6,0,0,157,2],
 "classviennacl_1_1vector__iterator.html":[6,0,0,158],
-"classviennacl_1_1vector__iterator.html#a070223d6eefc8da36c64a4c47618b154":[6,0,0,158,2],
-"classviennacl_1_1vector__iterator.html#a07383f1103e3fb45a61f55d5d39b9022":[6,0,0,158,8],
-"classviennacl_1_1vector__iterator.html#a16509d8f948514a2f81e0b83cf06396e":[6,0,0,158,10],
-"classviennacl_1_1vector__iterator.html#a4110a9e5c6b1c76fc16ee7afb3bee1f6":[6,0,0,158,6],
-"classviennacl_1_1vector__iterator.html#a54c60d200c37f74c74ae7f019533d8e4":[6,0,0,158,1],
-"classviennacl_1_1vector__iterator.html#a5514f0c1b4c70ee63b73a00f6fb91357":[6,0,0,158,4],
-"classviennacl_1_1vector__iterator.html#a5862045814c6cf2004f8208321c7d4cc":[6,0,0,158,3],
-"classviennacl_1_1vector__iterator.html#a70abd3b6fea5777f3af802e1fdd1134f":[6,0,0,158,7],
-"classviennacl_1_1vector__iterator.html#acc28ef3263b6eb16360b2e39ab1bcf9a":[6,0,0,158,0],
-"classviennacl_1_1vector__iterator.html#ade476415f537c00a88beb0b59c3d950e":[6,0,0,158,5],
-"classviennacl_1_1vector__iterator.html#afc719587759e23e8b0700622eeed6591":[6,0,0,158,9],
+"classviennacl_1_1vector__iterator.html#a28ca2b649fe60663bb841a1f63de5f6a":[6,0,0,158,5],
+"classviennacl_1_1vector__iterator.html#a3354efa8f7135919a35b13e4bf8edff8":[6,0,0,158,6],
+"classviennacl_1_1vector__iterator.html#a3d6f0cdf4dc263a0158620734e1e5c0b":[6,0,0,158,0],
+"classviennacl_1_1vector__iterator.html#a569410cd7f08cff5c98dfccf36d8e4af":[6,0,0,158,2],
+"classviennacl_1_1vector__iterator.html#a5e0e454f6331493d811d0c01e5f62a7a":[6,0,0,158,9],
+"classviennacl_1_1vector__iterator.html#a65a068f2037b7ab51d1bb2c3b3ffaaad":[6,0,0,158,3],
+"classviennacl_1_1vector__iterator.html#a66cfad479c0e3fc45e0b01aed8cf44d7":[6,0,0,158,8],
+"classviennacl_1_1vector__iterator.html#a945eb5d3193eaad1c776c1b7666d0e98":[6,0,0,158,10],
+"classviennacl_1_1vector__iterator.html#aa7ffa22176b67ae742e7cdacc96cf739":[6,0,0,158,1],
+"classviennacl_1_1vector__iterator.html#adf08866ed77efe9aa69bfb9a678dd7ca":[6,0,0,158,7],
+"classviennacl_1_1vector__iterator.html#affbd40843c435b5ee062b491da20955c":[6,0,0,158,4],
 "classviennacl_1_1vector__range.html":[6,0,0,159],
 "classviennacl_1_1vector__range.html#a0e8ff91829f522c94dac80759ff20afe":[6,0,0,159,9],
 "classviennacl_1_1vector__range.html#a200a915e7a287327517a5d003221d0dd":[6,0,0,159,11],
@@ -153,6 +192,7 @@ var NAVTREEINDEX8 =
 "cuda_2direct__solve_8hpp.html#afecd9de1634f971cfd4dce2d5ad0b3e5":[7,0,3,4,0,7,8],
 "cuda_2direct__solve_8hpp_source.html":[7,0,3,4,0,7],
 "cuda_2fft__operations_8hpp.html":[7,0,3,4,0,8],
+"cuda_2fft__operations_8hpp.html#a038f4f2510cb6267938cc1049df9b609":[7,0,3,4,0,8,32],
 "cuda_2fft__operations_8hpp.html#a0830a649eef44ee28c7c6ecc68b6d68d":[7,0,3,4,0,8,25],
 "cuda_2fft__operations_8hpp.html#a0ea13b0623b669778e42c76d25182418":[7,0,3,4,0,8,36],
 "cuda_2fft__operations_8hpp.html#a1e6214e945b8d60ea371f578f5ee58db":[7,0,3,4,0,8,18],
@@ -169,7 +209,6 @@ var NAVTREEINDEX8 =
 "cuda_2fft__operations_8hpp.html#a549bb69fa59c1d82ec34402e917db258":[7,0,3,4,0,8,12],
 "cuda_2fft__operations_8hpp.html#a5abf912b0fe2132fcc95233c46546951":[7,0,3,4,0,8,31],
 "cuda_2fft__operations_8hpp.html#a5fba21e48290e4123b1287d1e6bd43bd":[7,0,3,4,0,8,3],
-"cuda_2fft__operations_8hpp.html#a615307a1078bccf4de3a218967a3acc0":[7,0,3,4,0,8,32],
 "cuda_2fft__operations_8hpp.html#a62766cf517bab1547813f7db8ae78116":[7,0,3,4,0,8,23],
 "cuda_2fft__operations_8hpp.html#a6632b858aba1849edd0d834dab27486f":[7,0,3,4,0,8,10],
 "cuda_2fft__operations_8hpp.html#a6b46337d1aab49f0bc5d20e2699e4231":[7,0,3,4,0,8,24],
@@ -210,44 +249,5 @@ var NAVTREEINDEX8 =
 "cuda_2iterative__operations_8hpp.html#a65d8cfcf1cee766429508e117eada71d":[7,0,3,4,0,9,6],
 "cuda_2iterative__operations_8hpp.html#a69f7e032f6d9f6cbd97fd7516940af97":[7,0,3,4,0,9,18],
 "cuda_2iterative__operations_8hpp.html#a6c9f7768d5c2e10330ab997498f41453":[7,0,3,4,0,9,3],
-"cuda_2iterative__operations_8hpp.html#a6ca0c953be9082c14a9276435897d2e3":[7,0,3,4,0,9,38],
-"cuda_2iterative__operations_8hpp.html#a704ee2a70cf3563e3928fec38ac16bc0":[7,0,3,4,0,9,16],
-"cuda_2iterative__operations_8hpp.html#a75736f7687babaabe269f432b681503c":[7,0,3,4,0,9,15],
-"cuda_2iterative__operations_8hpp.html#a7f57426fbc4a00904dc1719dc0ce2951":[7,0,3,4,0,9,32],
-"cuda_2iterative__operations_8hpp.html#a7f982f594432ad424f4cb6e774b8fa19":[7,0,3,4,0,9,8],
-"cuda_2iterative__operations_8hpp.html#a86390fe48798192c7390e39d92f97520":[7,0,3,4,0,9,0],
-"cuda_2iterative__operations_8hpp.html#a8cc43bc91378501e1dd1dd755d71642a":[7,0,3,4,0,9,9],
-"cuda_2iterative__operations_8hpp.html#a9f7ae4617ce7d28d3aad4698b71fa758":[7,0,3,4,0,9,19],
-"cuda_2iterative__operations_8hpp.html#aa29b735545a2a7ea98658d36a6e86284":[7,0,3,4,0,9,31],
-"cuda_2iterative__operations_8hpp.html#aa83c7101b05e9185f660f930ca9efb2c":[7,0,3,4,0,9,22],
-"cuda_2iterative__operations_8hpp.html#ab06346505de4a3b8bf2a1ff523622903":[7,0,3,4,0,9,13],
-"cuda_2iterative__operations_8hpp.html#ab458dfdb7b06602a42f588468fe8db75":[7,0,3,4,0,9,27],
-"cuda_2iterative__operations_8hpp.html#acaaa759ba8f6ed9ce08b8e2d7eb17eac":[7,0,3,4,0,9,29],
-"cuda_2iterative__operations_8hpp.html#ad40f19322bc978ffba33972c6f63ff48":[7,0,3,4,0,9,28],
-"cuda_2iterative__operations_8hpp.html#ad6e3793be60ca5210a56f8d2c8fccd7f":[7,0,3,4,0,9,17],
-"cuda_2iterative__operations_8hpp.html#ae0d31ed131e01b317f245b01d1b860a0":[7,0,3,4,0,9,4],
-"cuda_2iterative__operations_8hpp.html#ae0d62b462379fe42e81f900a321eb297":[7,0,3,4,0,9,2],
-"cuda_2iterative__operations_8hpp.html#ae6abf596053acd24e2eeca31127c8f65":[7,0,3,4,0,9,23],
-"cuda_2iterative__operations_8hpp.html#aedeca519719a2fcd21198220cb2f05f2":[7,0,3,4,0,9,25],
-"cuda_2iterative__operations_8hpp.html#aef20cd32ec9f7c6299573e19318f976a":[7,0,3,4,0,9,24],
-"cuda_2iterative__operations_8hpp.html#af050e6eba3a68ce30af78180bf8fda4a":[7,0,3,4,0,9,11],
-"cuda_2iterative__operations_8hpp.html#af13d83b719540f28d9ec7a3c1feece02":[7,0,3,4,0,9,14],
-"cuda_2iterative__operations_8hpp.html#af8a1bdfc669f947e93987f66d3090172":[7,0,3,4,0,9,26],
-"cuda_2iterative__operations_8hpp_source.html":[7,0,3,4,0,9],
-"cuda_2matrix__operations_8hpp.html":[7,0,3,4,0,10],
-"cuda_2matrix__operations_8hpp.html#a0335a25a5814039dd142b201babd2e0c":[7,0,3,4,0,10,28],
-"cuda_2matrix__operations_8hpp.html#a0676f366f6cda64549cda3996576ff86":[7,0,3,4,0,10,27],
-"cuda_2matrix__operations_8hpp.html#a0d1d193d84b15dd9c5f2f69d6aae3d9e":[7,0,3,4,0,10,2],
-"cuda_2matrix__operations_8hpp.html#a0e2ce7c85a84de9322e85057648925cb":[7,0,3,4,0,10,18],
-"cuda_2matrix__operations_8hpp.html#a1353b9a545e853ebca52282e203b1257":[7,0,3,4,0,10,17],
-"cuda_2matrix__operations_8hpp.html#a14613b253ebab69b05ae740ac25db653":[7,0,3,4,0,10,34],
-"cuda_2matrix__operations_8hpp.html#a17b044b1830cfb447912c823796c555e":[7,0,3,4,0,10,12],
-"cuda_2matrix__operations_8hpp.html#a1d8ddd8a536b06f47f90a4b2f31ee83f":[7,0,3,4,0,10,9],
-"cuda_2matrix__operations_8hpp.html#a1e58e169da38debad39ef12233bcd44d":[7,0,3,4,0,10,21],
-"cuda_2matrix__operations_8hpp.html#a1f3705cf204519872b3bc80ba4d722d8":[7,0,3,4,0,10,32],
-"cuda_2matrix__operations_8hpp.html#a2db174e798f4e415ffb0f11c1b89dbc2":[7,0,3,4,0,10,37],
-"cuda_2matrix__operations_8hpp.html#a2f2692acec11817fd1ef26c63d052245":[7,0,3,4,0,10,41],
-"cuda_2matrix__operations_8hpp.html#a35b884c529815e76862fd445d3232a8b":[7,0,3,4,0,10,15],
-"cuda_2matrix__operations_8hpp.html#a3b7535979abdede56147bc5ff52314fd":[7,0,3,4,0,10,1],
-"cuda_2matrix__operations_8hpp.html#a42be7c8aa70b6d1d33b41b19dae6ffd4":[7,0,3,4,0,10,25]
+"cuda_2iterative__operations_8hpp.html#a6ca0c953be9082c14a9276435897d2e3":[7,0,3,4,0,9,38]
 };
