@@ -1,5 +1,44 @@
 var NAVTREEINDEX9 =
 {
+"cuda_2iterative__operations_8hpp.html#a704ee2a70cf3563e3928fec38ac16bc0":[7,0,3,4,0,9,16],
+"cuda_2iterative__operations_8hpp.html#a75736f7687babaabe269f432b681503c":[7,0,3,4,0,9,15],
+"cuda_2iterative__operations_8hpp.html#a7f57426fbc4a00904dc1719dc0ce2951":[7,0,3,4,0,9,32],
+"cuda_2iterative__operations_8hpp.html#a7f982f594432ad424f4cb6e774b8fa19":[7,0,3,4,0,9,8],
+"cuda_2iterative__operations_8hpp.html#a86390fe48798192c7390e39d92f97520":[7,0,3,4,0,9,0],
+"cuda_2iterative__operations_8hpp.html#a8cc43bc91378501e1dd1dd755d71642a":[7,0,3,4,0,9,9],
+"cuda_2iterative__operations_8hpp.html#a9f7ae4617ce7d28d3aad4698b71fa758":[7,0,3,4,0,9,19],
+"cuda_2iterative__operations_8hpp.html#aa29b735545a2a7ea98658d36a6e86284":[7,0,3,4,0,9,31],
+"cuda_2iterative__operations_8hpp.html#aa83c7101b05e9185f660f930ca9efb2c":[7,0,3,4,0,9,22],
+"cuda_2iterative__operations_8hpp.html#ab06346505de4a3b8bf2a1ff523622903":[7,0,3,4,0,9,13],
+"cuda_2iterative__operations_8hpp.html#ab458dfdb7b06602a42f588468fe8db75":[7,0,3,4,0,9,27],
+"cuda_2iterative__operations_8hpp.html#acaaa759ba8f6ed9ce08b8e2d7eb17eac":[7,0,3,4,0,9,29],
+"cuda_2iterative__operations_8hpp.html#ad40f19322bc978ffba33972c6f63ff48":[7,0,3,4,0,9,28],
+"cuda_2iterative__operations_8hpp.html#ad6e3793be60ca5210a56f8d2c8fccd7f":[7,0,3,4,0,9,17],
+"cuda_2iterative__operations_8hpp.html#ae0d31ed131e01b317f245b01d1b860a0":[7,0,3,4,0,9,4],
+"cuda_2iterative__operations_8hpp.html#ae0d62b462379fe42e81f900a321eb297":[7,0,3,4,0,9,2],
+"cuda_2iterative__operations_8hpp.html#ae6abf596053acd24e2eeca31127c8f65":[7,0,3,4,0,9,23],
+"cuda_2iterative__operations_8hpp.html#aedeca519719a2fcd21198220cb2f05f2":[7,0,3,4,0,9,25],
+"cuda_2iterative__operations_8hpp.html#aef20cd32ec9f7c6299573e19318f976a":[7,0,3,4,0,9,24],
+"cuda_2iterative__operations_8hpp.html#af050e6eba3a68ce30af78180bf8fda4a":[7,0,3,4,0,9,11],
+"cuda_2iterative__operations_8hpp.html#af13d83b719540f28d9ec7a3c1feece02":[7,0,3,4,0,9,14],
+"cuda_2iterative__operations_8hpp.html#af8a1bdfc669f947e93987f66d3090172":[7,0,3,4,0,9,26],
+"cuda_2iterative__operations_8hpp_source.html":[7,0,3,4,0,9],
+"cuda_2matrix__operations_8hpp.html":[7,0,3,4,0,10],
+"cuda_2matrix__operations_8hpp.html#a0335a25a5814039dd142b201babd2e0c":[7,0,3,4,0,10,28],
+"cuda_2matrix__operations_8hpp.html#a0676f366f6cda64549cda3996576ff86":[7,0,3,4,0,10,27],
+"cuda_2matrix__operations_8hpp.html#a0d1d193d84b15dd9c5f2f69d6aae3d9e":[7,0,3,4,0,10,2],
+"cuda_2matrix__operations_8hpp.html#a0e2ce7c85a84de9322e85057648925cb":[7,0,3,4,0,10,18],
+"cuda_2matrix__operations_8hpp.html#a1353b9a545e853ebca52282e203b1257":[7,0,3,4,0,10,17],
+"cuda_2matrix__operations_8hpp.html#a14613b253ebab69b05ae740ac25db653":[7,0,3,4,0,10,34],
+"cuda_2matrix__operations_8hpp.html#a17b044b1830cfb447912c823796c555e":[7,0,3,4,0,10,12],
+"cuda_2matrix__operations_8hpp.html#a1d8ddd8a536b06f47f90a4b2f31ee83f":[7,0,3,4,0,10,9],
+"cuda_2matrix__operations_8hpp.html#a1e58e169da38debad39ef12233bcd44d":[7,0,3,4,0,10,21],
+"cuda_2matrix__operations_8hpp.html#a1f3705cf204519872b3bc80ba4d722d8":[7,0,3,4,0,10,32],
+"cuda_2matrix__operations_8hpp.html#a2db174e798f4e415ffb0f11c1b89dbc2":[7,0,3,4,0,10,37],
+"cuda_2matrix__operations_8hpp.html#a2f2692acec11817fd1ef26c63d052245":[7,0,3,4,0,10,41],
+"cuda_2matrix__operations_8hpp.html#a35b884c529815e76862fd445d3232a8b":[7,0,3,4,0,10,15],
+"cuda_2matrix__operations_8hpp.html#a3b7535979abdede56147bc5ff52314fd":[7,0,3,4,0,10,1],
+"cuda_2matrix__operations_8hpp.html#a42be7c8aa70b6d1d33b41b19dae6ffd4":[7,0,3,4,0,10,25],
 "cuda_2matrix__operations_8hpp.html#a4c4e9facf296d533b6b9f0b0c23a88c7":[7,0,3,4,0,10,22],
 "cuda_2matrix__operations_8hpp.html#a4ef8acb7819438761f82f3284d7acd5e":[7,0,3,4,0,10,3],
 "cuda_2matrix__operations_8hpp.html#a5561702a83a13b07b7101754c93158c2":[7,0,3,4,0,10,33],
@@ -210,44 +249,5 @@ var NAVTREEINDEX9 =
 "custom-context_8cpp.html":[7,0,0,1,7],
 "custom-context_8cpp_source.html":[7,0,0,1,7],
 "custom-kernels_8cpp-example.html":[8,7],
-"custom-kernels_8cpp.html":[7,0,0,1,8],
-"custom-kernels_8cpp_source.html":[7,0,0,1,8],
-"cuthill__mckee_8hpp.html":[7,0,3,6,1],
-"cuthill__mckee_8hpp.html#a032f691cd245d13b51b951f8a10825f3":[7,0,3,6,1,11],
-"cuthill__mckee_8hpp.html#a0368076ca5c74ec328c48924db5feeb8":[7,0,3,6,1,7],
-"cuthill__mckee_8hpp.html#a1196927ad66b47cf5826181369c472d0":[7,0,3,6,1,9],
-"cuthill__mckee_8hpp.html#a46b125c9e12a72a453f0ff2885d0eafe":[7,0,3,6,1,3],
-"cuthill__mckee_8hpp.html#a633f2200739984a3b78ac3e02496da03":[7,0,3,6,1,5],
-"cuthill__mckee_8hpp.html#a91de3dbbe3f9a663fdbee15e1945fde2":[7,0,3,6,1,2],
-"cuthill__mckee_8hpp.html#aeeba1f9a93970b70dbdf8eced30e167d":[7,0,3,6,1,6],
-"cuthill__mckee_8hpp.html#af22338e452cee008bee5e38070ddc611":[7,0,3,6,1,10],
-"cuthill__mckee_8hpp.html#af4e69f290073504270f69f75bece0924":[7,0,3,6,1,4],
-"cuthill__mckee_8hpp.html#afc45d444ac8e66896ee5ba2b186a8510":[7,0,3,6,1,8],
-"cuthill__mckee_8hpp_source.html":[7,0,3,6,1],
-"cypress_8hpp.html":[7,0,3,2,0,0,2,0,0,1],
-"cypress_8hpp.html#a0465b4268c249dfaa94b987df68e0203":[7,0,3,2,0,0,2,0,0,1,11],
-"cypress_8hpp.html#a04b170219e447a120fb23c87fae66869":[7,0,3,2,0,0,2,0,0,1,10],
-"cypress_8hpp.html#a127308a8610f95cbc064d6cac6ca98a9":[7,0,3,2,0,0,2,0,0,1,1],
-"cypress_8hpp.html#a1a69df21383cd6fdcdbd391bc1146f6d":[7,0,3,2,0,0,2,0,0,1,8],
-"cypress_8hpp.html#a23ebc62288af5363da814000605f79e7":[7,0,3,2,0,0,2,0,0,1,9],
-"cypress_8hpp.html#a23fe3d74720124f6ef339cd196d86831":[7,0,3,2,0,0,2,0,0,1,0],
-"cypress_8hpp.html#a27db422105c8d9650b1248f09a972248":[7,0,3,2,0,0,2,0,0,1,6],
-"cypress_8hpp.html#a28f48231f00081a98ddcd7cd8135910c":[7,0,3,2,0,0,2,0,0,1,3],
-"cypress_8hpp.html#a40a59de4f3f2ca3c52708296c0541573":[7,0,3,2,0,0,2,0,0,1,13],
-"cypress_8hpp.html#a8638ef1d9e292eb6295ab2604dbaa4ce":[7,0,3,2,0,0,2,0,0,1,12],
-"cypress_8hpp.html#ab5cf26400e2a97ef5af2a86509451d44":[7,0,3,2,0,0,2,0,0,1,5],
-"cypress_8hpp.html#ab787739a0e379046b0859f1d1ba046fd":[7,0,3,2,0,0,2,0,0,1,7],
-"cypress_8hpp.html#acd226a7692103ffd46b9944a9737581e":[7,0,3,2,0,0,2,0,0,1,4],
-"cypress_8hpp.html#ae53b5bdcfa19555dc45f00ca47f356f8":[7,0,3,2,0,0,2,0,0,1,2],
-"cypress_8hpp_source.html":[7,0,3,2,0,0,2,0,0,1],
-"dense__blas_8cpp.html":[7,0,0,0,1],
-"dense__blas_8cpp.html#a0c464e202ab39eece213320f33750b8b":[7,0,0,0,1,0],
-"dense__blas_8cpp.html#a394a1b0572531e380bc94ec20cd7a20c":[7,0,0,0,1,2],
-"dense__blas_8cpp.html#a7044d46a24870e1508e14dc2b6c3c104":[7,0,0,0,1,3],
-"dense__blas_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,0,1,4],
-"dense__blas_8cpp.html#af6bb6f04705830fb7e059fe0572778d6":[7,0,0,0,1,1],
-"dense__blas_8cpp_source.html":[7,0,0,0,1],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html":[7,0,3,4,1,1,0],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a049a115f9821da18cc960a5170bd2692":[7,0,3,4,1,1,0,3],
-"detail_2bisect_2bisect__kernel__calls_8hpp.html#a4b0688e2a510e3fdc62fab34aedce77b":[7,0,3,4,1,1,0,1]
+"custom-kernels_8cpp.html":[7,0,0,1,8]
 };
