@@ -2,9 +2,10 @@ var searchData=
 [
   ['value_5ftype',['value_type',['../structviennacl_1_1result__of_1_1value__type.html',1,'viennacl::result_of']]],
   ['vandermonde_5fmatrix',['vandermonde_matrix',['../classviennacl_1_1vandermonde__matrix.html',1,'viennacl']]],
-  ['vector',['vector',['../classviennacl_1_1vector.html',1,'viennacl']]],
   ['vector',['vector',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html',1,'viennacl::linalg::opencl::kernels']]],
+  ['vector',['vector',['../classviennacl_1_1vector.html',1,'viennacl']]],
   ['vector_3c_20numerict_20_3e',['vector&lt; NumericT &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
+  ['vector_3c_20numerict_2c_20alignmentv_20_3e',['vector&lt; NumericT, AlignmentV &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
   ['vector_3c_20numerictype_20_3e',['vector&lt; NumericType &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
   ['vector_3c_20scalartype_20_3e',['vector&lt; ScalarType &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
   ['vector_3c_20unsigned_20int_20_3e',['vector&lt; unsigned int &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
@@ -18,8 +19,6 @@ var searchData=
   ['vector_5fbase_3c_20int_20_3e',['vector_base&lt; int &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
   ['vector_5fbase_3c_20long_20_3e',['vector_base&lt; long &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
   ['vector_5fbase_3c_20numerict_20_3e',['vector_base&lt; NumericT &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
-  ['vector_5fbase_3c_20numerictype_20_3e',['vector_base&lt; NumericType &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
-  ['vector_5fbase_3c_20scalartype_20_3e',['vector_base&lt; ScalarType &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
   ['vector_5fbase_3c_20short_20_3e',['vector_base&lt; short &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
   ['vector_5fbase_3c_20unsigned_20char_20_3e',['vector_base&lt; unsigned char &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
   ['vector_5fbase_3c_20unsigned_20int_20_3e',['vector_base&lt; unsigned int &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
