@@ -7,6 +7,7 @@ var searchData=
   ['op_5fargmax',['op_argmax',['../structviennacl_1_1op__argmax.html',1,'viennacl']]],
   ['op_5fargmin',['op_argmin',['../structviennacl_1_1op__argmin.html',1,'viennacl']]],
   ['op_5fasin',['op_asin',['../structviennacl_1_1op__asin.html',1,'viennacl']]],
+  ['op_5fassign',['op_assign',['../structop__assign.html',1,'']]],
   ['op_5fassign',['op_assign',['../structviennacl_1_1op__assign.html',1,'viennacl']]],
   ['op_5fatan',['op_atan',['../structviennacl_1_1op__atan.html',1,'viennacl']]],
   ['op_5fatan2',['op_atan2',['../structviennacl_1_1op__atan2.html',1,'viennacl']]],
@@ -40,12 +41,16 @@ var searchData=
   ['op_5flog10',['op_log10',['../structviennacl_1_1op__log10.html',1,'viennacl']]],
   ['op_5fmat_5fmat_5fprod',['op_mat_mat_prod',['../structviennacl_1_1op__mat__mat__prod.html',1,'viennacl']]],
   ['op_5fmatrix_5fdiag',['op_matrix_diag',['../structviennacl_1_1op__matrix__diag.html',1,'viennacl']]],
+  ['op_5fmax',['op_max',['../structviennacl_1_1op__max.html',1,'viennacl']]],
+  ['op_5fmin',['op_min',['../structviennacl_1_1op__min.html',1,'viennacl']]],
+  ['op_5fminus_5fassign',['op_minus_assign',['../structop__minus__assign.html',1,'']]],
   ['op_5fmult',['op_mult',['../structviennacl_1_1op__mult.html',1,'viennacl']]],
   ['op_5fneq',['op_neq',['../structviennacl_1_1op__neq.html',1,'viennacl']]],
   ['op_5fnorm_5f1',['op_norm_1',['../structviennacl_1_1op__norm__1.html',1,'viennacl']]],
   ['op_5fnorm_5f2',['op_norm_2',['../structviennacl_1_1op__norm__2.html',1,'viennacl']]],
   ['op_5fnorm_5ffrobenius',['op_norm_frobenius',['../structviennacl_1_1op__norm__frobenius.html',1,'viennacl']]],
   ['op_5fnorm_5finf',['op_norm_inf',['../structviennacl_1_1op__norm__inf.html',1,'viennacl']]],
+  ['op_5fplus_5fassign',['op_plus_assign',['../structop__plus__assign.html',1,'']]],
   ['op_5fpow',['op_pow',['../structviennacl_1_1op__pow.html',1,'viennacl']]],
   ['op_5fprod',['op_prod',['../structviennacl_1_1op__prod.html',1,'viennacl']]],
   ['op_5freduce_5fcolumns',['op_reduce_columns',['../structviennacl_1_1op__reduce__columns.html',1,'viennacl']]],
@@ -110,6 +115,8 @@ var searchData=
   ['op_5ftype_5finfo_3c_20op_5finplace_5fsub_20_3e',['op_type_info< op_inplace_sub >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__sub_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fmat_5fmat_5fprod_20_3e',['op_type_info< op_mat_mat_prod >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mat__mat__prod_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fmatrix_5fdiag_20_3e',['op_type_info< op_matrix_diag >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__matrix__diag_01_4.html',1,'viennacl::scheduler::result_of']]],
+  ['op_5ftype_5finfo_3c_20op_5fmax_20_3e',['op_type_info< op_max >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__max_01_4.html',1,'viennacl::scheduler::result_of']]],
+  ['op_5ftype_5finfo_3c_20op_5fmin_20_3e',['op_type_info< op_min >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__min_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fmult_20_3e',['op_type_info< op_mult >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mult_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fnorm_5f1_20_3e',['op_type_info< op_norm_1 >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__1_01_4.html',1,'viennacl::scheduler::result_of']]],
   ['op_5ftype_5finfo_3c_20op_5fnorm_5f2_20_3e',['op_type_info< op_norm_2 >',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__2_01_4.html',1,'viennacl::scheduler::result_of']]],
