@@ -10,12 +10,13 @@ var searchData=
   ['scan_2ecpp',['scan.cpp',['../scan_8cpp.html',1,'']]],
   ['scheduler_2ecpp',['scheduler.cpp',['../benchmarks_2scheduler_8cpp.html',1,'']]],
   ['scheduler_2ecpp',['scheduler.cpp',['../tutorial_2scheduler_8cpp.html',1,'']]],
-  ['scheduler_5fmatrix_2ecpp',['scheduler_matrix.cpp',['../tests_2src_2scheduler__matrix_8cpp.html',1,'']]],
-  ['scheduler_5fmatrix_2ecpp',['scheduler_matrix.cpp',['../examples_2tutorial_2scheduler__matrix_8cpp.html',1,'']]],
+  ['scheduler_5fmatrix_2ecpp',['scheduler_matrix.cpp',['../scheduler__matrix_8cpp.html',1,'']]],
   ['scheduler_5fmatrix_5fmatrix_2ecpp',['scheduler_matrix_matrix.cpp',['../scheduler__matrix__matrix_8cpp.html',1,'']]],
   ['scheduler_5fmatrix_5fvector_2ecpp',['scheduler_matrix_vector.cpp',['../scheduler__matrix__vector_8cpp.html',1,'']]],
   ['scheduler_5fsparse_2ecpp',['scheduler_sparse.cpp',['../scheduler__sparse_8cpp.html',1,'']]],
   ['scheduler_5fvector_2ecpp',['scheduler_vector.cpp',['../scheduler__vector_8cpp.html',1,'']]],
+  ['scrapper_2ehpp',['scrapper.hpp',['../scrapper_8hpp.html',1,'']]],
+  ['self_5fassign_2ecpp',['self_assign.cpp',['../self__assign_8cpp.html',1,'']]],
   ['sha1_2ehpp',['sha1.hpp',['../sha1_8hpp.html',1,'']]],
   ['shared_2dlibrary_2edox',['shared-library.dox',['../shared-library_8dox.html',1,'']]],
   ['shared_5fptr_2ehpp',['shared_ptr.hpp',['../shared__ptr_8hpp.html',1,'']]],
@@ -28,17 +29,17 @@ var searchData=
   ['spai_2ddynamic_2ehpp',['spai-dynamic.hpp',['../spai-dynamic_8hpp.html',1,'']]],
   ['spai_2dstatic_2ehpp',['spai-static.hpp',['../spai-static_8hpp.html',1,'']]],
   ['spai_2ecpp',['spai.cpp',['../spai_8cpp.html',1,'']]],
+  ['spai_2ehpp',['spai.hpp',['../detail_2spai_2spai_8hpp.html',1,'']]],
   ['spai_2ehpp',['spai.hpp',['../opencl_2kernels_2spai_8hpp.html',1,'']]],
   ['spai_2ehpp',['spai.hpp',['../spai_8hpp.html',1,'']]],
-  ['spai_2ehpp',['spai.hpp',['../detail_2spai_2spai_8hpp.html',1,'']]],
   ['spai_5ftag_2ehpp',['spai_tag.hpp',['../spai__tag_8hpp.html',1,'']]],
   ['sparse_2ecpp',['sparse.cpp',['../examples_2tutorial_2sparse_8cpp.html',1,'']]],
   ['sparse_2ecpp',['sparse.cpp',['../examples_2benchmarks_2sparse_8cpp.html',1,'']]],
   ['sparse_2ecpp',['sparse.cpp',['../tests_2src_2sparse_8cpp.html',1,'']]],
-  ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../sparse__matrix__operations_8hpp.html',1,'']]],
-  ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../host__based_2sparse__matrix__operations_8hpp.html',1,'']]],
-  ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../cuda_2sparse__matrix__operations_8hpp.html',1,'']]],
   ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../opencl_2sparse__matrix__operations_8hpp.html',1,'']]],
+  ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../cuda_2sparse__matrix__operations_8hpp.html',1,'']]],
+  ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../host__based_2sparse__matrix__operations_8hpp.html',1,'']]],
+  ['sparse_5fmatrix_5foperations_2ehpp',['sparse_matrix_operations.hpp',['../sparse__matrix__operations_8hpp.html',1,'']]],
   ['sparse_5fmatrix_5foperations_5fsolve_2ehpp',['sparse_matrix_operations_solve.hpp',['../sparse__matrix__operations__solve_8hpp.html',1,'']]],
   ['sparse_5fvector_2ehpp',['sparse_vector.hpp',['../sparse__vector_8hpp.html',1,'']]],
   ['spmdm_2ecpp',['spmdm.cpp',['../spmdm_8cpp.html',1,'']]],
@@ -47,8 +48,8 @@ var searchData=
   ['start_2ehpp',['start.hpp',['../start_8hpp.html',1,'']]],
   ['stride_2ehpp',['stride.hpp',['../stride_8hpp.html',1,'']]],
   ['structs_2ehpp',['structs.hpp',['../structs_8hpp.html',1,'']]],
-  ['structured_2dmatrices_2ecpp',['structured-matrices.cpp',['../tests_2src_2structured-matrices_8cpp.html',1,'']]],
   ['structured_2dmatrices_2ecpp',['structured-matrices.cpp',['../examples_2tutorial_2structured-matrices_8cpp.html',1,'']]],
+  ['structured_2dmatrices_2ecpp',['structured-matrices.cpp',['../tests_2src_2structured-matrices_8cpp.html',1,'']]],
   ['structured_2dmatrices_2edox',['structured-matrices.dox',['../structured-matrices_8dox.html',1,'']]],
   ['svd_2ecpp',['svd.cpp',['../svd_8cpp.html',1,'']]],
   ['svd_2ehpp',['svd.hpp',['../svd_8hpp.html',1,'']]],
