@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['a',['a',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a5cf958857eb2a201b5974db2f46468d8',1,'viennacl::linalg::opencl::kernels::ambm_config::a()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a37e4352942d0a54619364b499e73b1d3',1,'viennacl::linalg::opencl::kernels::asbs_config::a()'],['../changelog.html#a61722308a5fd44e7073ee454e4e699c3',1,'A():&#160;changelog']]],
+  ['a',['a',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a5cf958857eb2a201b5974db2f46468d8',1,'viennacl::linalg::opencl::kernels::ambm_config::a()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a37e4352942d0a54619364b499e73b1d3',1,'viennacl::linalg::opencl::kernels::asbs_config::a()']]],
   ['a_5ffetching_5fpolicy',['A_fetching_policy',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a9b3d791ae84fbc96c75b63fd50c4eac7',1,'viennacl::device_specific::matrix_product_parameters']]],
   ['a_5fslice_5f',['A_slice_',['../classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__slicing.html#ab19d7e937b799b41cdb6707ea54c438f',1,'viennacl::linalg::detail::amg::amg_slicing']]],
   ['assign_5fop',['assign_op',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a7a2c0d66c19102cbc2b7dd26782fcd52',1,'viennacl::linalg::opencl::kernels::ambm_config::assign_op()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a1d02ac1b9ae28dd0fdb35a38f96258cf',1,'viennacl::linalg::opencl::kernels::asbs_config::assign_op()']]]
