@@ -1,14 +1,15 @@
 var vector__float__double_8cpp =
 [
-    [ "BOOST_UBLAS_NDEBUG", "vector__float__double_8cpp.html#aa2c0476a142c9e172a2c18d054b6c210", null ],
+    [ "vector_proxy", "classvector__proxy.html", "classvector__proxy" ],
     [ "GENERATE_UNARY_OP_TEST", "vector__float__double_8cpp.html#a1a31691278c2c097329150c6fd1a04f2", null ],
-    [ "VIENNACL_WITH_UBLAS", "vector__float__double_8cpp.html#af9d2311f8dd8c5536101e46f1351df56", null ],
     [ "check", "vector__float__double_8cpp.html#a4a5d2084b73dcf0a4eb7c53af452e9a3", null ],
     [ "diff", "vector__float__double_8cpp.html#a28966b44e6f7b9d4b21ea274ce507503", null ],
     [ "diff", "vector__float__double_8cpp.html#abb415d601ffd2f90ab5b8c0c5ed37fcb", null ],
     [ "diff", "vector__float__double_8cpp.html#ac9cdd803369376cdf31cba3dedafa739", null ],
-    [ "diff", "vector__float__double_8cpp.html#a244af8a9755388ff60c8f62905537ea4", null ],
+    [ "diff", "vector__float__double_8cpp.html#af21acead8d9fc830d018ebd10045d086", null ],
     [ "main", "vector__float__double_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4", null ],
-    [ "test", "vector__float__double_8cpp.html#a9f8ddcb40078b98954fd07f7745789ac", null ],
+    [ "proxy_copy", "vector__float__double_8cpp.html#af58462ac765a0fb3b2f35f6245acd131", null ],
+    [ "proxy_copy", "vector__float__double_8cpp.html#a772fd210577b8c77b874ab50fea12807", null ],
+    [ "test", "vector__float__double_8cpp.html#a372953495e22570af3e118e7535ca6ce", null ],
     [ "test", "vector__float__double_8cpp.html#ac6dd046cff9262f2cbe9dc33537fbdbc", null ]
 ];
\ No newline at end of file
