@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2014, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -16,6 +16,10 @@
 ============================================================================= */
 
 
+/** \file tests/src/matrix_vector.cpp  Tests routines for matrix-vector operaions (BLAS level 2) using floating point arithmetic.
+*   \test Tests routines for matrix-vector operaions (BLAS level 2) using floating point arithmetic.
+**/
+
 //
 // *** System
 //
@@ -54,7 +58,7 @@ using namespace boost::numeric;
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType & s1, viennacl::scalar<ScalarType> & s2)
 {
    viennacl::backend::finish();
@@ -63,7 +67,7 @@ ScalarType diff(ScalarType & s1, viennacl::scalar<ScalarType> & s2)
    return 0;
 }
 
-template <typename ScalarType, typename VCLVectorType>
+template<typename ScalarType, typename VCLVectorType>
 ScalarType diff(ublas::vector<ScalarType> const & v1, VCLVectorType const & v2)
 {
    ublas::vector<ScalarType> v2_cpu(v2.size());
@@ -81,7 +85,7 @@ ScalarType diff(ublas::vector<ScalarType> const & v1, VCLVectorType const & v2)
    return norm_inf(v2_cpu);
 }
 
-template <typename ScalarType, typename VCLMatrixType>
+template<typename ScalarType, typename VCLMatrixType>
 ScalarType diff(ublas::matrix<ScalarType> const & mat1, VCLMatrixType const & mat2)
 {
    ublas::matrix<ScalarType> mat2_cpu(mat2.size1(), mat2.size2());
@@ -106,7 +110,7 @@ ScalarType diff(ublas::matrix<ScalarType> const & mat1, VCLMatrixType const & ma
 // -------------------------------------------------------------
 //
 
-template <typename NumericT, typename Epsilon,
+template<typename NumericT, typename Epsilon,
           typename UblasMatrixType, typename UblasVectorType,
           typename VCLMatrixType, typename VCLVectorType1, typename VCLVectorType2>
 int test_prod_rank1(Epsilon const & epsilon,
@@ -127,7 +131,7 @@ int test_prod_rank1(Epsilon const & epsilon,
 
    ublas_m1 += ublas::outer_prod(ublas_v1, ublas_v2);
    vcl_m1 += viennacl::linalg::outer_prod(vcl_v1, vcl_v2);
-   if( std::fabs(diff(ublas_m1, vcl_m1)) > epsilon )
+   if ( std::fabs(diff(ublas_m1, vcl_m1)) > epsilon )
    {
       std::cout << "# Error at operation: rank 1 update" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_m1, vcl_m1)) << std::endl;
@@ -141,7 +145,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_m1 += NumericT(4.2) * ublas::outer_prod(ublas_v1, ublas_v2);
    vcl_m1 += NumericT(2.1) * viennacl::linalg::outer_prod(vcl_v1, vcl_v2);
    vcl_m1 += viennacl::linalg::outer_prod(vcl_v1, vcl_v2) * NumericT(2.1);  //check proper compilation
-   if( std::fabs(diff(ublas_m1, vcl_m1)) > epsilon )
+   if ( std::fabs(diff(ublas_m1, vcl_m1)) > epsilon )
    {
       std::cout << "# Error at operation: scaled rank 1 update - CPU Scalar" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_m1, vcl_m1)) << std::endl;
@@ -153,7 +157,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_m1 += NumericT(4.2) * ublas::outer_prod(ublas_v1, ublas_v2);
    vcl_m1 += viennacl::scalar<NumericT>(NumericT(2.1)) * viennacl::linalg::outer_prod(vcl_v1, vcl_v2);
    vcl_m1 += viennacl::linalg::outer_prod(vcl_v1, vcl_v2) * viennacl::scalar<NumericT>(NumericT(2.1));  //check proper compilation
-   if( std::fabs(diff(ublas_m1, vcl_m1)) > epsilon )
+   if ( std::fabs(diff(ublas_m1, vcl_m1)) > epsilon )
    {
       std::cout << "# Error at operation: scaled rank 1 update - GPU Scalar" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_m1, vcl_m1)) << std::endl;
@@ -168,7 +172,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_v1 = viennacl::linalg::prod(ublas_m1, ublas_v2);
    vcl_v1   = viennacl::linalg::prod(vcl_m1, vcl_v2);
 
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: matrix-vector product" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -184,7 +188,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_v1 = alpha * viennacl::linalg::prod(ublas_m1, ublas_v2) + beta * ublas_v1;
    vcl_v1   = alpha * viennacl::linalg::prod(vcl_m1, vcl_v2) + beta * vcl_v1;
 
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: matrix-vector product with scaled additions" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -199,7 +203,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_v2 = alpha * viennacl::linalg::prod(trans(ublas_m1), ublas_v1);
    vcl_v2   = alpha * viennacl::linalg::prod(trans(vcl_m1), vcl_v1);
 
-   if( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
+   if ( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
    {
       std::cout << "# Error at operation: transposed matrix-vector product" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v2, vcl_v2)) << std::endl;
@@ -210,7 +214,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_v2 = alpha * viennacl::linalg::prod(trans(ublas_m1), ublas_v1) + beta * ublas_v2;
    vcl_v2   = alpha * viennacl::linalg::prod(trans(vcl_m1), vcl_v1) + beta * vcl_v2;
 
-   if( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
+   if ( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
    {
       std::cout << "# Error at operation: transposed matrix-vector product with scaled additions" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v2, vcl_v2)) << std::endl;
@@ -225,7 +229,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_v2 = row(ublas_m1, std::size_t(7));
    vcl_v2   = row(vcl_m1, std::size_t(7));
 
-   if( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
+   if ( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
    {
       std::cout << "# Error at operation: diagonal extraction from matrix" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v2, vcl_v2)) << std::endl;
@@ -236,7 +240,7 @@ int test_prod_rank1(Epsilon const & epsilon,
    ublas_v1 = column(ublas_m1, std::size_t(7));
    vcl_v1   = column(vcl_m1, std::size_t(7));
 
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: diagonal extraction from matrix" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v2, vcl_v2)) << std::endl;
@@ -255,7 +259,7 @@ int test_prod_rank1(Epsilon const & epsilon,
      ublas_v2[i] = ublas_m1(i + 3, i);
    vcl_v2   = diag(vcl_m1, static_cast<int>(-3));
 
-   if( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
+   if ( std::fabs(diff(ublas_v2, vcl_v2)) > epsilon )
    {
       std::cout << "# Error at operation: diagonal extraction from matrix" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v2, vcl_v2)) << std::endl;
@@ -268,7 +272,7 @@ int test_prod_rank1(Epsilon const & epsilon,
      A(i + (A.size1() - ublas_m1.size2()), i) = ublas_v2[i];
    vcl_m2 = diag(vcl_v2, static_cast<int>(ublas_m1.size2()) - static_cast<int>(A.size1()));
 
-   if( std::fabs(diff(A, vcl_m2)) > epsilon )
+   if ( std::fabs(diff(A, vcl_m2)) > epsilon )
    {
       std::cout << "# Error at operation: Matrix assignment from diagonal" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(A, vcl_m2)) << std::endl;
@@ -281,7 +285,7 @@ int test_prod_rank1(Epsilon const & epsilon,
 
 
 
-template <typename NumericT, typename Epsilon,
+template<typename NumericT, typename Epsilon,
           typename UblasMatrixType, typename UblasVectorType,
           typename VCLMatrixType, typename VCLVectorType1>
 int test_solve(Epsilon const & epsilon,
@@ -301,7 +305,7 @@ int test_solve(Epsilon const & epsilon,
    std::cout << "Upper triangular solver" << std::endl;
    ublas_v1 = ublas::solve(ublas_m1, ublas_v1, ublas::upper_tag());
    vcl_v1 = viennacl::linalg::solve(vcl_m1, vcl_v1, viennacl::linalg::upper_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: upper triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -313,7 +317,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(ublas_m1, ublas_v1, ublas::unit_upper_tag());
    vcl_v1 = viennacl::linalg::solve(vcl_m1, vcl_v1, viennacl::linalg::unit_upper_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: unit upper triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -325,7 +329,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(ublas_m1, ublas_v1, ublas::lower_tag());
    vcl_v1 = viennacl::linalg::solve(vcl_m1, vcl_v1, viennacl::linalg::lower_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: lower triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -337,7 +341,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(ublas_m1, ublas_v1, ublas::unit_lower_tag());
    vcl_v1 = viennacl::linalg::solve(vcl_m1, vcl_v1, viennacl::linalg::unit_lower_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: unit lower triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -353,7 +357,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(trans(ublas_m1), ublas_v1, ublas::upper_tag());
    vcl_v1 = viennacl::linalg::solve(trans(vcl_m1), vcl_v1, viennacl::linalg::upper_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: upper triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -365,7 +369,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(trans(ublas_m1), ublas_v1, ublas::unit_upper_tag());
    vcl_v1 = viennacl::linalg::solve(trans(vcl_m1), vcl_v1, viennacl::linalg::unit_upper_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: unit upper triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -377,7 +381,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(trans(ublas_m1), ublas_v1, ublas::lower_tag());
    vcl_v1 = viennacl::linalg::solve(trans(vcl_m1), vcl_v1, viennacl::linalg::lower_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: lower triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -389,7 +393,7 @@ int test_solve(Epsilon const & epsilon,
    viennacl::copy(ublas_v1, vcl_v1);
    ublas_v1 = ublas::solve(trans(ublas_m1), ublas_v1, ublas::unit_lower_tag());
    vcl_v1 = viennacl::linalg::solve(trans(vcl_m1), vcl_v1, viennacl::linalg::unit_lower_tag());
-   if( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
+   if ( std::fabs(diff(ublas_v1, vcl_v1)) > epsilon )
    {
       std::cout << "# Error at operation: unit lower triangular solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(ublas_v1, vcl_v1)) << std::endl;
@@ -473,7 +477,7 @@ int test(Epsilon const& epsilon)
    }
    vcl_matrix.resize(2*num_rows, 2*num_cols, true);
    viennacl::copy(vcl_matrix, matrix);
-   if( std::fabs(diff(matrix, vcl_matrix)) > epsilon )
+   if ( std::fabs(diff(matrix, vcl_matrix)) > epsilon )
    {
       std::cout << "# Error at operation: matrix resize (to larger)" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(matrix, vcl_matrix)) << std::endl;
@@ -490,7 +494,7 @@ int test(Epsilon const& epsilon)
    std::cout << "Matrix resizing (to smaller)" << std::endl;
    matrix.resize(result.size(), rhs.size(), true);
    vcl_matrix.resize(result.size(), rhs.size(), true);
-   if( std::fabs(diff(matrix, vcl_matrix)) > epsilon )
+   if ( std::fabs(diff(matrix, vcl_matrix)) > epsilon )
    {
       std::cout << "# Error at operation: matrix resize (to smaller)" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(matrix, vcl_matrix)) << std::endl;
@@ -1036,7 +1040,7 @@ int test(Epsilon const& epsilon)
    //viennacl::copy(square_matrix, vcl_square_matrix);
    viennacl::linalg::lu_substitute(vcl_square_matrix, vcl_lu_rhs);
 
-   if( std::fabs(diff(lu_rhs, vcl_lu_rhs)) > epsilon )
+   if ( std::fabs(diff(lu_rhs, vcl_lu_rhs)) > epsilon )
    {
       std::cout << "# Error at operation: dense solver" << std::endl;
       std::cout << "  diff: " << std::fabs(diff(lu_rhs, vcl_lu_rhs)) << std::endl;
@@ -1062,22 +1066,22 @@ int main()
 
    int retval = EXIT_SUCCESS;
 
-   std::cout << std::endl;
-   std::cout << "----------------------------------------------" << std::endl;
-   std::cout << std::endl;
-   {
-      typedef float NumericT;
-      NumericT epsilon = NumericT(1.0E-3);
-      std::cout << "# Testing setup:" << std::endl;
-      std::cout << "  eps:     " << epsilon << std::endl;
-      std::cout << "  numeric: float" << std::endl;
-      std::cout << "  layout: row-major" << std::endl;
-      retval = test<NumericT, viennacl::row_major>(epsilon);
-      if( retval == EXIT_SUCCESS )
-         std::cout << "# Test passed" << std::endl;
-      else
-         return retval;
-   }
+//   std::cout << std::endl;
+//   std::cout << "----------------------------------------------" << std::endl;
+//   std::cout << std::endl;
+//   {
+//      typedef float NumericT;
+//      NumericT epsilon = NumericT(1.0E-3);
+//      std::cout << "# Testing setup:" << std::endl;
+//      std::cout << "  eps:     " << epsilon << std::endl;
+//      std::cout << "  numeric: float" << std::endl;
+//      std::cout << "  layout: row-major" << std::endl;
+//      retval = test<NumericT, viennacl::row_major>(epsilon);
+//      if ( retval == EXIT_SUCCESS )
+//         std::cout << "# Test passed" << std::endl;
+//      else
+//         return retval;
+//   }
    std::cout << std::endl;
    std::cout << "----------------------------------------------" << std::endl;
    std::cout << std::endl;
@@ -1089,7 +1093,7 @@ int main()
       std::cout << "  numeric: float" << std::endl;
       std::cout << "  layout: column-major" << std::endl;
       retval = test<NumericT, viennacl::column_major>(epsilon);
-      if( retval == EXIT_SUCCESS )
+      if ( retval == EXIT_SUCCESS )
          std::cout << "# Test passed" << std::endl;
       else
          return retval;
@@ -1100,7 +1104,7 @@ int main()
 
 
 #ifdef VIENNACL_WITH_OPENCL
-   if( viennacl::ocl::current_device().double_support() )
+   if ( viennacl::ocl::current_device().double_support() )
 #endif
    {
       {
@@ -1111,7 +1115,7 @@ int main()
          std::cout << "  numeric: double" << std::endl;
          std::cout << "  layout: row-major" << std::endl;
          retval = test<NumericT, viennacl::row_major>(epsilon);
-            if( retval == EXIT_SUCCESS )
+            if ( retval == EXIT_SUCCESS )
                std::cout << "# Test passed" << std::endl;
             else
               return retval;
@@ -1127,7 +1131,7 @@ int main()
          std::cout << "  numeric: double" << std::endl;
          std::cout << "  layout: column-major" << std::endl;
          retval = test<NumericT, viennacl::column_major>(epsilon);
-            if( retval == EXIT_SUCCESS )
+            if ( retval == EXIT_SUCCESS )
                std::cout << "# Test passed" << std::endl;
             else
               return retval;
