@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2014, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -15,6 +15,12 @@
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
 
+
+
+/** \file tests/src/scheduler_matrix.cpp  Tests the scheduler for matrix-operations (no matrix-matrix).
+*   \test Tests the scheduler for matrix-operations (no matrix-matrix).
+**/
+
 #define VIENNACL_WITH_UBLAS
 //#define NDEBUG
 //#define VIENNACL_BUILD_INFO
@@ -49,7 +55,7 @@
 
 using namespace boost::numeric;
 
-template <typename MatrixType, typename VCLMatrixType>
+template<typename MatrixType, typename VCLMatrixType>
 bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A, double epsilon)
 {
   typedef typename MatrixType::value_type   value_type;
@@ -62,9 +68,9 @@ bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A,
   {
     for (std::size_t j=0; j<ublas_A.size2(); ++j)
     {
-      if (ublas_A(i,j) != vcl_A_cpu(i,j))
+      if (std::fabs(ublas_A(i,j) - vcl_A_cpu(i,j)) > 0)
       {
-        if ( (std::abs(ublas_A(i,j) - vcl_A_cpu(i,j)) / std::max(ublas_A(i,j), vcl_A_cpu(i,j)) > epsilon) || (vcl_A_cpu(i,j) != vcl_A_cpu(i,j)) )
+        if ( (std::fabs(ublas_A(i,j) - vcl_A_cpu(i,j)) / std::max(std::fabs(ublas_A(i,j)), std::fabs(vcl_A_cpu(i,j))) > epsilon) || std::fabs(vcl_A_cpu(i,j) - vcl_A_cpu(i,j)) > 0 )
         {
           std::cout << "Error at index (" << i << ", " << j << "): " << ublas_A(i,j) << " vs " << vcl_A_cpu(i,j) << std::endl;
           std::cout << std::endl << "TEST failed!" << std::endl;
@@ -81,7 +87,7 @@ bool check_for_equality(MatrixType const & ublas_A, VCLMatrixType const & vcl_A,
 
 
 
-template <typename UBLASMatrixType,
+template<typename UBLASMatrixType,
           typename ViennaCLMatrixType1, typename ViennaCLMatrixType2, typename ViennaCLMatrixType3>
 int run_test(double epsilon,
              UBLASMatrixType & ublas_A, UBLASMatrixType & ublas_B, UBLASMatrixType & ublas_C,
@@ -336,7 +342,7 @@ int run_test(double epsilon,
   { \
   for (std::size_t i=0; i<ublas_C.size1(); ++i) \
     for (std::size_t j=0; j<ublas_C.size2(); ++j) \
-      ublas_C(i,j) = OPNAME(ublas_A(i,j)); \
+      ublas_C(i,j) = static_cast<cpu_value_type>(OPNAME(ublas_A(i,j))); \
   viennacl::scheduler::statement my_statement(vcl_C, viennacl::op_assign(), viennacl::linalg::element_##OPNAME(vcl_A)); \
   viennacl::scheduler::execute(my_statement); \
   if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS) \
@@ -345,7 +351,7 @@ int run_test(double epsilon,
   { \
   for (std::size_t i=0; i<ublas_C.size1(); ++i) \
     for (std::size_t j=0; j<ublas_C.size2(); ++j) \
-      ublas_C(i,j) = OPNAME(ublas_A(i,j) / cpu_value_type(2)); \
+      ublas_C(i,j) = static_cast<cpu_value_type>(OPNAME(ublas_A(i,j) / cpu_value_type(2))); \
   viennacl::scheduler::statement my_statement(vcl_C, viennacl::op_assign(), viennacl::linalg::element_##OPNAME(vcl_A / cpu_value_type(2))); \
   viennacl::scheduler::execute(my_statement); \
   if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS) \
@@ -369,6 +375,69 @@ int run_test(double epsilon,
 
 #undef GENERATE_UNARY_OP_TEST
 
+  if (ublas_C.size1() == ublas_C.size2()) // transposition tests
+  {
+    std::cout << "z = element_fabs(x - trans(y))... ";
+    {
+    for (std::size_t i=0; i<ublas_C.size1(); ++i)
+      for (std::size_t j=0; j<ublas_C.size2(); ++j)
+        ublas_C(i,j) = std::fabs(ublas_A(i,j) - ublas_B(j,i));
+    viennacl::scheduler::statement   my_statement(vcl_C, viennacl::op_assign(), viennacl::linalg::element_fabs((vcl_A) - trans(vcl_B)));
+    viennacl::scheduler::execute(my_statement);
+
+    if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS)
+      return EXIT_FAILURE;
+    }
+
+    std::cout << "z = element_fabs(trans(x) - (y))... ";
+    {
+    for (std::size_t i=0; i<ublas_C.size1(); ++i)
+      for (std::size_t j=0; j<ublas_C.size2(); ++j)
+        ublas_C(i,j) = std::fabs(ublas_A(j,i) - ublas_B(i,j));
+    viennacl::scheduler::statement   my_statement(vcl_C, viennacl::op_assign(), viennacl::linalg::element_fabs(trans(vcl_A) - (vcl_B)));
+    viennacl::scheduler::execute(my_statement);
+
+    if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS)
+      return EXIT_FAILURE;
+    }
+
+    std::cout << "z = element_fabs(trans(x) - trans(y))... ";
+    {
+    for (std::size_t i=0; i<ublas_C.size1(); ++i)
+      for (std::size_t j=0; j<ublas_C.size2(); ++j)
+        ublas_C(i,j) = std::fabs(ublas_A(j,i) - ublas_B(j,i));
+    viennacl::scheduler::statement   my_statement(vcl_C, viennacl::op_assign(), viennacl::linalg::element_fabs(trans(vcl_A) - trans(vcl_B)));
+    viennacl::scheduler::execute(my_statement);
+
+    if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS)
+      return EXIT_FAILURE;
+    }
+
+    std::cout << "z += trans(x)... ";
+    {
+    for (std::size_t i=0; i<ublas_C.size1(); ++i)
+      for (std::size_t j=0; j<ublas_C.size2(); ++j)
+        ublas_C(i,j) += ublas_A(j,i);
+    viennacl::scheduler::statement   my_statement(vcl_C, viennacl::op_inplace_add(), trans(vcl_A));
+    viennacl::scheduler::execute(my_statement);
+
+    if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS)
+      return EXIT_FAILURE;
+    }
+
+    std::cout << "z -= trans(x)... ";
+    {
+    for (std::size_t i=0; i<ublas_C.size1(); ++i)
+      for (std::size_t j=0; j<ublas_C.size2(); ++j)
+        ublas_C(i,j) -= ublas_A(j,i);
+    viennacl::scheduler::statement   my_statement(vcl_C, viennacl::op_inplace_sub(), trans(vcl_A));
+    viennacl::scheduler::execute(my_statement);
+
+    if (!check_for_equality(ublas_C, vcl_C, epsilon) != EXIT_SUCCESS)
+      return EXIT_FAILURE;
+    }
+
+  }
 
   std::cout << std::endl;
   std::cout << "----------------------------------------------" << std::endl;
@@ -381,7 +450,7 @@ int run_test(double epsilon,
 
 
 
-template <typename T, typename ScalarType>
+template<typename T, typename ScalarType>
 int run_test(double epsilon)
 {
     //typedef float               ScalarType;
@@ -391,8 +460,8 @@ int run_test(double epsilon)
 
     std::size_t dim_rows = 131;
     std::size_t dim_cols = 33;
-    //std::size_t dim_rows = 5;
-    //std::size_t dim_cols = 3;
+    //std::size_t dim_rows = 4;
+    //std::size_t dim_cols = 4;
 
     //setup ublas objects:
     MatrixType ublas_A(dim_rows, dim_cols);
@@ -896,10 +965,10 @@ int main (int, const char **)
 
 
 #ifdef VIENNACL_WITH_OPENCL
-   if( viennacl::ocl::current_device().double_support() )
+   if ( viennacl::ocl::current_device().double_support() )
 #endif
   {
-    double epsilon = 1e-12;
+    epsilon = 1e-12;
     std::cout << "# Testing setup:" << std::endl;
     std::cout << "  eps:     " << epsilon << std::endl;
     std::cout << "  numeric: double" << std::endl;
