@@ -1,5 +1,5 @@
 /* =========================================================================
-   Copyright (c) 2010-2013, Institute for Microelectronics,
+   Copyright (c) 2010-2014, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -15,8 +15,10 @@
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
 
-//#define NDEBUG
-//#define VIENNACL_DEBUG_BUILD
+
+/** \file tests/src/scheduler_matrix_matrix.cpp  Tests the scheduler for dense matrix-matrix-operations.
+*   \test Tests the scheduler for dense matrix-matrix-operations.
+**/
 
 //
 // *** System
@@ -59,7 +61,7 @@ using namespace boost::numeric;
 //
 // -------------------------------------------------------------
 //
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ScalarType & s1, viennacl::scalar<ScalarType> & s2)
 {
    viennacl::backend::finish();
@@ -68,7 +70,7 @@ ScalarType diff(ScalarType & s1, viennacl::scalar<ScalarType> & s2)
    return 0;
 }
 
-template <typename ScalarType>
+template<typename ScalarType>
 ScalarType diff(ublas::vector<ScalarType> & v1, viennacl::vector<ScalarType> & v2)
 {
    ublas::vector<ScalarType> v2_cpu(v2.size());
@@ -87,7 +89,7 @@ ScalarType diff(ublas::vector<ScalarType> & v1, viennacl::vector<ScalarType> & v
 }
 
 
-template <typename ScalarType, typename VCLMatrixType>
+template<typename ScalarType, typename VCLMatrixType>
 ScalarType diff(ublas::matrix<ScalarType> & mat1, VCLMatrixType & mat2)
 {
    ublas::matrix<ScalarType> mat2_cpu(mat2.size1(), mat2.size2());
@@ -145,7 +147,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -162,7 +164,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -178,7 +180,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -199,7 +201,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -216,7 +218,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -233,7 +235,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -252,7 +254,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -269,7 +271,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -286,7 +288,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -307,7 +309,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -323,7 +325,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -340,7 +342,7 @@ int test_prod(Epsilon const& epsilon,
    }
    act_diff = std::fabs(diff(C, vcl_C));
 
-   if( act_diff > epsilon )
+   if ( act_diff > epsilon )
    {
      std::cout << "# Error at operation: matrix-matrix product" << std::endl;
      std::cout << "  diff: " << act_diff << std::endl;
@@ -916,7 +918,7 @@ int main()
       std::cout << "  eps:     " << epsilon << std::endl;
       std::cout << "  numeric: float" << std::endl;
       retval = test<NumericT>(epsilon);
-      if( retval == EXIT_SUCCESS )
+      if ( retval == EXIT_SUCCESS )
         std::cout << "# Test passed" << std::endl;
       else
         return retval;
@@ -925,7 +927,7 @@ int main()
    std::cout << "----------------------------------------------" << std::endl;
    std::cout << std::endl;
 #ifdef VIENNACL_WITH_OPENCL
-   if( viennacl::ocl::current_device().double_support() )
+   if ( viennacl::ocl::current_device().double_support() )
 #endif
    {
       {
@@ -935,7 +937,7 @@ int main()
         std::cout << "  eps:     " << epsilon << std::endl;
         std::cout << "  numeric: double" << std::endl;
         retval = test<NumericT>(epsilon);
-        if( retval == EXIT_SUCCESS )
+        if ( retval == EXIT_SUCCESS )
           std::cout << "# Test passed" << std::endl;
         else
           return retval;
