@@ -68,7 +68,7 @@ __global__ void pipelined_cg_vector_kernel(NumericT * result,
   // parallel reduction in work group
   __shared__ NumericT shared_array[256];
   shared_array[threadIdx.x] = inner_prod_contrib;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -189,7 +189,7 @@ __global__ void pipelined_cg_csr_vec_mul_kernel(
   __shared__ NumericT shared_array_pAp[256];
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -218,7 +218,7 @@ void pipelined_cg_prod(compressed_matrix<NumericT> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_csr_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
+  pipelined_cg_csr_vec_mul_kernel<<<256, 256>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                 detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
@@ -322,7 +322,7 @@ __global__ void pipelined_cg_coo_vec_mul_kernel(const unsigned int * coords, //(
   __shared__ NumericT shared_array_pAp[256];
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -406,7 +406,7 @@ __global__ void pipelined_cg_ell_vec_mul_kernel(const unsigned int * coords,
   __shared__ NumericT shared_array_pAp[256];
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -433,7 +433,7 @@ void pipelined_cg_prod(ell_matrix<NumericT> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_ell_vec_mul_kernel<<<256, 128>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
+  pipelined_cg_ell_vec_mul_kernel<<<256, 256>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                 detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
                                                 static_cast<unsigned int>(A.internal_size1()),
                                                 static_cast<unsigned int>(A.maxnnz()),
@@ -494,7 +494,7 @@ __global__ void pipelined_cg_sliced_ell_vec_mul_kernel(const unsigned int * colu
   __shared__ NumericT shared_array_pAp[256];
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -520,7 +520,7 @@ void pipelined_cg_prod(sliced_ell_matrix<NumericT> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_sliced_ell_vec_mul_kernel<<<128, A.rows_per_block()>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
+  pipelined_cg_sliced_ell_vec_mul_kernel<<<256, A.rows_per_block()>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
                                                                       detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                                       detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                                       detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
@@ -587,7 +587,7 @@ __global__ void pipelined_cg_hyb_vec_mul_kernel(const unsigned int * ell_coords,
   __shared__ NumericT shared_array_pAp[256];
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -615,7 +615,7 @@ void pipelined_cg_prod(hyb_matrix<NumericT> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_hyb_vec_mul_kernel<<<256, 128>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
+  pipelined_cg_hyb_vec_mul_kernel<<<256, 256>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                 detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle4().cuda_handle()),
@@ -651,7 +651,7 @@ __global__ void pipelined_bicgstab_update_s_kernel(NumericT * s,
 
   shared_array[threadIdx.x] = inner_prod_buffer[threadIdx.x];
   shared_array_Ap_in_r0[threadIdx.x] = inner_prod_buffer[threadIdx.x + 3 * chunk_size];
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride) {
@@ -679,7 +679,7 @@ __global__ void pipelined_bicgstab_update_s_kernel(NumericT * s,
 
   // parallel reduction in work group
   shared_array[threadIdx.x] = inner_prod_contrib;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -703,7 +703,7 @@ void pipelined_bicgstab_update_s(vector_base<NumericT> & s,
   unsigned int chunk_size   = static_cast<unsigned int>(buffer_chunk_size);
   unsigned int chunk_offset = static_cast<unsigned int>(buffer_chunk_offset);
 
-  pipelined_bicgstab_update_s_kernel<<<128, 128>>>(detail::cuda_arg<NumericT>(s),
+  pipelined_bicgstab_update_s_kernel<<<256, 256>>>(detail::cuda_arg<NumericT>(s),
                                                    detail::cuda_arg<NumericT>(r),
                                                    detail::cuda_arg<NumericT>(Ap),
                                                    size,
@@ -751,7 +751,7 @@ __global__ void pipelined_bicgstab_vector_kernel(NumericT * result,
   // parallel reduction in work group
   __shared__ NumericT shared_array[256];
   shared_array[threadIdx.x] = inner_prod_r_r0star;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -774,7 +774,7 @@ void pipelined_bicgstab_vector_update(vector_base<NumericT> & result, NumericT a
   (void)buffer_chunk_size;
   unsigned int size = static_cast<unsigned int>(result.size());
 
-  pipelined_bicgstab_vector_kernel<<<128, 128>>>(detail::cuda_arg<NumericT>(result),
+  pipelined_bicgstab_vector_kernel<<<256, 256>>>(detail::cuda_arg<NumericT>(result),
                                                  alpha,
                                                  detail::cuda_arg<NumericT>(p),
                                                  omega,
@@ -882,7 +882,7 @@ __global__ void pipelined_bicgstab_csr_vec_mul_kernel(
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
   shared_array_r0Ap[threadIdx.x] = inner_prod_r0Ap;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -917,7 +917,7 @@ void pipelined_bicgstab_prod(compressed_matrix<NumericT> const & A,
   unsigned int chunk_size   = static_cast<unsigned int>(buffer_chunk_size);
   unsigned int chunk_offset = static_cast<unsigned int>(buffer_chunk_offset);
 
-  pipelined_bicgstab_csr_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
+  pipelined_bicgstab_csr_vec_mul_kernel<<<256, 256>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
                                                       detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                       detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                       detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
@@ -1031,7 +1031,7 @@ __global__ void pipelined_bicgstab_coo_vec_mul_kernel(const unsigned int * coord
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
   shared_array_r0Ap[threadIdx.x] = inner_prod_r0Ap;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1129,7 +1129,7 @@ __global__ void pipelined_bicgstab_ell_vec_mul_kernel(const unsigned int * coord
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
   shared_array_r0Ap[threadIdx.x] = inner_prod_r0Ap;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1162,7 +1162,7 @@ void pipelined_bicgstab_prod(ell_matrix<NumericT> const & A,
   unsigned int chunk_size   = static_cast<unsigned int>(buffer_chunk_size);
   unsigned int chunk_offset = static_cast<unsigned int>(buffer_chunk_offset);
 
-  pipelined_bicgstab_ell_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
+  pipelined_bicgstab_ell_vec_mul_kernel<<<256, 256>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                       detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
                                                       static_cast<unsigned int>(A.internal_size1()),
                                                       static_cast<unsigned int>(A.maxnnz()),
@@ -1231,7 +1231,7 @@ __global__ void pipelined_bicgstab_sliced_ell_vec_mul_kernel(const unsigned int
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
   shared_array_r0Ap[threadIdx.x] = inner_prod_r0Ap;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1263,7 +1263,7 @@ void pipelined_bicgstab_prod(sliced_ell_matrix<NumericT> const & A,
   unsigned int chunk_size   = static_cast<unsigned int>(buffer_chunk_size);
   unsigned int chunk_offset = static_cast<unsigned int>(buffer_chunk_offset);
 
-  pipelined_bicgstab_sliced_ell_vec_mul_kernel<<<128, A.rows_per_block()>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
+  pipelined_bicgstab_sliced_ell_vec_mul_kernel<<<256, A.rows_per_block()>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
                                                                             detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                                             detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                                             detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
@@ -1338,7 +1338,7 @@ __global__ void pipelined_bicgstab_hyb_vec_mul_kernel(const unsigned int * ell_c
   shared_array_ApAp[threadIdx.x] = inner_prod_ApAp;
   shared_array_pAp[threadIdx.x]  = inner_prod_pAp;
   shared_array_r0Ap[threadIdx.x] = inner_prod_r0Ap;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1372,7 +1372,7 @@ void pipelined_bicgstab_prod(hyb_matrix<NumericT> const & A,
   unsigned int chunk_size   = static_cast<unsigned int>(buffer_chunk_size);
   unsigned int chunk_offset = static_cast<unsigned int>(buffer_chunk_offset);
 
-  pipelined_bicgstab_hyb_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
+  pipelined_bicgstab_hyb_vec_mul_kernel<<<256, 256>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                       detail::cuda_arg<NumericT>(A.handle().cuda_handle()),
                                                       detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                       detail::cuda_arg<unsigned int>(A.handle4().cuda_handle()),
@@ -1408,7 +1408,7 @@ __global__ void pipelined_gmres_normalize_vk_kernel(T * vk,
 
   // parallel reduction in work group to compute <vk, vk>
   shared_array[threadIdx.x] = inner_prod_buffer[threadIdx.x + chunk_size];
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1431,7 +1431,7 @@ __global__ void pipelined_gmres_normalize_vk_kernel(T * vk,
 
   // parallel reduction in work group
   shared_array[threadIdx.x] = inner_prod_contrib;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1493,35 +1493,30 @@ __global__ void pipelined_gmres_gram_schmidt_stage1_kernel(T const * krylov_basi
                                                            unsigned int chunk_size)
 {
   __shared__ T shared_array[7*128];
-  T vi_in_vk[7];
   T value_vk = 0;
 
   unsigned int k_base = 0;
   while (k_base < k)
   {
     unsigned int vecs_in_iteration = (k - k_base > 7) ? 7 : (k - k_base);
-    vi_in_vk[0] = 0;
-    vi_in_vk[1] = 0;
-    vi_in_vk[2] = 0;
-    vi_in_vk[3] = 0;
-    vi_in_vk[4] = 0;
-    vi_in_vk[5] = 0;
-    vi_in_vk[6] = 0;
-    for (unsigned int i = blockDim.x * blockIdx.x + threadIdx.x; i < size; i += gridDim.x * blockDim.x) {
+
+    for (unsigned int j=0; j<vecs_in_iteration; ++j)
+      shared_array[threadIdx.x + j*chunk_size] = 0;
+
+    for (unsigned int i = blockDim.x * blockIdx.x + threadIdx.x; i < size; i += gridDim.x * blockDim.x)
+    {
       value_vk = krylov_basis[i + k * internal_size];
 
       for (unsigned int j=0; j<vecs_in_iteration; ++j)
-        vi_in_vk[j] += value_vk * krylov_basis[i + (k_base + j) * internal_size];
+        shared_array[threadIdx.x + j*chunk_size] += value_vk * krylov_basis[i + (k_base + j) * internal_size];
     }
 
     // parallel reduction in work group
-    for (uint j=0; j<vecs_in_iteration; ++j)
-      shared_array[threadIdx.x + j*chunk_size] = vi_in_vk[j];
-    for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+    for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
     {
       __syncthreads();
       if (threadIdx.x < stride) {
-        for (uint j=0; j<vecs_in_iteration; ++j)
+        for (unsigned int j=0; j<vecs_in_iteration; ++j)
           shared_array[threadIdx.x + j*chunk_size] += shared_array[threadIdx.x + j*chunk_size + stride];
       }
     }
@@ -1582,13 +1577,13 @@ __global__ void pipelined_gmres_gram_schmidt_stage2_kernel(T * krylov_basis,
     unsigned int vecs_in_iteration = (k - k_base > 7) ? 7 : (k - k_base);
 
     // parallel reduction in work group for <v_i, v_k>
-    for (uint j=0; j<vecs_in_iteration; ++j)
+    for (unsigned int j=0; j<vecs_in_iteration; ++j)
       shared_array[threadIdx.x + j*chunk_size] = vi_in_vk_buffer[threadIdx.x + (k_base + j) * chunk_size];
-    for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+    for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
     {
       __syncthreads();
       if (threadIdx.x < stride) {
-        for (uint j=0; j<vecs_in_iteration; ++j)
+        for (unsigned int j=0; j<vecs_in_iteration; ++j)
           shared_array[threadIdx.x + j*chunk_size] += shared_array[threadIdx.x + j*chunk_size + stride];
       }
     }
@@ -1616,7 +1611,7 @@ __global__ void pipelined_gmres_gram_schmidt_stage2_kernel(T * krylov_basis,
 
   // parallel reduction in work group for <v_k, v_k>
   shared_array[threadIdx.x] = vk_dot_vk;
-  for (uint stride=blockDim.x/2; stride > 0; stride /= 2)
+  for (unsigned int stride=blockDim.x/2; stride > 0; stride /= 2)
   {
     __syncthreads();
     if (threadIdx.x < stride)
@@ -1714,7 +1709,7 @@ void pipelined_gmres_prod(compressed_matrix<T> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_csr_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
+  pipelined_cg_csr_vec_mul_kernel<<<128, 256>>>(detail::cuda_arg<unsigned int>(A.handle1().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                 detail::cuda_arg<T>(A.handle().cuda_handle()),
@@ -1758,7 +1753,7 @@ void pipelined_gmres_prod(ell_matrix<T> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_ell_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
+  pipelined_cg_ell_vec_mul_kernel<<<128, 256>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                 detail::cuda_arg<T>(A.handle().cuda_handle()),
                                                 static_cast<unsigned int>(A.internal_size1()),
                                                 static_cast<unsigned int>(A.maxnnz()),
@@ -1801,7 +1796,7 @@ void pipelined_gmres_prod(hyb_matrix<T> const & A,
   unsigned int size = p.size();
   unsigned int buffer_size_per_vector = static_cast<unsigned int>(inner_prod_buffer.size()) / static_cast<unsigned int>(3);
 
-  pipelined_cg_hyb_vec_mul_kernel<<<128, 128>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
+  pipelined_cg_hyb_vec_mul_kernel<<<128, 256>>>(detail::cuda_arg<unsigned int>(A.handle2().cuda_handle()),
                                                 detail::cuda_arg<T>(A.handle().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle3().cuda_handle()),
                                                 detail::cuda_arg<unsigned int>(A.handle4().cuda_handle()),
