@@ -39,7 +39,7 @@
   #include "viennacl/linalg/cuda/direct_solve.hpp"
 #endif
 
-#define VIENNACL_DIRECT_SOLVE_BLOCKSIZE 64
+#define VIENNACL_DIRECT_SOLVE_BLOCKSIZE 128
 
 namespace viennacl
 {
@@ -66,16 +66,16 @@ namespace detail
     switch (viennacl::traits::handle(A).get_active_handle_id())
     {
       case viennacl::MAIN_MEMORY:
-        viennacl::linalg::host_based::inplace_solve(A, false, const_cast<matrix_base<NumericT> &>(B), false, SolverTagT());
+        viennacl::linalg::host_based::inplace_solve(A, const_cast<matrix_base<NumericT> &>(B), SolverTagT());
         break;
   #ifdef VIENNACL_WITH_OPENCL
       case viennacl::OPENCL_MEMORY:
-        viennacl::linalg::opencl::inplace_solve(A, false, const_cast<matrix_base<NumericT> &>(B), false, SolverTagT());
+        viennacl::linalg::opencl::inplace_solve(A, const_cast<matrix_base<NumericT> &>(B), SolverTagT());
         break;
   #endif
   #ifdef VIENNACL_WITH_CUDA
       case viennacl::CUDA_MEMORY:
-        viennacl::linalg::cuda::inplace_solve(A, false, const_cast<matrix_base<NumericT> &>(B), false, SolverTagT());
+        viennacl::linalg::cuda::inplace_solve(A, const_cast<matrix_base<NumericT> &>(B), SolverTagT());
         break;
   #endif
       case viennacl::MEMORY_NOT_INITIALIZED:
@@ -85,115 +85,6 @@ namespace detail
     }
   }
 
-  /** @brief Direct inplace solver for dense triangular systems with transposed right hand side using a single kernel launch.
-  *
-  * @param A       The system matrix
-  * @param proxy_B The transposed matrix of row vectors, where the solution is directly written to
-  */
-  template<typename NumericT, typename SolverTagT>
-  void inplace_solve_kernel(matrix_base<NumericT> const & A,
-                            matrix_expression<const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans>  & proxy_B,
-                            SolverTagT)
-  {
-    assert( (viennacl::traits::size1(A) == viennacl::traits::size2(A))       && bool("Size check failed in inplace_solve(): size1(A) != size2(A)"));
-    assert( (viennacl::traits::size1(A) == viennacl::traits::size1(proxy_B)) && bool("Size check failed in inplace_solve(): size1(A) != size1(B^T)"));
-
-    switch (viennacl::traits::handle(A).get_active_handle_id())
-    {
-      case viennacl::MAIN_MEMORY:
-        viennacl::linalg::host_based::inplace_solve(A, false, const_cast<matrix_base<NumericT> &>(proxy_B.lhs()), true, SolverTagT());
-        break;
-  #ifdef VIENNACL_WITH_OPENCL
-      case viennacl::OPENCL_MEMORY:
-        viennacl::linalg::opencl::inplace_solve(A, false, const_cast<matrix_base<NumericT> &>(proxy_B.lhs()), true, SolverTagT());
-        break;
-  #endif
-  #ifdef VIENNACL_WITH_CUDA
-      case viennacl::CUDA_MEMORY:
-        viennacl::linalg::cuda::inplace_solve(A, false, const_cast<matrix_base<NumericT> &>(proxy_B.lhs()), true, SolverTagT());
-        break;
-  #endif
-      case viennacl::MEMORY_NOT_INITIALIZED:
-        throw memory_exception("not initialised!");
-      default:
-        throw memory_exception("not implemented");
-    }
-  }
-
-  //upper triangular solver for transposed lower triangular matrices
-  /** @brief Direct inplace solver for dense triangular systems that stem from transposed triangular systems. Uses a single kernel launch.
-  *
-  * @param proxy_A  The system matrix proxy
-  * @param B        The matrix holding the load vectors, where the solution is directly written to
-  */
-  template<typename NumericT, typename SolverTagT>
-  void inplace_solve_kernel(matrix_expression<const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans> const & proxy_A,
-                            matrix_base<NumericT> & B,
-                            SolverTagT)
-  {
-    assert( (viennacl::traits::size1(proxy_A) == viennacl::traits::size2(proxy_A)) && bool("Size check failed in inplace_solve(): size1(A) != size2(A)"));
-    assert( (viennacl::traits::size1(proxy_A) == viennacl::traits::size1(B))       && bool("Size check failed in inplace_solve(): size1(A^T) != size1(B)"));
-
-    switch (viennacl::traits::handle(proxy_A.lhs()).get_active_handle_id())
-    {
-      case viennacl::MAIN_MEMORY:
-        viennacl::linalg::host_based::inplace_solve(const_cast<matrix_base<NumericT> &>(proxy_A.lhs()), true, B, false, SolverTagT());
-        break;
-  #ifdef VIENNACL_WITH_OPENCL
-      case viennacl::OPENCL_MEMORY:
-        viennacl::linalg::opencl::inplace_solve(const_cast<matrix_base<NumericT> &>(proxy_A.lhs()), true, B, false, SolverTagT());
-        break;
-  #endif
-  #ifdef VIENNACL_WITH_CUDA
-      case viennacl::CUDA_MEMORY:
-        viennacl::linalg::cuda::inplace_solve(const_cast<matrix_base<NumericT> &>(proxy_A.lhs()), true, B, false, SolverTagT());
-        break;
-  #endif
-      case viennacl::MEMORY_NOT_INITIALIZED:
-        throw memory_exception("not initialised!");
-      default:
-        throw memory_exception("not implemented");
-    }
-  }
-
-  /** @brief Direct inplace solver for dense transposed triangular systems with transposed right hand side using a single kernel launch. Matlab notation: A' \ B'
-  *
-  * @param proxy_A  The system matrix proxy
-  * @param proxy_B  The matrix holding the load vectors, where the solution is directly written to
-  */
-  template<typename NumericT, typename SolverTagT>
-  void inplace_solve_kernel(matrix_expression< const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans> const & proxy_A,
-                            matrix_expression< const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans>       & proxy_B,
-                            SolverTagT)
-  {
-    assert( (viennacl::traits::size1(proxy_A) == viennacl::traits::size2(proxy_A)) && bool("Size check failed in inplace_solve(): size1(A) != size2(A)"));
-    assert( (viennacl::traits::size1(proxy_A) == viennacl::traits::size1(proxy_B)) && bool("Size check failed in inplace_solve(): size1(A^T) != size1(B^T)"));
-
-    switch (viennacl::traits::handle(proxy_A.lhs()).get_active_handle_id())
-    {
-      case viennacl::MAIN_MEMORY:
-        viennacl::linalg::host_based::inplace_solve(const_cast<matrix_base<NumericT> &>(proxy_A.lhs()), true,
-                                                    const_cast<matrix_base<NumericT> &>(proxy_B.lhs()), true, SolverTagT());
-
-        break;
-  #ifdef VIENNACL_WITH_OPENCL
-      case viennacl::OPENCL_MEMORY:
-        viennacl::linalg::opencl::inplace_solve(const_cast<matrix_base<NumericT> &>(proxy_A.lhs()), true,
-                                                const_cast<matrix_base<NumericT> &>(proxy_B.lhs()), true, SolverTagT());
-        break;
-  #endif
-  #ifdef VIENNACL_WITH_CUDA
-      case viennacl::CUDA_MEMORY:
-        viennacl::linalg::cuda::inplace_solve(const_cast<matrix_base<NumericT> &>(proxy_A.lhs()), true,
-                                              const_cast<matrix_base<NumericT> &>(proxy_B.lhs()), true, SolverTagT());
-        break;
-  #endif
-      case viennacl::MEMORY_NOT_INITIALIZED:
-        throw memory_exception("not initialised!");
-      default:
-        throw memory_exception("not implemented");
-    }
-  }
 
   //
   // A \ b
@@ -210,51 +101,16 @@ namespace detail
     switch (viennacl::traits::handle(mat).get_active_handle_id())
     {
       case viennacl::MAIN_MEMORY:
-        viennacl::linalg::host_based::inplace_solve(mat, false, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
+        viennacl::linalg::host_based::inplace_solve(mat, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
         break;
   #ifdef VIENNACL_WITH_OPENCL
       case viennacl::OPENCL_MEMORY:
-        viennacl::linalg::opencl::inplace_solve(mat, false, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
+        viennacl::linalg::opencl::inplace_solve(mat, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
         break;
   #endif
   #ifdef VIENNACL_WITH_CUDA
       case viennacl::CUDA_MEMORY:
-        viennacl::linalg::cuda::inplace_solve(mat, false, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
-        break;
-  #endif
-      case viennacl::MEMORY_NOT_INITIALIZED:
-        throw memory_exception("not initialised!");
-      default:
-        throw memory_exception("not implemented");
-    }
-  }
-
-  /** @brief Direct inplace solver for dense upper triangular systems that stem from transposed lower triangular systems. Uses a single kernel launch.
-  *
-  * @param proxy    The system matrix proxy
-  * @param vec    The load vector, where the solution is directly written to
-  */
-  template<typename NumericT, typename SolverTagT>
-  void inplace_solve_vec_kernel(matrix_expression<const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans> const & proxy,
-                                const vector_base<NumericT> & vec,
-                                SolverTagT)
-  {
-    assert( (proxy.lhs().size1() == vec.size()) && bool("Size check failed in inplace_solve(): size1(A) != size(b)"));
-    assert( (proxy.lhs().size2() == vec.size()) && bool("Size check failed in inplace_solve(): size2(A) != size(b)"));
-
-    switch (viennacl::traits::handle(proxy.lhs()).get_active_handle_id())
-    {
-      case viennacl::MAIN_MEMORY:
-        viennacl::linalg::host_based::inplace_solve(proxy.lhs(), true, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
-        break;
-  #ifdef VIENNACL_WITH_OPENCL
-      case viennacl::OPENCL_MEMORY:
-        viennacl::linalg::opencl::inplace_solve(proxy.lhs(), true, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
-        break;
-  #endif
-  #ifdef VIENNACL_WITH_CUDA
-      case viennacl::CUDA_MEMORY:
-        viennacl::linalg::cuda::inplace_solve(proxy.lhs(), true, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
+        viennacl::linalg::cuda::inplace_solve(mat, const_cast<vector_base<NumericT> &>(vec), SolverTagT());
         break;
   #endif
       case viennacl::MEMORY_NOT_INITIALIZED:
@@ -268,6 +124,8 @@ namespace detail
   template<typename MatrixT1, typename MatrixT2, typename SolverTagT>
   void inplace_solve_lower_impl(MatrixT1 const & A, MatrixT2 & B, SolverTagT)
   {
+    typedef typename viennacl::result_of::cpu_value_type<MatrixT1>::type  NumericType;
+
     vcl_size_t blockSize = VIENNACL_DIRECT_SOLVE_BLOCKSIZE;
     if (A.size1() <= blockSize)
       inplace_solve_kernel(A, B, SolverTagT());
@@ -276,23 +134,18 @@ namespace detail
       for (vcl_size_t i = 0; i < A.size1(); i = i + blockSize)
       {
         vcl_size_t Apos1 = i;
-        vcl_size_t Apos2 = i + blockSize;
+        vcl_size_t Apos2 = std::min<vcl_size_t>(A.size1(), i + blockSize);
         vcl_size_t Bpos = B.size2();
-        if (Apos2 > A.size1())
-        {
-          inplace_solve_kernel(viennacl::project(A, viennacl::range(Apos1, A.size1()), viennacl::range(Apos1, A.size2())),
-                               viennacl::project(B, viennacl::range(Apos1, A.size1()), viennacl::range(0, Bpos)),
-                               SolverTagT());
-          break;
-        }
         inplace_solve_kernel(viennacl::project(A, viennacl::range(Apos1, Apos2), viennacl::range(Apos1, Apos2)),
-                             viennacl::project(B, viennacl::range(Apos1, Apos2), viennacl::range(0, Bpos)),
+                             viennacl::project(B, viennacl::range(Apos1, Apos2), viennacl::range(0,     Bpos)),
                              SolverTagT());
         if (Apos2 < A.size1())
         {
-          viennacl::project(B, viennacl::range(Apos2, B.size1()), viennacl::range(0, Bpos)) -=
-                            viennacl::linalg::prod(viennacl::project(const_cast<MatrixT1 &>(A), viennacl::range(Apos2, A.size1()), viennacl::range(Apos1, Apos2)),
-                                                   viennacl::project(B, viennacl::range(Apos1, Apos2), viennacl::range(0, Bpos)));
+          viennacl::matrix_range<MatrixT2> B_lower(B, viennacl::range(Apos2, B.size1()), viennacl::range(0, Bpos));
+          viennacl::linalg::prod_impl(viennacl::project(A, viennacl::range(Apos2, A.size1()), viennacl::range(Apos1, Apos2)),
+                                      viennacl::project(B, viennacl::range(Apos1, Apos2),     viennacl::range(0,     Bpos)),
+                                      B_lower,
+                                      NumericType(-1.0), NumericType(1.0));
         }
       }
     }
@@ -313,6 +166,8 @@ namespace detail
   template<typename MatrixT1, typename MatrixT2, typename SolverTagT>
   void inplace_solve_upper_impl(MatrixT1 const & A, MatrixT2 & B, SolverTagT)
   {
+    typedef typename viennacl::result_of::cpu_value_type<MatrixT1>::type  NumericType;
+
     int blockSize = VIENNACL_DIRECT_SOLVE_BLOCKSIZE;
     if (static_cast<int>(A.size1()) <= blockSize)
       inplace_solve_kernel(A, B, SolverTagT());
@@ -320,24 +175,20 @@ namespace detail
     {
       for (int i = static_cast<int>(A.size1()); i > 0; i = i - blockSize)
       {
-        int Apos1 = i - blockSize;
+        vcl_size_t Apos1 = vcl_size_t(std::max<int>(0, i - blockSize));
         vcl_size_t Apos2 = vcl_size_t(i);
         vcl_size_t Bpos = B.size2();
-        if (Apos1 < 0)
-        {
-          inplace_solve_kernel(viennacl::project(A, viennacl::range(0, Apos2), viennacl::range(0, Apos2)),
-                               viennacl::project(B, viennacl::range(0, Apos2), viennacl::range(0, Bpos)),
-                               SolverTagT());
-          break;
-        }
-        inplace_solve_kernel(viennacl::project(A, viennacl::range(vcl_size_t(Apos1), Apos2), viennacl::range(vcl_size_t(Apos1), Apos2)),
-                             viennacl::project(B, viennacl::range(vcl_size_t(Apos1), Apos2), viennacl::range(0, Bpos)),
+        inplace_solve_kernel(viennacl::project(A, viennacl::range(Apos1, Apos2), viennacl::range(Apos1, Apos2)),
+                             viennacl::project(B, viennacl::range(Apos1, Apos2), viennacl::range(0, Bpos)),
                              SolverTagT());
         if (Apos1 > 0)
         {
-          viennacl::project(B, viennacl::range(0, vcl_size_t(Apos1)), viennacl::range(0, Bpos)) -=
-                            viennacl::linalg::prod(viennacl::project(const_cast<MatrixT1 &>(A), viennacl::range(0, vcl_size_t(Apos1)), viennacl::range(vcl_size_t(Apos1), Apos2)),
-                                                   viennacl::project(B, viennacl::range(vcl_size_t(Apos1), Apos2), viennacl::range(0, Bpos)));
+          viennacl::matrix_range<MatrixT2> B_upper(B, viennacl::range(0, Apos1), viennacl::range(0, Bpos));
+
+          viennacl::linalg::prod_impl(viennacl::project(A, viennacl::range(0,     Apos1), viennacl::range(Apos1, Apos2)),
+                                      viennacl::project(B, viennacl::range(Apos1, Apos2), viennacl::range(0,     Bpos)),
+                                      B_upper,
+                                      NumericType(-1.0), NumericType(1.0));
         }
       }
     }
@@ -380,10 +231,14 @@ void inplace_solve(const matrix_base<NumericT> & A,
                    matrix_expression<const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans> proxy_B,
                    SolverTagT)
 {
-  matrix_base<NumericT> B(proxy_B);
+  typedef typename matrix_base<NumericT>::handle_type    handle_type;
+
+  matrix_base<NumericT> B(const_cast<handle_type &>(proxy_B.lhs().handle()),
+                          proxy_B.lhs().size2(), proxy_B.lhs().start2(), proxy_B.lhs().stride2(), proxy_B.lhs().internal_size2(),
+                          proxy_B.lhs().size1(), proxy_B.lhs().start1(), proxy_B.lhs().stride1(), proxy_B.lhs().internal_size1(),
+                          !proxy_B.lhs().row_major());
+
   detail::inplace_solve_impl(A,B,SolverTagT());
-  B=trans(B);
-  const_cast<matrix_base<NumericT> &>(proxy_B.lhs()) = B;
 }
 
 //upper triangular solver for transposed lower triangular matrices
@@ -397,7 +252,13 @@ void inplace_solve(const matrix_expression< const matrix_base<NumericT>, const m
                    matrix_base<NumericT> & B,
                    SolverTagT)
 {
-  matrix_base<NumericT> A(proxy_A);
+  typedef typename matrix_base<NumericT>::handle_type    handle_type;
+
+  matrix_base<NumericT> A(const_cast<handle_type &>(proxy_A.lhs().handle()),
+                          proxy_A.lhs().size2(), proxy_A.lhs().start2(), proxy_A.lhs().stride2(), proxy_A.lhs().internal_size2(),
+                          proxy_A.lhs().size1(), proxy_A.lhs().start1(), proxy_A.lhs().stride1(), proxy_A.lhs().internal_size1(),
+                          !proxy_A.lhs().row_major());
+
   detail::inplace_solve_impl(A,B,SolverTagT());
 }
 
@@ -411,11 +272,19 @@ void inplace_solve(matrix_expression< const matrix_base<NumericT>, const matrix_
                    matrix_expression< const matrix_base<NumericT>, const matrix_base<NumericT>, op_trans>         proxy_B,
                    SolverTagT)
 {
-  matrix_base<NumericT> A(proxy_A);
-  matrix_base<NumericT> B(proxy_B);
+  typedef typename matrix_base<NumericT>::handle_type    handle_type;
+
+  matrix_base<NumericT> A(const_cast<handle_type &>(proxy_A.lhs().handle()),
+                          proxy_A.lhs().size2(), proxy_A.lhs().start2(), proxy_A.lhs().stride2(), proxy_A.lhs().internal_size2(),
+                          proxy_A.lhs().size1(), proxy_A.lhs().start1(), proxy_A.lhs().stride1(), proxy_A.lhs().internal_size1(),
+                          !proxy_A.lhs().row_major());
+
+  matrix_base<NumericT> B(const_cast<handle_type &>(proxy_B.lhs().handle()),
+                          proxy_B.lhs().size2(), proxy_B.lhs().start2(), proxy_B.lhs().stride2(), proxy_B.lhs().internal_size2(),
+                          proxy_B.lhs().size1(), proxy_B.lhs().start1(), proxy_B.lhs().stride1(), proxy_B.lhs().internal_size1(),
+                          !proxy_B.lhs().row_major());
+
   detail::inplace_solve_impl(A,B,SolverTagT());
-  B=trans(B);
-  const_cast<matrix_base<NumericT> &>(proxy_B.lhs()) = B;
 }
 
 
@@ -497,32 +366,26 @@ matrix_base<NumericT> solve(const matrix_expression< const matrix_base<NumericT>
 namespace detail
 {
   template<typename MatrixT1, typename VectorT, typename SolverTagT>
-  void inplace_solve_lower_vec_impl(MatrixT1 const & A, VectorT & B, SolverTagT)
+  void inplace_solve_lower_vec_impl(MatrixT1 const & A, VectorT & b, SolverTagT)
   {
     vcl_size_t blockSize = VIENNACL_DIRECT_SOLVE_BLOCKSIZE;
-    if (A.size1() < blockSize)
-      inplace_solve_vec_kernel(A, B, SolverTagT());
+    if (A.size1() <= blockSize)
+      inplace_solve_vec_kernel(A, b, SolverTagT());
     else
     {
+      VectorT temp(b);
       for (vcl_size_t i = 0; i < A.size1(); i = i + blockSize)
       {
         vcl_size_t Apos1 = i;
-        vcl_size_t Apos2 = i + blockSize;
-        if (i > A.size2())
-        {
-          inplace_solve_vec_kernel(viennacl::project(A, viennacl::range(Apos1, A.size1()), viennacl::range(Apos1, A.size2())),
-                                   viennacl::project(B, viennacl::range(Apos1, A.size1())),
-                                   SolverTagT());
-          break;
-        }
+        vcl_size_t Apos2 = std::min<vcl_size_t>(A.size1(), i + blockSize);
         inplace_solve_vec_kernel(viennacl::project(A, viennacl::range(Apos1, Apos2), viennacl::range(Apos1, Apos2)),
-                                 viennacl::project(B, viennacl::range(Apos1, Apos2)),
+                                 viennacl::project(b, viennacl::range(Apos1, Apos2)),
                                  SolverTagT());
         if (Apos2 < A.size1())
         {
-          VectorT temp(viennacl::linalg::prod(viennacl::project(A, viennacl::range(Apos2, A.size1()), viennacl::range(Apos1, Apos2)),
-                       viennacl::project(B, viennacl::range(Apos1, Apos2))));
-          viennacl::project(B, viennacl::range(Apos2, A.size1())) -= temp;
+          viennacl::project(temp, viennacl::range(Apos2, A.size1())) = viennacl::linalg::prod(viennacl::project(A, viennacl::range(Apos2, A.size1()), viennacl::range(Apos1, Apos2)),
+                                                                                              viennacl::project(b, viennacl::range(Apos1, Apos2)));
+          viennacl::project(b, viennacl::range(Apos2, A.size1())) -= viennacl::project(temp, viennacl::range(Apos2, A.size1()));
         }
       }
     }
@@ -541,47 +404,41 @@ namespace detail
   }
 
   template<typename MatrixT1, typename VectorT, typename SolverTagT>
-  void inplace_solve_upper_vec_impl(MatrixT1 const & A, VectorT & B, SolverTagT)
+  void inplace_solve_upper_vec_impl(MatrixT1 const & A, VectorT & b, SolverTagT)
   {
     int blockSize = VIENNACL_DIRECT_SOLVE_BLOCKSIZE;
-    if (static_cast<int>(A.size1()) < blockSize)
-      inplace_solve_vec_kernel(A, B, SolverTagT());
+    if (static_cast<int>(A.size1()) <= blockSize)
+      inplace_solve_vec_kernel(A, b, SolverTagT());
     else
     {
+      VectorT temp(b);
       for (int i = static_cast<int>(A.size1()); i > 0; i = i - blockSize)
       {
-        int Apos1 = i - blockSize;
+        vcl_size_t Apos1 = vcl_size_t(std::max<int>(0, i - blockSize));
         vcl_size_t Apos2 = vcl_size_t(i);
-        if (Apos1 < 0)
-        {
-          inplace_solve_vec_kernel(viennacl::project(A, viennacl::range(0, Apos2), viennacl::range(0, Apos2)),
-                                   viennacl::project(B, viennacl::range(0, Apos2)),
-                                   SolverTagT());
-          break;
-        }
-        inplace_solve_vec_kernel(viennacl::project(A, viennacl::range(vcl_size_t(Apos1), Apos2), viennacl::range(vcl_size_t(Apos1), Apos2)),
-                                 viennacl::project(B, viennacl::range(vcl_size_t(Apos1), Apos2)),
+        inplace_solve_vec_kernel(viennacl::project(A, viennacl::range(Apos1, Apos2), viennacl::range(Apos1, Apos2)),
+                                 viennacl::project(b, viennacl::range(Apos1, Apos2)),
                                  SolverTagT());
         if (Apos1 > 0)
         {
-          VectorT temp(viennacl::linalg::prod(viennacl::project(A, viennacl::range(0, vcl_size_t(Apos1)), viennacl::range(vcl_size_t(Apos1), Apos2)),
-                       viennacl::project(B, viennacl::range(vcl_size_t(Apos1), Apos2))));
-          viennacl::project(B, viennacl::range(0, vcl_size_t(Apos1))) -= temp;
+          viennacl::project(temp, viennacl::range(0, Apos1)) = viennacl::linalg::prod(viennacl::project(A, viennacl::range(0,     Apos1), viennacl::range(Apos1, Apos2)),
+                                                                                      viennacl::project(b, viennacl::range(Apos1, Apos2)));
+          viennacl::project(b, viennacl::range(0, Apos1)) -= viennacl::project(temp, viennacl::range(0, Apos1));
         }
       }
     }
   }
 
   template<typename MatrixT1, typename VectorT>
-  void inplace_solve_vec_impl(MatrixT1 const & A, VectorT & B, viennacl::linalg::upper_tag)
+  void inplace_solve_vec_impl(MatrixT1 const & A, VectorT & b, viennacl::linalg::upper_tag)
   {
-    inplace_solve_upper_vec_impl(A, B, viennacl::linalg::upper_tag());
+    inplace_solve_upper_vec_impl(A, b, viennacl::linalg::upper_tag());
   }
 
   template<typename MatrixT1, typename VectorT>
-  void inplace_solve_vec_impl(MatrixT1 const & A, VectorT & B, viennacl::linalg::unit_upper_tag)
+  void inplace_solve_vec_impl(MatrixT1 const & A, VectorT & b, viennacl::linalg::unit_upper_tag)
   {
-    inplace_solve_upper_vec_impl(A, B, viennacl::linalg::unit_upper_tag());
+    inplace_solve_upper_vec_impl(A, b, viennacl::linalg::unit_upper_tag());
   }
 
 } // namespace detail
@@ -612,7 +469,13 @@ void inplace_solve(matrix_expression<const matrix_base<NumericT>, const matrix_b
                    vector_base<NumericT> & vec,
                    SolverTagT const & tag)
 {
-  matrix_base<NumericT> mat(proxy);
+  typedef typename matrix_base<NumericT>::handle_type    handle_type;
+
+  // wrap existing matrix in a new matrix_base object (no data copy)
+  matrix_base<NumericT> mat(const_cast<handle_type &>(proxy.lhs().handle()),
+                            proxy.lhs().size2(), proxy.lhs().start2(), proxy.lhs().stride2(), proxy.lhs().internal_size2(),
+                            proxy.lhs().size1(), proxy.lhs().start1(), proxy.lhs().stride1(), proxy.lhs().internal_size1(),
+                            !proxy.lhs().row_major());
   detail::inplace_solve_vec_impl(mat, vec, tag);
 }
 
