@@ -1340,7 +1340,7 @@ void prod_impl(const viennacl::ell_matrix<NumericT, AlignmentV> & sp_mat,
         NumericT sp_mat_val = static_cast<NumericT>(sp_mat_elements[offset]);
         vcl_size_t sp_mat_col = static_cast<vcl_size_t>(sp_mat_coords[offset]);
 
-        if (bool(sp_mat_val))
+        if (sp_mat_val < 0 || sp_mat_val > 0) // sp_mat_val != 0 without compiler warnings
         {
           if (result.row_major())
             for (vcl_size_t col = 0; col < d_mat.size2(); ++col)
@@ -1379,7 +1379,8 @@ void prod_impl(const viennacl::ell_matrix<NumericT, AlignmentV> & sp_mat,
           NumericT sp_mat_val = static_cast<NumericT>(sp_mat_elements[offset]);
           vcl_size_t sp_mat_col = static_cast<vcl_size_t>(sp_mat_coords[offset]);
 
-          if (bool(sp_mat_val)) {
+          if (sp_mat_val < 0 || sp_mat_val > 0)  // sp_mat_val != 0 without compiler warnings
+          {
             if (result.row_major())
               result_wrapper_row( row, col) += sp_mat_val * d_mat_wrapper_col( sp_mat_col, col);
             else
@@ -1463,7 +1464,7 @@ void prod_impl(const viennacl::ell_matrix<NumericT, AlignmentV> & sp_mat,
           NumericT sp_mat_val = static_cast<NumericT>(sp_mat_elements[offset]);
           vcl_size_t sp_mat_col = static_cast<vcl_size_t>(sp_mat_coords[offset]);
 
-          if (bool(sp_mat_val))
+          if (sp_mat_val < 0 || sp_mat_val > 0) // sp_mat_val != 0 without compiler warnings
           {
             if (result.row_major())
               result_wrapper_row( row, col) += sp_mat_val * d_mat_wrapper_row( col, sp_mat_col);
@@ -1500,7 +1501,7 @@ void prod_impl(const viennacl::ell_matrix<NumericT, AlignmentV> & sp_mat,
         NumericT sp_mat_val = static_cast<NumericT>(sp_mat_elements[offset]);
         vcl_size_t sp_mat_col = static_cast<vcl_size_t>(sp_mat_coords[offset]);
 
-        if (bool(sp_mat_val))
+        if (sp_mat_val < 0 || sp_mat_val > 0)  // sp_mat_val != 0 without compiler warnings
         {
           if (result.row_major())
             for (vcl_size_t col = 0; col < d_mat.size2(); ++col)
@@ -1700,7 +1701,7 @@ void prod_impl(const viennacl::hyb_matrix<NumericT, AlignmentV> & mat,
         vcl_size_t offset = row + item_id * mat.internal_size1();
         NumericT val = elements[offset];
 
-        if (bool(val))
+        if (val < 0 || val > 0)  // val != 0 without compiler warnings
         {
           vcl_size_t col = static_cast<vcl_size_t>(coords[offset]);
           if (d_mat.row_major())
@@ -1795,7 +1796,7 @@ void prod_impl(const viennacl::hyb_matrix<NumericT, AlignmentV> & mat,
         vcl_size_t offset = row + item_id * mat.internal_size1();
         NumericT val = elements[offset];
 
-        if (bool(val))
+        if (val < 0 || val > 0)  // val != 0 without compiler warnings
         {
           vcl_size_t col = static_cast<vcl_size_t>(coords[offset]);
           if (d_mat.lhs().row_major())
