@@ -372,7 +372,99 @@ void element_op(vector_base<NumericT> & vec1,
 
 
 //implementation of inner product:
-//namespace {
+
+namespace detail
+{
+
+// the following circumvents problems when trying to use a variable of template parameter type for a reduction.
+// Such a behavior is not covered by the OpenMP standard, hence we manually apply some preprocessor magic to resolve the problem.
+// See https://github.com/viennacl/viennacl-dev/issues/112 for a detailed explanation and discussion.
+
+#define VIENNACL_INNER_PROD_IMPL_1(RESULTSCALART, TEMPSCALART) \
+  inline RESULTSCALART inner_prod_impl(RESULTSCALART const * data_vec1, vcl_size_t start1, vcl_size_t inc1, vcl_size_t size1, \
+                                       RESULTSCALART const * data_vec2, vcl_size_t start2, vcl_size_t inc2) { \
+    TEMPSCALART temp = 0;
+
+#define VIENNACL_INNER_PROD_IMPL_2(RESULTSCALART) \
+    for (long i = 0; i < static_cast<long>(size1); ++i) \
+      temp += data_vec1[static_cast<vcl_size_t>(i)*inc1+start1] * data_vec2[static_cast<vcl_size_t>(i)*inc2+start2]; \
+    return static_cast<RESULTSCALART>(temp); \
+  }
+
+// char
+VIENNACL_INNER_PROD_IMPL_1(char, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(char)
+
+VIENNACL_INNER_PROD_IMPL_1(unsigned char, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(unsigned char)
+
+
+// short
+VIENNACL_INNER_PROD_IMPL_1(short, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(short)
+
+VIENNACL_INNER_PROD_IMPL_1(unsigned short, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(unsigned short)
+
+
+// int
+VIENNACL_INNER_PROD_IMPL_1(int, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(int)
+
+VIENNACL_INNER_PROD_IMPL_1(unsigned int, unsigned int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(unsigned int)
+
+
+// long
+VIENNACL_INNER_PROD_IMPL_1(long, long)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(long)
+
+VIENNACL_INNER_PROD_IMPL_1(unsigned long, unsigned long)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(unsigned long)
+
+
+// float
+VIENNACL_INNER_PROD_IMPL_1(float, float)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(float)
+
+// double
+VIENNACL_INNER_PROD_IMPL_1(double, double)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_INNER_PROD_IMPL_2(double)
+
+#undef VIENNACL_INNER_PROD_IMPL_1
+#undef VIENNACL_INNER_PROD_IMPL_2
+}
+
 /** @brief Computes the inner product of two vectors - implementation. Library users should call inner_prod(vec1, vec2).
 *
 * @param vec1 The first vector
@@ -396,15 +488,8 @@ void inner_prod_impl(vector_base<NumericT> const & vec1,
   vcl_size_t start2 = viennacl::traits::start(vec2);
   vcl_size_t inc2   = viennacl::traits::stride(vec2);
 
-  value_type temp = 0;
-
-#ifdef VIENNACL_WITH_OPENMP
-  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
-#endif
-  for (long i = 0; i < static_cast<long>(size1); ++i)
-    temp += data_vec1[static_cast<vcl_size_t>(i)*inc1+start1] * data_vec2[static_cast<vcl_size_t>(i)*inc2+start2];
-
-  result = temp;  //Note: Assignment to result might be expensive, thus 'temp' is used for accumulation
+  result = detail::inner_prod_impl(data_vec1, start1, inc1, size1,
+                                   data_vec2, start2, inc2);  //Note: Assignment to result might be expensive, thus a temporary is introduced here
 }
 
 template<typename NumericT>
@@ -445,6 +530,93 @@ void inner_prod_impl(vector_base<NumericT> const & x,
 }
 
 
+namespace detail
+{
+
+#define VIENNACL_NORM_1_IMPL_1(RESULTSCALART, TEMPSCALART) \
+  inline RESULTSCALART norm_1_impl(RESULTSCALART const * data_vec1, vcl_size_t start1, vcl_size_t inc1, vcl_size_t size1) { \
+    TEMPSCALART temp = 0;
+
+#define VIENNACL_NORM_1_IMPL_2(RESULTSCALART, TEMPSCALART) \
+    for (long i = 0; i < static_cast<long>(size1); ++i) \
+      temp += static_cast<TEMPSCALART>(std::fabs(static_cast<double>(data_vec1[static_cast<vcl_size_t>(i)*inc1+start1]))); \
+    return static_cast<RESULTSCALART>(temp); \
+  }
+
+// char
+VIENNACL_NORM_1_IMPL_1(char, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(char, int)
+
+VIENNACL_NORM_1_IMPL_1(unsigned char, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(unsigned char, int)
+
+// short
+VIENNACL_NORM_1_IMPL_1(short, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(short, int)
+
+VIENNACL_NORM_1_IMPL_1(unsigned short, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(unsigned short, int)
+
+
+// int
+VIENNACL_NORM_1_IMPL_1(int, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(int, int)
+
+VIENNACL_NORM_1_IMPL_1(unsigned int, unsigned int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(unsigned int, unsigned int)
+
+
+// long
+VIENNACL_NORM_1_IMPL_1(long, long)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(long, long)
+
+VIENNACL_NORM_1_IMPL_1(unsigned long, unsigned long)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(unsigned long, unsigned long)
+
+
+// float
+VIENNACL_NORM_1_IMPL_1(float, float)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(float, float)
+
+// double
+VIENNACL_NORM_1_IMPL_1(double, double)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_1_IMPL_2(double, double)
+
+#undef VIENNACL_NORM_1_IMPL_1
+#undef VIENNACL_NORM_1_IMPL_2
+
+}
+
 /** @brief Computes the l^1-norm of a vector
 *
 * @param vec1 The vector
@@ -462,17 +634,102 @@ void norm_1_impl(vector_base<NumericT> const & vec1,
   vcl_size_t inc1   = viennacl::traits::stride(vec1);
   vcl_size_t size1  = viennacl::traits::size(vec1);
 
-  value_type temp = 0;
+  result = detail::norm_1_impl(data_vec1, start1, inc1, size1);  //Note: Assignment to result might be expensive, thus using a temporary for accumulation
+}
 
+
+
+namespace detail
+{
+
+#define VIENNACL_NORM_2_IMPL_1(RESULTSCALART, TEMPSCALART) \
+  inline RESULTSCALART norm_2_impl(RESULTSCALART const * data_vec1, vcl_size_t start1, vcl_size_t inc1, vcl_size_t size1) { \
+    TEMPSCALART temp = 0;
+
+#define VIENNACL_NORM_2_IMPL_2(RESULTSCALART, TEMPSCALART) \
+    for (long i = 0; i < static_cast<long>(size1); ++i) { \
+      RESULTSCALART data = data_vec1[static_cast<vcl_size_t>(i)*inc1+start1]; \
+      temp += static_cast<TEMPSCALART>(data * data); \
+    } \
+    return static_cast<RESULTSCALART>(temp); \
+  }
+
+// char
+VIENNACL_NORM_2_IMPL_1(char, int)
 #ifdef VIENNACL_WITH_OPENMP
   #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
 #endif
-  for (long i = 0; i < static_cast<long>(size1); ++i)
-    temp += static_cast<value_type>(std::fabs(static_cast<double>(data_vec1[static_cast<vcl_size_t>(i)*inc1+start1])));  //casting to double in order to avoid problems if T is an integer type
+VIENNACL_NORM_2_IMPL_2(char, int)
+
+VIENNACL_NORM_2_IMPL_1(unsigned char, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(unsigned char, int)
+
+
+// short
+VIENNACL_NORM_2_IMPL_1(short, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(short, int)
+
+VIENNACL_NORM_2_IMPL_1(unsigned short, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(unsigned short, int)
+
+
+// int
+VIENNACL_NORM_2_IMPL_1(int, int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(int, int)
+
+VIENNACL_NORM_2_IMPL_1(unsigned int, unsigned int)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(unsigned int, unsigned int)
+
+
+// long
+VIENNACL_NORM_2_IMPL_1(long, long)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(long, long)
+
+VIENNACL_NORM_2_IMPL_1(unsigned long, unsigned long)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(unsigned long, unsigned long)
+
+
+// float
+VIENNACL_NORM_2_IMPL_1(float, float)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(float, float)
+
+// double
+VIENNACL_NORM_2_IMPL_1(double, double)
+#ifdef VIENNACL_WITH_OPENMP
+  #pragma omp parallel for reduction(+: temp) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+#endif
+VIENNACL_NORM_2_IMPL_2(double, double)
+
+#undef VIENNACL_NORM_2_IMPL_1
+#undef VIENNACL_NORM_2_IMPL_2
 
-  result = temp;  //Note: Assignment to result might be expensive, thus 'temp' is used for accumulation
 }
 
+
 /** @brief Computes the l^2-norm of a vector - implementation
 *
 * @param vec1 The vector
@@ -490,19 +747,7 @@ void norm_2_impl(vector_base<NumericT> const & vec1,
   vcl_size_t inc1   = viennacl::traits::stride(vec1);
   vcl_size_t size1  = viennacl::traits::size(vec1);
 
-  value_type temp = 0;
-  value_type data = 0;
-
-#ifdef VIENNACL_WITH_OPENMP
-  #pragma omp parallel for reduction(+: temp) private(data) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
-#endif
-  for (long i = 0; i < static_cast<long>(size1); ++i)
-  {
-    data = data_vec1[static_cast<vcl_size_t>(i)*inc1+start1];
-    temp += data * data;
-  }
-
-  result = std::sqrt(temp);  //Note: Assignment to result might be expensive, thus 'temp' is used for accumulation
+  result = std::sqrt(detail::norm_2_impl(data_vec1, start1, inc1, size1));  //Note: Assignment to result might be expensive, thus 'temp' is used for accumulation
 }
 
 /** @brief Computes the supremum-norm of a vector
@@ -648,18 +893,16 @@ void plane_rotation(vector_base<NumericT> & vec1,
   vcl_size_t start2 = viennacl::traits::start(vec2);
   vcl_size_t inc2   = viennacl::traits::stride(vec2);
 
-  value_type temp1 = 0;
-  value_type temp2 = 0;
   value_type data_alpha = alpha;
   value_type data_beta  = beta;
 
 #ifdef VIENNACL_WITH_OPENMP
-  #pragma omp parallel for private(temp1, temp2) if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
+  #pragma omp parallel for if (size1 > VIENNACL_OPENMP_VECTOR_MIN_SIZE)
 #endif
   for (long i = 0; i < static_cast<long>(size1); ++i)
   {
-    temp1 = data_vec1[static_cast<vcl_size_t>(i)*inc1+start1];
-    temp2 = data_vec2[static_cast<vcl_size_t>(i)*inc2+start2];
+    value_type temp1 = data_vec1[static_cast<vcl_size_t>(i)*inc1+start1];
+    value_type temp2 = data_vec2[static_cast<vcl_size_t>(i)*inc2+start2];
 
     data_vec1[static_cast<vcl_size_t>(i)*inc1+start1] = data_alpha * temp1 + data_beta * temp2;
     data_vec2[static_cast<vcl_size_t>(i)*inc2+start2] = data_alpha * temp2 - data_beta * temp1;
