@@ -70,13 +70,11 @@ namespace detail
 /** @brief Direct inplace solver for dense triangular systems. Matlab notation: A \ B
 *
 * @param A    The system matrix
-* @param A_trans  Whether A is to be transposed
 * @param B    The matrix of row vectors, where the solution is directly written to
-* @param B_trans  Whether B is to be transposed
 */
 template<typename NumericT, typename SolverTagT>
-void inplace_solve(const matrix_base<NumericT> & A, bool A_trans,
-                   matrix_base<NumericT> & B, bool B_trans,
+void inplace_solve(matrix_base<NumericT> const & A,
+                   matrix_base<NumericT> & B,
                    SolverTagT)
 {
   viennacl::ocl::context & ctx = const_cast<viennacl::ocl::context &>(viennacl::traits::opencl_handle(A).context());
@@ -108,17 +106,13 @@ void inplace_solve(const matrix_base<NumericT> & A, bool A_trans,
   }
 
   std::stringstream ss;
-  if (A_trans) ss << "trans_";
   ss << SolverTagT::name();
-  if (B_trans) ss << "_trans";
   ss << "_solve";
 
   viennacl::ocl::kernel & k = ctx.get_kernel(program_name, ss.str());
 
-  if (B_trans)
-    k.global_work_size(0, B.size1() * k.local_work_size());
-  else
-    k.global_work_size(0, B.size2() * k.local_work_size());
+  k.local_work_size(0, 128);
+  k.global_work_size(0, B.size2() * k.local_work_size());
   detail::inplace_solve_impl(A, B, k);
 }
 
@@ -129,16 +123,15 @@ void inplace_solve(const matrix_base<NumericT> & A, bool A_trans,
 //
 
 template<typename NumericT, typename SOLVERTAG>
-void inplace_solve(matrix_base<NumericT> const & A, bool A_trans,
+void inplace_solve(matrix_base<NumericT> const & A,
                    vector_base<NumericT>       & x,
                    SOLVERTAG)
 {
   cl_uint options = detail::get_option_for_solver_tag(SOLVERTAG());
-  if (A_trans)
-    options |= 0x02;
 
   viennacl::ocl::kernel & k = detail::legacy_kernel_for_matrix(A,  "triangular_substitute_inplace");
 
+  k.local_work_size(0, 128);
   k.global_work_size(0, k.local_work_size());
   viennacl::ocl::enqueue(k(viennacl::traits::opencl_handle(A),
                            cl_uint(viennacl::traits::start1(A)),         cl_uint(viennacl::traits::start2(A)),
