@@ -63,6 +63,15 @@ void pipelined_cg_vector_update(vector_base<NumericT> & result,
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<NumericT>::program_name(), "cg_vector_update");
   cl_uint    vec_size = cl_uint(viennacl::traits::size(result));
 
+  k.local_work_size(0, 128);
+  k.global_work_size(0, 128*128);
+
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(result, alpha, p, r, Ap, beta, inner_prod_buffer, vec_size, viennacl::ocl::local_mem(k.local_work_size() * sizeof(NumericT))));
 }
 
@@ -82,6 +91,13 @@ void pipelined_cg_prod(compressed_matrix<NumericT> const & A,
 
   k.local_work_size(0, 128);
   k.global_work_size(0, 128*128);
+
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(A.handle1().opencl_handle(), A.handle2().opencl_handle(), A.handle3().opencl_handle(), A.handle().opencl_handle(), cl_uint(A.blocks1()),
                            p,
                            Ap,
@@ -89,7 +105,8 @@ void pipelined_cg_prod(compressed_matrix<NumericT> const & A,
                            inner_prod_buffer,
                            buffer_size_per_vector,
                            viennacl::ocl::local_mem(k.local_work_size() * sizeof(NumericT)),
-                           viennacl::ocl::local_mem(k.local_work_size() * sizeof(NumericT))
+                           viennacl::ocl::local_mem(k.local_work_size() * sizeof(NumericT)),
+                           viennacl::ocl::local_mem(1024 * sizeof(NumericT))
                           ));
 
 }
@@ -148,6 +165,12 @@ void pipelined_cg_prod(ell_matrix<NumericT> const & A,
   k.local_work_size(0, thread_num);
   k.global_work_size(0, thread_num * group_num);
 
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(A.handle2().opencl_handle(),
                            A.handle().opencl_handle(),
                            cl_uint(A.internal_size1()),
@@ -178,7 +201,7 @@ void pipelined_cg_prod(sliced_ell_matrix<NumericT> const & A,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<NumericT>::program_name(), "cg_sliced_ell_prod");
 
-  unsigned int thread_num = A.rows_per_block();
+  unsigned int thread_num = static_cast<unsigned int>(A.rows_per_block());
   unsigned int group_num = 256;
 
   k.local_work_size(0, thread_num);
@@ -214,12 +237,18 @@ void pipelined_cg_prod(hyb_matrix<NumericT> const & A,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<NumericT>::program_name(), "cg_hyb_prod");
 
-  unsigned int thread_num = 256;
+  unsigned int thread_num = 128;
   unsigned int group_num = 128;
 
   k.local_work_size(0, thread_num);
   k.global_work_size(0, thread_num * group_num);
 
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(A.handle2().opencl_handle(),
                            A.handle().opencl_handle(),
                            A.handle3().opencl_handle(),
@@ -259,6 +288,12 @@ void pipelined_bicgstab_update_s(vector_base<NumericT> & s,
   k.local_work_size(0, 128);
   k.global_work_size(0, 128*128);
 
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   cl_uint chunk_size   = cl_uint(buffer_chunk_size);
   cl_uint chunk_offset = cl_uint(buffer_chunk_offset);
   viennacl::ocl::enqueue(k(s, r, Ap,
@@ -284,6 +319,13 @@ void pipelined_bicgstab_vector_update(vector_base<NumericT> & result, NumericT a
 
   k.local_work_size(0, 128);
   k.global_work_size(0, 128*128);
+
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(result, alpha, p, omega, s,
                            residual, As,
                            beta, Ap,
@@ -314,6 +356,13 @@ void pipelined_bicgstab_prod(compressed_matrix<NumericT> const & A,
 
   k.local_work_size(0, 128);
   k.global_work_size(0, 128*128);
+
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(A.handle1().opencl_handle(), A.handle2().opencl_handle(), A.handle3().opencl_handle(), A.handle().opencl_handle(), cl_uint(A.blocks1()),
                            p,
                            Ap,
@@ -391,6 +440,12 @@ void pipelined_bicgstab_prod(ell_matrix<NumericT> const & A,
   k.local_work_size(0, thread_num);
   k.global_work_size(0, thread_num * group_num);
 
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(A.handle2().opencl_handle(),
                            A.handle().opencl_handle(),
                            cl_uint(A.internal_size1()),
@@ -426,8 +481,8 @@ void pipelined_bicgstab_prod(sliced_ell_matrix<NumericT> const & A,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<NumericT>::program_name(), "bicgstab_sliced_ell_prod");
 
-  unsigned int thread_num = A.rows_per_block();
-  unsigned int group_num = 128;
+  unsigned int thread_num = static_cast<unsigned int>(A.rows_per_block());
+  unsigned int group_num = (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id) ? 256 : 128;
 
   k.local_work_size(0, thread_num);
   k.global_work_size(0, thread_num * group_num);
@@ -473,6 +528,12 @@ void pipelined_bicgstab_prod(hyb_matrix<NumericT> const & A,
   k.local_work_size(0, thread_num);
   k.global_work_size(0, thread_num * group_num);
 
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*256);
+  }
+
   viennacl::ocl::enqueue(k(A.handle2().opencl_handle(),
                            A.handle().opencl_handle(),
                            A.handle3().opencl_handle(),
@@ -556,8 +617,7 @@ void pipelined_gmres_gram_schmidt_stage1(vector_base<T> const & device_krylov_ba
   cl_uint ocl_k            = cl_uint(param_k);
   cl_uint chunk_size = cl_uint(buffer_chunk_size);
   viennacl::ocl::enqueue(k(device_krylov_basis, size_vk, internal_size_vk, ocl_k,
-                           vi_in_vk_buffer, chunk_size,
-                           viennacl::ocl::local_mem(7 * k.local_work_size() * sizeof(T))
+                           vi_in_vk_buffer, chunk_size
                            ));
 }
 
@@ -577,6 +637,9 @@ void pipelined_gmres_gram_schmidt_stage2(vector_base<T> & device_krylov_basis,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<T>::program_name(), "gmres_gram_schmidt_2");
 
+  k.local_work_size(0, 128);
+  k.global_work_size(0, 128*128);
+
   cl_uint size_vk          = cl_uint(v_k_size);
   cl_uint internal_size_vk = cl_uint(v_k_internal_size);
   cl_uint ocl_k            = cl_uint(param_k);
@@ -604,6 +667,9 @@ void pipelined_gmres_update_result(vector_base<T> & result,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<T>::program_name(), "gmres_update_result");
 
+  k.local_work_size(0, 128);
+  k.global_work_size(0, 128*128);
+
   cl_uint size_vk          = cl_uint(v_k_size);
   cl_uint internal_size_vk = cl_uint(v_k_internal_size);
   cl_uint ocl_k            = cl_uint(param_k);
@@ -633,6 +699,13 @@ void pipelined_gmres_prod(compressed_matrix<T> const & A,
 
   k.local_work_size(0, 128);
   k.global_work_size(0, 128*128);
+
+  if (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id)
+  {
+    k.local_work_size(0, 256);
+    k.global_work_size(0, 256*128);
+  }
+
   viennacl::ocl::enqueue(k(A.handle1().opencl_handle(), A.handle2().opencl_handle(), A.handle3().opencl_handle(), A.handle().opencl_handle(), cl_uint(A.blocks1()),
                            p, start_p,
                            Ap, start_Ap,
@@ -640,7 +713,8 @@ void pipelined_gmres_prod(compressed_matrix<T> const & A,
                            inner_prod_buffer,
                            buffer_size_per_vector,
                            viennacl::ocl::local_mem(k.local_work_size() * sizeof(T)),
-                           viennacl::ocl::local_mem(k.local_work_size() * sizeof(T))
+                           viennacl::ocl::local_mem(k.local_work_size() * sizeof(T)),
+                           viennacl::ocl::local_mem(1024 * sizeof(T))
                           ));
 
 }
@@ -698,7 +772,7 @@ void pipelined_gmres_prod(ell_matrix<T> const & A,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<T>::program_name(), "gmres_ell_prod");
 
-  unsigned int thread_num = 128;
+  unsigned int thread_num = (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id) ? 256 : 128;
   unsigned int group_num = 128;
 
   k.local_work_size(0, thread_num);
@@ -736,7 +810,7 @@ void pipelined_gmres_prod(sliced_ell_matrix<T> const & A,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<T>::program_name(), "gmres_sliced_ell_prod");
 
-  unsigned int thread_num = A.rows_per_block();
+  unsigned int thread_num = static_cast<unsigned int>(A.rows_per_block());
   unsigned int group_num = 128;
 
   k.local_work_size(0, thread_num);
@@ -774,12 +848,13 @@ void pipelined_gmres_prod(hyb_matrix<T> const & A,
 
   viennacl::ocl::kernel & k = ctx.get_kernel(viennacl::linalg::opencl::kernels::iterative<T>::program_name(), "gmres_hyb_prod");
 
-  unsigned int thread_num = 128;
+  unsigned int thread_num = (ctx.current_device().vendor_id() == viennacl::ocl::nvidia_id) ? 256 : 128;
   unsigned int group_num = 128;
 
   k.local_work_size(0, thread_num);
   k.global_work_size(0, thread_num * group_num);
 
+
   viennacl::ocl::enqueue(k(A.handle2().opencl_handle(),
                            A.handle().opencl_handle(),
                            A.handle3().opencl_handle(),
