@@ -527,7 +527,7 @@ void generate_compressed_matrix_trans_lu_forward(StringT & source, std::string c
   source.append("  { \n");
   source.append("    col_index    = (i < nnz) ? column_indices[i] : 0; \n");
   source.append("    matrix_entry = (i < nnz) ? elements[i]       : 0; \n");
-  source.append("    row_index_lookahead[get_local_id(0)] = (row_at_window_start + get_local_id(0) < size) ? row_indices[row_at_window_start + get_local_id(0)] : size - 1; \n");
+  source.append("    row_index_lookahead[get_local_id(0)] = (row_at_window_start + get_local_id(0) < size) ? row_indices[row_at_window_start + get_local_id(0)] : nnz; \n");
 
   source.append("    barrier(CLK_LOCAL_MEM_FENCE); \n");
 
@@ -668,7 +668,7 @@ void generate_compressed_matrix_trans_unit_lu_forward(StringT & source, std::str
   source.append("  { \n");
   source.append("    col_index    = (i < nnz) ? column_indices[i] : 0; \n");
   source.append("    matrix_entry = (i < nnz) ? elements[i]       : 0; \n");
-  source.append("    row_index_lookahead[get_local_id(0)] = (row_at_window_start + get_local_id(0) < size) ? row_indices[row_at_window_start + get_local_id(0)] : size - 1; \n");
+  source.append("    row_index_lookahead[get_local_id(0)] = (row_at_window_start + get_local_id(0) < size) ? row_indices[row_at_window_start + get_local_id(0)] : nnz; \n");
 
   source.append("    barrier(CLK_LOCAL_MEM_FENCE); \n");
 
@@ -895,28 +895,99 @@ void generate_compressed_matrix_unit_lu_forward(StringT & source, std::string co
 template<typename StringT>
 void generate_compressed_matrix_vec_mul(StringT & source, std::string const & numeric_string)
 {
-
   source.append("__kernel void vec_mul( \n");
   source.append("  __global const unsigned int * row_indices, \n");
   source.append("  __global const unsigned int * column_indices, \n");
+  source.append("  __global const unsigned int * row_blocks, \n");
   source.append("  __global const "); source.append(numeric_string); source.append(" * elements, \n");
+  source.append("  unsigned int num_blocks, \n");
   source.append("  __global const "); source.append(numeric_string); source.append(" * x, \n");
   source.append("  uint4 layout_x, \n");
   source.append("  __global "); source.append(numeric_string); source.append(" * result, \n");
   source.append("  uint4 layout_result) \n");
   source.append("{ \n");
-  source.append("  for (unsigned int row = get_global_id(0); row < layout_result.z; row += get_global_size(0)) \n");
-  source.append("  { \n");
-  source.append("    "); source.append(numeric_string); source.append(" dot_prod = 0; \n");
-  source.append("    unsigned int row_end = row_indices[row+1]; \n");
-  source.append("    for (unsigned int i = row_indices[row]; i < row_end; ++i) \n");
-  source.append("      dot_prod += elements[i] * x[column_indices[i] * layout_x.y + layout_x.x]; \n");
-  source.append("    result[row * layout_result.y + layout_result.x] = dot_prod; \n");
+  source.append("  __local "); source.append(numeric_string); source.append(" shared_elements[1024]; \n");
+
+  source.append("  unsigned int row_start = row_blocks[get_group_id(0)]; \n");
+  source.append("  unsigned int row_stop  = row_blocks[get_group_id(0) + 1]; \n");
+  source.append("  unsigned int rows_to_process = row_stop - row_start; \n");
+  source.append("  unsigned int element_start = row_indices[row_start]; \n");
+  source.append("  unsigned int element_stop = row_indices[row_stop]; \n");
+
+  source.append("  if (rows_to_process > 4) { \n"); // CSR stream
+      // load to shared buffer:
+  source.append("    for (unsigned int i = element_start + get_local_id(0); i < element_stop; i += get_local_size(0)) \n");
+  source.append("      shared_elements[i - element_start] = elements[i] * x[column_indices[i] * layout_x.y + layout_x.x]; \n");
+
+  source.append("    barrier(CLK_LOCAL_MEM_FENCE); \n");
+
+      // use one thread per row to sum:
+  source.append("    for (unsigned int row = row_start + get_local_id(0); row < row_stop; row += get_local_size(0)) { \n");
+  source.append("      "); source.append(numeric_string); source.append(" dot_prod = 0; \n");
+  source.append("      unsigned int thread_row_start = row_indices[row]     - element_start; \n");
+  source.append("      unsigned int thread_row_stop  = row_indices[row + 1] - element_start; \n");
+  source.append("      for (unsigned int i = thread_row_start; i < thread_row_stop; ++i) \n");
+  source.append("        dot_prod += shared_elements[i]; \n");
+  source.append("      result[row * layout_result.y + layout_result.x] = dot_prod; \n");
+  source.append("    } \n");
   source.append("  } \n");
+
+      // use multiple threads for the summation
+  source.append("  else if (rows_to_process > 1) \n"); // CSR stream with local reduction
+  source.append("  {\n");
+      // load to shared buffer:
+  source.append("    for (unsigned int i = element_start + get_local_id(0); i < element_stop; i += get_local_size(0))\n");
+  source.append("      shared_elements[i - element_start] = elements[i] * x[column_indices[i] * layout_x.y + layout_x.x];\n");
+
+  source.append("    barrier(CLK_LOCAL_MEM_FENCE); \n");
+
+    // sum each row separately using a reduction:
+  source.append("    for (unsigned int row = row_start; row < row_stop; ++row)\n");
+  source.append("    {\n");
+  source.append("      unsigned int current_row_start = row_indices[row]     - element_start;\n");
+  source.append("      unsigned int current_row_stop  = row_indices[row + 1] - element_start;\n");
+  source.append("      unsigned int thread_base_id  = current_row_start + get_local_id(0);\n");
+
+      // sum whatever exceeds the current buffer:
+  source.append("      for (unsigned int j = thread_base_id + get_local_size(0); j < current_row_stop; j += get_local_size(0))\n");
+  source.append("        shared_elements[thread_base_id] += shared_elements[j];\n");
+
+      // reduction
+  source.append("      for (unsigned int stride = get_local_size(0)/2; stride > 0; stride /= 2)\n");
+  source.append("      {\n");
+  source.append("        barrier(CLK_LOCAL_MEM_FENCE);\n");
+  source.append("        if (get_local_id(0) < stride && thread_base_id < current_row_stop)\n");
+  source.append("          shared_elements[thread_base_id] += (thread_base_id + stride < current_row_stop) ? shared_elements[thread_base_id+stride] : 0;\n");
+  source.append("      }\n");
+  source.append("      if (get_local_id(0) == 0)\n");
+  source.append("        result[row * layout_result.y + layout_result.x] = shared_elements[current_row_start];\n");
+  source.append("    }\n");
+  source.append("  }\n");
+
+
+  source.append("  else  \n"); // CSR vector for a single row
+  source.append("  { \n");
+      // load and sum to shared buffer:
+  source.append("    shared_elements[get_local_id(0)] = 0; \n");
+  source.append("    for (unsigned int i = element_start + get_local_id(0); i < element_stop; i += get_local_size(0)) \n");
+  source.append("      shared_elements[get_local_id(0)] += elements[i] * x[column_indices[i] * layout_x.y + layout_x.x]; \n");
+
+      // reduction to obtain final result
+  source.append("    for (unsigned int stride = get_local_size(0)/2; stride > 0; stride /= 2) { \n");
+  source.append("      barrier(CLK_LOCAL_MEM_FENCE); \n");
+  source.append("      if (get_local_id(0) < stride) \n");
+  source.append("        shared_elements[get_local_id(0)] += shared_elements[get_local_id(0) + stride]; \n");
+  source.append("    } \n");
+
+  source.append("    if (get_local_id(0) == 0) \n");
+  source.append("      result[row_start * layout_result.y + layout_result.x] = shared_elements[0]; \n");
+  source.append("  } \n");
+
   source.append("} \n");
 
 }
 
+
 template<typename StringT>
 void generate_compressed_matrix_vec_mul4(StringT & source, std::string const & numeric_string)
 {
